/* Automatically @generated by tree-sitter v0.25.10 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 2192
#define LARGE_STATE_COUNT 451
#define SYMBOL_COUNT 279
#define ALIAS_COUNT 0
#define TOKEN_COUNT 159
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 0
#define MAX_ALIAS_SEQUENCE_LENGTH 11
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 1
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_SLASH_SLASH = 1,
  aux_sym_comment_token1 = 2,
  anon_sym_SLASH_STAR = 3,
  aux_sym_comment_token2 = 4,
  anon_sym_SLASH = 5,
  anon_sym_import = 6,
  anon_sym_from = 7,
  anon_sym_LBRACE = 8,
  anon_sym_COMMA = 9,
  anon_sym_RBRACE = 10,
  anon_sym_STAR = 11,
  anon_sym_as = 12,
  anon_sym_SEMI = 13,
  anon_sym_export = 14,
  anon_sym_default = 15,
  anon_sym_AT = 16,
  anon_sym_Entry = 17,
  anon_sym_Component = 18,
  anon_sym_State = 19,
  anon_sym_Prop = 20,
  anon_sym_Link = 21,
  anon_sym_Provide = 22,
  anon_sym_Consume = 23,
  anon_sym_Builder = 24,
  anon_sym_Styles = 25,
  anon_sym_Extend = 26,
  anon_sym_AnimatableExtend = 27,
  anon_sym_Watch = 28,
  anon_sym_StorageLink = 29,
  anon_sym_StorageProp = 30,
  anon_sym_LocalStorageLink = 31,
  anon_sym_LocalStorageProp = 32,
  anon_sym_ObjectLink = 33,
  anon_sym_Observed = 34,
  anon_sym_LPAREN = 35,
  anon_sym_RPAREN = 36,
  anon_sym_struct = 37,
  anon_sym_private = 38,
  anon_sym_public = 39,
  anon_sym_protected = 40,
  anon_sym_static = 41,
  anon_sym_readonly = 42,
  anon_sym_COLON = 43,
  anon_sym_EQ = 44,
  anon_sym_build = 45,
  anon_sym_DOT = 46,
  anon_sym_Text = 47,
  anon_sym_Button = 48,
  anon_sym_Image = 49,
  anon_sym_TextInput = 50,
  anon_sym_TextArea = 51,
  anon_sym_Column = 52,
  anon_sym_Row = 53,
  anon_sym_Stack = 54,
  anon_sym_Flex = 55,
  anon_sym_Grid = 56,
  anon_sym_GridRow = 57,
  anon_sym_GridCol = 58,
  anon_sym_List = 59,
  anon_sym_ScrollList = 60,
  anon_sym_ListItem = 61,
  anon_sym_GridItem = 62,
  anon_sym_ForEach = 63,
  sym_identifier = 64,
  anon_sym_DQUOTE = 65,
  aux_sym_string_literal_token1 = 66,
  anon_sym_SQUOTE = 67,
  aux_sym_string_literal_token2 = 68,
  anon_sym_BSLASH = 69,
  aux_sym_escape_sequence_token1 = 70,
  aux_sym_escape_sequence_token2 = 71,
  aux_sym_escape_sequence_token3 = 72,
  aux_sym_escape_sequence_token4 = 73,
  anon_sym_DOLLAR = 74,
  sym_numeric_literal = 75,
  anon_sym_true = 76,
  anon_sym_false = 77,
  anon_sym_null = 78,
  anon_sym_PIPE_PIPE = 79,
  anon_sym_AMP_AMP = 80,
  anon_sym_PIPE = 81,
  anon_sym_CARET = 82,
  anon_sym_AMP = 83,
  anon_sym_EQ_EQ = 84,
  anon_sym_BANG_EQ = 85,
  anon_sym_EQ_EQ_EQ = 86,
  anon_sym_BANG_EQ_EQ = 87,
  anon_sym_LT = 88,
  anon_sym_GT = 89,
  anon_sym_LT_EQ = 90,
  anon_sym_GT_EQ = 91,
  anon_sym_instanceof = 92,
  anon_sym_in = 93,
  anon_sym_LT_LT = 94,
  anon_sym_GT_GT = 95,
  anon_sym_GT_GT_GT = 96,
  anon_sym_PLUS = 97,
  anon_sym_DASH = 98,
  anon_sym_PERCENT = 99,
  anon_sym_STAR_STAR = 100,
  anon_sym_BANG = 101,
  anon_sym_TILDE = 102,
  anon_sym_typeof = 103,
  anon_sym_void = 104,
  anon_sym_delete = 105,
  anon_sym_PLUS_EQ = 106,
  anon_sym_DASH_EQ = 107,
  anon_sym_STAR_EQ = 108,
  anon_sym_SLASH_EQ = 109,
  anon_sym_PERCENT_EQ = 110,
  anon_sym_AMP_EQ = 111,
  anon_sym_PIPE_EQ = 112,
  anon_sym_CARET_EQ = 113,
  anon_sym_LT_LT_EQ = 114,
  anon_sym_GT_GT_EQ = 115,
  anon_sym_GT_GT_GT_EQ = 116,
  anon_sym_QMARK = 117,
  anon_sym_await = 118,
  anon_sym_number = 119,
  anon_sym_string = 120,
  anon_sym_boolean = 121,
  anon_sym_any = 122,
  anon_sym_undefined = 123,
  anon_sym_EQ_GT = 124,
  anon_sym_LBRACK = 125,
  anon_sym_RBRACK = 126,
  anon_sym_extends = 127,
  anon_sym_if = 128,
  anon_sym_else = 129,
  anon_sym_async = 130,
  anon_sym_DOT_DOT_DOT = 131,
  anon_sym_var = 132,
  anon_sym_let = 133,
  anon_sym_const = 134,
  anon_sym_return = 135,
  anon_sym_try = 136,
  anon_sym_catch = 137,
  anon_sym_finally = 138,
  anon_sym_throw = 139,
  anon_sym_for = 140,
  anon_sym_while = 141,
  anon_sym_break = 142,
  anon_sym_continue = 143,
  anon_sym_QMARK_DOT = 144,
  anon_sym_interface = 145,
  anon_sym_type = 146,
  anon_sym_enum = 147,
  anon_sym_abstract = 148,
  anon_sym_class = 149,
  anon_sym_implements = 150,
  anon_sym_constructor = 151,
  anon_sym_function = 152,
  anon_sym_BQUOTE = 153,
  sym_template_chars = 154,
  anon_sym_DOLLARr = 155,
  anon_sym_PLUS_PLUS = 156,
  anon_sym_DASH_DASH = 157,
  anon_sym_new = 158,
  sym_source_file = 159,
  sym_comment = 160,
  sym_import_declaration = 161,
  sym_export_declaration = 162,
  sym_decorator = 163,
  sym_component_declaration = 164,
  sym_component_body = 165,
  sym_property_declaration = 166,
  sym_build_method = 167,
  sym_build_body = 168,
  sym_modifier_chain_expression = 169,
  sym_ui_element_with_modifiers = 170,
  sym_ui_component = 171,
  sym_container_content_body = 172,
  sym_arkts_ui_element = 173,
  sym_ui_custom_component_statement = 174,
  sym_ui_control_flow = 175,
  sym_component_parameters = 176,
  sym_component_parameter = 177,
  sym_for_each_statement = 178,
  sym_string_literal = 179,
  sym_escape_sequence = 180,
  sym_expression = 181,
  sym_state_binding_expression = 182,
  sym_boolean_literal = 183,
  sym_null_literal = 184,
  sym_binary_expression = 185,
  sym_unary_expression = 186,
  sym_assignment_expression = 187,
  sym_conditional_expression = 188,
  sym_await_expression = 189,
  sym_as_expression = 190,
  sym_type_annotation = 191,
  sym_primary_type = 192,
  sym_generic_type = 193,
  sym_type_arguments = 194,
  sym_qualified_type = 195,
  sym_union_type = 196,
  sym_function_type = 197,
  sym_array_type = 198,
  sym_tuple_type = 199,
  sym_conditional_type = 200,
  sym_type_parameters = 201,
  sym_type_parameter = 202,
  sym_expression_statement = 203,
  sym_if_statement = 204,
  sym_ui_if_statement = 205,
  sym_method_declaration = 206,
  sym_parameter_list = 207,
  sym_parameter = 208,
  sym_block_statement = 209,
  sym_statement = 210,
  sym_variable_declaration = 211,
  sym_variable_declarator = 212,
  sym_return_statement = 213,
  sym_try_statement = 214,
  sym_catch_clause = 215,
  sym_finally_clause = 216,
  sym_throw_statement = 217,
  sym_for_statement = 218,
  sym_while_statement = 219,
  sym_break_statement = 220,
  sym_continue_statement = 221,
  sym_arrow_function = 222,
  sym_call_expression = 223,
  sym_argument_list = 224,
  sym_spread_element = 225,
  sym_member_expression = 226,
  sym_subscript_expression = 227,
  sym_parenthesized_expression = 228,
  sym_interface_declaration = 229,
  sym_type_declaration = 230,
  sym_enum_declaration = 231,
  sym_enum_body = 232,
  sym_enum_member = 233,
  sym_class_declaration = 234,
  sym_class_body = 235,
  sym_implements_clause = 236,
  sym_constructor_declaration = 237,
  sym_function_declaration = 238,
  sym_extend_function_body = 239,
  sym_object_type = 240,
  sym_type_member = 241,
  sym_array_literal = 242,
  sym_object_literal = 243,
  sym_property_assignment = 244,
  sym_property_name = 245,
  sym_template_literal = 246,
  sym_template_substitution = 247,
  sym_resource_expression = 248,
  sym_update_expression = 249,
  sym_new_expression = 250,
  aux_sym_source_file_repeat1 = 251,
  aux_sym_import_declaration_repeat1 = 252,
  aux_sym_export_declaration_repeat1 = 253,
  aux_sym_decorator_repeat1 = 254,
  aux_sym_component_declaration_repeat1 = 255,
  aux_sym_component_body_repeat1 = 256,
  aux_sym_build_body_repeat1 = 257,
  aux_sym_component_parameters_repeat1 = 258,
  aux_sym_string_literal_repeat1 = 259,
  aux_sym_string_literal_repeat2 = 260,
  aux_sym_type_arguments_repeat1 = 261,
  aux_sym_qualified_type_repeat1 = 262,
  aux_sym_union_type_repeat1 = 263,
  aux_sym_array_type_repeat1 = 264,
  aux_sym_type_parameters_repeat1 = 265,
  aux_sym_ui_if_statement_repeat1 = 266,
  aux_sym_parameter_list_repeat1 = 267,
  aux_sym_block_statement_repeat1 = 268,
  aux_sym_variable_declaration_repeat1 = 269,
  aux_sym_argument_list_repeat1 = 270,
  aux_sym_enum_body_repeat1 = 271,
  aux_sym_class_body_repeat1 = 272,
  aux_sym_implements_clause_repeat1 = 273,
  aux_sym_extend_function_body_repeat1 = 274,
  aux_sym_object_type_repeat1 = 275,
  aux_sym_array_literal_repeat1 = 276,
  aux_sym_object_literal_repeat1 = 277,
  aux_sym_template_literal_repeat1 = 278,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_SLASH_SLASH] = "//",
  [aux_sym_comment_token1] = "comment_token1",
  [anon_sym_SLASH_STAR] = "/*",
  [aux_sym_comment_token2] = "comment_token2",
  [anon_sym_SLASH] = "/",
  [anon_sym_import] = "import",
  [anon_sym_from] = "from",
  [anon_sym_LBRACE] = "{",
  [anon_sym_COMMA] = ",",
  [anon_sym_RBRACE] = "}",
  [anon_sym_STAR] = "*",
  [anon_sym_as] = "as",
  [anon_sym_SEMI] = ";",
  [anon_sym_export] = "export",
  [anon_sym_default] = "default",
  [anon_sym_AT] = "@",
  [anon_sym_Entry] = "Entry",
  [anon_sym_Component] = "Component",
  [anon_sym_State] = "State",
  [anon_sym_Prop] = "Prop",
  [anon_sym_Link] = "Link",
  [anon_sym_Provide] = "Provide",
  [anon_sym_Consume] = "Consume",
  [anon_sym_Builder] = "Builder",
  [anon_sym_Styles] = "Styles",
  [anon_sym_Extend] = "Extend",
  [anon_sym_AnimatableExtend] = "AnimatableExtend",
  [anon_sym_Watch] = "Watch",
  [anon_sym_StorageLink] = "StorageLink",
  [anon_sym_StorageProp] = "StorageProp",
  [anon_sym_LocalStorageLink] = "LocalStorageLink",
  [anon_sym_LocalStorageProp] = "LocalStorageProp",
  [anon_sym_ObjectLink] = "ObjectLink",
  [anon_sym_Observed] = "Observed",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_struct] = "struct",
  [anon_sym_private] = "private",
  [anon_sym_public] = "public",
  [anon_sym_protected] = "protected",
  [anon_sym_static] = "static",
  [anon_sym_readonly] = "readonly",
  [anon_sym_COLON] = ":",
  [anon_sym_EQ] = "=",
  [anon_sym_build] = "build",
  [anon_sym_DOT] = ".",
  [anon_sym_Text] = "Text",
  [anon_sym_Button] = "Button",
  [anon_sym_Image] = "Image",
  [anon_sym_TextInput] = "TextInput",
  [anon_sym_TextArea] = "TextArea",
  [anon_sym_Column] = "Column",
  [anon_sym_Row] = "Row",
  [anon_sym_Stack] = "Stack",
  [anon_sym_Flex] = "Flex",
  [anon_sym_Grid] = "Grid",
  [anon_sym_GridRow] = "GridRow",
  [anon_sym_GridCol] = "GridCol",
  [anon_sym_List] = "List",
  [anon_sym_ScrollList] = "ScrollList",
  [anon_sym_ListItem] = "ListItem",
  [anon_sym_GridItem] = "GridItem",
  [anon_sym_ForEach] = "ForEach",
  [sym_identifier] = "identifier",
  [anon_sym_DQUOTE] = "\"",
  [aux_sym_string_literal_token1] = "string_literal_token1",
  [anon_sym_SQUOTE] = "'",
  [aux_sym_string_literal_token2] = "string_literal_token2",
  [anon_sym_BSLASH] = "\\",
  [aux_sym_escape_sequence_token1] = "escape_sequence_token1",
  [aux_sym_escape_sequence_token2] = "escape_sequence_token2",
  [aux_sym_escape_sequence_token3] = "escape_sequence_token3",
  [aux_sym_escape_sequence_token4] = "escape_sequence_token4",
  [anon_sym_DOLLAR] = "$",
  [sym_numeric_literal] = "numeric_literal",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_null] = "null",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE] = "|",
  [anon_sym_CARET] = "^",
  [anon_sym_AMP] = "&",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_EQ_EQ_EQ] = "===",
  [anon_sym_BANG_EQ_EQ] = "!==",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_instanceof] = "instanceof",
  [anon_sym_in] = "in",
  [anon_sym_LT_LT] = "<<",
  [anon_sym_GT_GT] = ">>",
  [anon_sym_GT_GT_GT] = ">>>",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_PERCENT] = "%",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_typeof] = "typeof",
  [anon_sym_void] = "void",
  [anon_sym_delete] = "delete",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_STAR_EQ] = "*=",
  [anon_sym_SLASH_EQ] = "/=",
  [anon_sym_PERCENT_EQ] = "%=",
  [anon_sym_AMP_EQ] = "&=",
  [anon_sym_PIPE_EQ] = "|=",
  [anon_sym_CARET_EQ] = "^=",
  [anon_sym_LT_LT_EQ] = "<<=",
  [anon_sym_GT_GT_EQ] = ">>=",
  [anon_sym_GT_GT_GT_EQ] = ">>>=",
  [anon_sym_QMARK] = "\?",
  [anon_sym_await] = "await",
  [anon_sym_number] = "number",
  [anon_sym_string] = "string",
  [anon_sym_boolean] = "boolean",
  [anon_sym_any] = "any",
  [anon_sym_undefined] = "undefined",
  [anon_sym_EQ_GT] = "=>",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_extends] = "extends",
  [anon_sym_if] = "if",
  [anon_sym_else] = "else",
  [anon_sym_async] = "async",
  [anon_sym_DOT_DOT_DOT] = "...",
  [anon_sym_var] = "var",
  [anon_sym_let] = "let",
  [anon_sym_const] = "const",
  [anon_sym_return] = "return",
  [anon_sym_try] = "try",
  [anon_sym_catch] = "catch",
  [anon_sym_finally] = "finally",
  [anon_sym_throw] = "throw",
  [anon_sym_for] = "for",
  [anon_sym_while] = "while",
  [anon_sym_break] = "break",
  [anon_sym_continue] = "continue",
  [anon_sym_QMARK_DOT] = "\?.",
  [anon_sym_interface] = "interface",
  [anon_sym_type] = "type",
  [anon_sym_enum] = "enum",
  [anon_sym_abstract] = "abstract",
  [anon_sym_class] = "class",
  [anon_sym_implements] = "implements",
  [anon_sym_constructor] = "constructor",
  [anon_sym_function] = "function",
  [anon_sym_BQUOTE] = "`",
  [sym_template_chars] = "template_chars",
  [anon_sym_DOLLARr] = "$r",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_new] = "new",
  [sym_source_file] = "source_file",
  [sym_comment] = "comment",
  [sym_import_declaration] = "import_declaration",
  [sym_export_declaration] = "export_declaration",
  [sym_decorator] = "decorator",
  [sym_component_declaration] = "component_declaration",
  [sym_component_body] = "component_body",
  [sym_property_declaration] = "property_declaration",
  [sym_build_method] = "build_method",
  [sym_build_body] = "build_body",
  [sym_modifier_chain_expression] = "modifier_chain_expression",
  [sym_ui_element_with_modifiers] = "ui_element_with_modifiers",
  [sym_ui_component] = "ui_component",
  [sym_container_content_body] = "container_content_body",
  [sym_arkts_ui_element] = "arkts_ui_element",
  [sym_ui_custom_component_statement] = "ui_custom_component_statement",
  [sym_ui_control_flow] = "ui_control_flow",
  [sym_component_parameters] = "component_parameters",
  [sym_component_parameter] = "component_parameter",
  [sym_for_each_statement] = "for_each_statement",
  [sym_string_literal] = "string_literal",
  [sym_escape_sequence] = "escape_sequence",
  [sym_expression] = "expression",
  [sym_state_binding_expression] = "state_binding_expression",
  [sym_boolean_literal] = "boolean_literal",
  [sym_null_literal] = "null_literal",
  [sym_binary_expression] = "binary_expression",
  [sym_unary_expression] = "unary_expression",
  [sym_assignment_expression] = "assignment_expression",
  [sym_conditional_expression] = "conditional_expression",
  [sym_await_expression] = "await_expression",
  [sym_as_expression] = "as_expression",
  [sym_type_annotation] = "type_annotation",
  [sym_primary_type] = "primary_type",
  [sym_generic_type] = "generic_type",
  [sym_type_arguments] = "type_arguments",
  [sym_qualified_type] = "qualified_type",
  [sym_union_type] = "union_type",
  [sym_function_type] = "function_type",
  [sym_array_type] = "array_type",
  [sym_tuple_type] = "tuple_type",
  [sym_conditional_type] = "conditional_type",
  [sym_type_parameters] = "type_parameters",
  [sym_type_parameter] = "type_parameter",
  [sym_expression_statement] = "expression_statement",
  [sym_if_statement] = "if_statement",
  [sym_ui_if_statement] = "ui_if_statement",
  [sym_method_declaration] = "method_declaration",
  [sym_parameter_list] = "parameter_list",
  [sym_parameter] = "parameter",
  [sym_block_statement] = "block_statement",
  [sym_statement] = "statement",
  [sym_variable_declaration] = "variable_declaration",
  [sym_variable_declarator] = "variable_declarator",
  [sym_return_statement] = "return_statement",
  [sym_try_statement] = "try_statement",
  [sym_catch_clause] = "catch_clause",
  [sym_finally_clause] = "finally_clause",
  [sym_throw_statement] = "throw_statement",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_break_statement] = "break_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_arrow_function] = "arrow_function",
  [sym_call_expression] = "call_expression",
  [sym_argument_list] = "argument_list",
  [sym_spread_element] = "spread_element",
  [sym_member_expression] = "member_expression",
  [sym_subscript_expression] = "subscript_expression",
  [sym_parenthesized_expression] = "parenthesized_expression",
  [sym_interface_declaration] = "interface_declaration",
  [sym_type_declaration] = "type_declaration",
  [sym_enum_declaration] = "enum_declaration",
  [sym_enum_body] = "enum_body",
  [sym_enum_member] = "enum_member",
  [sym_class_declaration] = "class_declaration",
  [sym_class_body] = "class_body",
  [sym_implements_clause] = "implements_clause",
  [sym_constructor_declaration] = "constructor_declaration",
  [sym_function_declaration] = "function_declaration",
  [sym_extend_function_body] = "extend_function_body",
  [sym_object_type] = "object_type",
  [sym_type_member] = "type_member",
  [sym_array_literal] = "array_literal",
  [sym_object_literal] = "object_literal",
  [sym_property_assignment] = "property_assignment",
  [sym_property_name] = "property_name",
  [sym_template_literal] = "template_literal",
  [sym_template_substitution] = "template_substitution",
  [sym_resource_expression] = "resource_expression",
  [sym_update_expression] = "update_expression",
  [sym_new_expression] = "new_expression",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_import_declaration_repeat1] = "import_declaration_repeat1",
  [aux_sym_export_declaration_repeat1] = "export_declaration_repeat1",
  [aux_sym_decorator_repeat1] = "decorator_repeat1",
  [aux_sym_component_declaration_repeat1] = "component_declaration_repeat1",
  [aux_sym_component_body_repeat1] = "component_body_repeat1",
  [aux_sym_build_body_repeat1] = "build_body_repeat1",
  [aux_sym_component_parameters_repeat1] = "component_parameters_repeat1",
  [aux_sym_string_literal_repeat1] = "string_literal_repeat1",
  [aux_sym_string_literal_repeat2] = "string_literal_repeat2",
  [aux_sym_type_arguments_repeat1] = "type_arguments_repeat1",
  [aux_sym_qualified_type_repeat1] = "qualified_type_repeat1",
  [aux_sym_union_type_repeat1] = "union_type_repeat1",
  [aux_sym_array_type_repeat1] = "array_type_repeat1",
  [aux_sym_type_parameters_repeat1] = "type_parameters_repeat1",
  [aux_sym_ui_if_statement_repeat1] = "ui_if_statement_repeat1",
  [aux_sym_parameter_list_repeat1] = "parameter_list_repeat1",
  [aux_sym_block_statement_repeat1] = "block_statement_repeat1",
  [aux_sym_variable_declaration_repeat1] = "variable_declaration_repeat1",
  [aux_sym_argument_list_repeat1] = "argument_list_repeat1",
  [aux_sym_enum_body_repeat1] = "enum_body_repeat1",
  [aux_sym_class_body_repeat1] = "class_body_repeat1",
  [aux_sym_implements_clause_repeat1] = "implements_clause_repeat1",
  [aux_sym_extend_function_body_repeat1] = "extend_function_body_repeat1",
  [aux_sym_object_type_repeat1] = "object_type_repeat1",
  [aux_sym_array_literal_repeat1] = "array_literal_repeat1",
  [aux_sym_object_literal_repeat1] = "object_literal_repeat1",
  [aux_sym_template_literal_repeat1] = "template_literal_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_SLASH_SLASH] = anon_sym_SLASH_SLASH,
  [aux_sym_comment_token1] = aux_sym_comment_token1,
  [anon_sym_SLASH_STAR] = anon_sym_SLASH_STAR,
  [aux_sym_comment_token2] = aux_sym_comment_token2,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_import] = anon_sym_import,
  [anon_sym_from] = anon_sym_from,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_export] = anon_sym_export,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_Entry] = anon_sym_Entry,
  [anon_sym_Component] = anon_sym_Component,
  [anon_sym_State] = anon_sym_State,
  [anon_sym_Prop] = anon_sym_Prop,
  [anon_sym_Link] = anon_sym_Link,
  [anon_sym_Provide] = anon_sym_Provide,
  [anon_sym_Consume] = anon_sym_Consume,
  [anon_sym_Builder] = anon_sym_Builder,
  [anon_sym_Styles] = anon_sym_Styles,
  [anon_sym_Extend] = anon_sym_Extend,
  [anon_sym_AnimatableExtend] = anon_sym_AnimatableExtend,
  [anon_sym_Watch] = anon_sym_Watch,
  [anon_sym_StorageLink] = anon_sym_StorageLink,
  [anon_sym_StorageProp] = anon_sym_StorageProp,
  [anon_sym_LocalStorageLink] = anon_sym_LocalStorageLink,
  [anon_sym_LocalStorageProp] = anon_sym_LocalStorageProp,
  [anon_sym_ObjectLink] = anon_sym_ObjectLink,
  [anon_sym_Observed] = anon_sym_Observed,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_private] = anon_sym_private,
  [anon_sym_public] = anon_sym_public,
  [anon_sym_protected] = anon_sym_protected,
  [anon_sym_static] = anon_sym_static,
  [anon_sym_readonly] = anon_sym_readonly,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_build] = anon_sym_build,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_Text] = anon_sym_Text,
  [anon_sym_Button] = anon_sym_Button,
  [anon_sym_Image] = anon_sym_Image,
  [anon_sym_TextInput] = anon_sym_TextInput,
  [anon_sym_TextArea] = anon_sym_TextArea,
  [anon_sym_Column] = anon_sym_Column,
  [anon_sym_Row] = anon_sym_Row,
  [anon_sym_Stack] = anon_sym_Stack,
  [anon_sym_Flex] = anon_sym_Flex,
  [anon_sym_Grid] = anon_sym_Grid,
  [anon_sym_GridRow] = anon_sym_GridRow,
  [anon_sym_GridCol] = anon_sym_GridCol,
  [anon_sym_List] = anon_sym_List,
  [anon_sym_ScrollList] = anon_sym_ScrollList,
  [anon_sym_ListItem] = anon_sym_ListItem,
  [anon_sym_GridItem] = anon_sym_GridItem,
  [anon_sym_ForEach] = anon_sym_ForEach,
  [sym_identifier] = sym_identifier,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [aux_sym_string_literal_token1] = aux_sym_string_literal_token1,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [aux_sym_string_literal_token2] = aux_sym_string_literal_token2,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [aux_sym_escape_sequence_token1] = aux_sym_escape_sequence_token1,
  [aux_sym_escape_sequence_token2] = aux_sym_escape_sequence_token2,
  [aux_sym_escape_sequence_token3] = aux_sym_escape_sequence_token3,
  [aux_sym_escape_sequence_token4] = aux_sym_escape_sequence_token4,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [sym_numeric_literal] = sym_numeric_literal,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_null] = anon_sym_null,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_EQ_EQ_EQ] = anon_sym_EQ_EQ_EQ,
  [anon_sym_BANG_EQ_EQ] = anon_sym_BANG_EQ_EQ,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_instanceof] = anon_sym_instanceof,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_LT_LT] = anon_sym_LT_LT,
  [anon_sym_GT_GT] = anon_sym_GT_GT,
  [anon_sym_GT_GT_GT] = anon_sym_GT_GT_GT,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_typeof] = anon_sym_typeof,
  [anon_sym_void] = anon_sym_void,
  [anon_sym_delete] = anon_sym_delete,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_STAR_EQ] = anon_sym_STAR_EQ,
  [anon_sym_SLASH_EQ] = anon_sym_SLASH_EQ,
  [anon_sym_PERCENT_EQ] = anon_sym_PERCENT_EQ,
  [anon_sym_AMP_EQ] = anon_sym_AMP_EQ,
  [anon_sym_PIPE_EQ] = anon_sym_PIPE_EQ,
  [anon_sym_CARET_EQ] = anon_sym_CARET_EQ,
  [anon_sym_LT_LT_EQ] = anon_sym_LT_LT_EQ,
  [anon_sym_GT_GT_EQ] = anon_sym_GT_GT_EQ,
  [anon_sym_GT_GT_GT_EQ] = anon_sym_GT_GT_GT_EQ,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_await] = anon_sym_await,
  [anon_sym_number] = anon_sym_number,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_boolean] = anon_sym_boolean,
  [anon_sym_any] = anon_sym_any,
  [anon_sym_undefined] = anon_sym_undefined,
  [anon_sym_EQ_GT] = anon_sym_EQ_GT,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_extends] = anon_sym_extends,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_async] = anon_sym_async,
  [anon_sym_DOT_DOT_DOT] = anon_sym_DOT_DOT_DOT,
  [anon_sym_var] = anon_sym_var,
  [anon_sym_let] = anon_sym_let,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_try] = anon_sym_try,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_finally] = anon_sym_finally,
  [anon_sym_throw] = anon_sym_throw,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_continue] = anon_sym_continue,
  [anon_sym_QMARK_DOT] = anon_sym_QMARK_DOT,
  [anon_sym_interface] = anon_sym_interface,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_abstract] = anon_sym_abstract,
  [anon_sym_class] = anon_sym_class,
  [anon_sym_implements] = anon_sym_implements,
  [anon_sym_constructor] = anon_sym_constructor,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_BQUOTE] = anon_sym_BQUOTE,
  [sym_template_chars] = sym_template_chars,
  [anon_sym_DOLLARr] = anon_sym_DOLLARr,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_new] = anon_sym_new,
  [sym_source_file] = sym_source_file,
  [sym_comment] = sym_comment,
  [sym_import_declaration] = sym_import_declaration,
  [sym_export_declaration] = sym_export_declaration,
  [sym_decorator] = sym_decorator,
  [sym_component_declaration] = sym_component_declaration,
  [sym_component_body] = sym_component_body,
  [sym_property_declaration] = sym_property_declaration,
  [sym_build_method] = sym_build_method,
  [sym_build_body] = sym_build_body,
  [sym_modifier_chain_expression] = sym_modifier_chain_expression,
  [sym_ui_element_with_modifiers] = sym_ui_element_with_modifiers,
  [sym_ui_component] = sym_ui_component,
  [sym_container_content_body] = sym_container_content_body,
  [sym_arkts_ui_element] = sym_arkts_ui_element,
  [sym_ui_custom_component_statement] = sym_ui_custom_component_statement,
  [sym_ui_control_flow] = sym_ui_control_flow,
  [sym_component_parameters] = sym_component_parameters,
  [sym_component_parameter] = sym_component_parameter,
  [sym_for_each_statement] = sym_for_each_statement,
  [sym_string_literal] = sym_string_literal,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_expression] = sym_expression,
  [sym_state_binding_expression] = sym_state_binding_expression,
  [sym_boolean_literal] = sym_boolean_literal,
  [sym_null_literal] = sym_null_literal,
  [sym_binary_expression] = sym_binary_expression,
  [sym_unary_expression] = sym_unary_expression,
  [sym_assignment_expression] = sym_assignment_expression,
  [sym_conditional_expression] = sym_conditional_expression,
  [sym_await_expression] = sym_await_expression,
  [sym_as_expression] = sym_as_expression,
  [sym_type_annotation] = sym_type_annotation,
  [sym_primary_type] = sym_primary_type,
  [sym_generic_type] = sym_generic_type,
  [sym_type_arguments] = sym_type_arguments,
  [sym_qualified_type] = sym_qualified_type,
  [sym_union_type] = sym_union_type,
  [sym_function_type] = sym_function_type,
  [sym_array_type] = sym_array_type,
  [sym_tuple_type] = sym_tuple_type,
  [sym_conditional_type] = sym_conditional_type,
  [sym_type_parameters] = sym_type_parameters,
  [sym_type_parameter] = sym_type_parameter,
  [sym_expression_statement] = sym_expression_statement,
  [sym_if_statement] = sym_if_statement,
  [sym_ui_if_statement] = sym_ui_if_statement,
  [sym_method_declaration] = sym_method_declaration,
  [sym_parameter_list] = sym_parameter_list,
  [sym_parameter] = sym_parameter,
  [sym_block_statement] = sym_block_statement,
  [sym_statement] = sym_statement,
  [sym_variable_declaration] = sym_variable_declaration,
  [sym_variable_declarator] = sym_variable_declarator,
  [sym_return_statement] = sym_return_statement,
  [sym_try_statement] = sym_try_statement,
  [sym_catch_clause] = sym_catch_clause,
  [sym_finally_clause] = sym_finally_clause,
  [sym_throw_statement] = sym_throw_statement,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_break_statement] = sym_break_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_arrow_function] = sym_arrow_function,
  [sym_call_expression] = sym_call_expression,
  [sym_argument_list] = sym_argument_list,
  [sym_spread_element] = sym_spread_element,
  [sym_member_expression] = sym_member_expression,
  [sym_subscript_expression] = sym_subscript_expression,
  [sym_parenthesized_expression] = sym_parenthesized_expression,
  [sym_interface_declaration] = sym_interface_declaration,
  [sym_type_declaration] = sym_type_declaration,
  [sym_enum_declaration] = sym_enum_declaration,
  [sym_enum_body] = sym_enum_body,
  [sym_enum_member] = sym_enum_member,
  [sym_class_declaration] = sym_class_declaration,
  [sym_class_body] = sym_class_body,
  [sym_implements_clause] = sym_implements_clause,
  [sym_constructor_declaration] = sym_constructor_declaration,
  [sym_function_declaration] = sym_function_declaration,
  [sym_extend_function_body] = sym_extend_function_body,
  [sym_object_type] = sym_object_type,
  [sym_type_member] = sym_type_member,
  [sym_array_literal] = sym_array_literal,
  [sym_object_literal] = sym_object_literal,
  [sym_property_assignment] = sym_property_assignment,
  [sym_property_name] = sym_property_name,
  [sym_template_literal] = sym_template_literal,
  [sym_template_substitution] = sym_template_substitution,
  [sym_resource_expression] = sym_resource_expression,
  [sym_update_expression] = sym_update_expression,
  [sym_new_expression] = sym_new_expression,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_import_declaration_repeat1] = aux_sym_import_declaration_repeat1,
  [aux_sym_export_declaration_repeat1] = aux_sym_export_declaration_repeat1,
  [aux_sym_decorator_repeat1] = aux_sym_decorator_repeat1,
  [aux_sym_component_declaration_repeat1] = aux_sym_component_declaration_repeat1,
  [aux_sym_component_body_repeat1] = aux_sym_component_body_repeat1,
  [aux_sym_build_body_repeat1] = aux_sym_build_body_repeat1,
  [aux_sym_component_parameters_repeat1] = aux_sym_component_parameters_repeat1,
  [aux_sym_string_literal_repeat1] = aux_sym_string_literal_repeat1,
  [aux_sym_string_literal_repeat2] = aux_sym_string_literal_repeat2,
  [aux_sym_type_arguments_repeat1] = aux_sym_type_arguments_repeat1,
  [aux_sym_qualified_type_repeat1] = aux_sym_qualified_type_repeat1,
  [aux_sym_union_type_repeat1] = aux_sym_union_type_repeat1,
  [aux_sym_array_type_repeat1] = aux_sym_array_type_repeat1,
  [aux_sym_type_parameters_repeat1] = aux_sym_type_parameters_repeat1,
  [aux_sym_ui_if_statement_repeat1] = aux_sym_ui_if_statement_repeat1,
  [aux_sym_parameter_list_repeat1] = aux_sym_parameter_list_repeat1,
  [aux_sym_block_statement_repeat1] = aux_sym_block_statement_repeat1,
  [aux_sym_variable_declaration_repeat1] = aux_sym_variable_declaration_repeat1,
  [aux_sym_argument_list_repeat1] = aux_sym_argument_list_repeat1,
  [aux_sym_enum_body_repeat1] = aux_sym_enum_body_repeat1,
  [aux_sym_class_body_repeat1] = aux_sym_class_body_repeat1,
  [aux_sym_implements_clause_repeat1] = aux_sym_implements_clause_repeat1,
  [aux_sym_extend_function_body_repeat1] = aux_sym_extend_function_body_repeat1,
  [aux_sym_object_type_repeat1] = aux_sym_object_type_repeat1,
  [aux_sym_array_literal_repeat1] = aux_sym_array_literal_repeat1,
  [aux_sym_object_literal_repeat1] = aux_sym_object_literal_repeat1,
  [aux_sym_template_literal_repeat1] = aux_sym_template_literal_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_SLASH_SLASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_comment_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SLASH_STAR] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_comment_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_import] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_from] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_export] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Entry] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Component] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_State] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Prop] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Link] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Provide] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Consume] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Builder] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Styles] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Extend] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AnimatableExtend] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Watch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_StorageLink] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_StorageProp] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LocalStorageLink] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LocalStorageProp] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ObjectLink] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Observed] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_private] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_public] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_protected] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_static] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_readonly] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_build] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Text] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Button] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Image] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TextInput] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TextArea] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Column] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Row] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Stack] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Flex] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_Grid] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GridRow] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GridCol] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_List] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ScrollList] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ListItem] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GridItem] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ForEach] = {
    .visible = true,
    .named = false,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_literal_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_string_literal_token2] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_escape_sequence_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_escape_sequence_token4] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [sym_numeric_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_null] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_instanceof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typeof] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_void] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delete] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_GT_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_await] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_number] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_boolean] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_any] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_undefined] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extends] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_async] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_var] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_let] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_finally] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throw] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_continue] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interface] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_abstract] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_class] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_implements] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_constructor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym_template_chars] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOLLARr] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_new] = {
    .visible = true,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_import_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_export_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_decorator] = {
    .visible = true,
    .named = true,
  },
  [sym_component_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_component_body] = {
    .visible = true,
    .named = true,
  },
  [sym_property_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_build_method] = {
    .visible = true,
    .named = true,
  },
  [sym_build_body] = {
    .visible = true,
    .named = true,
  },
  [sym_modifier_chain_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_ui_element_with_modifiers] = {
    .visible = true,
    .named = true,
  },
  [sym_ui_component] = {
    .visible = true,
    .named = true,
  },
  [sym_container_content_body] = {
    .visible = true,
    .named = true,
  },
  [sym_arkts_ui_element] = {
    .visible = true,
    .named = true,
  },
  [sym_ui_custom_component_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_ui_control_flow] = {
    .visible = true,
    .named = true,
  },
  [sym_component_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_component_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_for_each_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_string_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_state_binding_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_null_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_await_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_as_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_type_annotation] = {
    .visible = true,
    .named = true,
  },
  [sym_primary_type] = {
    .visible = true,
    .named = true,
  },
  [sym_generic_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_qualified_type] = {
    .visible = true,
    .named = true,
  },
  [sym_union_type] = {
    .visible = true,
    .named = true,
  },
  [sym_function_type] = {
    .visible = true,
    .named = true,
  },
  [sym_array_type] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_type] = {
    .visible = true,
    .named = true,
  },
  [sym_conditional_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_type_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_expression_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_ui_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_method_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter_list] = {
    .visible = true,
    .named = true,
  },
  [sym_parameter] = {
    .visible = true,
    .named = true,
  },
  [sym_block_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_variable_declarator] = {
    .visible = true,
    .named = true,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_finally_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_throw_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_arrow_function] = {
    .visible = true,
    .named = true,
  },
  [sym_call_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_argument_list] = {
    .visible = true,
    .named = true,
  },
  [sym_spread_element] = {
    .visible = true,
    .named = true,
  },
  [sym_member_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_subscript_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_parenthesized_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_interface_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_type_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_body] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_member] = {
    .visible = true,
    .named = true,
  },
  [sym_class_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_class_body] = {
    .visible = true,
    .named = true,
  },
  [sym_implements_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_constructor_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_function_declaration] = {
    .visible = true,
    .named = true,
  },
  [sym_extend_function_body] = {
    .visible = true,
    .named = true,
  },
  [sym_object_type] = {
    .visible = true,
    .named = true,
  },
  [sym_type_member] = {
    .visible = true,
    .named = true,
  },
  [sym_array_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_object_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_property_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_property_name] = {
    .visible = true,
    .named = true,
  },
  [sym_template_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_template_substitution] = {
    .visible = true,
    .named = true,
  },
  [sym_resource_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_update_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_new_expression] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_import_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_export_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_decorator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_component_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_component_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_build_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_component_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_literal_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_qualified_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_union_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_type_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_ui_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameter_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_block_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variable_declaration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_argument_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_implements_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_extend_function_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_array_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_object_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_template_literal_repeat1] = {
    .visible = false,
    .named = false,
  },
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 2,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 2,
  [12] = 12,
  [13] = 13,
  [14] = 13,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 13,
  [19] = 13,
  [20] = 13,
  [21] = 13,
  [22] = 13,
  [23] = 13,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 6,
  [29] = 29,
  [30] = 5,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 6,
  [36] = 5,
  [37] = 10,
  [38] = 9,
  [39] = 8,
  [40] = 40,
  [41] = 40,
  [42] = 40,
  [43] = 43,
  [44] = 43,
  [45] = 40,
  [46] = 46,
  [47] = 43,
  [48] = 40,
  [49] = 8,
  [50] = 43,
  [51] = 40,
  [52] = 52,
  [53] = 43,
  [54] = 40,
  [55] = 9,
  [56] = 43,
  [57] = 40,
  [58] = 10,
  [59] = 43,
  [60] = 43,
  [61] = 43,
  [62] = 43,
  [63] = 43,
  [64] = 43,
  [65] = 43,
  [66] = 66,
  [67] = 67,
  [68] = 66,
  [69] = 69,
  [70] = 70,
  [71] = 67,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 69,
  [77] = 72,
  [78] = 70,
  [79] = 73,
  [80] = 74,
  [81] = 75,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 104,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 130,
  [131] = 106,
  [132] = 107,
  [133] = 108,
  [134] = 109,
  [135] = 110,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 156,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 120,
  [161] = 161,
  [162] = 162,
  [163] = 127,
  [164] = 123,
  [165] = 165,
  [166] = 166,
  [167] = 125,
  [168] = 128,
  [169] = 169,
  [170] = 136,
  [171] = 171,
  [172] = 172,
  [173] = 115,
  [174] = 129,
  [175] = 116,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 124,
  [185] = 185,
  [186] = 186,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 191,
  [192] = 192,
  [193] = 193,
  [194] = 194,
  [195] = 194,
  [196] = 194,
  [197] = 194,
  [198] = 194,
  [199] = 194,
  [200] = 194,
  [201] = 75,
  [202] = 75,
  [203] = 75,
  [204] = 97,
  [205] = 205,
  [206] = 101,
  [207] = 102,
  [208] = 83,
  [209] = 103,
  [210] = 205,
  [211] = 104,
  [212] = 84,
  [213] = 85,
  [214] = 205,
  [215] = 86,
  [216] = 87,
  [217] = 88,
  [218] = 89,
  [219] = 90,
  [220] = 91,
  [221] = 92,
  [222] = 93,
  [223] = 94,
  [224] = 75,
  [225] = 225,
  [226] = 225,
  [227] = 106,
  [228] = 107,
  [229] = 108,
  [230] = 109,
  [231] = 205,
  [232] = 110,
  [233] = 96,
  [234] = 205,
  [235] = 205,
  [236] = 82,
  [237] = 98,
  [238] = 99,
  [239] = 114,
  [240] = 225,
  [241] = 2,
  [242] = 105,
  [243] = 111,
  [244] = 112,
  [245] = 225,
  [246] = 225,
  [247] = 225,
  [248] = 113,
  [249] = 100,
  [250] = 205,
  [251] = 95,
  [252] = 95,
  [253] = 110,
  [254] = 118,
  [255] = 123,
  [256] = 108,
  [257] = 116,
  [258] = 137,
  [259] = 106,
  [260] = 106,
  [261] = 107,
  [262] = 127,
  [263] = 108,
  [264] = 109,
  [265] = 128,
  [266] = 110,
  [267] = 129,
  [268] = 105,
  [269] = 122,
  [270] = 111,
  [271] = 112,
  [272] = 125,
  [273] = 117,
  [274] = 274,
  [275] = 109,
  [276] = 100,
  [277] = 101,
  [278] = 102,
  [279] = 113,
  [280] = 115,
  [281] = 114,
  [282] = 83,
  [283] = 84,
  [284] = 107,
  [285] = 85,
  [286] = 119,
  [287] = 86,
  [288] = 124,
  [289] = 87,
  [290] = 88,
  [291] = 89,
  [292] = 121,
  [293] = 90,
  [294] = 91,
  [295] = 92,
  [296] = 136,
  [297] = 93,
  [298] = 94,
  [299] = 104,
  [300] = 120,
  [301] = 96,
  [302] = 103,
  [303] = 104,
  [304] = 97,
  [305] = 82,
  [306] = 98,
  [307] = 99,
  [308] = 130,
  [309] = 152,
  [310] = 116,
  [311] = 121,
  [312] = 148,
  [313] = 149,
  [314] = 154,
  [315] = 155,
  [316] = 156,
  [317] = 157,
  [318] = 158,
  [319] = 124,
  [320] = 104,
  [321] = 159,
  [322] = 161,
  [323] = 193,
  [324] = 171,
  [325] = 172,
  [326] = 176,
  [327] = 177,
  [328] = 178,
  [329] = 183,
  [330] = 185,
  [331] = 189,
  [332] = 139,
  [333] = 140,
  [334] = 138,
  [335] = 144,
  [336] = 127,
  [337] = 337,
  [338] = 117,
  [339] = 128,
  [340] = 118,
  [341] = 165,
  [342] = 129,
  [343] = 180,
  [344] = 190,
  [345] = 106,
  [346] = 107,
  [347] = 108,
  [348] = 109,
  [349] = 151,
  [350] = 137,
  [351] = 143,
  [352] = 110,
  [353] = 147,
  [354] = 151,
  [355] = 181,
  [356] = 120,
  [357] = 122,
  [358] = 123,
  [359] = 125,
  [360] = 360,
  [361] = 136,
  [362] = 115,
  [363] = 116,
  [364] = 127,
  [365] = 128,
  [366] = 129,
  [367] = 123,
  [368] = 125,
  [369] = 124,
  [370] = 119,
  [371] = 186,
  [372] = 141,
  [373] = 150,
  [374] = 145,
  [375] = 179,
  [376] = 143,
  [377] = 187,
  [378] = 188,
  [379] = 191,
  [380] = 192,
  [381] = 136,
  [382] = 115,
  [383] = 153,
  [384] = 166,
  [385] = 142,
  [386] = 169,
  [387] = 181,
  [388] = 182,
  [389] = 162,
  [390] = 130,
  [391] = 146,
  [392] = 120,
  [393] = 183,
  [394] = 172,
  [395] = 178,
  [396] = 141,
  [397] = 150,
  [398] = 145,
  [399] = 123,
  [400] = 179,
  [401] = 185,
  [402] = 189,
  [403] = 124,
  [404] = 125,
  [405] = 187,
  [406] = 188,
  [407] = 191,
  [408] = 192,
  [409] = 153,
  [410] = 166,
  [411] = 142,
  [412] = 144,
  [413] = 169,
  [414] = 129,
  [415] = 182,
  [416] = 162,
  [417] = 116,
  [418] = 146,
  [419] = 147,
  [420] = 151,
  [421] = 190,
  [422] = 115,
  [423] = 180,
  [424] = 127,
  [425] = 148,
  [426] = 149,
  [427] = 151,
  [428] = 139,
  [429] = 152,
  [430] = 128,
  [431] = 140,
  [432] = 154,
  [433] = 155,
  [434] = 156,
  [435] = 157,
  [436] = 158,
  [437] = 177,
  [438] = 120,
  [439] = 159,
  [440] = 161,
  [441] = 193,
  [442] = 186,
  [443] = 136,
  [444] = 138,
  [445] = 165,
  [446] = 171,
  [447] = 176,
  [448] = 448,
  [449] = 6,
  [450] = 5,
  [451] = 8,
  [452] = 9,
  [453] = 10,
  [454] = 104,
  [455] = 136,
  [456] = 125,
  [457] = 128,
  [458] = 116,
  [459] = 129,
  [460] = 460,
  [461] = 120,
  [462] = 115,
  [463] = 123,
  [464] = 464,
  [465] = 460,
  [466] = 127,
  [467] = 467,
  [468] = 467,
  [469] = 467,
  [470] = 470,
  [471] = 467,
  [472] = 464,
  [473] = 464,
  [474] = 138,
  [475] = 153,
  [476] = 161,
  [477] = 464,
  [478] = 464,
  [479] = 467,
  [480] = 159,
  [481] = 464,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 483,
  [486] = 483,
  [487] = 2,
  [488] = 483,
  [489] = 2,
  [490] = 483,
  [491] = 482,
  [492] = 482,
  [493] = 482,
  [494] = 482,
  [495] = 495,
  [496] = 496,
  [497] = 497,
  [498] = 498,
  [499] = 499,
  [500] = 500,
  [501] = 501,
  [502] = 502,
  [503] = 503,
  [504] = 504,
  [505] = 505,
  [506] = 506,
  [507] = 506,
  [508] = 508,
  [509] = 509,
  [510] = 503,
  [511] = 501,
  [512] = 503,
  [513] = 505,
  [514] = 506,
  [515] = 504,
  [516] = 503,
  [517] = 504,
  [518] = 501,
  [519] = 506,
  [520] = 520,
  [521] = 501,
  [522] = 520,
  [523] = 523,
  [524] = 500,
  [525] = 503,
  [526] = 505,
  [527] = 527,
  [528] = 501,
  [529] = 501,
  [530] = 520,
  [531] = 520,
  [532] = 520,
  [533] = 503,
  [534] = 505,
  [535] = 504,
  [536] = 504,
  [537] = 537,
  [538] = 502,
  [539] = 508,
  [540] = 523,
  [541] = 503,
  [542] = 501,
  [543] = 520,
  [544] = 505,
  [545] = 504,
  [546] = 537,
  [547] = 505,
  [548] = 504,
  [549] = 527,
  [550] = 506,
  [551] = 509,
  [552] = 506,
  [553] = 505,
  [554] = 520,
  [555] = 555,
  [556] = 556,
  [557] = 557,
  [558] = 558,
  [559] = 559,
  [560] = 560,
  [561] = 561,
  [562] = 562,
  [563] = 563,
  [564] = 564,
  [565] = 565,
  [566] = 566,
  [567] = 557,
  [568] = 568,
  [569] = 569,
  [570] = 570,
  [571] = 571,
  [572] = 572,
  [573] = 573,
  [574] = 556,
  [575] = 558,
  [576] = 560,
  [577] = 562,
  [578] = 564,
  [579] = 565,
  [580] = 570,
  [581] = 573,
  [582] = 582,
  [583] = 583,
  [584] = 584,
  [585] = 582,
  [586] = 586,
  [587] = 587,
  [588] = 583,
  [589] = 584,
  [590] = 590,
  [591] = 591,
  [592] = 592,
  [593] = 2,
  [594] = 568,
  [595] = 595,
  [596] = 555,
  [597] = 597,
  [598] = 598,
  [599] = 599,
  [600] = 569,
  [601] = 601,
  [602] = 602,
  [603] = 603,
  [604] = 604,
  [605] = 566,
  [606] = 557,
  [607] = 568,
  [608] = 569,
  [609] = 571,
  [610] = 610,
  [611] = 556,
  [612] = 558,
  [613] = 560,
  [614] = 562,
  [615] = 564,
  [616] = 565,
  [617] = 570,
  [618] = 573,
  [619] = 582,
  [620] = 583,
  [621] = 584,
  [622] = 622,
  [623] = 623,
  [624] = 624,
  [625] = 625,
  [626] = 626,
  [627] = 566,
  [628] = 557,
  [629] = 568,
  [630] = 569,
  [631] = 571,
  [632] = 632,
  [633] = 598,
  [634] = 556,
  [635] = 558,
  [636] = 560,
  [637] = 562,
  [638] = 564,
  [639] = 565,
  [640] = 570,
  [641] = 573,
  [642] = 582,
  [643] = 583,
  [644] = 584,
  [645] = 598,
  [646] = 646,
  [647] = 598,
  [648] = 566,
  [649] = 557,
  [650] = 568,
  [651] = 569,
  [652] = 652,
  [653] = 623,
  [654] = 571,
  [655] = 655,
  [656] = 556,
  [657] = 558,
  [658] = 560,
  [659] = 562,
  [660] = 564,
  [661] = 565,
  [662] = 570,
  [663] = 573,
  [664] = 582,
  [665] = 583,
  [666] = 623,
  [667] = 584,
  [668] = 668,
  [669] = 669,
  [670] = 623,
  [671] = 571,
  [672] = 672,
  [673] = 673,
  [674] = 674,
  [675] = 623,
  [676] = 676,
  [677] = 677,
  [678] = 566,
  [679] = 679,
  [680] = 591,
  [681] = 592,
  [682] = 669,
  [683] = 676,
  [684] = 684,
  [685] = 572,
  [686] = 590,
  [687] = 602,
  [688] = 610,
  [689] = 571,
  [690] = 558,
  [691] = 560,
  [692] = 562,
  [693] = 564,
  [694] = 565,
  [695] = 570,
  [696] = 598,
  [697] = 679,
  [698] = 591,
  [699] = 592,
  [700] = 679,
  [701] = 679,
  [702] = 591,
  [703] = 592,
  [704] = 679,
  [705] = 591,
  [706] = 592,
  [707] = 591,
  [708] = 561,
  [709] = 598,
  [710] = 566,
  [711] = 557,
  [712] = 568,
  [713] = 569,
  [714] = 556,
  [715] = 573,
  [716] = 582,
  [717] = 583,
  [718] = 584,
  [719] = 684,
  [720] = 586,
  [721] = 559,
  [722] = 75,
  [723] = 5,
  [724] = 6,
  [725] = 106,
  [726] = 85,
  [727] = 108,
  [728] = 109,
  [729] = 110,
  [730] = 86,
  [731] = 87,
  [732] = 88,
  [733] = 89,
  [734] = 90,
  [735] = 91,
  [736] = 101,
  [737] = 186,
  [738] = 102,
  [739] = 114,
  [740] = 92,
  [741] = 93,
  [742] = 94,
  [743] = 95,
  [744] = 83,
  [745] = 10,
  [746] = 112,
  [747] = 143,
  [748] = 119,
  [749] = 105,
  [750] = 111,
  [751] = 84,
  [752] = 96,
  [753] = 154,
  [754] = 169,
  [755] = 181,
  [756] = 99,
  [757] = 139,
  [758] = 130,
  [759] = 97,
  [760] = 103,
  [761] = 82,
  [762] = 171,
  [763] = 9,
  [764] = 764,
  [765] = 6,
  [766] = 121,
  [767] = 98,
  [768] = 183,
  [769] = 113,
  [770] = 107,
  [771] = 137,
  [772] = 180,
  [773] = 118,
  [774] = 124,
  [775] = 122,
  [776] = 8,
  [777] = 8,
  [778] = 117,
  [779] = 190,
  [780] = 144,
  [781] = 165,
  [782] = 147,
  [783] = 188,
  [784] = 148,
  [785] = 146,
  [786] = 142,
  [787] = 141,
  [788] = 150,
  [789] = 149,
  [790] = 145,
  [791] = 151,
  [792] = 152,
  [793] = 189,
  [794] = 176,
  [795] = 182,
  [796] = 155,
  [797] = 156,
  [798] = 179,
  [799] = 140,
  [800] = 178,
  [801] = 801,
  [802] = 187,
  [803] = 157,
  [804] = 166,
  [805] = 172,
  [806] = 185,
  [807] = 158,
  [808] = 177,
  [809] = 162,
  [810] = 191,
  [811] = 192,
  [812] = 193,
  [813] = 130,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 119,
  [819] = 137,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 121,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 144,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 190,
  [838] = 165,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 180,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 848,
  [850] = 75,
  [851] = 851,
  [852] = 186,
  [853] = 853,
  [854] = 851,
  [855] = 186,
  [856] = 853,
  [857] = 857,
  [858] = 858,
  [859] = 859,
  [860] = 853,
  [861] = 186,
  [862] = 862,
  [863] = 863,
  [864] = 114,
  [865] = 865,
  [866] = 110,
  [867] = 186,
  [868] = 868,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 872,
  [873] = 873,
  [874] = 874,
  [875] = 875,
  [876] = 853,
  [877] = 877,
  [878] = 878,
  [879] = 186,
  [880] = 880,
  [881] = 881,
  [882] = 95,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 886,
  [887] = 887,
  [888] = 859,
  [889] = 104,
  [890] = 841,
  [891] = 853,
  [892] = 106,
  [893] = 107,
  [894] = 105,
  [895] = 111,
  [896] = 112,
  [897] = 113,
  [898] = 898,
  [899] = 857,
  [900] = 858,
  [901] = 887,
  [902] = 108,
  [903] = 109,
  [904] = 904,
  [905] = 865,
  [906] = 121,
  [907] = 98,
  [908] = 875,
  [909] = 103,
  [910] = 128,
  [911] = 99,
  [912] = 119,
  [913] = 125,
  [914] = 118,
  [915] = 120,
  [916] = 124,
  [917] = 123,
  [918] = 96,
  [919] = 886,
  [920] = 136,
  [921] = 115,
  [922] = 116,
  [923] = 880,
  [924] = 898,
  [925] = 83,
  [926] = 84,
  [927] = 862,
  [928] = 86,
  [929] = 87,
  [930] = 88,
  [931] = 89,
  [932] = 90,
  [933] = 91,
  [934] = 96,
  [935] = 97,
  [936] = 82,
  [937] = 98,
  [938] = 99,
  [939] = 137,
  [940] = 881,
  [941] = 130,
  [942] = 870,
  [943] = 97,
  [944] = 872,
  [945] = 885,
  [946] = 874,
  [947] = 863,
  [948] = 948,
  [949] = 873,
  [950] = 871,
  [951] = 841,
  [952] = 904,
  [953] = 883,
  [954] = 884,
  [955] = 877,
  [956] = 869,
  [957] = 129,
  [958] = 878,
  [959] = 83,
  [960] = 84,
  [961] = 868,
  [962] = 122,
  [963] = 85,
  [964] = 86,
  [965] = 853,
  [966] = 87,
  [967] = 88,
  [968] = 89,
  [969] = 90,
  [970] = 91,
  [971] = 117,
  [972] = 101,
  [973] = 102,
  [974] = 127,
  [975] = 92,
  [976] = 93,
  [977] = 94,
  [978] = 82,
  [979] = 85,
  [980] = 92,
  [981] = 93,
  [982] = 94,
  [983] = 186,
  [984] = 984,
  [985] = 103,
  [986] = 171,
  [987] = 987,
  [988] = 186,
  [989] = 187,
  [990] = 188,
  [991] = 987,
  [992] = 984,
  [993] = 987,
  [994] = 172,
  [995] = 183,
  [996] = 984,
  [997] = 984,
  [998] = 101,
  [999] = 102,
  [1000] = 141,
  [1001] = 191,
  [1002] = 192,
  [1003] = 150,
  [1004] = 176,
  [1005] = 145,
  [1006] = 177,
  [1007] = 149,
  [1008] = 157,
  [1009] = 178,
  [1010] = 166,
  [1011] = 142,
  [1012] = 151,
  [1013] = 152,
  [1014] = 185,
  [1015] = 180,
  [1016] = 169,
  [1017] = 181,
  [1018] = 987,
  [1019] = 182,
  [1020] = 153,
  [1021] = 189,
  [1022] = 162,
  [1023] = 155,
  [1024] = 146,
  [1025] = 147,
  [1026] = 193,
  [1027] = 154,
  [1028] = 190,
  [1029] = 156,
  [1030] = 139,
  [1031] = 179,
  [1032] = 140,
  [1033] = 159,
  [1034] = 161,
  [1035] = 158,
  [1036] = 165,
  [1037] = 148,
  [1038] = 987,
  [1039] = 984,
  [1040] = 143,
  [1041] = 138,
  [1042] = 144,
  [1043] = 1043,
  [1044] = 1044,
  [1045] = 1043,
  [1046] = 1044,
  [1047] = 1047,
  [1048] = 1043,
  [1049] = 1044,
  [1050] = 1050,
  [1051] = 1043,
  [1052] = 1050,
  [1053] = 1044,
  [1054] = 1054,
  [1055] = 1054,
  [1056] = 1056,
  [1057] = 1044,
  [1058] = 1050,
  [1059] = 1054,
  [1060] = 1050,
  [1061] = 1050,
  [1062] = 1062,
  [1063] = 1056,
  [1064] = 1050,
  [1065] = 1043,
  [1066] = 1066,
  [1067] = 1054,
  [1068] = 1054,
  [1069] = 1069,
  [1070] = 1070,
  [1071] = 1071,
  [1072] = 1072,
  [1073] = 1073,
  [1074] = 1074,
  [1075] = 1075,
  [1076] = 1076,
  [1077] = 1077,
  [1078] = 1078,
  [1079] = 1079,
  [1080] = 1080,
  [1081] = 1081,
  [1082] = 1082,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 1086,
  [1087] = 1087,
  [1088] = 1088,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1091,
  [1092] = 1092,
  [1093] = 101,
  [1094] = 102,
  [1095] = 1095,
  [1096] = 1096,
  [1097] = 1097,
  [1098] = 1098,
  [1099] = 1092,
  [1100] = 1100,
  [1101] = 1101,
  [1102] = 1102,
  [1103] = 1103,
  [1104] = 1104,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 1088,
  [1108] = 1108,
  [1109] = 1109,
  [1110] = 1102,
  [1111] = 1104,
  [1112] = 1112,
  [1113] = 1090,
  [1114] = 1087,
  [1115] = 103,
  [1116] = 1102,
  [1117] = 1092,
  [1118] = 1091,
  [1119] = 1089,
  [1120] = 1120,
  [1121] = 1105,
  [1122] = 1102,
  [1123] = 1123,
  [1124] = 1104,
  [1125] = 1102,
  [1126] = 1104,
  [1127] = 1101,
  [1128] = 1128,
  [1129] = 1100,
  [1130] = 1130,
  [1131] = 1120,
  [1132] = 1132,
  [1133] = 1133,
  [1134] = 1096,
  [1135] = 1103,
  [1136] = 1092,
  [1137] = 1137,
  [1138] = 1130,
  [1139] = 1132,
  [1140] = 1102,
  [1141] = 1112,
  [1142] = 1108,
  [1143] = 1109,
  [1144] = 1104,
  [1145] = 1123,
  [1146] = 1092,
  [1147] = 1147,
  [1148] = 1147,
  [1149] = 1147,
  [1150] = 151,
  [1151] = 1151,
  [1152] = 1147,
  [1153] = 1147,
  [1154] = 898,
  [1155] = 1155,
  [1156] = 1156,
  [1157] = 869,
  [1158] = 865,
  [1159] = 1159,
  [1160] = 1160,
  [1161] = 1161,
  [1162] = 1160,
  [1163] = 1161,
  [1164] = 1161,
  [1165] = 1160,
  [1166] = 1161,
  [1167] = 1161,
  [1168] = 1161,
  [1169] = 1160,
  [1170] = 1160,
  [1171] = 1160,
  [1172] = 1160,
  [1173] = 1161,
  [1174] = 1161,
  [1175] = 1161,
  [1176] = 1161,
  [1177] = 1161,
  [1178] = 1160,
  [1179] = 1160,
  [1180] = 1160,
  [1181] = 1160,
  [1182] = 1182,
  [1183] = 1183,
  [1184] = 1184,
  [1185] = 1185,
  [1186] = 1186,
  [1187] = 1187,
  [1188] = 1188,
  [1189] = 1189,
  [1190] = 1190,
  [1191] = 1191,
  [1192] = 1192,
  [1193] = 1193,
  [1194] = 1194,
  [1195] = 1191,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 1198,
  [1199] = 1188,
  [1200] = 1200,
  [1201] = 1201,
  [1202] = 1202,
  [1203] = 1203,
  [1204] = 1204,
  [1205] = 1191,
  [1206] = 1188,
  [1207] = 1207,
  [1208] = 1208,
  [1209] = 1191,
  [1210] = 1210,
  [1211] = 1188,
  [1212] = 1212,
  [1213] = 1191,
  [1214] = 1214,
  [1215] = 1188,
  [1216] = 1182,
  [1217] = 1191,
  [1218] = 1188,
  [1219] = 1219,
  [1220] = 1220,
  [1221] = 1188,
  [1222] = 1222,
  [1223] = 1223,
  [1224] = 1224,
  [1225] = 1225,
  [1226] = 1191,
  [1227] = 1224,
  [1228] = 1228,
  [1229] = 1229,
  [1230] = 1224,
  [1231] = 1223,
  [1232] = 1232,
  [1233] = 1224,
  [1234] = 1234,
  [1235] = 1235,
  [1236] = 1182,
  [1237] = 1237,
  [1238] = 1229,
  [1239] = 1204,
  [1240] = 1212,
  [1241] = 1228,
  [1242] = 1232,
  [1243] = 1234,
  [1244] = 1244,
  [1245] = 1245,
  [1246] = 1183,
  [1247] = 1187,
  [1248] = 1189,
  [1249] = 1188,
  [1250] = 1193,
  [1251] = 1194,
  [1252] = 1197,
  [1253] = 1201,
  [1254] = 1254,
  [1255] = 1229,
  [1256] = 1224,
  [1257] = 1257,
  [1258] = 1204,
  [1259] = 1228,
  [1260] = 1183,
  [1261] = 1229,
  [1262] = 1204,
  [1263] = 1228,
  [1264] = 1183,
  [1265] = 1229,
  [1266] = 1266,
  [1267] = 1204,
  [1268] = 1228,
  [1269] = 1183,
  [1270] = 1229,
  [1271] = 1204,
  [1272] = 1228,
  [1273] = 1183,
  [1274] = 1229,
  [1275] = 1204,
  [1276] = 1228,
  [1277] = 1183,
  [1278] = 1183,
  [1279] = 1198,
  [1280] = 1191,
  [1281] = 1244,
  [1282] = 1182,
  [1283] = 1245,
  [1284] = 1182,
  [1285] = 1182,
  [1286] = 1182,
  [1287] = 1182,
  [1288] = 1288,
  [1289] = 1289,
  [1290] = 1289,
  [1291] = 1291,
  [1292] = 1292,
  [1293] = 1293,
  [1294] = 1294,
  [1295] = 75,
  [1296] = 1296,
  [1297] = 1297,
  [1298] = 1298,
  [1299] = 1299,
  [1300] = 1300,
  [1301] = 1301,
  [1302] = 1302,
  [1303] = 1303,
  [1304] = 1304,
  [1305] = 865,
  [1306] = 1306,
  [1307] = 1307,
  [1308] = 1308,
  [1309] = 1309,
  [1310] = 1310,
  [1311] = 1311,
  [1312] = 1301,
  [1313] = 1313,
  [1314] = 1314,
  [1315] = 1315,
  [1316] = 108,
  [1317] = 1301,
  [1318] = 1318,
  [1319] = 1319,
  [1320] = 1320,
  [1321] = 1321,
  [1322] = 1322,
  [1323] = 1301,
  [1324] = 1324,
  [1325] = 1325,
  [1326] = 1301,
  [1327] = 853,
  [1328] = 1328,
  [1329] = 1329,
  [1330] = 1330,
  [1331] = 1331,
  [1332] = 1301,
  [1333] = 1333,
  [1334] = 869,
  [1335] = 1301,
  [1336] = 1336,
  [1337] = 1337,
  [1338] = 1338,
  [1339] = 110,
  [1340] = 1340,
  [1341] = 1341,
  [1342] = 1342,
  [1343] = 1343,
  [1344] = 1344,
  [1345] = 898,
  [1346] = 1346,
  [1347] = 1347,
  [1348] = 1348,
  [1349] = 1301,
  [1350] = 1350,
  [1351] = 1351,
  [1352] = 1352,
  [1353] = 1353,
  [1354] = 1354,
  [1355] = 1355,
  [1356] = 1356,
  [1357] = 1357,
  [1358] = 1358,
  [1359] = 1359,
  [1360] = 1360,
  [1361] = 1361,
  [1362] = 1362,
  [1363] = 1363,
  [1364] = 1364,
  [1365] = 1365,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 1368,
  [1369] = 1369,
  [1370] = 1370,
  [1371] = 1371,
  [1372] = 1372,
  [1373] = 1373,
  [1374] = 1374,
  [1375] = 124,
  [1376] = 1376,
  [1377] = 1377,
  [1378] = 1378,
  [1379] = 1379,
  [1380] = 106,
  [1381] = 107,
  [1382] = 109,
  [1383] = 114,
  [1384] = 75,
  [1385] = 75,
  [1386] = 1386,
  [1387] = 1387,
  [1388] = 75,
  [1389] = 104,
  [1390] = 1387,
  [1391] = 75,
  [1392] = 1387,
  [1393] = 1387,
  [1394] = 117,
  [1395] = 118,
  [1396] = 1387,
  [1397] = 1397,
  [1398] = 1398,
  [1399] = 1399,
  [1400] = 1400,
  [1401] = 1398,
  [1402] = 1402,
  [1403] = 186,
  [1404] = 1400,
  [1405] = 1399,
  [1406] = 136,
  [1407] = 1398,
  [1408] = 1408,
  [1409] = 1409,
  [1410] = 1410,
  [1411] = 1411,
  [1412] = 1412,
  [1413] = 1400,
  [1414] = 1414,
  [1415] = 1415,
  [1416] = 1416,
  [1417] = 853,
  [1418] = 1398,
  [1419] = 1419,
  [1420] = 1398,
  [1421] = 1421,
  [1422] = 1422,
  [1423] = 853,
  [1424] = 1424,
  [1425] = 1415,
  [1426] = 1397,
  [1427] = 1410,
  [1428] = 1409,
  [1429] = 1429,
  [1430] = 1430,
  [1431] = 1430,
  [1432] = 1416,
  [1433] = 186,
  [1434] = 1434,
  [1435] = 1435,
  [1436] = 1436,
  [1437] = 1437,
  [1438] = 1438,
  [1439] = 1411,
  [1440] = 1440,
  [1441] = 1441,
  [1442] = 1435,
  [1443] = 1443,
  [1444] = 1438,
  [1445] = 1445,
  [1446] = 1402,
  [1447] = 1400,
  [1448] = 1421,
  [1449] = 1440,
  [1450] = 1400,
  [1451] = 1422,
  [1452] = 1452,
  [1453] = 1412,
  [1454] = 1441,
  [1455] = 1445,
  [1456] = 1429,
  [1457] = 1408,
  [1458] = 125,
  [1459] = 1459,
  [1460] = 110,
  [1461] = 120,
  [1462] = 116,
  [1463] = 1463,
  [1464] = 108,
  [1465] = 115,
  [1466] = 123,
  [1467] = 1467,
  [1468] = 108,
  [1469] = 109,
  [1470] = 1470,
  [1471] = 124,
  [1472] = 110,
  [1473] = 109,
  [1474] = 1474,
  [1475] = 104,
  [1476] = 1467,
  [1477] = 1477,
  [1478] = 106,
  [1479] = 159,
  [1480] = 107,
  [1481] = 1481,
  [1482] = 106,
  [1483] = 107,
  [1484] = 1481,
  [1485] = 136,
  [1486] = 1486,
  [1487] = 107,
  [1488] = 138,
  [1489] = 109,
  [1490] = 106,
  [1491] = 1491,
  [1492] = 1492,
  [1493] = 114,
  [1494] = 1474,
  [1495] = 107,
  [1496] = 124,
  [1497] = 1497,
  [1498] = 161,
  [1499] = 1499,
  [1500] = 1470,
  [1501] = 106,
  [1502] = 1502,
  [1503] = 1503,
  [1504] = 104,
  [1505] = 1477,
  [1506] = 1506,
  [1507] = 1497,
  [1508] = 1508,
  [1509] = 1509,
  [1510] = 1499,
  [1511] = 1506,
  [1512] = 1512,
  [1513] = 114,
  [1514] = 1512,
  [1515] = 153,
  [1516] = 109,
  [1517] = 1517,
  [1518] = 129,
  [1519] = 123,
  [1520] = 115,
  [1521] = 117,
  [1522] = 125,
  [1523] = 1523,
  [1524] = 127,
  [1525] = 136,
  [1526] = 1526,
  [1527] = 128,
  [1528] = 117,
  [1529] = 118,
  [1530] = 128,
  [1531] = 118,
  [1532] = 120,
  [1533] = 129,
  [1534] = 127,
  [1535] = 1535,
  [1536] = 116,
  [1537] = 1537,
  [1538] = 1538,
  [1539] = 1539,
  [1540] = 1539,
  [1541] = 1541,
  [1542] = 1541,
  [1543] = 1543,
  [1544] = 1538,
  [1545] = 1545,
  [1546] = 1538,
  [1547] = 1547,
  [1548] = 1548,
  [1549] = 1549,
  [1550] = 1550,
  [1551] = 1549,
  [1552] = 1548,
  [1553] = 1549,
  [1554] = 1554,
  [1555] = 128,
  [1556] = 1550,
  [1557] = 1548,
  [1558] = 1558,
  [1559] = 1554,
  [1560] = 1560,
  [1561] = 127,
  [1562] = 1550,
  [1563] = 115,
  [1564] = 1564,
  [1565] = 1554,
  [1566] = 1549,
  [1567] = 123,
  [1568] = 1548,
  [1569] = 120,
  [1570] = 1554,
  [1571] = 1541,
  [1572] = 1572,
  [1573] = 1539,
  [1574] = 129,
  [1575] = 1554,
  [1576] = 1541,
  [1577] = 1554,
  [1578] = 1538,
  [1579] = 1539,
  [1580] = 1549,
  [1581] = 1538,
  [1582] = 1550,
  [1583] = 1548,
  [1584] = 1554,
  [1585] = 116,
  [1586] = 1550,
  [1587] = 125,
  [1588] = 1588,
  [1589] = 1539,
  [1590] = 1541,
  [1591] = 1591,
  [1592] = 1592,
  [1593] = 1593,
  [1594] = 1594,
  [1595] = 1595,
  [1596] = 1596,
  [1597] = 1597,
  [1598] = 1598,
  [1599] = 1599,
  [1600] = 1600,
  [1601] = 1601,
  [1602] = 1602,
  [1603] = 1603,
  [1604] = 1604,
  [1605] = 1605,
  [1606] = 1606,
  [1607] = 1607,
  [1608] = 1608,
  [1609] = 1609,
  [1610] = 1610,
  [1611] = 1611,
  [1612] = 1612,
  [1613] = 1613,
  [1614] = 1614,
  [1615] = 1615,
  [1616] = 1616,
  [1617] = 1617,
  [1618] = 1618,
  [1619] = 1619,
  [1620] = 1620,
  [1621] = 1621,
  [1622] = 1622,
  [1623] = 1623,
  [1624] = 1624,
  [1625] = 1625,
  [1626] = 1626,
  [1627] = 1627,
  [1628] = 1628,
  [1629] = 1617,
  [1630] = 1630,
  [1631] = 1593,
  [1632] = 1632,
  [1633] = 1633,
  [1634] = 1622,
  [1635] = 1635,
  [1636] = 1636,
  [1637] = 1637,
  [1638] = 1638,
  [1639] = 1602,
  [1640] = 1640,
  [1641] = 1618,
  [1642] = 1642,
  [1643] = 1643,
  [1644] = 1644,
  [1645] = 1640,
  [1646] = 1624,
  [1647] = 1598,
  [1648] = 1623,
  [1649] = 1649,
  [1650] = 1606,
  [1651] = 1651,
  [1652] = 1652,
  [1653] = 1653,
  [1654] = 1654,
  [1655] = 1644,
  [1656] = 1609,
  [1657] = 1657,
  [1658] = 1658,
  [1659] = 1659,
  [1660] = 1660,
  [1661] = 1661,
  [1662] = 1662,
  [1663] = 1663,
  [1664] = 1664,
  [1665] = 1665,
  [1666] = 1666,
  [1667] = 1667,
  [1668] = 1668,
  [1669] = 1669,
  [1670] = 1670,
  [1671] = 1669,
  [1672] = 1672,
  [1673] = 1673,
  [1674] = 1674,
  [1675] = 1675,
  [1676] = 1676,
  [1677] = 1677,
  [1678] = 1678,
  [1679] = 1679,
  [1680] = 1680,
  [1681] = 1681,
  [1682] = 1682,
  [1683] = 1683,
  [1684] = 1684,
  [1685] = 1685,
  [1686] = 1686,
  [1687] = 1687,
  [1688] = 1688,
  [1689] = 1636,
  [1690] = 1690,
  [1691] = 1691,
  [1692] = 1692,
  [1693] = 1693,
  [1694] = 1694,
  [1695] = 1695,
  [1696] = 1696,
  [1697] = 1677,
  [1698] = 1698,
  [1699] = 1699,
  [1700] = 1700,
  [1701] = 1701,
  [1702] = 1702,
  [1703] = 1673,
  [1704] = 1698,
  [1705] = 1705,
  [1706] = 1706,
  [1707] = 1707,
  [1708] = 1708,
  [1709] = 1661,
  [1710] = 1686,
  [1711] = 1711,
  [1712] = 1681,
  [1713] = 1713,
  [1714] = 1714,
  [1715] = 1715,
  [1716] = 1707,
  [1717] = 1659,
  [1718] = 1660,
  [1719] = 1719,
  [1720] = 1664,
  [1721] = 1665,
  [1722] = 1666,
  [1723] = 1672,
  [1724] = 1692,
  [1725] = 1693,
  [1726] = 1706,
  [1727] = 1692,
  [1728] = 1728,
  [1729] = 1677,
  [1730] = 1698,
  [1731] = 1659,
  [1732] = 1702,
  [1733] = 1706,
  [1734] = 1660,
  [1735] = 1708,
  [1736] = 1736,
  [1737] = 1661,
  [1738] = 1738,
  [1739] = 1686,
  [1740] = 1713,
  [1741] = 1741,
  [1742] = 1742,
  [1743] = 1707,
  [1744] = 1659,
  [1745] = 1660,
  [1746] = 1664,
  [1747] = 1665,
  [1748] = 1666,
  [1749] = 1662,
  [1750] = 1672,
  [1751] = 1601,
  [1752] = 1713,
  [1753] = 1753,
  [1754] = 1698,
  [1755] = 1755,
  [1756] = 1702,
  [1757] = 1757,
  [1758] = 1758,
  [1759] = 1759,
  [1760] = 1706,
  [1761] = 1761,
  [1762] = 1708,
  [1763] = 1676,
  [1764] = 1661,
  [1765] = 1686,
  [1766] = 1766,
  [1767] = 1713,
  [1768] = 1768,
  [1769] = 1707,
  [1770] = 1659,
  [1771] = 1660,
  [1772] = 1664,
  [1773] = 1665,
  [1774] = 1666,
  [1775] = 1672,
  [1776] = 1776,
  [1777] = 1664,
  [1778] = 1778,
  [1779] = 1670,
  [1780] = 1780,
  [1781] = 1686,
  [1782] = 1713,
  [1783] = 1783,
  [1784] = 1660,
  [1785] = 1707,
  [1786] = 1665,
  [1787] = 1787,
  [1788] = 1686,
  [1789] = 1713,
  [1790] = 1660,
  [1791] = 1664,
  [1792] = 1792,
  [1793] = 1686,
  [1794] = 1713,
  [1795] = 1795,
  [1796] = 1660,
  [1797] = 1797,
  [1798] = 1664,
  [1799] = 1742,
  [1800] = 1686,
  [1801] = 1713,
  [1802] = 1660,
  [1803] = 1664,
  [1804] = 1686,
  [1805] = 1713,
  [1806] = 1660,
  [1807] = 1664,
  [1808] = 1808,
  [1809] = 1686,
  [1810] = 1713,
  [1811] = 1811,
  [1812] = 1660,
  [1813] = 1664,
  [1814] = 1683,
  [1815] = 1815,
  [1816] = 1816,
  [1817] = 1817,
  [1818] = 1693,
  [1819] = 1657,
  [1820] = 1820,
  [1821] = 1702,
  [1822] = 1822,
  [1823] = 1823,
  [1824] = 1700,
  [1825] = 1825,
  [1826] = 1657,
  [1827] = 1827,
  [1828] = 1627,
  [1829] = 1766,
  [1830] = 1830,
  [1831] = 1672,
  [1832] = 1832,
  [1833] = 1833,
  [1834] = 1834,
  [1835] = 1835,
  [1836] = 1692,
  [1837] = 1820,
  [1838] = 1693,
  [1839] = 1839,
  [1840] = 1708,
  [1841] = 1841,
  [1842] = 1842,
  [1843] = 1758,
  [1844] = 1844,
  [1845] = 1845,
  [1846] = 1846,
  [1847] = 1677,
  [1848] = 1848,
  [1849] = 1815,
  [1850] = 1698,
  [1851] = 1815,
  [1852] = 1657,
  [1853] = 1820,
  [1854] = 1780,
  [1855] = 1702,
  [1856] = 1815,
  [1857] = 1665,
  [1858] = 1657,
  [1859] = 1820,
  [1860] = 1674,
  [1861] = 1815,
  [1862] = 1862,
  [1863] = 1657,
  [1864] = 1820,
  [1865] = 1865,
  [1866] = 1815,
  [1867] = 1706,
  [1868] = 1657,
  [1869] = 1833,
  [1870] = 1822,
  [1871] = 1815,
  [1872] = 1708,
  [1873] = 1873,
  [1874] = 1661,
  [1875] = 1686,
  [1876] = 1876,
  [1877] = 1666,
  [1878] = 1878,
  [1879] = 1879,
  [1880] = 1880,
  [1881] = 1881,
  [1882] = 1667,
  [1883] = 1883,
  [1884] = 1668,
  [1885] = 1699,
  [1886] = 1705,
  [1887] = 1887,
  [1888] = 1713,
  [1889] = 1679,
  [1890] = 1664,
  [1891] = 1891,
  [1892] = 1892,
  [1893] = 1893,
  [1894] = 1894,
  [1895] = 1895,
  [1896] = 1896,
  [1897] = 1891,
  [1898] = 1898,
  [1899] = 1894,
  [1900] = 1900,
  [1901] = 1901,
  [1902] = 1902,
  [1903] = 1903,
  [1904] = 1904,
  [1905] = 1894,
  [1906] = 1906,
  [1907] = 1907,
  [1908] = 1894,
  [1909] = 1909,
  [1910] = 1910,
  [1911] = 1911,
  [1912] = 1912,
  [1913] = 1913,
  [1914] = 1914,
  [1915] = 1915,
  [1916] = 1916,
  [1917] = 1894,
  [1918] = 1918,
  [1919] = 1919,
  [1920] = 1920,
  [1921] = 1921,
  [1922] = 1901,
  [1923] = 1923,
  [1924] = 1924,
  [1925] = 1898,
  [1926] = 1902,
  [1927] = 1927,
  [1928] = 1928,
  [1929] = 1929,
  [1930] = 1930,
  [1931] = 1902,
  [1932] = 1932,
  [1933] = 1933,
  [1934] = 1934,
  [1935] = 1935,
  [1936] = 1903,
  [1937] = 1928,
  [1938] = 1938,
  [1939] = 1939,
  [1940] = 1940,
  [1941] = 1941,
  [1942] = 1891,
  [1943] = 1924,
  [1944] = 1944,
  [1945] = 1945,
  [1946] = 1946,
  [1947] = 1947,
  [1948] = 1948,
  [1949] = 1949,
  [1950] = 1950,
  [1951] = 1891,
  [1952] = 1952,
  [1953] = 1894,
  [1954] = 1954,
  [1955] = 1955,
  [1956] = 1901,
  [1957] = 1957,
  [1958] = 1958,
  [1959] = 1901,
  [1960] = 1901,
  [1961] = 1902,
  [1962] = 1891,
  [1963] = 1963,
  [1964] = 1964,
  [1965] = 1965,
  [1966] = 1966,
  [1967] = 1967,
  [1968] = 1891,
  [1969] = 1969,
  [1970] = 1948,
  [1971] = 1923,
  [1972] = 1902,
  [1973] = 1973,
  [1974] = 1974,
  [1975] = 1901,
  [1976] = 1976,
  [1977] = 1902,
  [1978] = 1930,
  [1979] = 1909,
  [1980] = 1946,
  [1981] = 1904,
  [1982] = 1901,
  [1983] = 1983,
  [1984] = 1984,
  [1985] = 1938,
  [1986] = 1891,
  [1987] = 1930,
  [1988] = 1902,
  [1989] = 1894,
  [1990] = 1990,
  [1991] = 1930,
  [1992] = 1992,
  [1993] = 1920,
  [1994] = 1940,
  [1995] = 1966,
  [1996] = 1930,
  [1997] = 1997,
  [1998] = 1941,
  [1999] = 1944,
  [2000] = 1945,
  [2001] = 2001,
  [2002] = 1958,
  [2003] = 2003,
  [2004] = 2004,
  [2005] = 2005,
  [2006] = 2006,
  [2007] = 2007,
  [2008] = 2008,
  [2009] = 2009,
  [2010] = 2010,
  [2011] = 2011,
  [2012] = 2012,
  [2013] = 2013,
  [2014] = 2014,
  [2015] = 2009,
  [2016] = 2016,
  [2017] = 2017,
  [2018] = 2018,
  [2019] = 2003,
  [2020] = 2004,
  [2021] = 2021,
  [2022] = 2022,
  [2023] = 2023,
  [2024] = 2024,
  [2025] = 2025,
  [2026] = 2026,
  [2027] = 2004,
  [2028] = 2003,
  [2029] = 2029,
  [2030] = 2030,
  [2031] = 2031,
  [2032] = 2032,
  [2033] = 2003,
  [2034] = 2034,
  [2035] = 2035,
  [2036] = 2036,
  [2037] = 2037,
  [2038] = 2008,
  [2039] = 2039,
  [2040] = 2040,
  [2041] = 2041,
  [2042] = 2042,
  [2043] = 2043,
  [2044] = 2014,
  [2045] = 2045,
  [2046] = 2046,
  [2047] = 2047,
  [2048] = 2048,
  [2049] = 2049,
  [2050] = 2050,
  [2051] = 2012,
  [2052] = 2052,
  [2053] = 2009,
  [2054] = 2054,
  [2055] = 2010,
  [2056] = 2032,
  [2057] = 2057,
  [2058] = 2058,
  [2059] = 2059,
  [2060] = 2010,
  [2061] = 2041,
  [2062] = 2009,
  [2063] = 2010,
  [2064] = 2064,
  [2065] = 2065,
  [2066] = 2066,
  [2067] = 2037,
  [2068] = 2003,
  [2069] = 2024,
  [2070] = 2034,
  [2071] = 2071,
  [2072] = 2072,
  [2073] = 2003,
  [2074] = 2014,
  [2075] = 2034,
  [2076] = 2004,
  [2077] = 2009,
  [2078] = 2003,
  [2079] = 2034,
  [2080] = 2080,
  [2081] = 2025,
  [2082] = 2025,
  [2083] = 2010,
  [2084] = 2084,
  [2085] = 2085,
  [2086] = 2009,
  [2087] = 2037,
  [2088] = 2088,
  [2089] = 2089,
  [2090] = 2034,
  [2091] = 2037,
  [2092] = 2092,
  [2093] = 2010,
  [2094] = 2094,
  [2095] = 2037,
  [2096] = 2009,
  [2097] = 2010,
  [2098] = 2007,
  [2099] = 2041,
  [2100] = 2037,
  [2101] = 2101,
  [2102] = 2008,
  [2103] = 2007,
  [2104] = 2104,
  [2105] = 2014,
  [2106] = 2008,
  [2107] = 2107,
  [2108] = 2041,
  [2109] = 2109,
  [2110] = 2110,
  [2111] = 2111,
  [2112] = 2112,
  [2113] = 2113,
  [2114] = 2016,
  [2115] = 2115,
  [2116] = 2034,
  [2117] = 2117,
  [2118] = 2014,
  [2119] = 2037,
  [2120] = 2041,
  [2121] = 2121,
  [2122] = 2009,
  [2123] = 2025,
  [2124] = 2004,
  [2125] = 2010,
  [2126] = 2126,
  [2127] = 2127,
  [2128] = 2128,
  [2129] = 2007,
  [2130] = 2130,
  [2131] = 2008,
  [2132] = 2059,
  [2133] = 2133,
  [2134] = 2036,
  [2135] = 2117,
  [2136] = 2136,
  [2137] = 2046,
  [2138] = 2138,
  [2139] = 2084,
  [2140] = 2017,
  [2141] = 2041,
  [2142] = 2021,
  [2143] = 2143,
  [2144] = 2144,
  [2145] = 2145,
  [2146] = 2138,
  [2147] = 2034,
  [2148] = 2148,
  [2149] = 2149,
  [2150] = 2025,
  [2151] = 2007,
  [2152] = 2009,
  [2153] = 2153,
  [2154] = 2154,
  [2155] = 2014,
  [2156] = 2010,
  [2157] = 2157,
  [2158] = 2014,
  [2159] = 2014,
  [2160] = 2011,
  [2161] = 2004,
  [2162] = 2162,
  [2163] = 2145,
  [2164] = 2009,
  [2165] = 2117,
  [2166] = 2017,
  [2167] = 2117,
  [2168] = 2017,
  [2169] = 2117,
  [2170] = 2017,
  [2171] = 2017,
  [2172] = 2017,
  [2173] = 2017,
  [2174] = 2010,
  [2175] = 2040,
  [2176] = 2176,
  [2177] = 2177,
  [2178] = 2009,
  [2179] = 2179,
  [2180] = 2180,
  [2181] = 2181,
  [2182] = 2004,
  [2183] = 2037,
  [2184] = 2010,
  [2185] = 2185,
  [2186] = 2039,
  [2187] = 2187,
  [2188] = 2029,
  [2189] = 2189,
  [2190] = 2190,
  [2191] = 2191,
};

static const TSCharacterRange aux_sym_escape_sequence_token1_character_set_1[] = {
  {'"', '"'}, {'\'', '\''}, {'\\', '\\'}, {'b', 'b'}, {'f', 'f'}, {'n', 'n'}, {'r', 'r'}, {'t', 't'},
  {'v', 'v'},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(370);
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 872,
        '%', 917,
        '&', 888,
        '\'', 860,
        '(', 437,
        ')', 438,
        '*', 392,
        '+', 913,
        ',', 388,
        '-', 915,
        '.', 456,
        '/', 384,
        ':', 450,
        ';', 396,
        '<', 894,
        '=', 452,
        '>', 897,
        '?', 938,
        '@', 400,
        'A', 216,
        'B', 338,
        'C', 243,
        'E', 225,
        'F', 200,
        'G', 273,
        'I', 209,
        'L', 164,
        'O', 79,
        'P', 277,
        'R', 244,
        'S', 98,
        'T', 110,
        'W', 63,
        '[', 950,
        '\\', 864,
        ']', 951,
        '^', 886,
        '`', 992,
        'a', 80,
        'c', 67,
        'd', 111,
        'e', 190,
        'i', 150,
        'l', 134,
        'p', 272,
        's', 302,
        'u', 217,
        'w', 163,
        'x', 363,
        '{', 387,
        '|', 883,
        '}', 389,
        '~', 921,
        'b', 865,
        'f', 865,
        'n', 865,
        'r', 865,
        't', 865,
        'v', 865,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(868);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 917,
        '&', 888,
        '\'', 860,
        '(', 437,
        '*', 392,
        '+', 913,
        ',', 388,
        '-', 915,
        '.', 455,
        '/', 384,
        ':', 450,
        ';', 396,
        '<', 894,
        '=', 452,
        '>', 897,
        '?', 938,
        'B', 824,
        'C', 709,
        'F', 665,
        'G', 750,
        'I', 672,
        'L', 617,
        'R', 710,
        'S', 535,
        'T', 597,
        '[', 950,
        '^', 886,
        '`', 992,
        'a', 768,
        'd', 572,
        'e', 846,
        'f', 505,
        'i', 603,
        'n', 574,
        't', 748,
        'v', 715,
        '{', 387,
        '|', 883,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 917,
        '&', 888,
        '\'', 860,
        '(', 437,
        '*', 392,
        '+', 913,
        ',', 388,
        '-', 915,
        '.', 455,
        '/', 384,
        ':', 450,
        ';', 396,
        '<', 894,
        '=', 452,
        '>', 897,
        '?', 938,
        '[', 950,
        '^', 886,
        '`', 992,
        'a', 768,
        'b', 760,
        'c', 721,
        'd', 572,
        'e', 846,
        'f', 503,
        'i', 603,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '|', 883,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 917,
        '&', 888,
        '\'', 860,
        '(', 437,
        '*', 392,
        '+', 913,
        ',', 388,
        '-', 915,
        '.', 455,
        '/', 384,
        ':', 450,
        ';', 396,
        '<', 894,
        '=', 452,
        '>', 897,
        '?', 938,
        '[', 950,
        '^', 886,
        '`', 992,
        'a', 768,
        'b', 760,
        'c', 721,
        'd', 572,
        'e', 666,
        'f', 503,
        'i', 603,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '|', 883,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 917,
        '&', 888,
        '\'', 860,
        '(', 437,
        '*', 392,
        '+', 913,
        ',', 388,
        '-', 915,
        '.', 455,
        '/', 384,
        ':', 450,
        ';', 396,
        '<', 894,
        '=', 452,
        '>', 897,
        '?', 938,
        '[', 950,
        '^', 886,
        '`', 992,
        'a', 768,
        'b', 760,
        'c', 721,
        'd', 572,
        'f', 503,
        'i', 603,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '|', 883,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 917,
        '&', 888,
        '\'', 860,
        '(', 437,
        '*', 392,
        '+', 913,
        '-', 915,
        '.', 455,
        '/', 384,
        ':', 450,
        ';', 396,
        '<', 894,
        '=', 452,
        '>', 897,
        '?', 938,
        'B', 824,
        'C', 709,
        'F', 665,
        'G', 750,
        'I', 672,
        'L', 617,
        'R', 710,
        'S', 535,
        'T', 597,
        '[', 950,
        '^', 886,
        '`', 992,
        'a', 768,
        'd', 572,
        'f', 505,
        'i', 603,
        'n', 574,
        't', 748,
        'v', 715,
        '{', 387,
        '|', 883,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 917,
        '&', 888,
        '\'', 860,
        '(', 437,
        '*', 392,
        '+', 913,
        '-', 915,
        '.', 455,
        '/', 384,
        ':', 450,
        ';', 396,
        '<', 894,
        '=', 452,
        '>', 897,
        '?', 938,
        '[', 950,
        '^', 886,
        '`', 992,
        'a', 768,
        'b', 760,
        'c', 721,
        'd', 572,
        'e', 667,
        'f', 503,
        'i', 603,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '|', 883,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 916,
        '&', 887,
        '\'', 860,
        '(', 437,
        '*', 391,
        '+', 912,
        ',', 388,
        '-', 914,
        '.', 455,
        '/', 383,
        ';', 396,
        '<', 895,
        '=', 51,
        '>', 898,
        '?', 938,
        'B', 824,
        'C', 709,
        'F', 665,
        'G', 750,
        'I', 672,
        'L', 617,
        'R', 710,
        'S', 535,
        'T', 597,
        '[', 950,
        '^', 885,
        '`', 992,
        'a', 768,
        'd', 572,
        'e', 846,
        'f', 505,
        'i', 603,
        'n', 574,
        't', 748,
        'v', 715,
        '{', 387,
        '|', 884,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 916,
        '&', 887,
        '\'', 860,
        '(', 437,
        '*', 391,
        '+', 912,
        ',', 388,
        '-', 914,
        '.', 455,
        '/', 383,
        ';', 396,
        '<', 895,
        '=', 51,
        '>', 898,
        '?', 938,
        '[', 950,
        '^', 885,
        '`', 992,
        'a', 768,
        'b', 760,
        'c', 721,
        'd', 572,
        'e', 846,
        'f', 503,
        'i', 603,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '|', 884,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 916,
        '&', 887,
        '\'', 860,
        '(', 437,
        '*', 391,
        '+', 912,
        ',', 388,
        '-', 914,
        '.', 455,
        '/', 383,
        ';', 396,
        '<', 895,
        '=', 51,
        '>', 898,
        '?', 938,
        '[', 950,
        '^', 885,
        '`', 992,
        'a', 768,
        'b', 760,
        'c', 721,
        'd', 572,
        'e', 666,
        'f', 503,
        'i', 603,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '|', 884,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 916,
        '&', 887,
        '\'', 860,
        '(', 437,
        '*', 391,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 383,
        ':', 450,
        ';', 396,
        '<', 895,
        '=', 51,
        '>', 898,
        '?', 938,
        '[', 950,
        '^', 885,
        '`', 992,
        'a', 768,
        'b', 760,
        'c', 721,
        'd', 572,
        'f', 503,
        'i', 603,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '|', 884,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(10);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 916,
        '&', 887,
        '\'', 860,
        '(', 437,
        '*', 391,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 383,
        ';', 396,
        '<', 895,
        '=', 51,
        '>', 898,
        '?', 938,
        'B', 824,
        'C', 709,
        'F', 665,
        'G', 750,
        'I', 672,
        'L', 617,
        'R', 710,
        'S', 535,
        'T', 597,
        '[', 950,
        '^', 885,
        '`', 992,
        'a', 768,
        'd', 572,
        'f', 505,
        'i', 603,
        'n', 574,
        't', 748,
        'v', 715,
        '{', 387,
        '|', 884,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '!', 920,
        '"', 856,
        '$', 873,
        '%', 916,
        '&', 887,
        '\'', 860,
        '(', 437,
        '*', 391,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 383,
        ';', 396,
        '<', 895,
        '=', 51,
        '>', 898,
        '?', 938,
        '[', 950,
        '^', 885,
        '`', 992,
        'a', 768,
        'b', 760,
        'c', 721,
        'd', 572,
        'e', 667,
        'f', 503,
        'i', 603,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '|', 884,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '!', 50,
        '%', 917,
        '&', 888,
        '(', 437,
        ')', 438,
        '*', 392,
        '+', 913,
        ',', 388,
        '-', 915,
        '.', 455,
        '/', 384,
        ':', 450,
        ';', 396,
        '<', 894,
        '=', 452,
        '>', 897,
        '?', 938,
        '[', 950,
        ']', 951,
        '^', 886,
        'a', 294,
        'e', 354,
        'i', 223,
        'u', 365,
        'x', 363,
        '|', 883,
        '}', 389,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(13);
      if (set_contains(aux_sym_escape_sequence_token1_character_set_1, 9, lookahead)) ADVANCE(865);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(868);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '!', 50,
        '%', 916,
        '&', 887,
        '(', 437,
        ')', 438,
        '*', 391,
        '+', 912,
        ',', 388,
        '-', 914,
        '.', 455,
        '/', 383,
        ':', 450,
        ';', 396,
        '<', 895,
        '=', 51,
        '>', 898,
        '?', 938,
        '[', 950,
        ']', 951,
        '^', 885,
        'a', 294,
        'e', 354,
        'f', 283,
        'i', 223,
        '|', 884,
        '}', 389,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(14);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        ')', 438,
        '+', 912,
        ',', 388,
        '-', 914,
        '.', 456,
        '/', 37,
        ';', 396,
        '<', 893,
        '[', 950,
        ']', 951,
        '`', 992,
        'a', 770,
        'd', 572,
        'f', 505,
        'n', 574,
        't', 748,
        'v', 715,
        '{', 387,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        ')', 438,
        '+', 912,
        ',', 388,
        '-', 914,
        '.', 455,
        '/', 37,
        ':', 450,
        ';', 396,
        '<', 893,
        '=', 451,
        '>', 896,
        '?', 937,
        'B', 824,
        'C', 709,
        'F', 665,
        'G', 750,
        'I', 672,
        'L', 617,
        'R', 710,
        'S', 535,
        'T', 597,
        '[', 950,
        ']', 951,
        '`', 992,
        'a', 770,
        'd', 572,
        'f', 505,
        'i', 604,
        'n', 574,
        't', 748,
        'v', 715,
        '{', 387,
        '|', 882,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        ',', 388,
        '-', 914,
        '.', 456,
        '/', 37,
        '<', 893,
        '>', 896,
        '[', 950,
        ']', 951,
        '`', 992,
        'a', 686,
        'b', 731,
        'd', 572,
        'f', 505,
        'n', 573,
        's', 817,
        't', 748,
        'u', 690,
        'v', 715,
        '{', 387,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        ',', 388,
        '-', 914,
        '.', 456,
        '/', 37,
        '<', 893,
        '[', 950,
        '`', 992,
        'a', 770,
        'b', 760,
        'c', 721,
        'd', 572,
        'f', 503,
        'i', 604,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(18);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        ',', 388,
        '-', 914,
        '.', 455,
        '/', 37,
        '<', 893,
        '>', 896,
        '[', 950,
        ']', 951,
        '`', 992,
        'a', 770,
        'd', 572,
        'e', 846,
        'f', 505,
        'n', 574,
        't', 748,
        'v', 715,
        '{', 387,
        '|', 882,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(19);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 37,
        ';', 396,
        '<', 893,
        '[', 950,
        '`', 992,
        'a', 770,
        'c', 725,
        'd', 572,
        'f', 505,
        'l', 590,
        'n', 574,
        't', 748,
        'v', 510,
        '{', 387,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(20);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 21:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 37,
        '<', 893,
        '@', 400,
        '[', 950,
        '`', 992,
        'a', 528,
        'c', 658,
        'd', 572,
        'e', 847,
        'f', 504,
        'n', 574,
        's', 806,
        't', 748,
        'v', 715,
        '{', 387,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 22:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 37,
        '<', 893,
        'B', 824,
        'C', 709,
        'F', 665,
        'G', 750,
        'I', 672,
        'L', 617,
        'R', 710,
        'S', 535,
        'T', 597,
        '[', 950,
        '`', 992,
        'a', 770,
        'd', 572,
        'e', 667,
        'f', 505,
        'i', 604,
        'n', 574,
        't', 748,
        'v', 715,
        '{', 387,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(22);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 23:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 37,
        '<', 893,
        '[', 950,
        '`', 992,
        'a', 770,
        'b', 760,
        'c', 514,
        'd', 572,
        'e', 667,
        'f', 502,
        'i', 604,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(23);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 24:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 37,
        '<', 893,
        '[', 950,
        '`', 992,
        'a', 770,
        'b', 760,
        'c', 514,
        'd', 572,
        'f', 502,
        'i', 604,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(24);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 25:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 37,
        '<', 893,
        '[', 950,
        '`', 992,
        'a', 770,
        'b', 760,
        'c', 721,
        'd', 572,
        'e', 667,
        'f', 503,
        'i', 604,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(25);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 37,
        '<', 893,
        '[', 950,
        '`', 992,
        'a', 770,
        'b', 760,
        'c', 721,
        'd', 572,
        'e', 667,
        'f', 502,
        'i', 604,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(26);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 27:
      ADVANCE_MAP(
        '!', 919,
        '"', 856,
        '$', 873,
        '\'', 860,
        '(', 437,
        '+', 912,
        '-', 914,
        '.', 455,
        '/', 37,
        '<', 893,
        '[', 950,
        '`', 992,
        'a', 770,
        'b', 760,
        'c', 721,
        'd', 572,
        'f', 502,
        'i', 604,
        'l', 590,
        'n', 574,
        'r', 591,
        't', 616,
        'v', 510,
        'w', 615,
        '{', 387,
        '}', 389,
        '~', 921,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(27);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('_' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 28:
      ADVANCE_MAP(
        '"', 856,
        '\'', 860,
        '(', 437,
        ')', 438,
        '*', 390,
        ',', 388,
        '.', 456,
        '/', 37,
        ':', 450,
        ';', 396,
        '<', 893,
        '=', 453,
        '>', 896,
        '?', 937,
        '[', 950,
        '{', 387,
        '|', 882,
        '}', 389,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(28);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 29:
      if (lookahead == '"') ADVANCE(856);
      if (lookahead == '/') ADVANCE(858);
      if (lookahead == '\\') ADVANCE(864);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(859);
      if (lookahead != 0) ADVANCE(857);
      END_STATE();
    case 30:
      if (lookahead == '$') ADVANCE(871);
      if (lookahead == '/') ADVANCE(994);
      if (lookahead == '\\') ADVANCE(367);
      if (lookahead == '`') ADVANCE(992);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(995);
      if (lookahead != 0) ADVANCE(996);
      END_STATE();
    case 31:
      if (lookahead == '\'') ADVANCE(860);
      if (lookahead == '/') ADVANCE(862);
      if (lookahead == '\\') ADVANCE(864);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(863);
      if (lookahead != 0) ADVANCE(861);
      END_STATE();
    case 32:
      if (lookahead == '(') ADVANCE(437);
      if (lookahead == '/') ADVANCE(37);
      if (lookahead == '<') ADVANCE(893);
      if (lookahead == 'a') ADVANCE(771);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(32);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 33:
      if (lookahead == '(') ADVANCE(437);
      if (lookahead == '/') ADVANCE(37);
      if (lookahead == '<') ADVANCE(893);
      if (lookahead == 'f') ADVANCE(838);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(33);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 34:
      ADVANCE_MAP(
        '(', 437,
        '/', 37,
        '>', 896,
        '[', 950,
        ']', 951,
        'a', 687,
        'b', 731,
        'f', 505,
        'n', 825,
        's', 817,
        't', 749,
        'u', 690,
        'v', 715,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(34);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('c' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 35:
      if (lookahead == '(') ADVANCE(437);
      if (lookahead == '/') ADVANCE(37);
      if (lookahead == '@') ADVANCE(400);
      if (lookahead == 'a') ADVANCE(771);
      if (lookahead == 'p') ADVANCE(751);
      if (lookahead == 'r') ADVANCE(593);
      if (lookahead == 's') ADVANCE(822);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(35);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 36:
      ADVANCE_MAP(
        ')', 438,
        ',', 388,
        '.', 455,
        '/', 37,
        ':', 450,
        ';', 396,
        '<', 893,
        '=', 453,
        '>', 896,
        '?', 937,
        '[', 950,
        ']', 951,
        'e', 354,
        'i', 210,
        '{', 387,
        '|', 882,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(36);
      END_STATE();
    case 37:
      if (lookahead == '*') ADVANCE(378);
      if (lookahead == '/') ADVANCE(371);
      END_STATE();
    case 38:
      if (lookahead == '*') ADVANCE(382);
      if (lookahead == '/') ADVANCE(40);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(38);
      if (lookahead != 0) ADVANCE(39);
      END_STATE();
    case 39:
      if (lookahead == '*') ADVANCE(382);
      if (lookahead != 0) ADVANCE(39);
      END_STATE();
    case 40:
      if (lookahead == '*') ADVANCE(379);
      if (lookahead == '/') ADVANCE(372);
      if (lookahead != 0) ADVANCE(39);
      END_STATE();
    case 41:
      ADVANCE_MAP(
        ',', 388,
        '.', 455,
        '/', 37,
        ';', 396,
        '<', 893,
        '=', 451,
        '>', 896,
        '?', 937,
        '[', 950,
        'e', 846,
        '|', 882,
        '}', 389,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(41);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 42:
      if (lookahead == '.') ADVANCE(960);
      END_STATE();
    case 43:
      if (lookahead == '/') ADVANCE(37);
      if (lookahead == ';') ADVANCE(396);
      if (lookahead == 'e') ADVANCE(699);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(43);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 44:
      ADVANCE_MAP(
        '/', 37,
        '@', 400,
        'a', 771,
        'b', 837,
        'p', 751,
        'r', 593,
        's', 822,
        '}', 389,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(44);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('c' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 45:
      ADVANCE_MAP(
        '/', 37,
        '@', 400,
        'a', 771,
        'c', 732,
        'p', 751,
        'r', 593,
        's', 822,
        '}', 389,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(45);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 46:
      ADVANCE_MAP(
        '/', 37,
        'A', 697,
        'B', 833,
        'C', 712,
        'E', 701,
        'L', 630,
        'O', 525,
        'P', 758,
        'S', 794,
        'W', 515,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(46);
      if (lookahead == '$' ||
          ('D' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 47:
      if (lookahead == '/') ADVANCE(37);
      if (lookahead == 'a') ADVANCE(771);
      if (lookahead == 'c') ADVANCE(732);
      if (lookahead == 'r') ADVANCE(593);
      if (lookahead == 's') ADVANCE(822);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(47);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 48:
      if (lookahead == '/') ADVANCE(37);
      if (lookahead == 'a') ADVANCE(771);
      if (lookahead == 'r') ADVANCE(593);
      if (lookahead == 's') ADVANCE(822);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(48);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 49:
      if (lookahead == '/') ADVANCE(37);
      if (lookahead == 'a') ADVANCE(771);
      if (lookahead == 'r') ADVANCE(593);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(49);
      if (lookahead == '$' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 50:
      if (lookahead == '=') ADVANCE(890);
      END_STATE();
    case 51:
      if (lookahead == '=') ADVANCE(889);
      END_STATE();
    case 52:
      if (lookahead == 'E') ADVANCE(68);
      END_STATE();
    case 53:
      if (lookahead == 'E') ADVANCE(353);
      END_STATE();
    case 54:
      if (lookahead == 'L') ADVANCE(177);
      END_STATE();
    case 55:
      if (lookahead == 'L') ADVANCE(173);
      END_STATE();
    case 56:
      if (lookahead == 'L') ADVANCE(174);
      if (lookahead == 'P') ADVANCE(280);
      END_STATE();
    case 57:
      if (lookahead == 'L') ADVANCE(175);
      if (lookahead == 'P') ADVANCE(282);
      END_STATE();
    case 58:
      if (lookahead == 'S') ADVANCE(336);
      END_STATE();
    case 59:
      if (lookahead == 'a') ADVANCE(157);
      END_STATE();
    case 60:
      if (lookahead == 'a') ADVANCE(465);
      END_STATE();
    case 61:
      if (lookahead == 'a') ADVANCE(88);
      if (lookahead == 'o') ADVANCE(288);
      if (lookahead == 'y') ADVANCE(194);
      END_STATE();
    case 62:
      if (lookahead == 'a') ADVANCE(342);
      END_STATE();
    case 63:
      if (lookahead == 'a') ADVANCE(317);
      END_STATE();
    case 64:
      if (lookahead == 'a') ADVANCE(172);
      END_STATE();
    case 65:
      if (lookahead == 'a') ADVANCE(295);
      END_STATE();
    case 66:
      if (lookahead == 'a') ADVANCE(188);
      END_STATE();
    case 67:
      if (lookahead == 'a') ADVANCE(318);
      if (lookahead == 'l') ADVANCE(65);
      if (lookahead == 'o') ADVANCE(219);
      END_STATE();
    case 68:
      if (lookahead == 'a') ADVANCE(90);
      END_STATE();
    case 69:
      if (lookahead == 'a') ADVANCE(337);
      if (lookahead == 'r') ADVANCE(168);
      END_STATE();
    case 70:
      if (lookahead == 'a') ADVANCE(271);
      END_STATE();
    case 71:
      if (lookahead == 'a') ADVANCE(327);
      END_STATE();
    case 72:
      if (lookahead == 'a') ADVANCE(158);
      END_STATE();
    case 73:
      if (lookahead == 'a') ADVANCE(83);
      END_STATE();
    case 74:
      if (lookahead == 'a') ADVANCE(236);
      END_STATE();
    case 75:
      if (lookahead == 'a') ADVANCE(97);
      END_STATE();
    case 76:
      if (lookahead == 'a') ADVANCE(94);
      END_STATE();
    case 77:
      if (lookahead == 'a') ADVANCE(333);
      END_STATE();
    case 78:
      if (lookahead == 'a') ADVANCE(159);
      END_STATE();
    case 79:
      if (lookahead == 'b') ADVANCE(182);
      END_STATE();
    case 80:
      if (lookahead == 'b') ADVANCE(300);
      if (lookahead == 'n') ADVANCE(355);
      if (lookahead == 's') ADVANCE(395);
      if (lookahead == 'w') ADVANCE(64);
      END_STATE();
    case 81:
      if (lookahead == 'b') ADVANCE(300);
      if (lookahead == 's') ADVANCE(395);
      END_STATE();
    case 82:
      if (lookahead == 'b') ADVANCE(193);
      END_STATE();
    case 83:
      if (lookahead == 'b') ADVANCE(199);
      END_STATE();
    case 84:
      if (lookahead == 'c') ADVANCE(958);
      END_STATE();
    case 85:
      if (lookahead == 'c') ADVANCE(443);
      END_STATE();
    case 86:
      if (lookahead == 'c') ADVANCE(447);
      END_STATE();
    case 87:
      if (lookahead == 'c') ADVANCE(160);
      END_STATE();
    case 88:
      if (lookahead == 'c') ADVANCE(184);
      if (lookahead == 't') ADVANCE(115);
      END_STATE();
    case 89:
      if (lookahead == 'c') ADVANCE(161);
      END_STATE();
    case 90:
      if (lookahead == 'c') ADVANCE(162);
      END_STATE();
    case 91:
      if (lookahead == 'c') ADVANCE(66);
      END_STATE();
    case 92:
      if (lookahead == 'c') ADVANCE(308);
      END_STATE();
    case 93:
      if (lookahead == 'c') ADVANCE(311);
      END_STATE();
    case 94:
      if (lookahead == 'c') ADVANCE(313);
      END_STATE();
    case 95:
      if (lookahead == 'c') ADVANCE(326);
      END_STATE();
    case 96:
      if (lookahead == 'c') ADVANCE(139);
      END_STATE();
    case 97:
      if (lookahead == 'c') ADVANCE(123);
      END_STATE();
    case 98:
      if (lookahead == 'c') ADVANCE(278);
      if (lookahead == 't') ADVANCE(61);
      END_STATE();
    case 99:
      if (lookahead == 'c') ADVANCE(334);
      END_STATE();
    case 100:
      if (lookahead == 'd') ADVANCE(475);
      END_STATE();
    case 101:
      if (lookahead == 'd') ADVANCE(419);
      END_STATE();
    case 102:
      if (lookahead == 'd') ADVANCE(435);
      END_STATE();
    case 103:
      if (lookahead == 'd') ADVANCE(445);
      END_STATE();
    case 104:
      if (lookahead == 'd') ADVANCE(947);
      END_STATE();
    case 105:
      if (lookahead == 'd') ADVANCE(421);
      END_STATE();
    case 106:
      if (lookahead == 'd') ADVANCE(292);
      END_STATE();
    case 107:
      if (lookahead == 'd') ADVANCE(113);
      END_STATE();
    case 108:
      if (lookahead == 'd') ADVANCE(141);
      END_STATE();
    case 109:
      if (lookahead == 'd') ADVANCE(119);
      END_STATE();
    case 110:
      if (lookahead == 'e') ADVANCE(352);
      END_STATE();
    case 111:
      if (lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 112:
      if (lookahead == 'e') ADVANCE(956);
      END_STATE();
    case 113:
      if (lookahead == 'e') ADVANCE(155);
      END_STATE();
    case 114:
      if (lookahead == 'e') ADVANCE(461);
      END_STATE();
    case 115:
      if (lookahead == 'e') ADVANCE(405);
      END_STATE();
    case 116:
      if (lookahead == 'e') ADVANCE(974);
      END_STATE();
    case 117:
      if (lookahead == 'e') ADVANCE(924);
      END_STATE();
    case 118:
      if (lookahead == 'e') ADVANCE(413);
      END_STATE();
    case 119:
      if (lookahead == 'e') ADVANCE(411);
      END_STATE();
    case 120:
      if (lookahead == 'e') ADVANCE(56);
      END_STATE();
    case 121:
      if (lookahead == 'e') ADVANCE(441);
      END_STATE();
    case 122:
      if (lookahead == 'e') ADVANCE(977);
      END_STATE();
    case 123:
      if (lookahead == 'e') ADVANCE(980);
      END_STATE();
    case 124:
      if (lookahead == 'e') ADVANCE(981);
      END_STATE();
    case 125:
      if (lookahead == 'e') ADVANCE(351);
      END_STATE();
    case 126:
      if (lookahead == 'e') ADVANCE(53);
      END_STATE();
    case 127:
      if (lookahead == 'e') ADVANCE(228);
      END_STATE();
    case 128:
      if (lookahead == 'e') ADVANCE(92);
      END_STATE();
    case 129:
      if (lookahead == 'e') ADVANCE(231);
      END_STATE();
    case 130:
      if (lookahead == 'e') ADVANCE(206);
      END_STATE();
    case 131:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 132:
      if (lookahead == 'e') ADVANCE(275);
      END_STATE();
    case 133:
      if (lookahead == 'e') ADVANCE(207);
      END_STATE();
    case 134:
      if (lookahead == 'e') ADVANCE(303);
      END_STATE();
    case 135:
      if (lookahead == 'e') ADVANCE(291);
      END_STATE();
    case 136:
      if (lookahead == 'e') ADVANCE(103);
      END_STATE();
    case 137:
      if (lookahead == 'e') ADVANCE(99);
      END_STATE();
    case 138:
      if (lookahead == 'e') ADVANCE(104);
      END_STATE();
    case 139:
      if (lookahead == 'e') ADVANCE(247);
      END_STATE();
    case 140:
      if (lookahead == 'e') ADVANCE(276);
      END_STATE();
    case 141:
      if (lookahead == 'e') ADVANCE(270);
      END_STATE();
    case 142:
      if (lookahead == 'e') ADVANCE(238);
      END_STATE();
    case 143:
      if (lookahead == 'e') ADVANCE(60);
      END_STATE();
    case 144:
      if (lookahead == 'e') ADVANCE(235);
      END_STATE();
    case 145:
      if (lookahead == 'e') ADVANCE(152);
      END_STATE();
    case 146:
      if (lookahead == 'e') ADVANCE(215);
      END_STATE();
    case 147:
      if (lookahead == 'e') ADVANCE(239);
      END_STATE();
    case 148:
      if (lookahead == 'e') ADVANCE(330);
      END_STATE();
    case 149:
      if (lookahead == 'e') ADVANCE(57);
      END_STATE();
    case 150:
      if (lookahead == 'f') ADVANCE(954);
      if (lookahead == 'm') ADVANCE(265);
      if (lookahead == 'n') ADVANCE(905);
      END_STATE();
    case 151:
      if (lookahead == 'f') ADVANCE(901);
      END_STATE();
    case 152:
      if (lookahead == 'f') ADVANCE(62);
      END_STATE();
    case 153:
      if (lookahead == 'f') ADVANCE(62);
      if (lookahead == 'l') ADVANCE(148);
      END_STATE();
    case 154:
      if (lookahead == 'f') ADVANCE(75);
      END_STATE();
    case 155:
      if (lookahead == 'f') ADVANCE(179);
      END_STATE();
    case 156:
      if (lookahead == 'g') ADVANCE(942);
      END_STATE();
    case 157:
      if (lookahead == 'g') ADVANCE(114);
      END_STATE();
    case 158:
      if (lookahead == 'g') ADVANCE(120);
      END_STATE();
    case 159:
      if (lookahead == 'g') ADVANCE(149);
      END_STATE();
    case 160:
      if (lookahead == 'h') ADVANCE(423);
      END_STATE();
    case 161:
      if (lookahead == 'h') ADVANCE(969);
      END_STATE();
    case 162:
      if (lookahead == 'h') ADVANCE(489);
      END_STATE();
    case 163:
      if (lookahead == 'h') ADVANCE(178);
      END_STATE();
    case 164:
      if (lookahead == 'i') ADVANCE(218);
      if (lookahead == 'o') ADVANCE(91);
      END_STATE();
    case 165:
      if (lookahead == 'i') ADVANCE(201);
      if (lookahead == 't') ADVANCE(321);
      END_STATE();
    case 166:
      if (lookahead == 'i') ADVANCE(348);
      if (lookahead == 'o') ADVANCE(329);
      END_STATE();
    case 167:
      if (lookahead == 'i') ADVANCE(100);
      END_STATE();
    case 168:
      if (lookahead == 'i') ADVANCE(226);
      if (lookahead == 'u') ADVANCE(93);
      END_STATE();
    case 169:
      if (lookahead == 'i') ADVANCE(85);
      END_STATE();
    case 170:
      if (lookahead == 'i') ADVANCE(86);
      END_STATE();
    case 171:
      if (lookahead == 'i') ADVANCE(230);
      END_STATE();
    case 172:
      if (lookahead == 'i') ADVANCE(306);
      END_STATE();
    case 173:
      if (lookahead == 'i') ADVANCE(229);
      END_STATE();
    case 174:
      if (lookahead == 'i') ADVANCE(232);
      END_STATE();
    case 175:
      if (lookahead == 'i') ADVANCE(234);
      END_STATE();
    case 176:
      if (lookahead == 'i') ADVANCE(213);
      END_STATE();
    case 177:
      if (lookahead == 'i') ADVANCE(299);
      END_STATE();
    case 178:
      if (lookahead == 'i') ADVANCE(197);
      END_STATE();
    case 179:
      if (lookahead == 'i') ADVANCE(240);
      END_STATE();
    case 180:
      if (lookahead == 'i') ADVANCE(109);
      END_STATE();
    case 181:
      if (lookahead == 'i') ADVANCE(256);
      END_STATE();
    case 182:
      if (lookahead == 'j') ADVANCE(128);
      if (lookahead == 's') ADVANCE(132);
      END_STATE();
    case 183:
      if (lookahead == 'k') ADVANCE(409);
      END_STATE();
    case 184:
      if (lookahead == 'k') ADVANCE(471);
      END_STATE();
    case 185:
      if (lookahead == 'k') ADVANCE(433);
      END_STATE();
    case 186:
      if (lookahead == 'k') ADVANCE(425);
      END_STATE();
    case 187:
      if (lookahead == 'k') ADVANCE(429);
      END_STATE();
    case 188:
      if (lookahead == 'l') ADVANCE(58);
      END_STATE();
    case 189:
      if (lookahead == 'l') ADVANCE(479);
      END_STATE();
    case 190:
      if (lookahead == 'l') ADVANCE(296);
      if (lookahead == 'n') ADVANCE(339);
      if (lookahead == 'x') ADVANCE(263);
      END_STATE();
    case 191:
      if (lookahead == 'l') ADVANCE(65);
      if (lookahead == 'o') ADVANCE(241);
      END_STATE();
    case 192:
      if (lookahead == 'l') ADVANCE(202);
      END_STATE();
    case 193:
      if (lookahead == 'l') ADVANCE(169);
      END_STATE();
    case 194:
      if (lookahead == 'l') ADVANCE(135);
      END_STATE();
    case 195:
      if (lookahead == 'l') ADVANCE(146);
      END_STATE();
    case 196:
      if (lookahead == 'l') ADVANCE(146);
      if (lookahead == 'o') ADVANCE(286);
      END_STATE();
    case 197:
      if (lookahead == 'l') ADVANCE(116);
      END_STATE();
    case 198:
      if (lookahead == 'l') ADVANCE(312);
      END_STATE();
    case 199:
      if (lookahead == 'l') ADVANCE(126);
      END_STATE();
    case 200:
      if (lookahead == 'l') ADVANCE(125);
      if (lookahead == 'o') ADVANCE(269);
      END_STATE();
    case 201:
      if (lookahead == 'l') ADVANCE(108);
      END_STATE();
    case 202:
      if (lookahead == 'l') ADVANCE(54);
      END_STATE();
    case 203:
      if (lookahead == 'l') ADVANCE(340);
      if (lookahead == 'm') ADVANCE(266);
      if (lookahead == 'n') ADVANCE(301);
      END_STATE();
    case 204:
      if (lookahead == 'm') ADVANCE(265);
      if (lookahead == 'n') ADVANCE(905);
      END_STATE();
    case 205:
      if (lookahead == 'm') ADVANCE(982);
      END_STATE();
    case 206:
      if (lookahead == 'm') ADVANCE(487);
      END_STATE();
    case 207:
      if (lookahead == 'm') ADVANCE(485);
      END_STATE();
    case 208:
      if (lookahead == 'm') ADVANCE(386);
      END_STATE();
    case 209:
      if (lookahead == 'm') ADVANCE(59);
      END_STATE();
    case 210:
      if (lookahead == 'm') ADVANCE(267);
      END_STATE();
    case 211:
      if (lookahead == 'm') ADVANCE(221);
      END_STATE();
    case 212:
      if (lookahead == 'm') ADVANCE(118);
      END_STATE();
    case 213:
      if (lookahead == 'm') ADVANCE(71);
      END_STATE();
    case 214:
      if (lookahead == 'm') ADVANCE(268);
      if (lookahead == 'n') ADVANCE(905);
      END_STATE();
    case 215:
      if (lookahead == 'm') ADVANCE(147);
      END_STATE();
    case 216:
      if (lookahead == 'n') ADVANCE(176);
      END_STATE();
    case 217:
      if (lookahead == 'n') ADVANCE(107);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(366);
      END_STATE();
    case 218:
      if (lookahead == 'n') ADVANCE(183);
      if (lookahead == 's') ADVANCE(304);
      END_STATE();
    case 219:
      if (lookahead == 'n') ADVANCE(298);
      END_STATE();
    case 220:
      if (lookahead == 'n') ADVANCE(459);
      END_STATE();
    case 221:
      if (lookahead == 'n') ADVANCE(467);
      END_STATE();
    case 222:
      if (lookahead == 'n') ADVANCE(990);
      END_STATE();
    case 223:
      if (lookahead == 'n') ADVANCE(904);
      END_STATE();
    case 224:
      if (lookahead == 'n') ADVANCE(339);
      if (lookahead == 'x') ADVANCE(263);
      END_STATE();
    case 225:
      if (lookahead == 'n') ADVANCE(319);
      if (lookahead == 'x') ADVANCE(320);
      END_STATE();
    case 226:
      if (lookahead == 'n') ADVANCE(156);
      END_STATE();
    case 227:
      if (lookahead == 'n') ADVANCE(262);
      END_STATE();
    case 228:
      if (lookahead == 'n') ADVANCE(101);
      END_STATE();
    case 229:
      if (lookahead == 'n') ADVANCE(185);
      END_STATE();
    case 230:
      if (lookahead == 'n') ADVANCE(344);
      END_STATE();
    case 231:
      if (lookahead == 'n') ADVANCE(106);
      END_STATE();
    case 232:
      if (lookahead == 'n') ADVANCE(186);
      END_STATE();
    case 233:
      if (lookahead == 'n') ADVANCE(84);
      END_STATE();
    case 234:
      if (lookahead == 'n') ADVANCE(187);
      END_STATE();
    case 235:
      if (lookahead == 'n') ADVANCE(105);
      END_STATE();
    case 236:
      if (lookahead == 'n') ADVANCE(96);
      END_STATE();
    case 237:
      if (lookahead == 'n') ADVANCE(142);
      END_STATE();
    case 238:
      if (lookahead == 'n') ADVANCE(314);
      END_STATE();
    case 239:
      if (lookahead == 'n') ADVANCE(325);
      END_STATE();
    case 240:
      if (lookahead == 'n') ADVANCE(138);
      END_STATE();
    case 241:
      if (lookahead == 'n') ADVANCE(297);
      END_STATE();
    case 242:
      if (lookahead == 'n') ADVANCE(95);
      END_STATE();
    case 243:
      if (lookahead == 'o') ADVANCE(203);
      END_STATE();
    case 244:
      if (lookahead == 'o') ADVANCE(349);
      END_STATE();
    case 245:
      if (lookahead == 'o') ADVANCE(259);
      END_STATE();
    case 246:
      if (lookahead == 'o') ADVANCE(350);
      END_STATE();
    case 247:
      if (lookahead == 'o') ADVANCE(151);
      END_STATE();
    case 248:
      if (lookahead == 'o') ADVANCE(260);
      END_STATE();
    case 249:
      if (lookahead == 'o') ADVANCE(261);
      END_STATE();
    case 250:
      if (lookahead == 'o') ADVANCE(192);
      END_STATE();
    case 251:
      if (lookahead == 'o') ADVANCE(220);
      END_STATE();
    case 252:
      if (lookahead == 'o') ADVANCE(208);
      END_STATE();
    case 253:
      if (lookahead == 'o') ADVANCE(285);
      END_STATE();
    case 254:
      if (lookahead == 'o') ADVANCE(189);
      END_STATE();
    case 255:
      if (lookahead == 'o') ADVANCE(237);
      END_STATE();
    case 256:
      if (lookahead == 'o') ADVANCE(222);
      END_STATE();
    case 257:
      if (lookahead == 'o') ADVANCE(286);
      END_STATE();
    case 258:
      if (lookahead == 'o') ADVANCE(289);
      END_STATE();
    case 259:
      if (lookahead == 'p') ADVANCE(407);
      if (lookahead == 'v') ADVANCE(180);
      END_STATE();
    case 260:
      if (lookahead == 'p') ADVANCE(427);
      END_STATE();
    case 261:
      if (lookahead == 'p') ADVANCE(431);
      END_STATE();
    case 262:
      if (lookahead == 'p') ADVANCE(343);
      END_STATE();
    case 263:
      if (lookahead == 'p') ADVANCE(253);
      if (lookahead == 't') ADVANCE(129);
      END_STATE();
    case 264:
      if (lookahead == 'p') ADVANCE(124);
      END_STATE();
    case 265:
      if (lookahead == 'p') ADVANCE(196);
      END_STATE();
    case 266:
      if (lookahead == 'p') ADVANCE(255);
      END_STATE();
    case 267:
      if (lookahead == 'p') ADVANCE(195);
      END_STATE();
    case 268:
      if (lookahead == 'p') ADVANCE(257);
      END_STATE();
    case 269:
      if (lookahead == 'r') ADVANCE(52);
      END_STATE();
    case 270:
      if (lookahead == 'r') ADVANCE(415);
      END_STATE();
    case 271:
      if (lookahead == 'r') ADVANCE(961);
      END_STATE();
    case 272:
      if (lookahead == 'r') ADVANCE(166);
      if (lookahead == 'u') ADVANCE(82);
      END_STATE();
    case 273:
      if (lookahead == 'r') ADVANCE(167);
      END_STATE();
    case 274:
      if (lookahead == 'r') ADVANCE(356);
      END_STATE();
    case 275:
      if (lookahead == 'r') ADVANCE(347);
      END_STATE();
    case 276:
      if (lookahead == 'r') ADVANCE(154);
      END_STATE();
    case 277:
      if (lookahead == 'r') ADVANCE(245);
      END_STATE();
    case 278:
      if (lookahead == 'r') ADVANCE(250);
      END_STATE();
    case 279:
      if (lookahead == 'r') ADVANCE(345);
      END_STATE();
    case 280:
      if (lookahead == 'r') ADVANCE(248);
      END_STATE();
    case 281:
      if (lookahead == 'r') ADVANCE(76);
      END_STATE();
    case 282:
      if (lookahead == 'r') ADVANCE(249);
      END_STATE();
    case 283:
      if (lookahead == 'r') ADVANCE(252);
      END_STATE();
    case 284:
      if (lookahead == 'r') ADVANCE(252);
      if (lookahead == 'u') ADVANCE(242);
      END_STATE();
    case 285:
      if (lookahead == 'r') ADVANCE(309);
      END_STATE();
    case 286:
      if (lookahead == 'r') ADVANCE(310);
      END_STATE();
    case 287:
      if (lookahead == 'r') ADVANCE(143);
      END_STATE();
    case 288:
      if (lookahead == 'r') ADVANCE(72);
      END_STATE();
    case 289:
      if (lookahead == 'r') ADVANCE(78);
      END_STATE();
    case 290:
      if (lookahead == 's') ADVANCE(986);
      END_STATE();
    case 291:
      if (lookahead == 's') ADVANCE(417);
      END_STATE();
    case 292:
      if (lookahead == 's') ADVANCE(952);
      END_STATE();
    case 293:
      if (lookahead == 's') ADVANCE(988);
      END_STATE();
    case 294:
      if (lookahead == 's') ADVANCE(393);
      END_STATE();
    case 295:
      if (lookahead == 's') ADVANCE(290);
      END_STATE();
    case 296:
      if (lookahead == 's') ADVANCE(112);
      END_STATE();
    case 297:
      if (lookahead == 's') ADVANCE(307);
      END_STATE();
    case 298:
      if (lookahead == 's') ADVANCE(307);
      if (lookahead == 't') ADVANCE(171);
      END_STATE();
    case 299:
      if (lookahead == 's') ADVANCE(316);
      END_STATE();
    case 300:
      if (lookahead == 's') ADVANCE(322);
      END_STATE();
    case 301:
      if (lookahead == 's') ADVANCE(341);
      END_STATE();
    case 302:
      if (lookahead == 't') ADVANCE(69);
      END_STATE();
    case 303:
      if (lookahead == 't') ADVANCE(963);
      END_STATE();
    case 304:
      if (lookahead == 't') ADVANCE(482);
      END_STATE();
    case 305:
      if (lookahead == 't') ADVANCE(458);
      END_STATE();
    case 306:
      if (lookahead == 't') ADVANCE(939);
      END_STATE();
    case 307:
      if (lookahead == 't') ADVANCE(965);
      END_STATE();
    case 308:
      if (lookahead == 't') ADVANCE(55);
      END_STATE();
    case 309:
      if (lookahead == 't') ADVANCE(397);
      END_STATE();
    case 310:
      if (lookahead == 't') ADVANCE(385);
      END_STATE();
    case 311:
      if (lookahead == 't') ADVANCE(439);
      END_STATE();
    case 312:
      if (lookahead == 't') ADVANCE(399);
      END_STATE();
    case 313:
      if (lookahead == 't') ADVANCE(984);
      END_STATE();
    case 314:
      if (lookahead == 't') ADVANCE(403);
      END_STATE();
    case 315:
      if (lookahead == 't') ADVANCE(463);
      END_STATE();
    case 316:
      if (lookahead == 't') ADVANCE(483);
      END_STATE();
    case 317:
      if (lookahead == 't') ADVANCE(87);
      END_STATE();
    case 318:
      if (lookahead == 't') ADVANCE(89);
      END_STATE();
    case 319:
      if (lookahead == 't') ADVANCE(274);
      END_STATE();
    case 320:
      if (lookahead == 't') ADVANCE(127);
      END_STATE();
    case 321:
      if (lookahead == 't') ADVANCE(251);
      END_STATE();
    case 322:
      if (lookahead == 't') ADVANCE(281);
      END_STATE();
    case 323:
      if (lookahead == 't') ADVANCE(129);
      END_STATE();
    case 324:
      if (lookahead == 't') ADVANCE(74);
      END_STATE();
    case 325:
      if (lookahead == 't') ADVANCE(293);
      END_STATE();
    case 326:
      if (lookahead == 't') ADVANCE(181);
      END_STATE();
    case 327:
      if (lookahead == 't') ADVANCE(73);
      END_STATE();
    case 328:
      if (lookahead == 't') ADVANCE(279);
      END_STATE();
    case 329:
      if (lookahead == 't') ADVANCE(137);
      END_STATE();
    case 330:
      if (lookahead == 't') ADVANCE(117);
      END_STATE();
    case 331:
      if (lookahead == 't') ADVANCE(130);
      END_STATE();
    case 332:
      if (lookahead == 't') ADVANCE(133);
      END_STATE();
    case 333:
      if (lookahead == 't') ADVANCE(121);
      END_STATE();
    case 334:
      if (lookahead == 't') ADVANCE(136);
      END_STATE();
    case 335:
      if (lookahead == 't') ADVANCE(144);
      END_STATE();
    case 336:
      if (lookahead == 't') ADVANCE(258);
      END_STATE();
    case 337:
      if (lookahead == 't') ADVANCE(170);
      END_STATE();
    case 338:
      if (lookahead == 'u') ADVANCE(165);
      END_STATE();
    case 339:
      if (lookahead == 'u') ADVANCE(205);
      END_STATE();
    case 340:
      if (lookahead == 'u') ADVANCE(211);
      END_STATE();
    case 341:
      if (lookahead == 'u') ADVANCE(212);
      END_STATE();
    case 342:
      if (lookahead == 'u') ADVANCE(198);
      END_STATE();
    case 343:
      if (lookahead == 'u') ADVANCE(315);
      END_STATE();
    case 344:
      if (lookahead == 'u') ADVANCE(122);
      END_STATE();
    case 345:
      if (lookahead == 'u') ADVANCE(93);
      END_STATE();
    case 346:
      if (lookahead == 'u') ADVANCE(242);
      END_STATE();
    case 347:
      if (lookahead == 'v') ADVANCE(131);
      END_STATE();
    case 348:
      if (lookahead == 'v') ADVANCE(77);
      END_STATE();
    case 349:
      if (lookahead == 'w') ADVANCE(469);
      END_STATE();
    case 350:
      if (lookahead == 'w') ADVANCE(477);
      END_STATE();
    case 351:
      if (lookahead == 'x') ADVANCE(473);
      END_STATE();
    case 352:
      if (lookahead == 'x') ADVANCE(305);
      END_STATE();
    case 353:
      if (lookahead == 'x') ADVANCE(335);
      END_STATE();
    case 354:
      if (lookahead == 'x') ADVANCE(323);
      END_STATE();
    case 355:
      if (lookahead == 'y') ADVANCE(945);
      END_STATE();
    case 356:
      if (lookahead == 'y') ADVANCE(401);
      END_STATE();
    case 357:
      if (lookahead == 'y') ADVANCE(264);
      END_STATE();
    case 358:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(360);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(876);
      END_STATE();
    case 359:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(875);
      END_STATE();
    case 360:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(876);
      END_STATE();
    case 361:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(869);
      END_STATE();
    case 362:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(870);
      END_STATE();
    case 363:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(361);
      END_STATE();
    case 364:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(362);
      END_STATE();
    case 365:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(366);
      END_STATE();
    case 366:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(364);
      END_STATE();
    case 367:
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(993);
      END_STATE();
    case 368:
      if (eof) ADVANCE(370);
      ADVANCE_MAP(
        '!', 50,
        '"', 856,
        '%', 917,
        '&', 888,
        '\'', 860,
        '(', 437,
        '*', 392,
        '+', 913,
        ',', 388,
        '-', 915,
        '.', 455,
        '/', 384,
        ':', 450,
        ';', 396,
        '<', 894,
        '=', 452,
        '>', 897,
        '?', 938,
        '@', 400,
        '[', 950,
        '^', 886,
        'a', 81,
        'c', 191,
        'd', 145,
        'e', 224,
        'f', 284,
        'i', 214,
        'l', 134,
        's', 328,
        't', 357,
        'v', 70,
        '{', 387,
        '|', 883,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(368);
      END_STATE();
    case 369:
      if (eof) ADVANCE(370);
      ADVANCE_MAP(
        '!', 50,
        '%', 916,
        '&', 887,
        '(', 437,
        ')', 438,
        '*', 391,
        '+', 912,
        ',', 388,
        '-', 914,
        '.', 455,
        '/', 383,
        ':', 450,
        ';', 396,
        '<', 895,
        '=', 452,
        '>', 898,
        '?', 938,
        '@', 400,
        '[', 950,
        ']', 951,
        '^', 885,
        'a', 81,
        'c', 191,
        'e', 224,
        'f', 346,
        'i', 204,
        'l', 134,
        's', 328,
        't', 357,
        'v', 70,
        '{', 387,
        '|', 884,
        '}', 389,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(369);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead == '*') ADVANCE(382);
      if (lookahead != 0) ADVANCE(39);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead != 0 &&
          lookahead != '$' &&
          lookahead != '\\' &&
          lookahead != '`') ADVANCE(996);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(anon_sym_SLASH_SLASH);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(377);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead == '*') ADVANCE(381);
      if (lookahead == '/') ADVANCE(374);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(377);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead == '/') ADVANCE(375);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(376);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(377);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(aux_sym_comment_token1);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(377);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(anon_sym_SLASH_STAR);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(anon_sym_SLASH_STAR);
      if (lookahead == '*') ADVANCE(382);
      if (lookahead != 0 &&
          lookahead != '/') ADVANCE(39);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(anon_sym_SLASH_STAR);
      if (lookahead != 0 &&
          lookahead != '$' &&
          lookahead != '\\' &&
          lookahead != '`') ADVANCE(996);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(anon_sym_SLASH_STAR);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(377);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(aux_sym_comment_token2);
      if (lookahead == '*') ADVANCE(382);
      if (lookahead != 0 &&
          lookahead != '/') ADVANCE(39);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(378);
      if (lookahead == '/') ADVANCE(371);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '*') ADVANCE(378);
      if (lookahead == '/') ADVANCE(371);
      if (lookahead == '=') ADVANCE(929);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(anon_sym_import);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(anon_sym_from);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(918);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(918);
      if (lookahead == '=') ADVANCE(928);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(anon_sym_as);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 'y') ADVANCE(685);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 'y') ADVANCE(233);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(anon_sym_export);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(anon_sym_export);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(anon_sym_Entry);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(anon_sym_Entry);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(anon_sym_Component);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(anon_sym_Component);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(anon_sym_State);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(anon_sym_State);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(anon_sym_Prop);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(anon_sym_Prop);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(anon_sym_Link);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(anon_sym_Link);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(anon_sym_Provide);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(anon_sym_Provide);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(anon_sym_Consume);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(anon_sym_Consume);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(anon_sym_Builder);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(anon_sym_Builder);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(anon_sym_Styles);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(anon_sym_Styles);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(anon_sym_Extend);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(anon_sym_Extend);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(anon_sym_AnimatableExtend);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(anon_sym_AnimatableExtend);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(anon_sym_Watch);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(anon_sym_Watch);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 425:
      ACCEPT_TOKEN(anon_sym_StorageLink);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(anon_sym_StorageLink);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 427:
      ACCEPT_TOKEN(anon_sym_StorageProp);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(anon_sym_StorageProp);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(anon_sym_LocalStorageLink);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(anon_sym_LocalStorageLink);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(anon_sym_LocalStorageProp);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(anon_sym_LocalStorageProp);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 433:
      ACCEPT_TOKEN(anon_sym_ObjectLink);
      END_STATE();
    case 434:
      ACCEPT_TOKEN(anon_sym_ObjectLink);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 435:
      ACCEPT_TOKEN(anon_sym_Observed);
      END_STATE();
    case 436:
      ACCEPT_TOKEN(anon_sym_Observed);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 437:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 438:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 439:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 440:
      ACCEPT_TOKEN(anon_sym_struct);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 441:
      ACCEPT_TOKEN(anon_sym_private);
      END_STATE();
    case 442:
      ACCEPT_TOKEN(anon_sym_private);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 443:
      ACCEPT_TOKEN(anon_sym_public);
      END_STATE();
    case 444:
      ACCEPT_TOKEN(anon_sym_public);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 445:
      ACCEPT_TOKEN(anon_sym_protected);
      END_STATE();
    case 446:
      ACCEPT_TOKEN(anon_sym_protected);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 447:
      ACCEPT_TOKEN(anon_sym_static);
      END_STATE();
    case 448:
      ACCEPT_TOKEN(anon_sym_static);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 449:
      ACCEPT_TOKEN(anon_sym_readonly);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 450:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 451:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 452:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(889);
      if (lookahead == '>') ADVANCE(949);
      END_STATE();
    case 453:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '>') ADVANCE(949);
      END_STATE();
    case 454:
      ACCEPT_TOKEN(anon_sym_build);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 455:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 456:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(42);
      END_STATE();
    case 457:
      ACCEPT_TOKEN(anon_sym_Text);
      if (lookahead == 'A') ADVANCE(757);
      if (lookahead == 'I') ADVANCE(683);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('B' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 458:
      ACCEPT_TOKEN(anon_sym_Text);
      if (lookahead == 'A') ADVANCE(287);
      if (lookahead == 'I') ADVANCE(227);
      END_STATE();
    case 459:
      ACCEPT_TOKEN(anon_sym_Button);
      END_STATE();
    case 460:
      ACCEPT_TOKEN(anon_sym_Button);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 461:
      ACCEPT_TOKEN(anon_sym_Image);
      END_STATE();
    case 462:
      ACCEPT_TOKEN(anon_sym_Image);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 463:
      ACCEPT_TOKEN(anon_sym_TextInput);
      END_STATE();
    case 464:
      ACCEPT_TOKEN(anon_sym_TextInput);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 465:
      ACCEPT_TOKEN(anon_sym_TextArea);
      END_STATE();
    case 466:
      ACCEPT_TOKEN(anon_sym_TextArea);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 467:
      ACCEPT_TOKEN(anon_sym_Column);
      END_STATE();
    case 468:
      ACCEPT_TOKEN(anon_sym_Column);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 469:
      ACCEPT_TOKEN(anon_sym_Row);
      END_STATE();
    case 470:
      ACCEPT_TOKEN(anon_sym_Row);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 471:
      ACCEPT_TOKEN(anon_sym_Stack);
      END_STATE();
    case 472:
      ACCEPT_TOKEN(anon_sym_Stack);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 473:
      ACCEPT_TOKEN(anon_sym_Flex);
      END_STATE();
    case 474:
      ACCEPT_TOKEN(anon_sym_Flex);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 475:
      ACCEPT_TOKEN(anon_sym_Grid);
      if (lookahead == 'C') ADVANCE(254);
      if (lookahead == 'I') ADVANCE(331);
      if (lookahead == 'R') ADVANCE(246);
      END_STATE();
    case 476:
      ACCEPT_TOKEN(anon_sym_Grid);
      if (lookahead == 'C') ADVANCE(722);
      if (lookahead == 'I') ADVANCE(807);
      if (lookahead == 'R') ADVANCE(716);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 477:
      ACCEPT_TOKEN(anon_sym_GridRow);
      END_STATE();
    case 478:
      ACCEPT_TOKEN(anon_sym_GridRow);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 479:
      ACCEPT_TOKEN(anon_sym_GridCol);
      END_STATE();
    case 480:
      ACCEPT_TOKEN(anon_sym_GridCol);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 481:
      ACCEPT_TOKEN(anon_sym_List);
      if (lookahead == 'I') ADVANCE(809);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 482:
      ACCEPT_TOKEN(anon_sym_List);
      if (lookahead == 'I') ADVANCE(332);
      END_STATE();
    case 483:
      ACCEPT_TOKEN(anon_sym_ScrollList);
      END_STATE();
    case 484:
      ACCEPT_TOKEN(anon_sym_ScrollList);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 485:
      ACCEPT_TOKEN(anon_sym_ListItem);
      END_STATE();
    case 486:
      ACCEPT_TOKEN(anon_sym_ListItem);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 487:
      ACCEPT_TOKEN(anon_sym_GridItem);
      END_STATE();
    case 488:
      ACCEPT_TOKEN(anon_sym_GridItem);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 489:
      ACCEPT_TOKEN(anon_sym_ForEach);
      END_STATE();
    case 490:
      ACCEPT_TOKEN(anon_sym_ForEach);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 491:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E') ADVANCE(506);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 492:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'E') ADVANCE(849);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 493:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(631);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 494:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(632);
      if (lookahead == 'P') ADVANCE(759);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 495:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(633);
      if (lookahead == 'P') ADVANCE(761);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 496:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'L') ADVANCE(635);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 497:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'S') ADVANCE(820);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 498:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(609);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 499:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(530);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 500:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(466);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 501:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(640);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 502:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(649);
      if (lookahead == 'i') ADVANCE(705);
      if (lookahead == 'o') ADVANCE(742);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 503:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(649);
      if (lookahead == 'o') ADVANCE(742);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 504:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(649);
      if (lookahead == 'u') ADVANCE(693);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 505:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(649);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 506:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(532);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 507:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(529);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 508:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(621);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 509:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(775);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 510:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(743);
      if (lookahead == 'o') ADVANCE(619);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 511:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(558);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 512:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(681);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 513:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(648);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 514:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(802);
      if (lookahead == 'o') ADVANCE(679);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 515:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(804);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 516:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(811);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 517:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(810);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 518:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(610);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 519:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(691);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 520:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(657);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 521:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(541);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 522:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(813);
      if (lookahead == 'o') ADVANCE(764);
      if (lookahead == 'y') ADVANCE(663);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 523:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(815);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 524:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'a') ADVANCE(611);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 525:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'b') ADVANCE(638);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'b') ADVANCE(660);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'b') ADVANCE(587);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'b') ADVANCE(781);
      if (lookahead == 's') ADVANCE(850);
      if (lookahead == 'w') ADVANCE(508);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'b') ADVANCE(664);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(639);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(959);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(612);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(444);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(448);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(763);
      if (lookahead == 't') ADVANCE(499);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(613);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(614);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(582);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(803);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(792);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(793);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(796);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(513);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(816);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'c') ADVANCE(821);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(476);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(923);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(948);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(420);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(436);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(422);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(454);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(446);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(769);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(579);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(595);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(568);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'd') ADVANCE(727);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(877);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(462);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(878);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(925);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(957);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(975);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(978);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(406);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(414);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(412);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(494);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(442);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(845);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(651);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(842);
      if (lookahead == 'u') ADVANCE(653);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(842);
      if (lookahead == 'u') ADVANCE(654);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(492);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(688);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(669);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(670);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(607);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(711);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(548);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(714);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(500);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(773);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(550);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(501);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(744);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(512);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(544);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(789);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(798);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(553);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(511);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(745);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(746);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(703);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(848);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(805);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(695);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(698);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(542);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(495);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(955);
      if (lookahead == 'n') ADVANCE(903);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(955);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(922);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(902);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'f') ADVANCE(627);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(943);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(560);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(569);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'g') ADVANCE(602);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(490);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(970);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(424);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(636);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(755);
      if (lookahead == 'r') ADVANCE(828);
      if (lookahead == 'y') ADVANCE(737);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(774);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(546);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(547);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(839);
      if (lookahead == 'o') ADVANCE(814);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(786);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(706);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(684);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(668);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(533);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(534);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(702);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(724);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(659);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(689);
      if (lookahead == 'o') ADVANCE(543);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(692);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(694);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(696);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(676);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(778);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(661);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'i') ADVANCE(557);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'j') ADVANCE(601);
      if (lookahead == 's') ADVANCE(594);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'k') ADVANCE(472);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'k') ADVANCE(976);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'k') ADVANCE(410);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'k') ADVANCE(434);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'k') ADVANCE(426);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'k') ADVANCE(430);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(879);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(496);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(480);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(497);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(777);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(826);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(598);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(852);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(645);
      if (lookahead == 'm') ADVANCE(527);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(645);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(854);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(646);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(652);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(509);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(552);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(625);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(564);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(588);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(584);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(575);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(571);
      if (lookahead == 'o') ADVANCE(741);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(782);
      if (lookahead == 'x') ADVANCE(800);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(782);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'l') ADVANCE(556);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(488);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(486);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(983);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(498);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(678);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(567);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(739);
      if (lookahead == 'n') ADVANCE(776);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 676:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'm') ADVANCE(516);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(460);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(468);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(779);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(967);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(944);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 682:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(991);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 683:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(740);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 684:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(608);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(531);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(851);
      if (lookahead == 's') ADVANCE(850);
      if (lookahead == 'w') ADVANCE(508);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(851);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 688:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(554);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(641);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(555);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 691:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(538);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 692:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(642);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 693:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(539);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 694:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(643);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 695:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(549);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 696:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(644);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(634);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(551);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(830);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(655);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 701:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(812);
      if (lookahead == 'x') ADVANCE(818);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 702:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(581);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 703:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(795);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 704:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(596);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(520);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(835);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(780);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 708:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'n') ADVANCE(783);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 709:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(650);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 710:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(841);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 711:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(605);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 712:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(675);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 713:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(734);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 714:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(606);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 715:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(619);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 716:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(843);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(677);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 718:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(844);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(735);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 720:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(736);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 721:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(679);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(647);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 723:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(762);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 724:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(682);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 725:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(707);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 726:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(747);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 727:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(700);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 728:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(656);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 729:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(704);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(662);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 731:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(730);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 732:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(708);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 733:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(767);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 734:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(408);
      if (lookahead == 'v') ADVANCE(637);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 735:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(428);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 736:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(432);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 737:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(580);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 738:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(723);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 739:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(729);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 740:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'p') ADVANCE(832);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 741:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(491);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 742:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(973);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 743:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(962);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 744:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(941);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 745:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(840);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 746:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(416);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 747:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(989);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 748:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(829);
      if (lookahead == 'y') ADVANCE(737);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 749:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(829);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 750:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(618);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 751:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(620);
      if (lookahead == 'u') ADVANCE(526);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 752:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(853);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 753:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(836);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 754:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(680);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 755:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(718);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 756:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(521);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 757:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(583);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 758:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(713);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 759:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(719);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 760:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(586);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 761:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(720);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 762:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(791);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 763:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(728);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 764:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(518);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 765:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(834);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(623);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 767:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(524);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 768:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(394);
      if (lookahead == 'w') ADVANCE(508);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 769:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(953);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 770:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(850);
      if (lookahead == 'w') ADVANCE(508);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 771:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(850);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 772:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(987);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 773:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(418);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 774:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(784);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 775:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(772);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 776:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(827);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 777:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(561);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 778:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(788);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 779:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(790);
      if (lookahead == 't') ADVANCE(622);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 780:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(790);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 781:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(808);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 782:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(563);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 783:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 's') ADVANCE(819);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 784:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(481);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 785:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(457);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 786:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(940);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 787:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(464);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 788:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(484);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 789:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(964);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 790:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(966);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 791:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(398);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 792:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(440);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 793:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(985);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 794:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(522);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 795:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(404);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 796:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(493);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 797:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(799);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 798:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(831);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 799:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(717);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 800:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(576);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 801:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(519);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 802:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(536);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 803:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(628);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 804:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(537);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 805:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(562);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 806:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(753);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 807:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(577);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 808:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(756);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 809:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(578);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 810:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(626);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 811:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(507);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 812:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(752);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 813:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(566);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 814:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(589);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 815:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(570);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 816:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(592);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 817:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(766);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 818:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(599);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 819:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(765);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 820:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(733);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 821:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(726);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 822:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(517);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 823:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(600);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 824:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(797);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 825:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(653);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 826:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(673);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 827:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(674);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 828:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(559);
      if (lookahead == 'y') ADVANCE(968);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 829:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(559);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 830:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(671);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 831:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(754);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 832:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(787);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 833:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(624);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 834:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(545);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 835:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(565);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 836:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(540);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 837:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(629);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 838:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'u') ADVANCE(693);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 839:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'v') ADVANCE(523);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 840:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'v') ADVANCE(585);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 841:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'w') ADVANCE(470);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 842:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'w') ADVANCE(1001);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 843:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'w') ADVANCE(478);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 844:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'w') ADVANCE(972);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 845:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'x') ADVANCE(474);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 846:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'x') ADVANCE(800);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 847:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'x') ADVANCE(738);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 848:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'x') ADVANCE(785);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 849:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'x') ADVANCE(823);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 850:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'y') ADVANCE(685);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 851:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'y') ADVANCE(946);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 852:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'y') ADVANCE(971);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 853:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'y') ADVANCE(402);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 854:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'y') ADVANCE(449);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 855:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 856:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 857:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      END_STATE();
    case 858:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '*') ADVANCE(378);
      if (lookahead == '/') ADVANCE(371);
      END_STATE();
    case 859:
      ACCEPT_TOKEN(aux_sym_string_literal_token1);
      if (lookahead == '/') ADVANCE(858);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(859);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(857);
      END_STATE();
    case 860:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 861:
      ACCEPT_TOKEN(aux_sym_string_literal_token2);
      END_STATE();
    case 862:
      ACCEPT_TOKEN(aux_sym_string_literal_token2);
      if (lookahead == '*') ADVANCE(378);
      if (lookahead == '/') ADVANCE(371);
      END_STATE();
    case 863:
      ACCEPT_TOKEN(aux_sym_string_literal_token2);
      if (lookahead == '/') ADVANCE(862);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(863);
      if (lookahead != 0 &&
          lookahead != '\'' &&
          lookahead != '\\') ADVANCE(861);
      END_STATE();
    case 864:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 865:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token1);
      END_STATE();
    case 866:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token2);
      END_STATE();
    case 867:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(866);
      END_STATE();
    case 868:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(867);
      END_STATE();
    case 869:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token3);
      END_STATE();
    case 870:
      ACCEPT_TOKEN(aux_sym_escape_sequence_token4);
      END_STATE();
    case 871:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 872:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == 'r') ADVANCE(997);
      END_STATE();
    case 873:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == 'r') ADVANCE(998);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 874:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == '.') ADVANCE(359);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(358);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(874);
      END_STATE();
    case 875:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(358);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(875);
      END_STATE();
    case 876:
      ACCEPT_TOKEN(sym_numeric_literal);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(876);
      END_STATE();
    case 877:
      ACCEPT_TOKEN(anon_sym_true);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 878:
      ACCEPT_TOKEN(anon_sym_false);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 879:
      ACCEPT_TOKEN(anon_sym_null);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 880:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 881:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 882:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 883:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '=') ADVANCE(932);
      if (lookahead == '|') ADVANCE(880);
      END_STATE();
    case 884:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(880);
      END_STATE();
    case 885:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 886:
      ACCEPT_TOKEN(anon_sym_CARET);
      if (lookahead == '=') ADVANCE(933);
      END_STATE();
    case 887:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(881);
      END_STATE();
    case 888:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(881);
      if (lookahead == '=') ADVANCE(931);
      END_STATE();
    case 889:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      if (lookahead == '=') ADVANCE(891);
      END_STATE();
    case 890:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      if (lookahead == '=') ADVANCE(892);
      END_STATE();
    case 891:
      ACCEPT_TOKEN(anon_sym_EQ_EQ_EQ);
      END_STATE();
    case 892:
      ACCEPT_TOKEN(anon_sym_BANG_EQ_EQ);
      END_STATE();
    case 893:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 894:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(907);
      if (lookahead == '=') ADVANCE(899);
      END_STATE();
    case 895:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '<') ADVANCE(906);
      if (lookahead == '=') ADVANCE(899);
      END_STATE();
    case 896:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 897:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(900);
      if (lookahead == '>') ADVANCE(908);
      END_STATE();
    case 898:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(900);
      if (lookahead == '>') ADVANCE(909);
      END_STATE();
    case 899:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 900:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 901:
      ACCEPT_TOKEN(anon_sym_instanceof);
      END_STATE();
    case 902:
      ACCEPT_TOKEN(anon_sym_instanceof);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 903:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 's') ADVANCE(801);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 904:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 's') ADVANCE(324);
      END_STATE();
    case 905:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 's') ADVANCE(324);
      if (lookahead == 't') ADVANCE(140);
      END_STATE();
    case 906:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      END_STATE();
    case 907:
      ACCEPT_TOKEN(anon_sym_LT_LT);
      if (lookahead == '=') ADVANCE(934);
      END_STATE();
    case 908:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '=') ADVANCE(935);
      if (lookahead == '>') ADVANCE(911);
      END_STATE();
    case 909:
      ACCEPT_TOKEN(anon_sym_GT_GT);
      if (lookahead == '>') ADVANCE(910);
      END_STATE();
    case 910:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      END_STATE();
    case 911:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT);
      if (lookahead == '=') ADVANCE(936);
      END_STATE();
    case 912:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(999);
      END_STATE();
    case 913:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(999);
      if (lookahead == '=') ADVANCE(926);
      END_STATE();
    case 914:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(1000);
      END_STATE();
    case 915:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(1000);
      if (lookahead == '=') ADVANCE(927);
      END_STATE();
    case 916:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 917:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      if (lookahead == '=') ADVANCE(930);
      END_STATE();
    case 918:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 919:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 920:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(890);
      END_STATE();
    case 921:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 922:
      ACCEPT_TOKEN(anon_sym_typeof);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 923:
      ACCEPT_TOKEN(anon_sym_void);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 924:
      ACCEPT_TOKEN(anon_sym_delete);
      END_STATE();
    case 925:
      ACCEPT_TOKEN(anon_sym_delete);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 926:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 927:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 928:
      ACCEPT_TOKEN(anon_sym_STAR_EQ);
      END_STATE();
    case 929:
      ACCEPT_TOKEN(anon_sym_SLASH_EQ);
      END_STATE();
    case 930:
      ACCEPT_TOKEN(anon_sym_PERCENT_EQ);
      END_STATE();
    case 931:
      ACCEPT_TOKEN(anon_sym_AMP_EQ);
      END_STATE();
    case 932:
      ACCEPT_TOKEN(anon_sym_PIPE_EQ);
      END_STATE();
    case 933:
      ACCEPT_TOKEN(anon_sym_CARET_EQ);
      END_STATE();
    case 934:
      ACCEPT_TOKEN(anon_sym_LT_LT_EQ);
      END_STATE();
    case 935:
      ACCEPT_TOKEN(anon_sym_GT_GT_EQ);
      END_STATE();
    case 936:
      ACCEPT_TOKEN(anon_sym_GT_GT_GT_EQ);
      END_STATE();
    case 937:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 938:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == '.') ADVANCE(979);
      END_STATE();
    case 939:
      ACCEPT_TOKEN(anon_sym_await);
      END_STATE();
    case 940:
      ACCEPT_TOKEN(anon_sym_await);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 941:
      ACCEPT_TOKEN(anon_sym_number);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 942:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 943:
      ACCEPT_TOKEN(anon_sym_string);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 944:
      ACCEPT_TOKEN(anon_sym_boolean);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 945:
      ACCEPT_TOKEN(anon_sym_any);
      END_STATE();
    case 946:
      ACCEPT_TOKEN(anon_sym_any);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 947:
      ACCEPT_TOKEN(anon_sym_undefined);
      END_STATE();
    case 948:
      ACCEPT_TOKEN(anon_sym_undefined);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 949:
      ACCEPT_TOKEN(anon_sym_EQ_GT);
      END_STATE();
    case 950:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 951:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 952:
      ACCEPT_TOKEN(anon_sym_extends);
      END_STATE();
    case 953:
      ACCEPT_TOKEN(anon_sym_extends);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 954:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 955:
      ACCEPT_TOKEN(anon_sym_if);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 956:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 957:
      ACCEPT_TOKEN(anon_sym_else);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 958:
      ACCEPT_TOKEN(anon_sym_async);
      END_STATE();
    case 959:
      ACCEPT_TOKEN(anon_sym_async);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 960:
      ACCEPT_TOKEN(anon_sym_DOT_DOT_DOT);
      END_STATE();
    case 961:
      ACCEPT_TOKEN(anon_sym_var);
      END_STATE();
    case 962:
      ACCEPT_TOKEN(anon_sym_var);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 963:
      ACCEPT_TOKEN(anon_sym_let);
      END_STATE();
    case 964:
      ACCEPT_TOKEN(anon_sym_let);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 965:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 966:
      ACCEPT_TOKEN(anon_sym_const);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 967:
      ACCEPT_TOKEN(anon_sym_return);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 968:
      ACCEPT_TOKEN(anon_sym_try);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 969:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 970:
      ACCEPT_TOKEN(anon_sym_catch);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 971:
      ACCEPT_TOKEN(anon_sym_finally);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 972:
      ACCEPT_TOKEN(anon_sym_throw);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 973:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 974:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 975:
      ACCEPT_TOKEN(anon_sym_while);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 976:
      ACCEPT_TOKEN(anon_sym_break);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 977:
      ACCEPT_TOKEN(anon_sym_continue);
      END_STATE();
    case 978:
      ACCEPT_TOKEN(anon_sym_continue);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 979:
      ACCEPT_TOKEN(anon_sym_QMARK_DOT);
      END_STATE();
    case 980:
      ACCEPT_TOKEN(anon_sym_interface);
      END_STATE();
    case 981:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 982:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 983:
      ACCEPT_TOKEN(anon_sym_enum);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 984:
      ACCEPT_TOKEN(anon_sym_abstract);
      END_STATE();
    case 985:
      ACCEPT_TOKEN(anon_sym_abstract);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 986:
      ACCEPT_TOKEN(anon_sym_class);
      END_STATE();
    case 987:
      ACCEPT_TOKEN(anon_sym_class);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 988:
      ACCEPT_TOKEN(anon_sym_implements);
      END_STATE();
    case 989:
      ACCEPT_TOKEN(anon_sym_constructor);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 990:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 991:
      ACCEPT_TOKEN(anon_sym_function);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 992:
      ACCEPT_TOKEN(anon_sym_BQUOTE);
      END_STATE();
    case 993:
      ACCEPT_TOKEN(sym_template_chars);
      END_STATE();
    case 994:
      ACCEPT_TOKEN(sym_template_chars);
      if (lookahead == '*') ADVANCE(380);
      if (lookahead == '/') ADVANCE(373);
      if (lookahead != 0 &&
          lookahead != '$' &&
          lookahead != '\\' &&
          lookahead != '`') ADVANCE(996);
      END_STATE();
    case 995:
      ACCEPT_TOKEN(sym_template_chars);
      if (lookahead == '/') ADVANCE(994);
      if (lookahead == '\\') ADVANCE(367);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(995);
      if (lookahead != 0 &&
          lookahead != '$' &&
          lookahead != '`') ADVANCE(996);
      END_STATE();
    case 996:
      ACCEPT_TOKEN(sym_template_chars);
      if (lookahead != 0 &&
          lookahead != '$' &&
          lookahead != '\\' &&
          lookahead != '`') ADVANCE(996);
      END_STATE();
    case 997:
      ACCEPT_TOKEN(anon_sym_DOLLARr);
      END_STATE();
    case 998:
      ACCEPT_TOKEN(anon_sym_DOLLARr);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    case 999:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 1000:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 1001:
      ACCEPT_TOKEN(anon_sym_new);
      if (lookahead == '$' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(855);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 368},
  [2] = {.lex_state = 1},
  [3] = {.lex_state = 5},
  [4] = {.lex_state = 5},
  [5] = {.lex_state = 5},
  [6] = {.lex_state = 5},
  [7] = {.lex_state = 3},
  [8] = {.lex_state = 5},
  [9] = {.lex_state = 5},
  [10] = {.lex_state = 5},
  [11] = {.lex_state = 2},
  [12] = {.lex_state = 16},
  [13] = {.lex_state = 18},
  [14] = {.lex_state = 18},
  [15] = {.lex_state = 16},
  [16] = {.lex_state = 16},
  [17] = {.lex_state = 16},
  [18] = {.lex_state = 18},
  [19] = {.lex_state = 18},
  [20] = {.lex_state = 18},
  [21] = {.lex_state = 18},
  [22] = {.lex_state = 18},
  [23] = {.lex_state = 18},
  [24] = {.lex_state = 16},
  [25] = {.lex_state = 4},
  [26] = {.lex_state = 16},
  [27] = {.lex_state = 16},
  [28] = {.lex_state = 6},
  [29] = {.lex_state = 16},
  [30] = {.lex_state = 6},
  [31] = {.lex_state = 16},
  [32] = {.lex_state = 16},
  [33] = {.lex_state = 16},
  [34] = {.lex_state = 16},
  [35] = {.lex_state = 4},
  [36] = {.lex_state = 4},
  [37] = {.lex_state = 6},
  [38] = {.lex_state = 6},
  [39] = {.lex_state = 6},
  [40] = {.lex_state = 18},
  [41] = {.lex_state = 18},
  [42] = {.lex_state = 18},
  [43] = {.lex_state = 18},
  [44] = {.lex_state = 18},
  [45] = {.lex_state = 18},
  [46] = {.lex_state = 18},
  [47] = {.lex_state = 18},
  [48] = {.lex_state = 18},
  [49] = {.lex_state = 4},
  [50] = {.lex_state = 18},
  [51] = {.lex_state = 18},
  [52] = {.lex_state = 18},
  [53] = {.lex_state = 18},
  [54] = {.lex_state = 18},
  [55] = {.lex_state = 4},
  [56] = {.lex_state = 18},
  [57] = {.lex_state = 18},
  [58] = {.lex_state = 4},
  [59] = {.lex_state = 18},
  [60] = {.lex_state = 18},
  [61] = {.lex_state = 18},
  [62] = {.lex_state = 18},
  [63] = {.lex_state = 18},
  [64] = {.lex_state = 18},
  [65] = {.lex_state = 18},
  [66] = {.lex_state = 18},
  [67] = {.lex_state = 18},
  [68] = {.lex_state = 18},
  [69] = {.lex_state = 18},
  [70] = {.lex_state = 18},
  [71] = {.lex_state = 18},
  [72] = {.lex_state = 18},
  [73] = {.lex_state = 18},
  [74] = {.lex_state = 18},
  [75] = {.lex_state = 7},
  [76] = {.lex_state = 18},
  [77] = {.lex_state = 18},
  [78] = {.lex_state = 18},
  [79] = {.lex_state = 18},
  [80] = {.lex_state = 18},
  [81] = {.lex_state = 11},
  [82] = {.lex_state = 11},
  [83] = {.lex_state = 11},
  [84] = {.lex_state = 11},
  [85] = {.lex_state = 11},
  [86] = {.lex_state = 11},
  [87] = {.lex_state = 11},
  [88] = {.lex_state = 11},
  [89] = {.lex_state = 11},
  [90] = {.lex_state = 11},
  [91] = {.lex_state = 11},
  [92] = {.lex_state = 11},
  [93] = {.lex_state = 11},
  [94] = {.lex_state = 11},
  [95] = {.lex_state = 11},
  [96] = {.lex_state = 11},
  [97] = {.lex_state = 11},
  [98] = {.lex_state = 11},
  [99] = {.lex_state = 11},
  [100] = {.lex_state = 11},
  [101] = {.lex_state = 7},
  [102] = {.lex_state = 7},
  [103] = {.lex_state = 7},
  [104] = {.lex_state = 7},
  [105] = {.lex_state = 11},
  [106] = {.lex_state = 7},
  [107] = {.lex_state = 7},
  [108] = {.lex_state = 7},
  [109] = {.lex_state = 7},
  [110] = {.lex_state = 7},
  [111] = {.lex_state = 11},
  [112] = {.lex_state = 11},
  [113] = {.lex_state = 11},
  [114] = {.lex_state = 7},
  [115] = {.lex_state = 7},
  [116] = {.lex_state = 7},
  [117] = {.lex_state = 11},
  [118] = {.lex_state = 11},
  [119] = {.lex_state = 11},
  [120] = {.lex_state = 7},
  [121] = {.lex_state = 11},
  [122] = {.lex_state = 11},
  [123] = {.lex_state = 7},
  [124] = {.lex_state = 7},
  [125] = {.lex_state = 7},
  [126] = {.lex_state = 11},
  [127] = {.lex_state = 7},
  [128] = {.lex_state = 7},
  [129] = {.lex_state = 7},
  [130] = {.lex_state = 11},
  [131] = {.lex_state = 11},
  [132] = {.lex_state = 11},
  [133] = {.lex_state = 11},
  [134] = {.lex_state = 11},
  [135] = {.lex_state = 11},
  [136] = {.lex_state = 7},
  [137] = {.lex_state = 11},
  [138] = {.lex_state = 11},
  [139] = {.lex_state = 11},
  [140] = {.lex_state = 11},
  [141] = {.lex_state = 11},
  [142] = {.lex_state = 11},
  [143] = {.lex_state = 11},
  [144] = {.lex_state = 11},
  [145] = {.lex_state = 11},
  [146] = {.lex_state = 11},
  [147] = {.lex_state = 11},
  [148] = {.lex_state = 11},
  [149] = {.lex_state = 11},
  [150] = {.lex_state = 11},
  [151] = {.lex_state = 11},
  [152] = {.lex_state = 11},
  [153] = {.lex_state = 11},
  [154] = {.lex_state = 11},
  [155] = {.lex_state = 11},
  [156] = {.lex_state = 11},
  [157] = {.lex_state = 11},
  [158] = {.lex_state = 11},
  [159] = {.lex_state = 11},
  [160] = {.lex_state = 11},
  [161] = {.lex_state = 11},
  [162] = {.lex_state = 11},
  [163] = {.lex_state = 11},
  [164] = {.lex_state = 11},
  [165] = {.lex_state = 11},
  [166] = {.lex_state = 11},
  [167] = {.lex_state = 11},
  [168] = {.lex_state = 11},
  [169] = {.lex_state = 11},
  [170] = {.lex_state = 11},
  [171] = {.lex_state = 11},
  [172] = {.lex_state = 11},
  [173] = {.lex_state = 11},
  [174] = {.lex_state = 11},
  [175] = {.lex_state = 11},
  [176] = {.lex_state = 11},
  [177] = {.lex_state = 11},
  [178] = {.lex_state = 11},
  [179] = {.lex_state = 11},
  [180] = {.lex_state = 11},
  [181] = {.lex_state = 11},
  [182] = {.lex_state = 11},
  [183] = {.lex_state = 11},
  [184] = {.lex_state = 11},
  [185] = {.lex_state = 11},
  [186] = {.lex_state = 11},
  [187] = {.lex_state = 11},
  [188] = {.lex_state = 11},
  [189] = {.lex_state = 11},
  [190] = {.lex_state = 11},
  [191] = {.lex_state = 11},
  [192] = {.lex_state = 11},
  [193] = {.lex_state = 11},
  [194] = {.lex_state = 17},
  [195] = {.lex_state = 17},
  [196] = {.lex_state = 17},
  [197] = {.lex_state = 17},
  [198] = {.lex_state = 17},
  [199] = {.lex_state = 17},
  [200] = {.lex_state = 17},
  [201] = {.lex_state = 9},
  [202] = {.lex_state = 8},
  [203] = {.lex_state = 12},
  [204] = {.lex_state = 12},
  [205] = {.lex_state = 17},
  [206] = {.lex_state = 9},
  [207] = {.lex_state = 9},
  [208] = {.lex_state = 12},
  [209] = {.lex_state = 9},
  [210] = {.lex_state = 17},
  [211] = {.lex_state = 9},
  [212] = {.lex_state = 12},
  [213] = {.lex_state = 12},
  [214] = {.lex_state = 17},
  [215] = {.lex_state = 12},
  [216] = {.lex_state = 12},
  [217] = {.lex_state = 12},
  [218] = {.lex_state = 12},
  [219] = {.lex_state = 12},
  [220] = {.lex_state = 12},
  [221] = {.lex_state = 12},
  [222] = {.lex_state = 12},
  [223] = {.lex_state = 12},
  [224] = {.lex_state = 10},
  [225] = {.lex_state = 17},
  [226] = {.lex_state = 17},
  [227] = {.lex_state = 9},
  [228] = {.lex_state = 9},
  [229] = {.lex_state = 9},
  [230] = {.lex_state = 9},
  [231] = {.lex_state = 17},
  [232] = {.lex_state = 9},
  [233] = {.lex_state = 12},
  [234] = {.lex_state = 17},
  [235] = {.lex_state = 17},
  [236] = {.lex_state = 12},
  [237] = {.lex_state = 12},
  [238] = {.lex_state = 12},
  [239] = {.lex_state = 9},
  [240] = {.lex_state = 17},
  [241] = {.lex_state = 368},
  [242] = {.lex_state = 12},
  [243] = {.lex_state = 12},
  [244] = {.lex_state = 12},
  [245] = {.lex_state = 17},
  [246] = {.lex_state = 17},
  [247] = {.lex_state = 17},
  [248] = {.lex_state = 12},
  [249] = {.lex_state = 12},
  [250] = {.lex_state = 17},
  [251] = {.lex_state = 12},
  [252] = {.lex_state = 10},
  [253] = {.lex_state = 8},
  [254] = {.lex_state = 12},
  [255] = {.lex_state = 9},
  [256] = {.lex_state = 8},
  [257] = {.lex_state = 9},
  [258] = {.lex_state = 12},
  [259] = {.lex_state = 8},
  [260] = {.lex_state = 12},
  [261] = {.lex_state = 12},
  [262] = {.lex_state = 9},
  [263] = {.lex_state = 12},
  [264] = {.lex_state = 12},
  [265] = {.lex_state = 9},
  [266] = {.lex_state = 12},
  [267] = {.lex_state = 9},
  [268] = {.lex_state = 10},
  [269] = {.lex_state = 12},
  [270] = {.lex_state = 10},
  [271] = {.lex_state = 10},
  [272] = {.lex_state = 9},
  [273] = {.lex_state = 12},
  [274] = {.lex_state = 10},
  [275] = {.lex_state = 8},
  [276] = {.lex_state = 10},
  [277] = {.lex_state = 8},
  [278] = {.lex_state = 8},
  [279] = {.lex_state = 10},
  [280] = {.lex_state = 9},
  [281] = {.lex_state = 8},
  [282] = {.lex_state = 10},
  [283] = {.lex_state = 10},
  [284] = {.lex_state = 8},
  [285] = {.lex_state = 10},
  [286] = {.lex_state = 12},
  [287] = {.lex_state = 10},
  [288] = {.lex_state = 9},
  [289] = {.lex_state = 10},
  [290] = {.lex_state = 10},
  [291] = {.lex_state = 10},
  [292] = {.lex_state = 12},
  [293] = {.lex_state = 10},
  [294] = {.lex_state = 10},
  [295] = {.lex_state = 10},
  [296] = {.lex_state = 9},
  [297] = {.lex_state = 10},
  [298] = {.lex_state = 10},
  [299] = {.lex_state = 12},
  [300] = {.lex_state = 9},
  [301] = {.lex_state = 10},
  [302] = {.lex_state = 8},
  [303] = {.lex_state = 8},
  [304] = {.lex_state = 10},
  [305] = {.lex_state = 10},
  [306] = {.lex_state = 10},
  [307] = {.lex_state = 10},
  [308] = {.lex_state = 12},
  [309] = {.lex_state = 12},
  [310] = {.lex_state = 8},
  [311] = {.lex_state = 10},
  [312] = {.lex_state = 12},
  [313] = {.lex_state = 12},
  [314] = {.lex_state = 12},
  [315] = {.lex_state = 12},
  [316] = {.lex_state = 12},
  [317] = {.lex_state = 12},
  [318] = {.lex_state = 12},
  [319] = {.lex_state = 8},
  [320] = {.lex_state = 10},
  [321] = {.lex_state = 12},
  [322] = {.lex_state = 12},
  [323] = {.lex_state = 12},
  [324] = {.lex_state = 12},
  [325] = {.lex_state = 12},
  [326] = {.lex_state = 12},
  [327] = {.lex_state = 12},
  [328] = {.lex_state = 12},
  [329] = {.lex_state = 12},
  [330] = {.lex_state = 12},
  [331] = {.lex_state = 12},
  [332] = {.lex_state = 12},
  [333] = {.lex_state = 12},
  [334] = {.lex_state = 12},
  [335] = {.lex_state = 12},
  [336] = {.lex_state = 8},
  [337] = {.lex_state = 10},
  [338] = {.lex_state = 10},
  [339] = {.lex_state = 8},
  [340] = {.lex_state = 10},
  [341] = {.lex_state = 12},
  [342] = {.lex_state = 8},
  [343] = {.lex_state = 12},
  [344] = {.lex_state = 12},
  [345] = {.lex_state = 10},
  [346] = {.lex_state = 10},
  [347] = {.lex_state = 10},
  [348] = {.lex_state = 10},
  [349] = {.lex_state = 12},
  [350] = {.lex_state = 10},
  [351] = {.lex_state = 10},
  [352] = {.lex_state = 10},
  [353] = {.lex_state = 12},
  [354] = {.lex_state = 12},
  [355] = {.lex_state = 10},
  [356] = {.lex_state = 12},
  [357] = {.lex_state = 10},
  [358] = {.lex_state = 12},
  [359] = {.lex_state = 12},
  [360] = {.lex_state = 10},
  [361] = {.lex_state = 12},
  [362] = {.lex_state = 12},
  [363] = {.lex_state = 12},
  [364] = {.lex_state = 12},
  [365] = {.lex_state = 12},
  [366] = {.lex_state = 12},
  [367] = {.lex_state = 8},
  [368] = {.lex_state = 8},
  [369] = {.lex_state = 12},
  [370] = {.lex_state = 10},
  [371] = {.lex_state = 12},
  [372] = {.lex_state = 12},
  [373] = {.lex_state = 12},
  [374] = {.lex_state = 12},
  [375] = {.lex_state = 12},
  [376] = {.lex_state = 12},
  [377] = {.lex_state = 12},
  [378] = {.lex_state = 12},
  [379] = {.lex_state = 12},
  [380] = {.lex_state = 12},
  [381] = {.lex_state = 8},
  [382] = {.lex_state = 8},
  [383] = {.lex_state = 12},
  [384] = {.lex_state = 12},
  [385] = {.lex_state = 12},
  [386] = {.lex_state = 12},
  [387] = {.lex_state = 12},
  [388] = {.lex_state = 12},
  [389] = {.lex_state = 12},
  [390] = {.lex_state = 10},
  [391] = {.lex_state = 12},
  [392] = {.lex_state = 8},
  [393] = {.lex_state = 10},
  [394] = {.lex_state = 10},
  [395] = {.lex_state = 10},
  [396] = {.lex_state = 10},
  [397] = {.lex_state = 10},
  [398] = {.lex_state = 10},
  [399] = {.lex_state = 10},
  [400] = {.lex_state = 10},
  [401] = {.lex_state = 10},
  [402] = {.lex_state = 10},
  [403] = {.lex_state = 10},
  [404] = {.lex_state = 10},
  [405] = {.lex_state = 10},
  [406] = {.lex_state = 10},
  [407] = {.lex_state = 10},
  [408] = {.lex_state = 10},
  [409] = {.lex_state = 10},
  [410] = {.lex_state = 10},
  [411] = {.lex_state = 10},
  [412] = {.lex_state = 10},
  [413] = {.lex_state = 10},
  [414] = {.lex_state = 10},
  [415] = {.lex_state = 10},
  [416] = {.lex_state = 10},
  [417] = {.lex_state = 10},
  [418] = {.lex_state = 10},
  [419] = {.lex_state = 10},
  [420] = {.lex_state = 10},
  [421] = {.lex_state = 10},
  [422] = {.lex_state = 10},
  [423] = {.lex_state = 10},
  [424] = {.lex_state = 10},
  [425] = {.lex_state = 10},
  [426] = {.lex_state = 10},
  [427] = {.lex_state = 10},
  [428] = {.lex_state = 10},
  [429] = {.lex_state = 10},
  [430] = {.lex_state = 10},
  [431] = {.lex_state = 10},
  [432] = {.lex_state = 10},
  [433] = {.lex_state = 10},
  [434] = {.lex_state = 10},
  [435] = {.lex_state = 10},
  [436] = {.lex_state = 10},
  [437] = {.lex_state = 10},
  [438] = {.lex_state = 10},
  [439] = {.lex_state = 10},
  [440] = {.lex_state = 10},
  [441] = {.lex_state = 10},
  [442] = {.lex_state = 10},
  [443] = {.lex_state = 10},
  [444] = {.lex_state = 10},
  [445] = {.lex_state = 10},
  [446] = {.lex_state = 10},
  [447] = {.lex_state = 10},
  [448] = {.lex_state = 21},
  [449] = {.lex_state = 368},
  [450] = {.lex_state = 368},
  [451] = {.lex_state = 368},
  [452] = {.lex_state = 368},
  [453] = {.lex_state = 368},
  [454] = {.lex_state = 369},
  [455] = {.lex_state = 369},
  [456] = {.lex_state = 369},
  [457] = {.lex_state = 369},
  [458] = {.lex_state = 369},
  [459] = {.lex_state = 369},
  [460] = {.lex_state = 20},
  [461] = {.lex_state = 369},
  [462] = {.lex_state = 369},
  [463] = {.lex_state = 369},
  [464] = {.lex_state = 19},
  [465] = {.lex_state = 20},
  [466] = {.lex_state = 369},
  [467] = {.lex_state = 15},
  [468] = {.lex_state = 15},
  [469] = {.lex_state = 15},
  [470] = {.lex_state = 15},
  [471] = {.lex_state = 15},
  [472] = {.lex_state = 19},
  [473] = {.lex_state = 19},
  [474] = {.lex_state = 369},
  [475] = {.lex_state = 369},
  [476] = {.lex_state = 369},
  [477] = {.lex_state = 19},
  [478] = {.lex_state = 19},
  [479] = {.lex_state = 15},
  [480] = {.lex_state = 369},
  [481] = {.lex_state = 19},
  [482] = {.lex_state = 15},
  [483] = {.lex_state = 15},
  [484] = {.lex_state = 15},
  [485] = {.lex_state = 15},
  [486] = {.lex_state = 15},
  [487] = {.lex_state = 13},
  [488] = {.lex_state = 15},
  [489] = {.lex_state = 13},
  [490] = {.lex_state = 15},
  [491] = {.lex_state = 15},
  [492] = {.lex_state = 15},
  [493] = {.lex_state = 15},
  [494] = {.lex_state = 15},
  [495] = {.lex_state = 15},
  [496] = {.lex_state = 15},
  [497] = {.lex_state = 15},
  [498] = {.lex_state = 15},
  [499] = {.lex_state = 15},
  [500] = {.lex_state = 15},
  [501] = {.lex_state = 15},
  [502] = {.lex_state = 15},
  [503] = {.lex_state = 15},
  [504] = {.lex_state = 15},
  [505] = {.lex_state = 15},
  [506] = {.lex_state = 15},
  [507] = {.lex_state = 15},
  [508] = {.lex_state = 15},
  [509] = {.lex_state = 15},
  [510] = {.lex_state = 15},
  [511] = {.lex_state = 15},
  [512] = {.lex_state = 15},
  [513] = {.lex_state = 15},
  [514] = {.lex_state = 15},
  [515] = {.lex_state = 15},
  [516] = {.lex_state = 15},
  [517] = {.lex_state = 15},
  [518] = {.lex_state = 15},
  [519] = {.lex_state = 15},
  [520] = {.lex_state = 15},
  [521] = {.lex_state = 15},
  [522] = {.lex_state = 15},
  [523] = {.lex_state = 15},
  [524] = {.lex_state = 15},
  [525] = {.lex_state = 15},
  [526] = {.lex_state = 15},
  [527] = {.lex_state = 15},
  [528] = {.lex_state = 15},
  [529] = {.lex_state = 15},
  [530] = {.lex_state = 15},
  [531] = {.lex_state = 15},
  [532] = {.lex_state = 15},
  [533] = {.lex_state = 15},
  [534] = {.lex_state = 15},
  [535] = {.lex_state = 15},
  [536] = {.lex_state = 15},
  [537] = {.lex_state = 15},
  [538] = {.lex_state = 15},
  [539] = {.lex_state = 15},
  [540] = {.lex_state = 15},
  [541] = {.lex_state = 15},
  [542] = {.lex_state = 15},
  [543] = {.lex_state = 15},
  [544] = {.lex_state = 15},
  [545] = {.lex_state = 15},
  [546] = {.lex_state = 15},
  [547] = {.lex_state = 15},
  [548] = {.lex_state = 15},
  [549] = {.lex_state = 15},
  [550] = {.lex_state = 15},
  [551] = {.lex_state = 15},
  [552] = {.lex_state = 15},
  [553] = {.lex_state = 15},
  [554] = {.lex_state = 15},
  [555] = {.lex_state = 15},
  [556] = {.lex_state = 15},
  [557] = {.lex_state = 15},
  [558] = {.lex_state = 15},
  [559] = {.lex_state = 15},
  [560] = {.lex_state = 15},
  [561] = {.lex_state = 15},
  [562] = {.lex_state = 15},
  [563] = {.lex_state = 15},
  [564] = {.lex_state = 15},
  [565] = {.lex_state = 15},
  [566] = {.lex_state = 15},
  [567] = {.lex_state = 15},
  [568] = {.lex_state = 15},
  [569] = {.lex_state = 15},
  [570] = {.lex_state = 15},
  [571] = {.lex_state = 15},
  [572] = {.lex_state = 15},
  [573] = {.lex_state = 15},
  [574] = {.lex_state = 15},
  [575] = {.lex_state = 15},
  [576] = {.lex_state = 15},
  [577] = {.lex_state = 15},
  [578] = {.lex_state = 15},
  [579] = {.lex_state = 15},
  [580] = {.lex_state = 15},
  [581] = {.lex_state = 15},
  [582] = {.lex_state = 15},
  [583] = {.lex_state = 15},
  [584] = {.lex_state = 15},
  [585] = {.lex_state = 15},
  [586] = {.lex_state = 15},
  [587] = {.lex_state = 15},
  [588] = {.lex_state = 15},
  [589] = {.lex_state = 15},
  [590] = {.lex_state = 15},
  [591] = {.lex_state = 15},
  [592] = {.lex_state = 15},
  [593] = {.lex_state = 13},
  [594] = {.lex_state = 15},
  [595] = {.lex_state = 15},
  [596] = {.lex_state = 15},
  [597] = {.lex_state = 15},
  [598] = {.lex_state = 15},
  [599] = {.lex_state = 15},
  [600] = {.lex_state = 15},
  [601] = {.lex_state = 15},
  [602] = {.lex_state = 15},
  [603] = {.lex_state = 15},
  [604] = {.lex_state = 15},
  [605] = {.lex_state = 15},
  [606] = {.lex_state = 15},
  [607] = {.lex_state = 15},
  [608] = {.lex_state = 15},
  [609] = {.lex_state = 15},
  [610] = {.lex_state = 15},
  [611] = {.lex_state = 15},
  [612] = {.lex_state = 15},
  [613] = {.lex_state = 15},
  [614] = {.lex_state = 15},
  [615] = {.lex_state = 15},
  [616] = {.lex_state = 15},
  [617] = {.lex_state = 15},
  [618] = {.lex_state = 15},
  [619] = {.lex_state = 15},
  [620] = {.lex_state = 15},
  [621] = {.lex_state = 15},
  [622] = {.lex_state = 15},
  [623] = {.lex_state = 15},
  [624] = {.lex_state = 15},
  [625] = {.lex_state = 15},
  [626] = {.lex_state = 15},
  [627] = {.lex_state = 15},
  [628] = {.lex_state = 15},
  [629] = {.lex_state = 15},
  [630] = {.lex_state = 15},
  [631] = {.lex_state = 15},
  [632] = {.lex_state = 15},
  [633] = {.lex_state = 15},
  [634] = {.lex_state = 15},
  [635] = {.lex_state = 15},
  [636] = {.lex_state = 15},
  [637] = {.lex_state = 15},
  [638] = {.lex_state = 15},
  [639] = {.lex_state = 15},
  [640] = {.lex_state = 15},
  [641] = {.lex_state = 15},
  [642] = {.lex_state = 15},
  [643] = {.lex_state = 15},
  [644] = {.lex_state = 15},
  [645] = {.lex_state = 15},
  [646] = {.lex_state = 15},
  [647] = {.lex_state = 15},
  [648] = {.lex_state = 15},
  [649] = {.lex_state = 15},
  [650] = {.lex_state = 15},
  [651] = {.lex_state = 15},
  [652] = {.lex_state = 15},
  [653] = {.lex_state = 15},
  [654] = {.lex_state = 15},
  [655] = {.lex_state = 15},
  [656] = {.lex_state = 15},
  [657] = {.lex_state = 15},
  [658] = {.lex_state = 15},
  [659] = {.lex_state = 15},
  [660] = {.lex_state = 15},
  [661] = {.lex_state = 15},
  [662] = {.lex_state = 15},
  [663] = {.lex_state = 15},
  [664] = {.lex_state = 15},
  [665] = {.lex_state = 15},
  [666] = {.lex_state = 15},
  [667] = {.lex_state = 15},
  [668] = {.lex_state = 15},
  [669] = {.lex_state = 15},
  [670] = {.lex_state = 15},
  [671] = {.lex_state = 15},
  [672] = {.lex_state = 15},
  [673] = {.lex_state = 15},
  [674] = {.lex_state = 15},
  [675] = {.lex_state = 15},
  [676] = {.lex_state = 15},
  [677] = {.lex_state = 15},
  [678] = {.lex_state = 15},
  [679] = {.lex_state = 15},
  [680] = {.lex_state = 15},
  [681] = {.lex_state = 15},
  [682] = {.lex_state = 15},
  [683] = {.lex_state = 15},
  [684] = {.lex_state = 15},
  [685] = {.lex_state = 15},
  [686] = {.lex_state = 15},
  [687] = {.lex_state = 15},
  [688] = {.lex_state = 15},
  [689] = {.lex_state = 15},
  [690] = {.lex_state = 15},
  [691] = {.lex_state = 15},
  [692] = {.lex_state = 15},
  [693] = {.lex_state = 15},
  [694] = {.lex_state = 15},
  [695] = {.lex_state = 15},
  [696] = {.lex_state = 15},
  [697] = {.lex_state = 15},
  [698] = {.lex_state = 15},
  [699] = {.lex_state = 15},
  [700] = {.lex_state = 15},
  [701] = {.lex_state = 15},
  [702] = {.lex_state = 15},
  [703] = {.lex_state = 15},
  [704] = {.lex_state = 15},
  [705] = {.lex_state = 15},
  [706] = {.lex_state = 15},
  [707] = {.lex_state = 15},
  [708] = {.lex_state = 15},
  [709] = {.lex_state = 15},
  [710] = {.lex_state = 15},
  [711] = {.lex_state = 15},
  [712] = {.lex_state = 15},
  [713] = {.lex_state = 15},
  [714] = {.lex_state = 15},
  [715] = {.lex_state = 15},
  [716] = {.lex_state = 15},
  [717] = {.lex_state = 15},
  [718] = {.lex_state = 15},
  [719] = {.lex_state = 15},
  [720] = {.lex_state = 15},
  [721] = {.lex_state = 15},
  [722] = {.lex_state = 369},
  [723] = {.lex_state = 13},
  [724] = {.lex_state = 13},
  [725] = {.lex_state = 369},
  [726] = {.lex_state = 369},
  [727] = {.lex_state = 369},
  [728] = {.lex_state = 369},
  [729] = {.lex_state = 369},
  [730] = {.lex_state = 369},
  [731] = {.lex_state = 369},
  [732] = {.lex_state = 369},
  [733] = {.lex_state = 369},
  [734] = {.lex_state = 369},
  [735] = {.lex_state = 369},
  [736] = {.lex_state = 369},
  [737] = {.lex_state = 369},
  [738] = {.lex_state = 369},
  [739] = {.lex_state = 369},
  [740] = {.lex_state = 369},
  [741] = {.lex_state = 369},
  [742] = {.lex_state = 369},
  [743] = {.lex_state = 369},
  [744] = {.lex_state = 369},
  [745] = {.lex_state = 13},
  [746] = {.lex_state = 369},
  [747] = {.lex_state = 369},
  [748] = {.lex_state = 369},
  [749] = {.lex_state = 369},
  [750] = {.lex_state = 369},
  [751] = {.lex_state = 369},
  [752] = {.lex_state = 369},
  [753] = {.lex_state = 369},
  [754] = {.lex_state = 369},
  [755] = {.lex_state = 369},
  [756] = {.lex_state = 369},
  [757] = {.lex_state = 369},
  [758] = {.lex_state = 369},
  [759] = {.lex_state = 369},
  [760] = {.lex_state = 369},
  [761] = {.lex_state = 369},
  [762] = {.lex_state = 369},
  [763] = {.lex_state = 13},
  [764] = {.lex_state = 369},
  [765] = {.lex_state = 13},
  [766] = {.lex_state = 369},
  [767] = {.lex_state = 369},
  [768] = {.lex_state = 369},
  [769] = {.lex_state = 369},
  [770] = {.lex_state = 369},
  [771] = {.lex_state = 369},
  [772] = {.lex_state = 369},
  [773] = {.lex_state = 369},
  [774] = {.lex_state = 369},
  [775] = {.lex_state = 369},
  [776] = {.lex_state = 13},
  [777] = {.lex_state = 13},
  [778] = {.lex_state = 369},
  [779] = {.lex_state = 369},
  [780] = {.lex_state = 369},
  [781] = {.lex_state = 369},
  [782] = {.lex_state = 369},
  [783] = {.lex_state = 369},
  [784] = {.lex_state = 369},
  [785] = {.lex_state = 369},
  [786] = {.lex_state = 369},
  [787] = {.lex_state = 369},
  [788] = {.lex_state = 369},
  [789] = {.lex_state = 369},
  [790] = {.lex_state = 369},
  [791] = {.lex_state = 369},
  [792] = {.lex_state = 369},
  [793] = {.lex_state = 369},
  [794] = {.lex_state = 369},
  [795] = {.lex_state = 369},
  [796] = {.lex_state = 369},
  [797] = {.lex_state = 369},
  [798] = {.lex_state = 369},
  [799] = {.lex_state = 369},
  [800] = {.lex_state = 369},
  [801] = {.lex_state = 13},
  [802] = {.lex_state = 369},
  [803] = {.lex_state = 369},
  [804] = {.lex_state = 369},
  [805] = {.lex_state = 369},
  [806] = {.lex_state = 369},
  [807] = {.lex_state = 369},
  [808] = {.lex_state = 369},
  [809] = {.lex_state = 369},
  [810] = {.lex_state = 369},
  [811] = {.lex_state = 369},
  [812] = {.lex_state = 369},
  [813] = {.lex_state = 16},
  [814] = {.lex_state = 22},
  [815] = {.lex_state = 16},
  [816] = {.lex_state = 16},
  [817] = {.lex_state = 22},
  [818] = {.lex_state = 16},
  [819] = {.lex_state = 16},
  [820] = {.lex_state = 16},
  [821] = {.lex_state = 16},
  [822] = {.lex_state = 16},
  [823] = {.lex_state = 16},
  [824] = {.lex_state = 16},
  [825] = {.lex_state = 16},
  [826] = {.lex_state = 16},
  [827] = {.lex_state = 16},
  [828] = {.lex_state = 16},
  [829] = {.lex_state = 16},
  [830] = {.lex_state = 16},
  [831] = {.lex_state = 16},
  [832] = {.lex_state = 16},
  [833] = {.lex_state = 16},
  [834] = {.lex_state = 16},
  [835] = {.lex_state = 16},
  [836] = {.lex_state = 16},
  [837] = {.lex_state = 16},
  [838] = {.lex_state = 16},
  [839] = {.lex_state = 16},
  [840] = {.lex_state = 16},
  [841] = {.lex_state = 16},
  [842] = {.lex_state = 16},
  [843] = {.lex_state = 16},
  [844] = {.lex_state = 16},
  [845] = {.lex_state = 16},
  [846] = {.lex_state = 16},
  [847] = {.lex_state = 16},
  [848] = {.lex_state = 23},
  [849] = {.lex_state = 24},
  [850] = {.lex_state = 14},
  [851] = {.lex_state = 26},
  [852] = {.lex_state = 23},
  [853] = {.lex_state = 23},
  [854] = {.lex_state = 27},
  [855] = {.lex_state = 26},
  [856] = {.lex_state = 24},
  [857] = {.lex_state = 26},
  [858] = {.lex_state = 26},
  [859] = {.lex_state = 26},
  [860] = {.lex_state = 26},
  [861] = {.lex_state = 24},
  [862] = {.lex_state = 25},
  [863] = {.lex_state = 25},
  [864] = {.lex_state = 14},
  [865] = {.lex_state = 25},
  [866] = {.lex_state = 14},
  [867] = {.lex_state = 27},
  [868] = {.lex_state = 25},
  [869] = {.lex_state = 25},
  [870] = {.lex_state = 25},
  [871] = {.lex_state = 25},
  [872] = {.lex_state = 25},
  [873] = {.lex_state = 25},
  [874] = {.lex_state = 25},
  [875] = {.lex_state = 25},
  [876] = {.lex_state = 25},
  [877] = {.lex_state = 25},
  [878] = {.lex_state = 25},
  [879] = {.lex_state = 25},
  [880] = {.lex_state = 25},
  [881] = {.lex_state = 25},
  [882] = {.lex_state = 14},
  [883] = {.lex_state = 25},
  [884] = {.lex_state = 25},
  [885] = {.lex_state = 25},
  [886] = {.lex_state = 25},
  [887] = {.lex_state = 25},
  [888] = {.lex_state = 27},
  [889] = {.lex_state = 14},
  [890] = {.lex_state = 25},
  [891] = {.lex_state = 27},
  [892] = {.lex_state = 14},
  [893] = {.lex_state = 14},
  [894] = {.lex_state = 14},
  [895] = {.lex_state = 14},
  [896] = {.lex_state = 14},
  [897] = {.lex_state = 14},
  [898] = {.lex_state = 25},
  [899] = {.lex_state = 27},
  [900] = {.lex_state = 27},
  [901] = {.lex_state = 25},
  [902] = {.lex_state = 14},
  [903] = {.lex_state = 14},
  [904] = {.lex_state = 25},
  [905] = {.lex_state = 18},
  [906] = {.lex_state = 14},
  [907] = {.lex_state = 14},
  [908] = {.lex_state = 18},
  [909] = {.lex_state = 14},
  [910] = {.lex_state = 14},
  [911] = {.lex_state = 14},
  [912] = {.lex_state = 14},
  [913] = {.lex_state = 14},
  [914] = {.lex_state = 14},
  [915] = {.lex_state = 14},
  [916] = {.lex_state = 14},
  [917] = {.lex_state = 14},
  [918] = {.lex_state = 14},
  [919] = {.lex_state = 18},
  [920] = {.lex_state = 14},
  [921] = {.lex_state = 14},
  [922] = {.lex_state = 14},
  [923] = {.lex_state = 18},
  [924] = {.lex_state = 18},
  [925] = {.lex_state = 14},
  [926] = {.lex_state = 14},
  [927] = {.lex_state = 18},
  [928] = {.lex_state = 14},
  [929] = {.lex_state = 14},
  [930] = {.lex_state = 14},
  [931] = {.lex_state = 14},
  [932] = {.lex_state = 14},
  [933] = {.lex_state = 14},
  [934] = {.lex_state = 14},
  [935] = {.lex_state = 14},
  [936] = {.lex_state = 14},
  [937] = {.lex_state = 14},
  [938] = {.lex_state = 14},
  [939] = {.lex_state = 14},
  [940] = {.lex_state = 18},
  [941] = {.lex_state = 14},
  [942] = {.lex_state = 18},
  [943] = {.lex_state = 14},
  [944] = {.lex_state = 18},
  [945] = {.lex_state = 18},
  [946] = {.lex_state = 18},
  [947] = {.lex_state = 18},
  [948] = {.lex_state = 18},
  [949] = {.lex_state = 18},
  [950] = {.lex_state = 18},
  [951] = {.lex_state = 18},
  [952] = {.lex_state = 18},
  [953] = {.lex_state = 18},
  [954] = {.lex_state = 18},
  [955] = {.lex_state = 18},
  [956] = {.lex_state = 18},
  [957] = {.lex_state = 14},
  [958] = {.lex_state = 18},
  [959] = {.lex_state = 14},
  [960] = {.lex_state = 14},
  [961] = {.lex_state = 18},
  [962] = {.lex_state = 14},
  [963] = {.lex_state = 14},
  [964] = {.lex_state = 14},
  [965] = {.lex_state = 18},
  [966] = {.lex_state = 14},
  [967] = {.lex_state = 14},
  [968] = {.lex_state = 14},
  [969] = {.lex_state = 14},
  [970] = {.lex_state = 14},
  [971] = {.lex_state = 14},
  [972] = {.lex_state = 14},
  [973] = {.lex_state = 14},
  [974] = {.lex_state = 14},
  [975] = {.lex_state = 14},
  [976] = {.lex_state = 14},
  [977] = {.lex_state = 14},
  [978] = {.lex_state = 14},
  [979] = {.lex_state = 14},
  [980] = {.lex_state = 14},
  [981] = {.lex_state = 14},
  [982] = {.lex_state = 14},
  [983] = {.lex_state = 18},
  [984] = {.lex_state = 14},
  [985] = {.lex_state = 14},
  [986] = {.lex_state = 14},
  [987] = {.lex_state = 14},
  [988] = {.lex_state = 14},
  [989] = {.lex_state = 14},
  [990] = {.lex_state = 14},
  [991] = {.lex_state = 14},
  [992] = {.lex_state = 14},
  [993] = {.lex_state = 14},
  [994] = {.lex_state = 14},
  [995] = {.lex_state = 14},
  [996] = {.lex_state = 14},
  [997] = {.lex_state = 14},
  [998] = {.lex_state = 14},
  [999] = {.lex_state = 14},
  [1000] = {.lex_state = 14},
  [1001] = {.lex_state = 14},
  [1002] = {.lex_state = 14},
  [1003] = {.lex_state = 14},
  [1004] = {.lex_state = 14},
  [1005] = {.lex_state = 14},
  [1006] = {.lex_state = 14},
  [1007] = {.lex_state = 14},
  [1008] = {.lex_state = 14},
  [1009] = {.lex_state = 14},
  [1010] = {.lex_state = 14},
  [1011] = {.lex_state = 14},
  [1012] = {.lex_state = 14},
  [1013] = {.lex_state = 14},
  [1014] = {.lex_state = 14},
  [1015] = {.lex_state = 14},
  [1016] = {.lex_state = 14},
  [1017] = {.lex_state = 14},
  [1018] = {.lex_state = 14},
  [1019] = {.lex_state = 14},
  [1020] = {.lex_state = 14},
  [1021] = {.lex_state = 14},
  [1022] = {.lex_state = 14},
  [1023] = {.lex_state = 14},
  [1024] = {.lex_state = 14},
  [1025] = {.lex_state = 14},
  [1026] = {.lex_state = 14},
  [1027] = {.lex_state = 14},
  [1028] = {.lex_state = 14},
  [1029] = {.lex_state = 14},
  [1030] = {.lex_state = 14},
  [1031] = {.lex_state = 14},
  [1032] = {.lex_state = 14},
  [1033] = {.lex_state = 14},
  [1034] = {.lex_state = 14},
  [1035] = {.lex_state = 14},
  [1036] = {.lex_state = 14},
  [1037] = {.lex_state = 14},
  [1038] = {.lex_state = 14},
  [1039] = {.lex_state = 14},
  [1040] = {.lex_state = 14},
  [1041] = {.lex_state = 14},
  [1042] = {.lex_state = 14},
  [1043] = {.lex_state = 14},
  [1044] = {.lex_state = 14},
  [1045] = {.lex_state = 14},
  [1046] = {.lex_state = 14},
  [1047] = {.lex_state = 14},
  [1048] = {.lex_state = 14},
  [1049] = {.lex_state = 14},
  [1050] = {.lex_state = 14},
  [1051] = {.lex_state = 14},
  [1052] = {.lex_state = 14},
  [1053] = {.lex_state = 14},
  [1054] = {.lex_state = 14},
  [1055] = {.lex_state = 14},
  [1056] = {.lex_state = 14},
  [1057] = {.lex_state = 14},
  [1058] = {.lex_state = 14},
  [1059] = {.lex_state = 14},
  [1060] = {.lex_state = 14},
  [1061] = {.lex_state = 14},
  [1062] = {.lex_state = 14},
  [1063] = {.lex_state = 14},
  [1064] = {.lex_state = 14},
  [1065] = {.lex_state = 14},
  [1066] = {.lex_state = 14},
  [1067] = {.lex_state = 14},
  [1068] = {.lex_state = 14},
  [1069] = {.lex_state = 14},
  [1070] = {.lex_state = 14},
  [1071] = {.lex_state = 14},
  [1072] = {.lex_state = 14},
  [1073] = {.lex_state = 14},
  [1074] = {.lex_state = 14},
  [1075] = {.lex_state = 14},
  [1076] = {.lex_state = 14},
  [1077] = {.lex_state = 14},
  [1078] = {.lex_state = 14},
  [1079] = {.lex_state = 14},
  [1080] = {.lex_state = 14},
  [1081] = {.lex_state = 14},
  [1082] = {.lex_state = 14},
  [1083] = {.lex_state = 14},
  [1084] = {.lex_state = 14},
  [1085] = {.lex_state = 14},
  [1086] = {.lex_state = 14},
  [1087] = {.lex_state = 14},
  [1088] = {.lex_state = 14},
  [1089] = {.lex_state = 14},
  [1090] = {.lex_state = 14},
  [1091] = {.lex_state = 14},
  [1092] = {.lex_state = 14},
  [1093] = {.lex_state = 14},
  [1094] = {.lex_state = 14},
  [1095] = {.lex_state = 14},
  [1096] = {.lex_state = 14},
  [1097] = {.lex_state = 14},
  [1098] = {.lex_state = 14},
  [1099] = {.lex_state = 14},
  [1100] = {.lex_state = 14},
  [1101] = {.lex_state = 14},
  [1102] = {.lex_state = 14},
  [1103] = {.lex_state = 14},
  [1104] = {.lex_state = 14},
  [1105] = {.lex_state = 14},
  [1106] = {.lex_state = 14},
  [1107] = {.lex_state = 14},
  [1108] = {.lex_state = 14},
  [1109] = {.lex_state = 14},
  [1110] = {.lex_state = 14},
  [1111] = {.lex_state = 14},
  [1112] = {.lex_state = 14},
  [1113] = {.lex_state = 14},
  [1114] = {.lex_state = 14},
  [1115] = {.lex_state = 14},
  [1116] = {.lex_state = 14},
  [1117] = {.lex_state = 14},
  [1118] = {.lex_state = 14},
  [1119] = {.lex_state = 14},
  [1120] = {.lex_state = 14},
  [1121] = {.lex_state = 14},
  [1122] = {.lex_state = 14},
  [1123] = {.lex_state = 14},
  [1124] = {.lex_state = 14},
  [1125] = {.lex_state = 14},
  [1126] = {.lex_state = 14},
  [1127] = {.lex_state = 14},
  [1128] = {.lex_state = 14},
  [1129] = {.lex_state = 14},
  [1130] = {.lex_state = 14},
  [1131] = {.lex_state = 14},
  [1132] = {.lex_state = 14},
  [1133] = {.lex_state = 14},
  [1134] = {.lex_state = 14},
  [1135] = {.lex_state = 14},
  [1136] = {.lex_state = 14},
  [1137] = {.lex_state = 14},
  [1138] = {.lex_state = 14},
  [1139] = {.lex_state = 14},
  [1140] = {.lex_state = 14},
  [1141] = {.lex_state = 14},
  [1142] = {.lex_state = 14},
  [1143] = {.lex_state = 14},
  [1144] = {.lex_state = 14},
  [1145] = {.lex_state = 14},
  [1146] = {.lex_state = 14},
  [1147] = {.lex_state = 14},
  [1148] = {.lex_state = 14},
  [1149] = {.lex_state = 14},
  [1150] = {.lex_state = 14},
  [1151] = {.lex_state = 14},
  [1152] = {.lex_state = 14},
  [1153] = {.lex_state = 14},
  [1154] = {.lex_state = 15},
  [1155] = {.lex_state = 368},
  [1156] = {.lex_state = 368},
  [1157] = {.lex_state = 15},
  [1158] = {.lex_state = 15},
  [1159] = {.lex_state = 368},
  [1160] = {.lex_state = 34},
  [1161] = {.lex_state = 34},
  [1162] = {.lex_state = 34},
  [1163] = {.lex_state = 34},
  [1164] = {.lex_state = 34},
  [1165] = {.lex_state = 34},
  [1166] = {.lex_state = 34},
  [1167] = {.lex_state = 34},
  [1168] = {.lex_state = 34},
  [1169] = {.lex_state = 34},
  [1170] = {.lex_state = 34},
  [1171] = {.lex_state = 34},
  [1172] = {.lex_state = 34},
  [1173] = {.lex_state = 34},
  [1174] = {.lex_state = 34},
  [1175] = {.lex_state = 34},
  [1176] = {.lex_state = 34},
  [1177] = {.lex_state = 34},
  [1178] = {.lex_state = 34},
  [1179] = {.lex_state = 34},
  [1180] = {.lex_state = 34},
  [1181] = {.lex_state = 34},
  [1182] = {.lex_state = 34},
  [1183] = {.lex_state = 34},
  [1184] = {.lex_state = 34},
  [1185] = {.lex_state = 34},
  [1186] = {.lex_state = 34},
  [1187] = {.lex_state = 34},
  [1188] = {.lex_state = 34},
  [1189] = {.lex_state = 34},
  [1190] = {.lex_state = 34},
  [1191] = {.lex_state = 34},
  [1192] = {.lex_state = 34},
  [1193] = {.lex_state = 34},
  [1194] = {.lex_state = 34},
  [1195] = {.lex_state = 34},
  [1196] = {.lex_state = 34},
  [1197] = {.lex_state = 34},
  [1198] = {.lex_state = 34},
  [1199] = {.lex_state = 34},
  [1200] = {.lex_state = 34},
  [1201] = {.lex_state = 34},
  [1202] = {.lex_state = 34},
  [1203] = {.lex_state = 34},
  [1204] = {.lex_state = 34},
  [1205] = {.lex_state = 34},
  [1206] = {.lex_state = 34},
  [1207] = {.lex_state = 34},
  [1208] = {.lex_state = 34},
  [1209] = {.lex_state = 34},
  [1210] = {.lex_state = 34},
  [1211] = {.lex_state = 34},
  [1212] = {.lex_state = 34},
  [1213] = {.lex_state = 34},
  [1214] = {.lex_state = 34},
  [1215] = {.lex_state = 34},
  [1216] = {.lex_state = 34},
  [1217] = {.lex_state = 34},
  [1218] = {.lex_state = 34},
  [1219] = {.lex_state = 34},
  [1220] = {.lex_state = 34},
  [1221] = {.lex_state = 34},
  [1222] = {.lex_state = 34},
  [1223] = {.lex_state = 34},
  [1224] = {.lex_state = 34},
  [1225] = {.lex_state = 34},
  [1226] = {.lex_state = 34},
  [1227] = {.lex_state = 34},
  [1228] = {.lex_state = 34},
  [1229] = {.lex_state = 34},
  [1230] = {.lex_state = 34},
  [1231] = {.lex_state = 34},
  [1232] = {.lex_state = 34},
  [1233] = {.lex_state = 34},
  [1234] = {.lex_state = 34},
  [1235] = {.lex_state = 34},
  [1236] = {.lex_state = 34},
  [1237] = {.lex_state = 34},
  [1238] = {.lex_state = 34},
  [1239] = {.lex_state = 34},
  [1240] = {.lex_state = 34},
  [1241] = {.lex_state = 34},
  [1242] = {.lex_state = 34},
  [1243] = {.lex_state = 34},
  [1244] = {.lex_state = 34},
  [1245] = {.lex_state = 34},
  [1246] = {.lex_state = 34},
  [1247] = {.lex_state = 34},
  [1248] = {.lex_state = 34},
  [1249] = {.lex_state = 34},
  [1250] = {.lex_state = 34},
  [1251] = {.lex_state = 34},
  [1252] = {.lex_state = 34},
  [1253] = {.lex_state = 34},
  [1254] = {.lex_state = 34},
  [1255] = {.lex_state = 34},
  [1256] = {.lex_state = 34},
  [1257] = {.lex_state = 34},
  [1258] = {.lex_state = 34},
  [1259] = {.lex_state = 34},
  [1260] = {.lex_state = 34},
  [1261] = {.lex_state = 34},
  [1262] = {.lex_state = 34},
  [1263] = {.lex_state = 34},
  [1264] = {.lex_state = 34},
  [1265] = {.lex_state = 34},
  [1266] = {.lex_state = 34},
  [1267] = {.lex_state = 34},
  [1268] = {.lex_state = 34},
  [1269] = {.lex_state = 34},
  [1270] = {.lex_state = 34},
  [1271] = {.lex_state = 34},
  [1272] = {.lex_state = 34},
  [1273] = {.lex_state = 34},
  [1274] = {.lex_state = 34},
  [1275] = {.lex_state = 34},
  [1276] = {.lex_state = 34},
  [1277] = {.lex_state = 34},
  [1278] = {.lex_state = 34},
  [1279] = {.lex_state = 34},
  [1280] = {.lex_state = 34},
  [1281] = {.lex_state = 34},
  [1282] = {.lex_state = 34},
  [1283] = {.lex_state = 34},
  [1284] = {.lex_state = 34},
  [1285] = {.lex_state = 34},
  [1286] = {.lex_state = 34},
  [1287] = {.lex_state = 34},
  [1288] = {.lex_state = 34},
  [1289] = {.lex_state = 46},
  [1290] = {.lex_state = 46},
  [1291] = {.lex_state = 368},
  [1292] = {.lex_state = 368},
  [1293] = {.lex_state = 368},
  [1294] = {.lex_state = 368},
  [1295] = {.lex_state = 36},
  [1296] = {.lex_state = 368},
  [1297] = {.lex_state = 44},
  [1298] = {.lex_state = 368},
  [1299] = {.lex_state = 368},
  [1300] = {.lex_state = 368},
  [1301] = {.lex_state = 34},
  [1302] = {.lex_state = 44},
  [1303] = {.lex_state = 368},
  [1304] = {.lex_state = 368},
  [1305] = {.lex_state = 368},
  [1306] = {.lex_state = 368},
  [1307] = {.lex_state = 368},
  [1308] = {.lex_state = 368},
  [1309] = {.lex_state = 45},
  [1310] = {.lex_state = 368},
  [1311] = {.lex_state = 368},
  [1312] = {.lex_state = 34},
  [1313] = {.lex_state = 368},
  [1314] = {.lex_state = 44},
  [1315] = {.lex_state = 368},
  [1316] = {.lex_state = 36},
  [1317] = {.lex_state = 34},
  [1318] = {.lex_state = 368},
  [1319] = {.lex_state = 368},
  [1320] = {.lex_state = 368},
  [1321] = {.lex_state = 368},
  [1322] = {.lex_state = 368},
  [1323] = {.lex_state = 34},
  [1324] = {.lex_state = 368},
  [1325] = {.lex_state = 45},
  [1326] = {.lex_state = 34},
  [1327] = {.lex_state = 368},
  [1328] = {.lex_state = 368},
  [1329] = {.lex_state = 368},
  [1330] = {.lex_state = 368},
  [1331] = {.lex_state = 368},
  [1332] = {.lex_state = 34},
  [1333] = {.lex_state = 368},
  [1334] = {.lex_state = 368},
  [1335] = {.lex_state = 34},
  [1336] = {.lex_state = 368},
  [1337] = {.lex_state = 368},
  [1338] = {.lex_state = 368},
  [1339] = {.lex_state = 36},
  [1340] = {.lex_state = 368},
  [1341] = {.lex_state = 368},
  [1342] = {.lex_state = 368},
  [1343] = {.lex_state = 368},
  [1344] = {.lex_state = 368},
  [1345] = {.lex_state = 368},
  [1346] = {.lex_state = 368},
  [1347] = {.lex_state = 368},
  [1348] = {.lex_state = 368},
  [1349] = {.lex_state = 34},
  [1350] = {.lex_state = 368},
  [1351] = {.lex_state = 368},
  [1352] = {.lex_state = 368},
  [1353] = {.lex_state = 368},
  [1354] = {.lex_state = 368},
  [1355] = {.lex_state = 368},
  [1356] = {.lex_state = 368},
  [1357] = {.lex_state = 368},
  [1358] = {.lex_state = 45},
  [1359] = {.lex_state = 368},
  [1360] = {.lex_state = 368},
  [1361] = {.lex_state = 368},
  [1362] = {.lex_state = 368},
  [1363] = {.lex_state = 368},
  [1364] = {.lex_state = 368},
  [1365] = {.lex_state = 368},
  [1366] = {.lex_state = 368},
  [1367] = {.lex_state = 368},
  [1368] = {.lex_state = 368},
  [1369] = {.lex_state = 368},
  [1370] = {.lex_state = 368},
  [1371] = {.lex_state = 368},
  [1372] = {.lex_state = 368},
  [1373] = {.lex_state = 368},
  [1374] = {.lex_state = 368},
  [1375] = {.lex_state = 36},
  [1376] = {.lex_state = 368},
  [1377] = {.lex_state = 368},
  [1378] = {.lex_state = 368},
  [1379] = {.lex_state = 368},
  [1380] = {.lex_state = 0},
  [1381] = {.lex_state = 36},
  [1382] = {.lex_state = 0},
  [1383] = {.lex_state = 0},
  [1384] = {.lex_state = 36},
  [1385] = {.lex_state = 41},
  [1386] = {.lex_state = 28},
  [1387] = {.lex_state = 28},
  [1388] = {.lex_state = 28},
  [1389] = {.lex_state = 41},
  [1390] = {.lex_state = 28},
  [1391] = {.lex_state = 16},
  [1392] = {.lex_state = 28},
  [1393] = {.lex_state = 28},
  [1394] = {.lex_state = 0},
  [1395] = {.lex_state = 0},
  [1396] = {.lex_state = 28},
  [1397] = {.lex_state = 45},
  [1398] = {.lex_state = 28},
  [1399] = {.lex_state = 45},
  [1400] = {.lex_state = 28},
  [1401] = {.lex_state = 28},
  [1402] = {.lex_state = 44},
  [1403] = {.lex_state = 45},
  [1404] = {.lex_state = 28},
  [1405] = {.lex_state = 44},
  [1406] = {.lex_state = 41},
  [1407] = {.lex_state = 28},
  [1408] = {.lex_state = 35},
  [1409] = {.lex_state = 44},
  [1410] = {.lex_state = 44},
  [1411] = {.lex_state = 45},
  [1412] = {.lex_state = 44},
  [1413] = {.lex_state = 28},
  [1414] = {.lex_state = 45},
  [1415] = {.lex_state = 44},
  [1416] = {.lex_state = 35},
  [1417] = {.lex_state = 44},
  [1418] = {.lex_state = 28},
  [1419] = {.lex_state = 45},
  [1420] = {.lex_state = 28},
  [1421] = {.lex_state = 45},
  [1422] = {.lex_state = 45},
  [1423] = {.lex_state = 45},
  [1424] = {.lex_state = 44},
  [1425] = {.lex_state = 45},
  [1426] = {.lex_state = 44},
  [1427] = {.lex_state = 45},
  [1428] = {.lex_state = 45},
  [1429] = {.lex_state = 45},
  [1430] = {.lex_state = 44},
  [1431] = {.lex_state = 45},
  [1432] = {.lex_state = 35},
  [1433] = {.lex_state = 44},
  [1434] = {.lex_state = 45},
  [1435] = {.lex_state = 45},
  [1436] = {.lex_state = 44},
  [1437] = {.lex_state = 44},
  [1438] = {.lex_state = 45},
  [1439] = {.lex_state = 44},
  [1440] = {.lex_state = 44},
  [1441] = {.lex_state = 45},
  [1442] = {.lex_state = 44},
  [1443] = {.lex_state = 44},
  [1444] = {.lex_state = 44},
  [1445] = {.lex_state = 45},
  [1446] = {.lex_state = 45},
  [1447] = {.lex_state = 28},
  [1448] = {.lex_state = 44},
  [1449] = {.lex_state = 45},
  [1450] = {.lex_state = 28},
  [1451] = {.lex_state = 44},
  [1452] = {.lex_state = 44},
  [1453] = {.lex_state = 45},
  [1454] = {.lex_state = 44},
  [1455] = {.lex_state = 44},
  [1456] = {.lex_state = 44},
  [1457] = {.lex_state = 368},
  [1458] = {.lex_state = 41},
  [1459] = {.lex_state = 368},
  [1460] = {.lex_state = 41},
  [1461] = {.lex_state = 41},
  [1462] = {.lex_state = 41},
  [1463] = {.lex_state = 28},
  [1464] = {.lex_state = 41},
  [1465] = {.lex_state = 41},
  [1466] = {.lex_state = 41},
  [1467] = {.lex_state = 35},
  [1468] = {.lex_state = 28},
  [1469] = {.lex_state = 36},
  [1470] = {.lex_state = 35},
  [1471] = {.lex_state = 41},
  [1472] = {.lex_state = 28},
  [1473] = {.lex_state = 41},
  [1474] = {.lex_state = 35},
  [1475] = {.lex_state = 36},
  [1476] = {.lex_state = 368},
  [1477] = {.lex_state = 35},
  [1478] = {.lex_state = 36},
  [1479] = {.lex_state = 28},
  [1480] = {.lex_state = 36},
  [1481] = {.lex_state = 35},
  [1482] = {.lex_state = 41},
  [1483] = {.lex_state = 41},
  [1484] = {.lex_state = 368},
  [1485] = {.lex_state = 36},
  [1486] = {.lex_state = 36},
  [1487] = {.lex_state = 16},
  [1488] = {.lex_state = 28},
  [1489] = {.lex_state = 16},
  [1490] = {.lex_state = 28},
  [1491] = {.lex_state = 28},
  [1492] = {.lex_state = 28},
  [1493] = {.lex_state = 36},
  [1494] = {.lex_state = 368},
  [1495] = {.lex_state = 28},
  [1496] = {.lex_state = 28},
  [1497] = {.lex_state = 16},
  [1498] = {.lex_state = 28},
  [1499] = {.lex_state = 16},
  [1500] = {.lex_state = 368},
  [1501] = {.lex_state = 16},
  [1502] = {.lex_state = 16},
  [1503] = {.lex_state = 36},
  [1504] = {.lex_state = 28},
  [1505] = {.lex_state = 368},
  [1506] = {.lex_state = 16},
  [1507] = {.lex_state = 16},
  [1508] = {.lex_state = 28},
  [1509] = {.lex_state = 36},
  [1510] = {.lex_state = 16},
  [1511] = {.lex_state = 16},
  [1512] = {.lex_state = 16},
  [1513] = {.lex_state = 41},
  [1514] = {.lex_state = 16},
  [1515] = {.lex_state = 28},
  [1516] = {.lex_state = 28},
  [1517] = {.lex_state = 32},
  [1518] = {.lex_state = 41},
  [1519] = {.lex_state = 36},
  [1520] = {.lex_state = 36},
  [1521] = {.lex_state = 28},
  [1522] = {.lex_state = 36},
  [1523] = {.lex_state = 16},
  [1524] = {.lex_state = 36},
  [1525] = {.lex_state = 28},
  [1526] = {.lex_state = 16},
  [1527] = {.lex_state = 41},
  [1528] = {.lex_state = 16},
  [1529] = {.lex_state = 28},
  [1530] = {.lex_state = 36},
  [1531] = {.lex_state = 16},
  [1532] = {.lex_state = 36},
  [1533] = {.lex_state = 36},
  [1534] = {.lex_state = 41},
  [1535] = {.lex_state = 33},
  [1536] = {.lex_state = 36},
  [1537] = {.lex_state = 0},
  [1538] = {.lex_state = 30},
  [1539] = {.lex_state = 29},
  [1540] = {.lex_state = 29},
  [1541] = {.lex_state = 31},
  [1542] = {.lex_state = 31},
  [1543] = {.lex_state = 31},
  [1544] = {.lex_state = 30},
  [1545] = {.lex_state = 0},
  [1546] = {.lex_state = 30},
  [1547] = {.lex_state = 28},
  [1548] = {.lex_state = 30},
  [1549] = {.lex_state = 29},
  [1550] = {.lex_state = 31},
  [1551] = {.lex_state = 29},
  [1552] = {.lex_state = 30},
  [1553] = {.lex_state = 29},
  [1554] = {.lex_state = 28},
  [1555] = {.lex_state = 28},
  [1556] = {.lex_state = 31},
  [1557] = {.lex_state = 30},
  [1558] = {.lex_state = 30},
  [1559] = {.lex_state = 28},
  [1560] = {.lex_state = 0},
  [1561] = {.lex_state = 28},
  [1562] = {.lex_state = 31},
  [1563] = {.lex_state = 28},
  [1564] = {.lex_state = 28},
  [1565] = {.lex_state = 28},
  [1566] = {.lex_state = 29},
  [1567] = {.lex_state = 28},
  [1568] = {.lex_state = 30},
  [1569] = {.lex_state = 28},
  [1570] = {.lex_state = 28},
  [1571] = {.lex_state = 31},
  [1572] = {.lex_state = 16},
  [1573] = {.lex_state = 29},
  [1574] = {.lex_state = 28},
  [1575] = {.lex_state = 28},
  [1576] = {.lex_state = 31},
  [1577] = {.lex_state = 28},
  [1578] = {.lex_state = 30},
  [1579] = {.lex_state = 29},
  [1580] = {.lex_state = 29},
  [1581] = {.lex_state = 30},
  [1582] = {.lex_state = 31},
  [1583] = {.lex_state = 30},
  [1584] = {.lex_state = 28},
  [1585] = {.lex_state = 28},
  [1586] = {.lex_state = 31},
  [1587] = {.lex_state = 28},
  [1588] = {.lex_state = 16},
  [1589] = {.lex_state = 29},
  [1590] = {.lex_state = 31},
  [1591] = {.lex_state = 29},
  [1592] = {.lex_state = 47},
  [1593] = {.lex_state = 16},
  [1594] = {.lex_state = 0},
  [1595] = {.lex_state = 0},
  [1596] = {.lex_state = 16},
  [1597] = {.lex_state = 28},
  [1598] = {.lex_state = 0},
  [1599] = {.lex_state = 0},
  [1600] = {.lex_state = 16},
  [1601] = {.lex_state = 28},
  [1602] = {.lex_state = 0},
  [1603] = {.lex_state = 28},
  [1604] = {.lex_state = 16},
  [1605] = {.lex_state = 0},
  [1606] = {.lex_state = 0},
  [1607] = {.lex_state = 28},
  [1608] = {.lex_state = 0},
  [1609] = {.lex_state = 16},
  [1610] = {.lex_state = 28},
  [1611] = {.lex_state = 28},
  [1612] = {.lex_state = 0},
  [1613] = {.lex_state = 0},
  [1614] = {.lex_state = 28},
  [1615] = {.lex_state = 0},
  [1616] = {.lex_state = 16},
  [1617] = {.lex_state = 0},
  [1618] = {.lex_state = 48},
  [1619] = {.lex_state = 0},
  [1620] = {.lex_state = 28},
  [1621] = {.lex_state = 0},
  [1622] = {.lex_state = 16},
  [1623] = {.lex_state = 13},
  [1624] = {.lex_state = 16},
  [1625] = {.lex_state = 16},
  [1626] = {.lex_state = 0},
  [1627] = {.lex_state = 28},
  [1628] = {.lex_state = 28},
  [1629] = {.lex_state = 0},
  [1630] = {.lex_state = 43},
  [1631] = {.lex_state = 16},
  [1632] = {.lex_state = 16},
  [1633] = {.lex_state = 0},
  [1634] = {.lex_state = 16},
  [1635] = {.lex_state = 36},
  [1636] = {.lex_state = 28},
  [1637] = {.lex_state = 48},
  [1638] = {.lex_state = 16},
  [1639] = {.lex_state = 0},
  [1640] = {.lex_state = 0},
  [1641] = {.lex_state = 48},
  [1642] = {.lex_state = 0},
  [1643] = {.lex_state = 28},
  [1644] = {.lex_state = 0},
  [1645] = {.lex_state = 0},
  [1646] = {.lex_state = 16},
  [1647] = {.lex_state = 0},
  [1648] = {.lex_state = 13},
  [1649] = {.lex_state = 0},
  [1650] = {.lex_state = 0},
  [1651] = {.lex_state = 13},
  [1652] = {.lex_state = 28},
  [1653] = {.lex_state = 28},
  [1654] = {.lex_state = 16},
  [1655] = {.lex_state = 0},
  [1656] = {.lex_state = 16},
  [1657] = {.lex_state = 28},
  [1658] = {.lex_state = 0},
  [1659] = {.lex_state = 0},
  [1660] = {.lex_state = 16},
  [1661] = {.lex_state = 0},
  [1662] = {.lex_state = 0},
  [1663] = {.lex_state = 368},
  [1664] = {.lex_state = 0},
  [1665] = {.lex_state = 0},
  [1666] = {.lex_state = 0},
  [1667] = {.lex_state = 0},
  [1668] = {.lex_state = 0},
  [1669] = {.lex_state = 0},
  [1670] = {.lex_state = 0},
  [1671] = {.lex_state = 0},
  [1672] = {.lex_state = 0},
  [1673] = {.lex_state = 0},
  [1674] = {.lex_state = 0},
  [1675] = {.lex_state = 368},
  [1676] = {.lex_state = 0},
  [1677] = {.lex_state = 0},
  [1678] = {.lex_state = 0},
  [1679] = {.lex_state = 0},
  [1680] = {.lex_state = 28},
  [1681] = {.lex_state = 0},
  [1682] = {.lex_state = 0},
  [1683] = {.lex_state = 0},
  [1684] = {.lex_state = 0},
  [1685] = {.lex_state = 0},
  [1686] = {.lex_state = 16},
  [1687] = {.lex_state = 0},
  [1688] = {.lex_state = 16},
  [1689] = {.lex_state = 0},
  [1690] = {.lex_state = 13},
  [1691] = {.lex_state = 368},
  [1692] = {.lex_state = 28},
  [1693] = {.lex_state = 0},
  [1694] = {.lex_state = 0},
  [1695] = {.lex_state = 16},
  [1696] = {.lex_state = 0},
  [1697] = {.lex_state = 0},
  [1698] = {.lex_state = 0},
  [1699] = {.lex_state = 0},
  [1700] = {.lex_state = 49},
  [1701] = {.lex_state = 0},
  [1702] = {.lex_state = 0},
  [1703] = {.lex_state = 0},
  [1704] = {.lex_state = 0},
  [1705] = {.lex_state = 0},
  [1706] = {.lex_state = 0},
  [1707] = {.lex_state = 0},
  [1708] = {.lex_state = 0},
  [1709] = {.lex_state = 0},
  [1710] = {.lex_state = 16},
  [1711] = {.lex_state = 0},
  [1712] = {.lex_state = 0},
  [1713] = {.lex_state = 0},
  [1714] = {.lex_state = 0},
  [1715] = {.lex_state = 0},
  [1716] = {.lex_state = 0},
  [1717] = {.lex_state = 0},
  [1718] = {.lex_state = 16},
  [1719] = {.lex_state = 0},
  [1720] = {.lex_state = 0},
  [1721] = {.lex_state = 0},
  [1722] = {.lex_state = 0},
  [1723] = {.lex_state = 0},
  [1724] = {.lex_state = 28},
  [1725] = {.lex_state = 0},
  [1726] = {.lex_state = 0},
  [1727] = {.lex_state = 28},
  [1728] = {.lex_state = 0},
  [1729] = {.lex_state = 0},
  [1730] = {.lex_state = 0},
  [1731] = {.lex_state = 0},
  [1732] = {.lex_state = 0},
  [1733] = {.lex_state = 0},
  [1734] = {.lex_state = 16},
  [1735] = {.lex_state = 0},
  [1736] = {.lex_state = 29},
  [1737] = {.lex_state = 0},
  [1738] = {.lex_state = 0},
  [1739] = {.lex_state = 16},
  [1740] = {.lex_state = 0},
  [1741] = {.lex_state = 0},
  [1742] = {.lex_state = 31},
  [1743] = {.lex_state = 0},
  [1744] = {.lex_state = 0},
  [1745] = {.lex_state = 16},
  [1746] = {.lex_state = 0},
  [1747] = {.lex_state = 0},
  [1748] = {.lex_state = 0},
  [1749] = {.lex_state = 0},
  [1750] = {.lex_state = 0},
  [1751] = {.lex_state = 0},
  [1752] = {.lex_state = 0},
  [1753] = {.lex_state = 31},
  [1754] = {.lex_state = 0},
  [1755] = {.lex_state = 28},
  [1756] = {.lex_state = 0},
  [1757] = {.lex_state = 0},
  [1758] = {.lex_state = 28},
  [1759] = {.lex_state = 0},
  [1760] = {.lex_state = 0},
  [1761] = {.lex_state = 28},
  [1762] = {.lex_state = 0},
  [1763] = {.lex_state = 0},
  [1764] = {.lex_state = 0},
  [1765] = {.lex_state = 16},
  [1766] = {.lex_state = 49},
  [1767] = {.lex_state = 0},
  [1768] = {.lex_state = 0},
  [1769] = {.lex_state = 0},
  [1770] = {.lex_state = 0},
  [1771] = {.lex_state = 16},
  [1772] = {.lex_state = 0},
  [1773] = {.lex_state = 0},
  [1774] = {.lex_state = 0},
  [1775] = {.lex_state = 0},
  [1776] = {.lex_state = 28},
  [1777] = {.lex_state = 0},
  [1778] = {.lex_state = 0},
  [1779] = {.lex_state = 0},
  [1780] = {.lex_state = 16},
  [1781] = {.lex_state = 16},
  [1782] = {.lex_state = 0},
  [1783] = {.lex_state = 0},
  [1784] = {.lex_state = 16},
  [1785] = {.lex_state = 0},
  [1786] = {.lex_state = 0},
  [1787] = {.lex_state = 368},
  [1788] = {.lex_state = 16},
  [1789] = {.lex_state = 0},
  [1790] = {.lex_state = 16},
  [1791] = {.lex_state = 0},
  [1792] = {.lex_state = 28},
  [1793] = {.lex_state = 16},
  [1794] = {.lex_state = 0},
  [1795] = {.lex_state = 0},
  [1796] = {.lex_state = 16},
  [1797] = {.lex_state = 0},
  [1798] = {.lex_state = 0},
  [1799] = {.lex_state = 29},
  [1800] = {.lex_state = 16},
  [1801] = {.lex_state = 0},
  [1802] = {.lex_state = 16},
  [1803] = {.lex_state = 0},
  [1804] = {.lex_state = 16},
  [1805] = {.lex_state = 0},
  [1806] = {.lex_state = 16},
  [1807] = {.lex_state = 0},
  [1808] = {.lex_state = 0},
  [1809] = {.lex_state = 16},
  [1810] = {.lex_state = 0},
  [1811] = {.lex_state = 0},
  [1812] = {.lex_state = 16},
  [1813] = {.lex_state = 0},
  [1814] = {.lex_state = 0},
  [1815] = {.lex_state = 28},
  [1816] = {.lex_state = 0},
  [1817] = {.lex_state = 0},
  [1818] = {.lex_state = 0},
  [1819] = {.lex_state = 28},
  [1820] = {.lex_state = 368},
  [1821] = {.lex_state = 0},
  [1822] = {.lex_state = 49},
  [1823] = {.lex_state = 28},
  [1824] = {.lex_state = 49},
  [1825] = {.lex_state = 0},
  [1826] = {.lex_state = 28},
  [1827] = {.lex_state = 0},
  [1828] = {.lex_state = 0},
  [1829] = {.lex_state = 49},
  [1830] = {.lex_state = 368},
  [1831] = {.lex_state = 0},
  [1832] = {.lex_state = 30},
  [1833] = {.lex_state = 16},
  [1834] = {.lex_state = 0},
  [1835] = {.lex_state = 0},
  [1836] = {.lex_state = 28},
  [1837] = {.lex_state = 368},
  [1838] = {.lex_state = 0},
  [1839] = {.lex_state = 0},
  [1840] = {.lex_state = 0},
  [1841] = {.lex_state = 0},
  [1842] = {.lex_state = 0},
  [1843] = {.lex_state = 28},
  [1844] = {.lex_state = 368},
  [1845] = {.lex_state = 368},
  [1846] = {.lex_state = 16},
  [1847] = {.lex_state = 0},
  [1848] = {.lex_state = 0},
  [1849] = {.lex_state = 28},
  [1850] = {.lex_state = 0},
  [1851] = {.lex_state = 28},
  [1852] = {.lex_state = 28},
  [1853] = {.lex_state = 368},
  [1854] = {.lex_state = 16},
  [1855] = {.lex_state = 0},
  [1856] = {.lex_state = 28},
  [1857] = {.lex_state = 0},
  [1858] = {.lex_state = 28},
  [1859] = {.lex_state = 368},
  [1860] = {.lex_state = 0},
  [1861] = {.lex_state = 28},
  [1862] = {.lex_state = 0},
  [1863] = {.lex_state = 28},
  [1864] = {.lex_state = 368},
  [1865] = {.lex_state = 368},
  [1866] = {.lex_state = 28},
  [1867] = {.lex_state = 0},
  [1868] = {.lex_state = 28},
  [1869] = {.lex_state = 16},
  [1870] = {.lex_state = 49},
  [1871] = {.lex_state = 28},
  [1872] = {.lex_state = 0},
  [1873] = {.lex_state = 0},
  [1874] = {.lex_state = 0},
  [1875] = {.lex_state = 16},
  [1876] = {.lex_state = 30},
  [1877] = {.lex_state = 0},
  [1878] = {.lex_state = 368},
  [1879] = {.lex_state = 0},
  [1880] = {.lex_state = 0},
  [1881] = {.lex_state = 16},
  [1882] = {.lex_state = 16},
  [1883] = {.lex_state = 368},
  [1884] = {.lex_state = 0},
  [1885] = {.lex_state = 0},
  [1886] = {.lex_state = 0},
  [1887] = {.lex_state = 0},
  [1888] = {.lex_state = 0},
  [1889] = {.lex_state = 0},
  [1890] = {.lex_state = 0},
  [1891] = {.lex_state = 0},
  [1892] = {.lex_state = 0},
  [1893] = {.lex_state = 28},
  [1894] = {.lex_state = 0},
  [1895] = {.lex_state = 0},
  [1896] = {.lex_state = 28},
  [1897] = {.lex_state = 0},
  [1898] = {.lex_state = 0},
  [1899] = {.lex_state = 0},
  [1900] = {.lex_state = 0},
  [1901] = {.lex_state = 0},
  [1902] = {.lex_state = 0},
  [1903] = {.lex_state = 0},
  [1904] = {.lex_state = 0},
  [1905] = {.lex_state = 0},
  [1906] = {.lex_state = 28},
  [1907] = {.lex_state = 0},
  [1908] = {.lex_state = 0},
  [1909] = {.lex_state = 0},
  [1910] = {.lex_state = 0},
  [1911] = {.lex_state = 0},
  [1912] = {.lex_state = 0},
  [1913] = {.lex_state = 0},
  [1914] = {.lex_state = 16},
  [1915] = {.lex_state = 0},
  [1916] = {.lex_state = 16},
  [1917] = {.lex_state = 0},
  [1918] = {.lex_state = 0},
  [1919] = {.lex_state = 0},
  [1920] = {.lex_state = 0},
  [1921] = {.lex_state = 0},
  [1922] = {.lex_state = 0},
  [1923] = {.lex_state = 0},
  [1924] = {.lex_state = 0},
  [1925] = {.lex_state = 0},
  [1926] = {.lex_state = 0},
  [1927] = {.lex_state = 28},
  [1928] = {.lex_state = 0},
  [1929] = {.lex_state = 28},
  [1930] = {.lex_state = 0},
  [1931] = {.lex_state = 0},
  [1932] = {.lex_state = 0},
  [1933] = {.lex_state = 0},
  [1934] = {.lex_state = 28},
  [1935] = {.lex_state = 14},
  [1936] = {.lex_state = 0},
  [1937] = {.lex_state = 0},
  [1938] = {.lex_state = 0},
  [1939] = {.lex_state = 28},
  [1940] = {.lex_state = 0},
  [1941] = {.lex_state = 0},
  [1942] = {.lex_state = 0},
  [1943] = {.lex_state = 0},
  [1944] = {.lex_state = 28},
  [1945] = {.lex_state = 28},
  [1946] = {.lex_state = 0},
  [1947] = {.lex_state = 0},
  [1948] = {.lex_state = 0},
  [1949] = {.lex_state = 0},
  [1950] = {.lex_state = 0},
  [1951] = {.lex_state = 0},
  [1952] = {.lex_state = 0},
  [1953] = {.lex_state = 0},
  [1954] = {.lex_state = 0},
  [1955] = {.lex_state = 0},
  [1956] = {.lex_state = 0},
  [1957] = {.lex_state = 0},
  [1958] = {.lex_state = 0},
  [1959] = {.lex_state = 0},
  [1960] = {.lex_state = 0},
  [1961] = {.lex_state = 0},
  [1962] = {.lex_state = 0},
  [1963] = {.lex_state = 0},
  [1964] = {.lex_state = 0},
  [1965] = {.lex_state = 0},
  [1966] = {.lex_state = 0},
  [1967] = {.lex_state = 0},
  [1968] = {.lex_state = 0},
  [1969] = {.lex_state = 16},
  [1970] = {.lex_state = 0},
  [1971] = {.lex_state = 0},
  [1972] = {.lex_state = 0},
  [1973] = {.lex_state = 16},
  [1974] = {.lex_state = 0},
  [1975] = {.lex_state = 0},
  [1976] = {.lex_state = 0},
  [1977] = {.lex_state = 0},
  [1978] = {.lex_state = 0},
  [1979] = {.lex_state = 0},
  [1980] = {.lex_state = 0},
  [1981] = {.lex_state = 0},
  [1982] = {.lex_state = 0},
  [1983] = {.lex_state = 0},
  [1984] = {.lex_state = 0},
  [1985] = {.lex_state = 0},
  [1986] = {.lex_state = 0},
  [1987] = {.lex_state = 0},
  [1988] = {.lex_state = 0},
  [1989] = {.lex_state = 0},
  [1990] = {.lex_state = 0},
  [1991] = {.lex_state = 0},
  [1992] = {.lex_state = 0},
  [1993] = {.lex_state = 0},
  [1994] = {.lex_state = 0},
  [1995] = {.lex_state = 0},
  [1996] = {.lex_state = 0},
  [1997] = {.lex_state = 0},
  [1998] = {.lex_state = 0},
  [1999] = {.lex_state = 28},
  [2000] = {.lex_state = 28},
  [2001] = {.lex_state = 0},
  [2002] = {.lex_state = 0},
  [2003] = {.lex_state = 0},
  [2004] = {.lex_state = 0},
  [2005] = {.lex_state = 0},
  [2006] = {.lex_state = 368},
  [2007] = {.lex_state = 28},
  [2008] = {.lex_state = 0},
  [2009] = {.lex_state = 28},
  [2010] = {.lex_state = 0},
  [2011] = {.lex_state = 28},
  [2012] = {.lex_state = 0},
  [2013] = {.lex_state = 0},
  [2014] = {.lex_state = 0},
  [2015] = {.lex_state = 28},
  [2016] = {.lex_state = 28},
  [2017] = {.lex_state = 16},
  [2018] = {.lex_state = 368},
  [2019] = {.lex_state = 0},
  [2020] = {.lex_state = 0},
  [2021] = {.lex_state = 28},
  [2022] = {.lex_state = 0},
  [2023] = {.lex_state = 28},
  [2024] = {.lex_state = 28},
  [2025] = {.lex_state = 0},
  [2026] = {.lex_state = 28},
  [2027] = {.lex_state = 0},
  [2028] = {.lex_state = 0},
  [2029] = {.lex_state = 0},
  [2030] = {.lex_state = 0},
  [2031] = {.lex_state = 0},
  [2032] = {.lex_state = 0},
  [2033] = {.lex_state = 0},
  [2034] = {.lex_state = 0},
  [2035] = {.lex_state = 28},
  [2036] = {.lex_state = 28},
  [2037] = {.lex_state = 0},
  [2038] = {.lex_state = 0},
  [2039] = {.lex_state = 0},
  [2040] = {.lex_state = 0},
  [2041] = {.lex_state = 28},
  [2042] = {.lex_state = 28},
  [2043] = {.lex_state = 0},
  [2044] = {.lex_state = 0},
  [2045] = {.lex_state = 368},
  [2046] = {.lex_state = 28},
  [2047] = {.lex_state = 28},
  [2048] = {.lex_state = 0},
  [2049] = {.lex_state = 28},
  [2050] = {.lex_state = 0},
  [2051] = {.lex_state = 0},
  [2052] = {.lex_state = 0},
  [2053] = {.lex_state = 28},
  [2054] = {.lex_state = 0},
  [2055] = {.lex_state = 0},
  [2056] = {.lex_state = 0},
  [2057] = {.lex_state = 28},
  [2058] = {.lex_state = 0},
  [2059] = {.lex_state = 0},
  [2060] = {.lex_state = 0},
  [2061] = {.lex_state = 28},
  [2062] = {.lex_state = 28},
  [2063] = {.lex_state = 0},
  [2064] = {.lex_state = 0},
  [2065] = {.lex_state = 0},
  [2066] = {.lex_state = 0},
  [2067] = {.lex_state = 0},
  [2068] = {.lex_state = 0},
  [2069] = {.lex_state = 28},
  [2070] = {.lex_state = 0},
  [2071] = {.lex_state = 0},
  [2072] = {.lex_state = 28},
  [2073] = {.lex_state = 0},
  [2074] = {.lex_state = 0},
  [2075] = {.lex_state = 0},
  [2076] = {.lex_state = 0},
  [2077] = {.lex_state = 28},
  [2078] = {.lex_state = 0},
  [2079] = {.lex_state = 0},
  [2080] = {.lex_state = 0},
  [2081] = {.lex_state = 0},
  [2082] = {.lex_state = 0},
  [2083] = {.lex_state = 0},
  [2084] = {.lex_state = 28},
  [2085] = {.lex_state = 28},
  [2086] = {.lex_state = 28},
  [2087] = {.lex_state = 0},
  [2088] = {.lex_state = 13},
  [2089] = {.lex_state = 38},
  [2090] = {.lex_state = 0},
  [2091] = {.lex_state = 0},
  [2092] = {.lex_state = 0},
  [2093] = {.lex_state = 0},
  [2094] = {.lex_state = 28},
  [2095] = {.lex_state = 0},
  [2096] = {.lex_state = 28},
  [2097] = {.lex_state = 0},
  [2098] = {.lex_state = 28},
  [2099] = {.lex_state = 28},
  [2100] = {.lex_state = 0},
  [2101] = {.lex_state = 28},
  [2102] = {.lex_state = 0},
  [2103] = {.lex_state = 28},
  [2104] = {.lex_state = 0},
  [2105] = {.lex_state = 0},
  [2106] = {.lex_state = 0},
  [2107] = {.lex_state = 376},
  [2108] = {.lex_state = 28},
  [2109] = {.lex_state = 0},
  [2110] = {.lex_state = 0},
  [2111] = {.lex_state = 0},
  [2112] = {.lex_state = 0},
  [2113] = {.lex_state = 28},
  [2114] = {.lex_state = 28},
  [2115] = {.lex_state = 28},
  [2116] = {.lex_state = 0},
  [2117] = {.lex_state = 0},
  [2118] = {.lex_state = 0},
  [2119] = {.lex_state = 0},
  [2120] = {.lex_state = 28},
  [2121] = {.lex_state = 0},
  [2122] = {.lex_state = 28},
  [2123] = {.lex_state = 0},
  [2124] = {.lex_state = 0},
  [2125] = {.lex_state = 0},
  [2126] = {.lex_state = 0},
  [2127] = {.lex_state = 368},
  [2128] = {.lex_state = 28},
  [2129] = {.lex_state = 28},
  [2130] = {.lex_state = 28},
  [2131] = {.lex_state = 0},
  [2132] = {.lex_state = 0},
  [2133] = {.lex_state = 0},
  [2134] = {.lex_state = 28},
  [2135] = {.lex_state = 0},
  [2136] = {.lex_state = 0},
  [2137] = {.lex_state = 28},
  [2138] = {.lex_state = 28},
  [2139] = {.lex_state = 28},
  [2140] = {.lex_state = 16},
  [2141] = {.lex_state = 28},
  [2142] = {.lex_state = 28},
  [2143] = {.lex_state = 368},
  [2144] = {.lex_state = 0},
  [2145] = {.lex_state = 28},
  [2146] = {.lex_state = 28},
  [2147] = {.lex_state = 0},
  [2148] = {.lex_state = 28},
  [2149] = {.lex_state = 368},
  [2150] = {.lex_state = 0},
  [2151] = {.lex_state = 28},
  [2152] = {.lex_state = 28},
  [2153] = {.lex_state = 28},
  [2154] = {.lex_state = 28},
  [2155] = {.lex_state = 0},
  [2156] = {.lex_state = 0},
  [2157] = {.lex_state = 0},
  [2158] = {.lex_state = 0},
  [2159] = {.lex_state = 0},
  [2160] = {.lex_state = 28},
  [2161] = {.lex_state = 0},
  [2162] = {.lex_state = 0},
  [2163] = {.lex_state = 28},
  [2164] = {.lex_state = 28},
  [2165] = {.lex_state = 0},
  [2166] = {.lex_state = 16},
  [2167] = {.lex_state = 0},
  [2168] = {.lex_state = 16},
  [2169] = {.lex_state = 0},
  [2170] = {.lex_state = 16},
  [2171] = {.lex_state = 16},
  [2172] = {.lex_state = 16},
  [2173] = {.lex_state = 16},
  [2174] = {.lex_state = 0},
  [2175] = {.lex_state = 0},
  [2176] = {.lex_state = 0},
  [2177] = {.lex_state = 0},
  [2178] = {.lex_state = 28},
  [2179] = {.lex_state = 368},
  [2180] = {.lex_state = 28},
  [2181] = {.lex_state = 28},
  [2182] = {.lex_state = 0},
  [2183] = {.lex_state = 0},
  [2184] = {.lex_state = 0},
  [2185] = {.lex_state = 0},
  [2186] = {.lex_state = 0},
  [2187] = {.lex_state = 0},
  [2188] = {.lex_state = 0},
  [2189] = {.lex_state = 28},
  [2190] = {(TSStateId)(-1),},
  [2191] = {(TSStateId)(-1),},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [sym_comment] = STATE(0),
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_import] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_export] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_Entry] = ACTIONS(1),
    [anon_sym_Component] = ACTIONS(1),
    [anon_sym_State] = ACTIONS(1),
    [anon_sym_Prop] = ACTIONS(1),
    [anon_sym_Link] = ACTIONS(1),
    [anon_sym_Provide] = ACTIONS(1),
    [anon_sym_Consume] = ACTIONS(1),
    [anon_sym_Builder] = ACTIONS(1),
    [anon_sym_Styles] = ACTIONS(1),
    [anon_sym_Extend] = ACTIONS(1),
    [anon_sym_AnimatableExtend] = ACTIONS(1),
    [anon_sym_Watch] = ACTIONS(1),
    [anon_sym_StorageLink] = ACTIONS(1),
    [anon_sym_StorageProp] = ACTIONS(1),
    [anon_sym_LocalStorageLink] = ACTIONS(1),
    [anon_sym_LocalStorageProp] = ACTIONS(1),
    [anon_sym_ObjectLink] = ACTIONS(1),
    [anon_sym_Observed] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_private] = ACTIONS(1),
    [anon_sym_public] = ACTIONS(1),
    [anon_sym_protected] = ACTIONS(1),
    [anon_sym_static] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_Text] = ACTIONS(1),
    [anon_sym_Button] = ACTIONS(1),
    [anon_sym_Image] = ACTIONS(1),
    [anon_sym_TextInput] = ACTIONS(1),
    [anon_sym_TextArea] = ACTIONS(1),
    [anon_sym_Column] = ACTIONS(1),
    [anon_sym_Row] = ACTIONS(1),
    [anon_sym_Stack] = ACTIONS(1),
    [anon_sym_Flex] = ACTIONS(1),
    [anon_sym_Grid] = ACTIONS(1),
    [anon_sym_GridRow] = ACTIONS(1),
    [anon_sym_GridCol] = ACTIONS(1),
    [anon_sym_List] = ACTIONS(1),
    [anon_sym_ScrollList] = ACTIONS(1),
    [anon_sym_ListItem] = ACTIONS(1),
    [anon_sym_GridItem] = ACTIONS(1),
    [anon_sym_ForEach] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [aux_sym_escape_sequence_token1] = ACTIONS(1),
    [aux_sym_escape_sequence_token2] = ACTIONS(1),
    [aux_sym_escape_sequence_token3] = ACTIONS(1),
    [aux_sym_escape_sequence_token4] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_instanceof] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_LT_LT] = ACTIONS(1),
    [anon_sym_GT_GT] = ACTIONS(1),
    [anon_sym_GT_GT_GT] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_delete] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_STAR_EQ] = ACTIONS(1),
    [anon_sym_SLASH_EQ] = ACTIONS(1),
    [anon_sym_PERCENT_EQ] = ACTIONS(1),
    [anon_sym_AMP_EQ] = ACTIONS(1),
    [anon_sym_PIPE_EQ] = ACTIONS(1),
    [anon_sym_CARET_EQ] = ACTIONS(1),
    [anon_sym_LT_LT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_await] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [anon_sym_any] = ACTIONS(1),
    [anon_sym_undefined] = ACTIONS(1),
    [anon_sym_EQ_GT] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_extends] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_async] = ACTIONS(1),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1),
    [anon_sym_let] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_continue] = ACTIONS(1),
    [anon_sym_QMARK_DOT] = ACTIONS(1),
    [anon_sym_interface] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_abstract] = ACTIONS(1),
    [anon_sym_class] = ACTIONS(1),
    [anon_sym_implements] = ACTIONS(1),
    [anon_sym_BQUOTE] = ACTIONS(1),
    [anon_sym_DOLLARr] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(2054),
    [sym_comment] = STATE(1),
    [sym_import_declaration] = STATE(1368),
    [sym_export_declaration] = STATE(1368),
    [sym_decorator] = STATE(1500),
    [sym_component_declaration] = STATE(1368),
    [sym_variable_declaration] = STATE(1368),
    [sym_interface_declaration] = STATE(1368),
    [sym_type_declaration] = STATE(1368),
    [sym_enum_declaration] = STATE(1368),
    [sym_class_declaration] = STATE(1368),
    [sym_function_declaration] = STATE(1368),
    [aux_sym_source_file_repeat1] = STATE(1156),
    [aux_sym_component_declaration_repeat1] = STATE(1459),
    [ts_builtin_sym_end] = ACTIONS(7),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_import] = ACTIONS(9),
    [anon_sym_export] = ACTIONS(11),
    [anon_sym_AT] = ACTIONS(13),
    [anon_sym_struct] = ACTIONS(15),
    [anon_sym_async] = ACTIONS(17),
    [anon_sym_var] = ACTIONS(19),
    [anon_sym_let] = ACTIONS(19),
    [anon_sym_const] = ACTIONS(21),
    [anon_sym_interface] = ACTIONS(23),
    [anon_sym_type] = ACTIONS(25),
    [anon_sym_enum] = ACTIONS(27),
    [anon_sym_abstract] = ACTIONS(29),
    [anon_sym_class] = ACTIONS(31),
    [anon_sym_function] = ACTIONS(33),
  },
  [STATE(2)] = {
    [sym_comment] = STATE(2),
    [sym_type_arguments] = STATE(1519),
    [aux_sym_qualified_type_repeat1] = STATE(1316),
    [aux_sym_array_type_repeat1] = STATE(1469),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_COMMA] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_COLON] = ACTIONS(41),
    [anon_sym_EQ] = ACTIONS(43),
    [anon_sym_DOT] = ACTIONS(45),
    [anon_sym_Text] = ACTIONS(35),
    [anon_sym_Button] = ACTIONS(35),
    [anon_sym_Image] = ACTIONS(35),
    [anon_sym_TextInput] = ACTIONS(35),
    [anon_sym_TextArea] = ACTIONS(35),
    [anon_sym_Column] = ACTIONS(35),
    [anon_sym_Row] = ACTIONS(35),
    [anon_sym_Stack] = ACTIONS(35),
    [anon_sym_Flex] = ACTIONS(35),
    [anon_sym_Grid] = ACTIONS(35),
    [anon_sym_GridRow] = ACTIONS(35),
    [anon_sym_GridCol] = ACTIONS(35),
    [anon_sym_List] = ACTIONS(35),
    [anon_sym_ScrollList] = ACTIONS(35),
    [anon_sym_ListItem] = ACTIONS(35),
    [anon_sym_GridItem] = ACTIONS(35),
    [anon_sym_ForEach] = ACTIONS(35),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(48),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(51),
    [anon_sym_GT] = ACTIONS(48),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(54),
    [anon_sym_DASH_EQ] = ACTIONS(54),
    [anon_sym_STAR_EQ] = ACTIONS(54),
    [anon_sym_SLASH_EQ] = ACTIONS(54),
    [anon_sym_PERCENT_EQ] = ACTIONS(54),
    [anon_sym_AMP_EQ] = ACTIONS(54),
    [anon_sym_PIPE_EQ] = ACTIONS(54),
    [anon_sym_CARET_EQ] = ACTIONS(54),
    [anon_sym_LT_LT_EQ] = ACTIONS(54),
    [anon_sym_GT_GT_EQ] = ACTIONS(54),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(54),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(56),
    [anon_sym_LBRACK] = ACTIONS(58),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(3)] = {
    [sym_comment] = STATE(3),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(63),
    [anon_sym_COLON] = ACTIONS(41),
    [anon_sym_EQ] = ACTIONS(43),
    [anon_sym_DOT] = ACTIONS(37),
    [anon_sym_Text] = ACTIONS(35),
    [anon_sym_Button] = ACTIONS(35),
    [anon_sym_Image] = ACTIONS(35),
    [anon_sym_TextInput] = ACTIONS(35),
    [anon_sym_TextArea] = ACTIONS(35),
    [anon_sym_Column] = ACTIONS(35),
    [anon_sym_Row] = ACTIONS(35),
    [anon_sym_Stack] = ACTIONS(35),
    [anon_sym_Flex] = ACTIONS(35),
    [anon_sym_Grid] = ACTIONS(35),
    [anon_sym_GridRow] = ACTIONS(35),
    [anon_sym_GridCol] = ACTIONS(35),
    [anon_sym_List] = ACTIONS(35),
    [anon_sym_ScrollList] = ACTIONS(35),
    [anon_sym_ListItem] = ACTIONS(35),
    [anon_sym_GridItem] = ACTIONS(35),
    [anon_sym_ForEach] = ACTIONS(35),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(54),
    [anon_sym_DASH_EQ] = ACTIONS(54),
    [anon_sym_STAR_EQ] = ACTIONS(54),
    [anon_sym_SLASH_EQ] = ACTIONS(54),
    [anon_sym_PERCENT_EQ] = ACTIONS(54),
    [anon_sym_AMP_EQ] = ACTIONS(54),
    [anon_sym_PIPE_EQ] = ACTIONS(54),
    [anon_sym_CARET_EQ] = ACTIONS(54),
    [anon_sym_LT_LT_EQ] = ACTIONS(54),
    [anon_sym_GT_GT_EQ] = ACTIONS(54),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(54),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(56),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(4)] = {
    [sym_comment] = STATE(4),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(65),
    [anon_sym_COLON] = ACTIONS(41),
    [anon_sym_EQ] = ACTIONS(43),
    [anon_sym_DOT] = ACTIONS(37),
    [anon_sym_Text] = ACTIONS(35),
    [anon_sym_Button] = ACTIONS(35),
    [anon_sym_Image] = ACTIONS(35),
    [anon_sym_TextInput] = ACTIONS(35),
    [anon_sym_TextArea] = ACTIONS(35),
    [anon_sym_Column] = ACTIONS(35),
    [anon_sym_Row] = ACTIONS(35),
    [anon_sym_Stack] = ACTIONS(35),
    [anon_sym_Flex] = ACTIONS(35),
    [anon_sym_Grid] = ACTIONS(35),
    [anon_sym_GridRow] = ACTIONS(35),
    [anon_sym_GridCol] = ACTIONS(35),
    [anon_sym_List] = ACTIONS(35),
    [anon_sym_ScrollList] = ACTIONS(35),
    [anon_sym_ListItem] = ACTIONS(35),
    [anon_sym_GridItem] = ACTIONS(35),
    [anon_sym_ForEach] = ACTIONS(35),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(54),
    [anon_sym_DASH_EQ] = ACTIONS(54),
    [anon_sym_STAR_EQ] = ACTIONS(54),
    [anon_sym_SLASH_EQ] = ACTIONS(54),
    [anon_sym_PERCENT_EQ] = ACTIONS(54),
    [anon_sym_AMP_EQ] = ACTIONS(54),
    [anon_sym_PIPE_EQ] = ACTIONS(54),
    [anon_sym_CARET_EQ] = ACTIONS(54),
    [anon_sym_LT_LT_EQ] = ACTIONS(54),
    [anon_sym_GT_GT_EQ] = ACTIONS(54),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(54),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(56),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(5)] = {
    [sym_comment] = STATE(5),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(70),
    [anon_sym_RBRACE] = ACTIONS(70),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_as] = ACTIONS(67),
    [anon_sym_SEMI] = ACTIONS(70),
    [anon_sym_LPAREN] = ACTIONS(72),
    [anon_sym_COLON] = ACTIONS(75),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(72),
    [anon_sym_Text] = ACTIONS(79),
    [anon_sym_Button] = ACTIONS(79),
    [anon_sym_Image] = ACTIONS(79),
    [anon_sym_TextInput] = ACTIONS(79),
    [anon_sym_TextArea] = ACTIONS(79),
    [anon_sym_Column] = ACTIONS(79),
    [anon_sym_Row] = ACTIONS(79),
    [anon_sym_Stack] = ACTIONS(79),
    [anon_sym_Flex] = ACTIONS(79),
    [anon_sym_Grid] = ACTIONS(79),
    [anon_sym_GridRow] = ACTIONS(79),
    [anon_sym_GridCol] = ACTIONS(79),
    [anon_sym_List] = ACTIONS(79),
    [anon_sym_ScrollList] = ACTIONS(79),
    [anon_sym_ListItem] = ACTIONS(79),
    [anon_sym_GridItem] = ACTIONS(79),
    [anon_sym_ForEach] = ACTIONS(79),
    [sym_identifier] = ACTIONS(79),
    [anon_sym_DQUOTE] = ACTIONS(70),
    [anon_sym_SQUOTE] = ACTIONS(70),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [sym_numeric_literal] = ACTIONS(70),
    [anon_sym_true] = ACTIONS(79),
    [anon_sym_false] = ACTIONS(79),
    [anon_sym_null] = ACTIONS(79),
    [anon_sym_PIPE_PIPE] = ACTIONS(72),
    [anon_sym_AMP_AMP] = ACTIONS(72),
    [anon_sym_PIPE] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [anon_sym_EQ_EQ] = ACTIONS(67),
    [anon_sym_BANG_EQ] = ACTIONS(67),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(72),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(72),
    [anon_sym_LT] = ACTIONS(67),
    [anon_sym_GT] = ACTIONS(67),
    [anon_sym_LT_EQ] = ACTIONS(72),
    [anon_sym_GT_EQ] = ACTIONS(72),
    [anon_sym_instanceof] = ACTIONS(67),
    [anon_sym_in] = ACTIONS(67),
    [anon_sym_LT_LT] = ACTIONS(67),
    [anon_sym_GT_GT] = ACTIONS(67),
    [anon_sym_GT_GT_GT] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_PERCENT] = ACTIONS(67),
    [anon_sym_STAR_STAR] = ACTIONS(72),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(70),
    [anon_sym_typeof] = ACTIONS(79),
    [anon_sym_void] = ACTIONS(79),
    [anon_sym_delete] = ACTIONS(79),
    [anon_sym_PLUS_EQ] = ACTIONS(81),
    [anon_sym_DASH_EQ] = ACTIONS(81),
    [anon_sym_STAR_EQ] = ACTIONS(81),
    [anon_sym_SLASH_EQ] = ACTIONS(81),
    [anon_sym_PERCENT_EQ] = ACTIONS(81),
    [anon_sym_AMP_EQ] = ACTIONS(81),
    [anon_sym_PIPE_EQ] = ACTIONS(81),
    [anon_sym_CARET_EQ] = ACTIONS(81),
    [anon_sym_LT_LT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(79),
    [anon_sym_EQ_GT] = ACTIONS(83),
    [anon_sym_LBRACK] = ACTIONS(72),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_QMARK_DOT] = ACTIONS(72),
    [anon_sym_BQUOTE] = ACTIONS(70),
    [anon_sym_DOLLARr] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(72),
    [anon_sym_DASH_DASH] = ACTIONS(72),
    [anon_sym_new] = ACTIONS(79),
  },
  [STATE(6)] = {
    [sym_comment] = STATE(6),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_COLON] = ACTIONS(41),
    [anon_sym_EQ] = ACTIONS(43),
    [anon_sym_DOT] = ACTIONS(37),
    [anon_sym_Text] = ACTIONS(35),
    [anon_sym_Button] = ACTIONS(35),
    [anon_sym_Image] = ACTIONS(35),
    [anon_sym_TextInput] = ACTIONS(35),
    [anon_sym_TextArea] = ACTIONS(35),
    [anon_sym_Column] = ACTIONS(35),
    [anon_sym_Row] = ACTIONS(35),
    [anon_sym_Stack] = ACTIONS(35),
    [anon_sym_Flex] = ACTIONS(35),
    [anon_sym_Grid] = ACTIONS(35),
    [anon_sym_GridRow] = ACTIONS(35),
    [anon_sym_GridCol] = ACTIONS(35),
    [anon_sym_List] = ACTIONS(35),
    [anon_sym_ScrollList] = ACTIONS(35),
    [anon_sym_ListItem] = ACTIONS(35),
    [anon_sym_GridItem] = ACTIONS(35),
    [anon_sym_ForEach] = ACTIONS(35),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(54),
    [anon_sym_DASH_EQ] = ACTIONS(54),
    [anon_sym_STAR_EQ] = ACTIONS(54),
    [anon_sym_SLASH_EQ] = ACTIONS(54),
    [anon_sym_PERCENT_EQ] = ACTIONS(54),
    [anon_sym_AMP_EQ] = ACTIONS(54),
    [anon_sym_PIPE_EQ] = ACTIONS(54),
    [anon_sym_CARET_EQ] = ACTIONS(54),
    [anon_sym_LT_LT_EQ] = ACTIONS(54),
    [anon_sym_GT_GT_EQ] = ACTIONS(54),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(54),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(56),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(7)] = {
    [sym_comment] = STATE(7),
    [sym_type_arguments] = STATE(1519),
    [aux_sym_qualified_type_repeat1] = STATE(1316),
    [aux_sym_array_type_repeat1] = STATE(1469),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_COMMA] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_COLON] = ACTIONS(85),
    [anon_sym_EQ] = ACTIONS(87),
    [anon_sym_DOT] = ACTIONS(45),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(48),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(51),
    [anon_sym_GT] = ACTIONS(48),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(89),
    [anon_sym_DASH_EQ] = ACTIONS(89),
    [anon_sym_STAR_EQ] = ACTIONS(89),
    [anon_sym_SLASH_EQ] = ACTIONS(89),
    [anon_sym_PERCENT_EQ] = ACTIONS(89),
    [anon_sym_AMP_EQ] = ACTIONS(89),
    [anon_sym_PIPE_EQ] = ACTIONS(89),
    [anon_sym_CARET_EQ] = ACTIONS(89),
    [anon_sym_LT_LT_EQ] = ACTIONS(89),
    [anon_sym_GT_GT_EQ] = ACTIONS(89),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(89),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(91),
    [anon_sym_LBRACK] = ACTIONS(58),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_else] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(8)] = {
    [sym_comment] = STATE(8),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_EQ] = ACTIONS(43),
    [anon_sym_DOT] = ACTIONS(37),
    [anon_sym_Text] = ACTIONS(35),
    [anon_sym_Button] = ACTIONS(35),
    [anon_sym_Image] = ACTIONS(35),
    [anon_sym_TextInput] = ACTIONS(35),
    [anon_sym_TextArea] = ACTIONS(35),
    [anon_sym_Column] = ACTIONS(35),
    [anon_sym_Row] = ACTIONS(35),
    [anon_sym_Stack] = ACTIONS(35),
    [anon_sym_Flex] = ACTIONS(35),
    [anon_sym_Grid] = ACTIONS(35),
    [anon_sym_GridRow] = ACTIONS(35),
    [anon_sym_GridCol] = ACTIONS(35),
    [anon_sym_List] = ACTIONS(35),
    [anon_sym_ScrollList] = ACTIONS(35),
    [anon_sym_ListItem] = ACTIONS(35),
    [anon_sym_GridItem] = ACTIONS(35),
    [anon_sym_ForEach] = ACTIONS(35),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(54),
    [anon_sym_DASH_EQ] = ACTIONS(54),
    [anon_sym_STAR_EQ] = ACTIONS(54),
    [anon_sym_SLASH_EQ] = ACTIONS(54),
    [anon_sym_PERCENT_EQ] = ACTIONS(54),
    [anon_sym_AMP_EQ] = ACTIONS(54),
    [anon_sym_PIPE_EQ] = ACTIONS(54),
    [anon_sym_CARET_EQ] = ACTIONS(54),
    [anon_sym_LT_LT_EQ] = ACTIONS(54),
    [anon_sym_GT_GT_EQ] = ACTIONS(54),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(54),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(9)] = {
    [sym_comment] = STATE(9),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(70),
    [anon_sym_RBRACE] = ACTIONS(70),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_as] = ACTIONS(67),
    [anon_sym_SEMI] = ACTIONS(70),
    [anon_sym_LPAREN] = ACTIONS(72),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(72),
    [anon_sym_Text] = ACTIONS(79),
    [anon_sym_Button] = ACTIONS(79),
    [anon_sym_Image] = ACTIONS(79),
    [anon_sym_TextInput] = ACTIONS(79),
    [anon_sym_TextArea] = ACTIONS(79),
    [anon_sym_Column] = ACTIONS(79),
    [anon_sym_Row] = ACTIONS(79),
    [anon_sym_Stack] = ACTIONS(79),
    [anon_sym_Flex] = ACTIONS(79),
    [anon_sym_Grid] = ACTIONS(79),
    [anon_sym_GridRow] = ACTIONS(79),
    [anon_sym_GridCol] = ACTIONS(79),
    [anon_sym_List] = ACTIONS(79),
    [anon_sym_ScrollList] = ACTIONS(79),
    [anon_sym_ListItem] = ACTIONS(79),
    [anon_sym_GridItem] = ACTIONS(79),
    [anon_sym_ForEach] = ACTIONS(79),
    [sym_identifier] = ACTIONS(79),
    [anon_sym_DQUOTE] = ACTIONS(70),
    [anon_sym_SQUOTE] = ACTIONS(70),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [sym_numeric_literal] = ACTIONS(70),
    [anon_sym_true] = ACTIONS(79),
    [anon_sym_false] = ACTIONS(79),
    [anon_sym_null] = ACTIONS(79),
    [anon_sym_PIPE_PIPE] = ACTIONS(72),
    [anon_sym_AMP_AMP] = ACTIONS(72),
    [anon_sym_PIPE] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [anon_sym_EQ_EQ] = ACTIONS(67),
    [anon_sym_BANG_EQ] = ACTIONS(67),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(72),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(72),
    [anon_sym_LT] = ACTIONS(67),
    [anon_sym_GT] = ACTIONS(67),
    [anon_sym_LT_EQ] = ACTIONS(72),
    [anon_sym_GT_EQ] = ACTIONS(72),
    [anon_sym_instanceof] = ACTIONS(67),
    [anon_sym_in] = ACTIONS(67),
    [anon_sym_LT_LT] = ACTIONS(67),
    [anon_sym_GT_GT] = ACTIONS(67),
    [anon_sym_GT_GT_GT] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_PERCENT] = ACTIONS(67),
    [anon_sym_STAR_STAR] = ACTIONS(72),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(70),
    [anon_sym_typeof] = ACTIONS(79),
    [anon_sym_void] = ACTIONS(79),
    [anon_sym_delete] = ACTIONS(79),
    [anon_sym_PLUS_EQ] = ACTIONS(81),
    [anon_sym_DASH_EQ] = ACTIONS(81),
    [anon_sym_STAR_EQ] = ACTIONS(81),
    [anon_sym_SLASH_EQ] = ACTIONS(81),
    [anon_sym_PERCENT_EQ] = ACTIONS(81),
    [anon_sym_AMP_EQ] = ACTIONS(81),
    [anon_sym_PIPE_EQ] = ACTIONS(81),
    [anon_sym_CARET_EQ] = ACTIONS(81),
    [anon_sym_LT_LT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(79),
    [anon_sym_LBRACK] = ACTIONS(72),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_QMARK_DOT] = ACTIONS(72),
    [anon_sym_BQUOTE] = ACTIONS(70),
    [anon_sym_DOLLARr] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(72),
    [anon_sym_DASH_DASH] = ACTIONS(72),
    [anon_sym_new] = ACTIONS(79),
  },
  [STATE(10)] = {
    [sym_comment] = STATE(10),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(93),
    [anon_sym_LBRACE] = ACTIONS(95),
    [anon_sym_RBRACE] = ACTIONS(95),
    [anon_sym_STAR] = ACTIONS(93),
    [anon_sym_as] = ACTIONS(93),
    [anon_sym_SEMI] = ACTIONS(95),
    [anon_sym_LPAREN] = ACTIONS(95),
    [anon_sym_EQ] = ACTIONS(93),
    [anon_sym_DOT] = ACTIONS(95),
    [anon_sym_Text] = ACTIONS(93),
    [anon_sym_Button] = ACTIONS(93),
    [anon_sym_Image] = ACTIONS(93),
    [anon_sym_TextInput] = ACTIONS(93),
    [anon_sym_TextArea] = ACTIONS(93),
    [anon_sym_Column] = ACTIONS(93),
    [anon_sym_Row] = ACTIONS(93),
    [anon_sym_Stack] = ACTIONS(93),
    [anon_sym_Flex] = ACTIONS(93),
    [anon_sym_Grid] = ACTIONS(93),
    [anon_sym_GridRow] = ACTIONS(93),
    [anon_sym_GridCol] = ACTIONS(93),
    [anon_sym_List] = ACTIONS(93),
    [anon_sym_ScrollList] = ACTIONS(93),
    [anon_sym_ListItem] = ACTIONS(93),
    [anon_sym_GridItem] = ACTIONS(93),
    [anon_sym_ForEach] = ACTIONS(93),
    [sym_identifier] = ACTIONS(93),
    [anon_sym_DQUOTE] = ACTIONS(95),
    [anon_sym_SQUOTE] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(93),
    [sym_numeric_literal] = ACTIONS(95),
    [anon_sym_true] = ACTIONS(93),
    [anon_sym_false] = ACTIONS(93),
    [anon_sym_null] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(95),
    [anon_sym_AMP_AMP] = ACTIONS(95),
    [anon_sym_PIPE] = ACTIONS(93),
    [anon_sym_CARET] = ACTIONS(93),
    [anon_sym_AMP] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(95),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(95),
    [anon_sym_LT] = ACTIONS(93),
    [anon_sym_GT] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_EQ] = ACTIONS(95),
    [anon_sym_instanceof] = ACTIONS(93),
    [anon_sym_in] = ACTIONS(93),
    [anon_sym_LT_LT] = ACTIONS(93),
    [anon_sym_GT_GT] = ACTIONS(93),
    [anon_sym_GT_GT_GT] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(93),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(95),
    [anon_sym_BANG] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(95),
    [anon_sym_typeof] = ACTIONS(93),
    [anon_sym_void] = ACTIONS(93),
    [anon_sym_delete] = ACTIONS(93),
    [anon_sym_PLUS_EQ] = ACTIONS(95),
    [anon_sym_DASH_EQ] = ACTIONS(95),
    [anon_sym_STAR_EQ] = ACTIONS(95),
    [anon_sym_SLASH_EQ] = ACTIONS(95),
    [anon_sym_PERCENT_EQ] = ACTIONS(95),
    [anon_sym_AMP_EQ] = ACTIONS(95),
    [anon_sym_PIPE_EQ] = ACTIONS(95),
    [anon_sym_CARET_EQ] = ACTIONS(95),
    [anon_sym_LT_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_GT_EQ] = ACTIONS(95),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(95),
    [anon_sym_QMARK] = ACTIONS(93),
    [anon_sym_await] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(93),
    [anon_sym_async] = ACTIONS(93),
    [anon_sym_QMARK_DOT] = ACTIONS(95),
    [anon_sym_BQUOTE] = ACTIONS(95),
    [anon_sym_DOLLARr] = ACTIONS(93),
    [anon_sym_PLUS_PLUS] = ACTIONS(95),
    [anon_sym_DASH_DASH] = ACTIONS(95),
    [anon_sym_new] = ACTIONS(93),
  },
  [STATE(11)] = {
    [sym_comment] = STATE(11),
    [sym_type_arguments] = STATE(1519),
    [aux_sym_qualified_type_repeat1] = STATE(1316),
    [aux_sym_array_type_repeat1] = STATE(1469),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_COMMA] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_COLON] = ACTIONS(97),
    [anon_sym_EQ] = ACTIONS(99),
    [anon_sym_DOT] = ACTIONS(45),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(48),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(51),
    [anon_sym_GT] = ACTIONS(48),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(101),
    [anon_sym_DASH_EQ] = ACTIONS(101),
    [anon_sym_STAR_EQ] = ACTIONS(101),
    [anon_sym_SLASH_EQ] = ACTIONS(101),
    [anon_sym_PERCENT_EQ] = ACTIONS(101),
    [anon_sym_AMP_EQ] = ACTIONS(101),
    [anon_sym_PIPE_EQ] = ACTIONS(101),
    [anon_sym_CARET_EQ] = ACTIONS(101),
    [anon_sym_LT_LT_EQ] = ACTIONS(101),
    [anon_sym_GT_GT_EQ] = ACTIONS(101),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(101),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(103),
    [anon_sym_LBRACK] = ACTIONS(58),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(12)] = {
    [sym_comment] = STATE(12),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(833),
    [sym_ui_custom_component_statement] = STATE(833),
    [sym_ui_control_flow] = STATE(833),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(833),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_build_body_repeat1] = STATE(15),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(107),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(113),
    [anon_sym_Button] = ACTIONS(115),
    [anon_sym_Image] = ACTIONS(113),
    [anon_sym_TextInput] = ACTIONS(117),
    [anon_sym_TextArea] = ACTIONS(117),
    [anon_sym_Column] = ACTIONS(119),
    [anon_sym_Row] = ACTIONS(119),
    [anon_sym_Stack] = ACTIONS(119),
    [anon_sym_Flex] = ACTIONS(119),
    [anon_sym_Grid] = ACTIONS(119),
    [anon_sym_GridRow] = ACTIONS(119),
    [anon_sym_GridCol] = ACTIONS(119),
    [anon_sym_List] = ACTIONS(119),
    [anon_sym_ScrollList] = ACTIONS(119),
    [anon_sym_ListItem] = ACTIONS(119),
    [anon_sym_GridItem] = ACTIONS(119),
    [anon_sym_ForEach] = ACTIONS(121),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(133),
    [anon_sym_false] = ACTIONS(133),
    [anon_sym_null] = ACTIONS(135),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(139),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(13)] = {
    [sym_comment] = STATE(13),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(337),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_property_assignment] = STATE(1850),
    [sym_property_name] = STATE(2065),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(43),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_COMMA] = ACTIONS(161),
    [anon_sym_RBRACE] = ACTIONS(163),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(177),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(195),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(14)] = {
    [sym_comment] = STATE(14),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(337),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_property_assignment] = STATE(1704),
    [sym_property_name] = STATE(2065),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(43),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_COMMA] = ACTIONS(221),
    [anon_sym_RBRACE] = ACTIONS(223),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(177),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(195),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(15)] = {
    [sym_comment] = STATE(15),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(833),
    [sym_ui_custom_component_statement] = STATE(833),
    [sym_ui_control_flow] = STATE(833),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(833),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_build_body_repeat1] = STATE(16),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(225),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(113),
    [anon_sym_Button] = ACTIONS(115),
    [anon_sym_Image] = ACTIONS(113),
    [anon_sym_TextInput] = ACTIONS(117),
    [anon_sym_TextArea] = ACTIONS(117),
    [anon_sym_Column] = ACTIONS(119),
    [anon_sym_Row] = ACTIONS(119),
    [anon_sym_Stack] = ACTIONS(119),
    [anon_sym_Flex] = ACTIONS(119),
    [anon_sym_Grid] = ACTIONS(119),
    [anon_sym_GridRow] = ACTIONS(119),
    [anon_sym_GridCol] = ACTIONS(119),
    [anon_sym_List] = ACTIONS(119),
    [anon_sym_ScrollList] = ACTIONS(119),
    [anon_sym_ListItem] = ACTIONS(119),
    [anon_sym_GridItem] = ACTIONS(119),
    [anon_sym_ForEach] = ACTIONS(121),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(133),
    [anon_sym_false] = ACTIONS(133),
    [anon_sym_null] = ACTIONS(135),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(139),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(16)] = {
    [sym_comment] = STATE(16),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(833),
    [sym_ui_custom_component_statement] = STATE(833),
    [sym_ui_control_flow] = STATE(833),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(833),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_build_body_repeat1] = STATE(16),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(227),
    [anon_sym_RBRACE] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(232),
    [anon_sym_DOT] = ACTIONS(235),
    [anon_sym_Text] = ACTIONS(238),
    [anon_sym_Button] = ACTIONS(241),
    [anon_sym_Image] = ACTIONS(238),
    [anon_sym_TextInput] = ACTIONS(244),
    [anon_sym_TextArea] = ACTIONS(244),
    [anon_sym_Column] = ACTIONS(247),
    [anon_sym_Row] = ACTIONS(247),
    [anon_sym_Stack] = ACTIONS(247),
    [anon_sym_Flex] = ACTIONS(247),
    [anon_sym_Grid] = ACTIONS(247),
    [anon_sym_GridRow] = ACTIONS(247),
    [anon_sym_GridCol] = ACTIONS(247),
    [anon_sym_List] = ACTIONS(247),
    [anon_sym_ScrollList] = ACTIONS(247),
    [anon_sym_ListItem] = ACTIONS(247),
    [anon_sym_GridItem] = ACTIONS(247),
    [anon_sym_ForEach] = ACTIONS(250),
    [sym_identifier] = ACTIONS(253),
    [anon_sym_DQUOTE] = ACTIONS(256),
    [anon_sym_SQUOTE] = ACTIONS(259),
    [anon_sym_DOLLAR] = ACTIONS(262),
    [sym_numeric_literal] = ACTIONS(265),
    [anon_sym_true] = ACTIONS(268),
    [anon_sym_false] = ACTIONS(268),
    [anon_sym_null] = ACTIONS(271),
    [anon_sym_LT] = ACTIONS(274),
    [anon_sym_PLUS] = ACTIONS(277),
    [anon_sym_DASH] = ACTIONS(277),
    [anon_sym_BANG] = ACTIONS(280),
    [anon_sym_TILDE] = ACTIONS(280),
    [anon_sym_typeof] = ACTIONS(277),
    [anon_sym_void] = ACTIONS(277),
    [anon_sym_delete] = ACTIONS(277),
    [anon_sym_await] = ACTIONS(283),
    [anon_sym_LBRACK] = ACTIONS(286),
    [anon_sym_if] = ACTIONS(289),
    [anon_sym_async] = ACTIONS(292),
    [anon_sym_BQUOTE] = ACTIONS(295),
    [anon_sym_DOLLARr] = ACTIONS(298),
    [anon_sym_PLUS_PLUS] = ACTIONS(301),
    [anon_sym_DASH_DASH] = ACTIONS(301),
    [anon_sym_new] = ACTIONS(304),
  },
  [STATE(17)] = {
    [sym_comment] = STATE(17),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(833),
    [sym_ui_custom_component_statement] = STATE(833),
    [sym_ui_control_flow] = STATE(833),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(833),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_build_body_repeat1] = STATE(16),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(307),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(113),
    [anon_sym_Button] = ACTIONS(115),
    [anon_sym_Image] = ACTIONS(113),
    [anon_sym_TextInput] = ACTIONS(117),
    [anon_sym_TextArea] = ACTIONS(117),
    [anon_sym_Column] = ACTIONS(119),
    [anon_sym_Row] = ACTIONS(119),
    [anon_sym_Stack] = ACTIONS(119),
    [anon_sym_Flex] = ACTIONS(119),
    [anon_sym_Grid] = ACTIONS(119),
    [anon_sym_GridRow] = ACTIONS(119),
    [anon_sym_GridCol] = ACTIONS(119),
    [anon_sym_List] = ACTIONS(119),
    [anon_sym_ScrollList] = ACTIONS(119),
    [anon_sym_ListItem] = ACTIONS(119),
    [anon_sym_GridItem] = ACTIONS(119),
    [anon_sym_ForEach] = ACTIONS(121),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(133),
    [anon_sym_false] = ACTIONS(133),
    [anon_sym_null] = ACTIONS(135),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(139),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(18)] = {
    [sym_comment] = STATE(18),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(337),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_property_assignment] = STATE(1850),
    [sym_property_name] = STATE(2065),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(60),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_COMMA] = ACTIONS(161),
    [anon_sym_RBRACE] = ACTIONS(309),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(177),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(195),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(19)] = {
    [sym_comment] = STATE(19),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(337),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_property_assignment] = STATE(1698),
    [sym_property_name] = STATE(2065),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(53),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_COMMA] = ACTIONS(311),
    [anon_sym_RBRACE] = ACTIONS(313),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(177),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(195),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(20)] = {
    [sym_comment] = STATE(20),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(337),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_property_assignment] = STATE(1754),
    [sym_property_name] = STATE(2065),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(61),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_COMMA] = ACTIONS(315),
    [anon_sym_RBRACE] = ACTIONS(317),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(177),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(195),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(21)] = {
    [sym_comment] = STATE(21),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(337),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_property_assignment] = STATE(1698),
    [sym_property_name] = STATE(2065),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(59),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_COMMA] = ACTIONS(311),
    [anon_sym_RBRACE] = ACTIONS(319),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(177),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(195),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(22)] = {
    [sym_comment] = STATE(22),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(337),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_property_assignment] = STATE(1730),
    [sym_property_name] = STATE(2065),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(62),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_COMMA] = ACTIONS(321),
    [anon_sym_RBRACE] = ACTIONS(323),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(177),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(195),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(23)] = {
    [sym_comment] = STATE(23),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(337),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_property_assignment] = STATE(1754),
    [sym_property_name] = STATE(2065),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(64),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_COMMA] = ACTIONS(315),
    [anon_sym_RBRACE] = ACTIONS(325),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(167),
    [sym_identifier] = ACTIONS(169),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(177),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(189),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(195),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(24)] = {
    [sym_comment] = STATE(24),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(833),
    [sym_ui_custom_component_statement] = STATE(833),
    [sym_ui_control_flow] = STATE(833),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(833),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_build_body_repeat1] = STATE(17),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(327),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(113),
    [anon_sym_Button] = ACTIONS(115),
    [anon_sym_Image] = ACTIONS(113),
    [anon_sym_TextInput] = ACTIONS(117),
    [anon_sym_TextArea] = ACTIONS(117),
    [anon_sym_Column] = ACTIONS(119),
    [anon_sym_Row] = ACTIONS(119),
    [anon_sym_Stack] = ACTIONS(119),
    [anon_sym_Flex] = ACTIONS(119),
    [anon_sym_Grid] = ACTIONS(119),
    [anon_sym_GridRow] = ACTIONS(119),
    [anon_sym_GridCol] = ACTIONS(119),
    [anon_sym_List] = ACTIONS(119),
    [anon_sym_ScrollList] = ACTIONS(119),
    [anon_sym_ListItem] = ACTIONS(119),
    [anon_sym_GridItem] = ACTIONS(119),
    [anon_sym_ForEach] = ACTIONS(121),
    [sym_identifier] = ACTIONS(123),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(133),
    [anon_sym_false] = ACTIONS(133),
    [anon_sym_null] = ACTIONS(135),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(139),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(25)] = {
    [sym_comment] = STATE(25),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_COMMA] = ACTIONS(329),
    [anon_sym_RBRACE] = ACTIONS(331),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_COLON] = ACTIONS(97),
    [anon_sym_EQ] = ACTIONS(99),
    [anon_sym_DOT] = ACTIONS(37),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(101),
    [anon_sym_DASH_EQ] = ACTIONS(101),
    [anon_sym_STAR_EQ] = ACTIONS(101),
    [anon_sym_SLASH_EQ] = ACTIONS(101),
    [anon_sym_PERCENT_EQ] = ACTIONS(101),
    [anon_sym_AMP_EQ] = ACTIONS(101),
    [anon_sym_PIPE_EQ] = ACTIONS(101),
    [anon_sym_CARET_EQ] = ACTIONS(101),
    [anon_sym_LT_LT_EQ] = ACTIONS(101),
    [anon_sym_GT_GT_EQ] = ACTIONS(101),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(101),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(103),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(26)] = {
    [sym_comment] = STATE(26),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(842),
    [sym_ui_control_flow] = STATE(842),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(842),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_ui_if_statement_repeat1] = STATE(27),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(334),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(113),
    [anon_sym_Button] = ACTIONS(115),
    [anon_sym_Image] = ACTIONS(113),
    [anon_sym_TextInput] = ACTIONS(117),
    [anon_sym_TextArea] = ACTIONS(117),
    [anon_sym_Column] = ACTIONS(119),
    [anon_sym_Row] = ACTIONS(119),
    [anon_sym_Stack] = ACTIONS(119),
    [anon_sym_Flex] = ACTIONS(119),
    [anon_sym_Grid] = ACTIONS(119),
    [anon_sym_GridRow] = ACTIONS(119),
    [anon_sym_GridCol] = ACTIONS(119),
    [anon_sym_List] = ACTIONS(119),
    [anon_sym_ScrollList] = ACTIONS(119),
    [anon_sym_ListItem] = ACTIONS(119),
    [anon_sym_GridItem] = ACTIONS(119),
    [anon_sym_ForEach] = ACTIONS(121),
    [sym_identifier] = ACTIONS(336),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(133),
    [anon_sym_false] = ACTIONS(133),
    [anon_sym_null] = ACTIONS(135),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(139),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(27)] = {
    [sym_comment] = STATE(27),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(842),
    [sym_ui_control_flow] = STATE(842),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(842),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_ui_if_statement_repeat1] = STATE(27),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(338),
    [anon_sym_RBRACE] = ACTIONS(341),
    [anon_sym_LPAREN] = ACTIONS(343),
    [anon_sym_DOT] = ACTIONS(346),
    [anon_sym_Text] = ACTIONS(349),
    [anon_sym_Button] = ACTIONS(352),
    [anon_sym_Image] = ACTIONS(349),
    [anon_sym_TextInput] = ACTIONS(355),
    [anon_sym_TextArea] = ACTIONS(355),
    [anon_sym_Column] = ACTIONS(358),
    [anon_sym_Row] = ACTIONS(358),
    [anon_sym_Stack] = ACTIONS(358),
    [anon_sym_Flex] = ACTIONS(358),
    [anon_sym_Grid] = ACTIONS(358),
    [anon_sym_GridRow] = ACTIONS(358),
    [anon_sym_GridCol] = ACTIONS(358),
    [anon_sym_List] = ACTIONS(358),
    [anon_sym_ScrollList] = ACTIONS(358),
    [anon_sym_ListItem] = ACTIONS(358),
    [anon_sym_GridItem] = ACTIONS(358),
    [anon_sym_ForEach] = ACTIONS(361),
    [sym_identifier] = ACTIONS(364),
    [anon_sym_DQUOTE] = ACTIONS(367),
    [anon_sym_SQUOTE] = ACTIONS(370),
    [anon_sym_DOLLAR] = ACTIONS(373),
    [sym_numeric_literal] = ACTIONS(376),
    [anon_sym_true] = ACTIONS(379),
    [anon_sym_false] = ACTIONS(379),
    [anon_sym_null] = ACTIONS(382),
    [anon_sym_LT] = ACTIONS(385),
    [anon_sym_PLUS] = ACTIONS(388),
    [anon_sym_DASH] = ACTIONS(388),
    [anon_sym_BANG] = ACTIONS(391),
    [anon_sym_TILDE] = ACTIONS(391),
    [anon_sym_typeof] = ACTIONS(388),
    [anon_sym_void] = ACTIONS(388),
    [anon_sym_delete] = ACTIONS(388),
    [anon_sym_await] = ACTIONS(394),
    [anon_sym_LBRACK] = ACTIONS(397),
    [anon_sym_if] = ACTIONS(400),
    [anon_sym_async] = ACTIONS(403),
    [anon_sym_BQUOTE] = ACTIONS(406),
    [anon_sym_DOLLARr] = ACTIONS(409),
    [anon_sym_PLUS_PLUS] = ACTIONS(412),
    [anon_sym_DASH_DASH] = ACTIONS(412),
    [anon_sym_new] = ACTIONS(415),
  },
  [STATE(28)] = {
    [sym_comment] = STATE(28),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_COLON] = ACTIONS(85),
    [anon_sym_EQ] = ACTIONS(87),
    [anon_sym_DOT] = ACTIONS(37),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(89),
    [anon_sym_DASH_EQ] = ACTIONS(89),
    [anon_sym_STAR_EQ] = ACTIONS(89),
    [anon_sym_SLASH_EQ] = ACTIONS(89),
    [anon_sym_PERCENT_EQ] = ACTIONS(89),
    [anon_sym_AMP_EQ] = ACTIONS(89),
    [anon_sym_PIPE_EQ] = ACTIONS(89),
    [anon_sym_CARET_EQ] = ACTIONS(89),
    [anon_sym_LT_LT_EQ] = ACTIONS(89),
    [anon_sym_GT_GT_EQ] = ACTIONS(89),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(89),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(91),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_else] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(29)] = {
    [sym_comment] = STATE(29),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(842),
    [sym_ui_control_flow] = STATE(842),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(842),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_ui_if_statement_repeat1] = STATE(34),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(418),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(113),
    [anon_sym_Button] = ACTIONS(115),
    [anon_sym_Image] = ACTIONS(113),
    [anon_sym_TextInput] = ACTIONS(117),
    [anon_sym_TextArea] = ACTIONS(117),
    [anon_sym_Column] = ACTIONS(119),
    [anon_sym_Row] = ACTIONS(119),
    [anon_sym_Stack] = ACTIONS(119),
    [anon_sym_Flex] = ACTIONS(119),
    [anon_sym_Grid] = ACTIONS(119),
    [anon_sym_GridRow] = ACTIONS(119),
    [anon_sym_GridCol] = ACTIONS(119),
    [anon_sym_List] = ACTIONS(119),
    [anon_sym_ScrollList] = ACTIONS(119),
    [anon_sym_ListItem] = ACTIONS(119),
    [anon_sym_GridItem] = ACTIONS(119),
    [anon_sym_ForEach] = ACTIONS(121),
    [sym_identifier] = ACTIONS(336),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(133),
    [anon_sym_false] = ACTIONS(133),
    [anon_sym_null] = ACTIONS(135),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(139),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(30)] = {
    [sym_comment] = STATE(30),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(70),
    [anon_sym_RBRACE] = ACTIONS(70),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_as] = ACTIONS(67),
    [anon_sym_SEMI] = ACTIONS(70),
    [anon_sym_LPAREN] = ACTIONS(72),
    [anon_sym_COLON] = ACTIONS(75),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(72),
    [sym_identifier] = ACTIONS(79),
    [anon_sym_DQUOTE] = ACTIONS(70),
    [anon_sym_SQUOTE] = ACTIONS(70),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [sym_numeric_literal] = ACTIONS(70),
    [anon_sym_true] = ACTIONS(79),
    [anon_sym_false] = ACTIONS(79),
    [anon_sym_null] = ACTIONS(79),
    [anon_sym_PIPE_PIPE] = ACTIONS(72),
    [anon_sym_AMP_AMP] = ACTIONS(72),
    [anon_sym_PIPE] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [anon_sym_EQ_EQ] = ACTIONS(67),
    [anon_sym_BANG_EQ] = ACTIONS(67),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(72),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(72),
    [anon_sym_LT] = ACTIONS(67),
    [anon_sym_GT] = ACTIONS(67),
    [anon_sym_LT_EQ] = ACTIONS(72),
    [anon_sym_GT_EQ] = ACTIONS(72),
    [anon_sym_instanceof] = ACTIONS(67),
    [anon_sym_in] = ACTIONS(67),
    [anon_sym_LT_LT] = ACTIONS(67),
    [anon_sym_GT_GT] = ACTIONS(67),
    [anon_sym_GT_GT_GT] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_PERCENT] = ACTIONS(67),
    [anon_sym_STAR_STAR] = ACTIONS(72),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(70),
    [anon_sym_typeof] = ACTIONS(79),
    [anon_sym_void] = ACTIONS(79),
    [anon_sym_delete] = ACTIONS(79),
    [anon_sym_PLUS_EQ] = ACTIONS(81),
    [anon_sym_DASH_EQ] = ACTIONS(81),
    [anon_sym_STAR_EQ] = ACTIONS(81),
    [anon_sym_SLASH_EQ] = ACTIONS(81),
    [anon_sym_PERCENT_EQ] = ACTIONS(81),
    [anon_sym_AMP_EQ] = ACTIONS(81),
    [anon_sym_PIPE_EQ] = ACTIONS(81),
    [anon_sym_CARET_EQ] = ACTIONS(81),
    [anon_sym_LT_LT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(79),
    [anon_sym_EQ_GT] = ACTIONS(83),
    [anon_sym_LBRACK] = ACTIONS(72),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_else] = ACTIONS(79),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_var] = ACTIONS(79),
    [anon_sym_let] = ACTIONS(79),
    [anon_sym_const] = ACTIONS(79),
    [anon_sym_return] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(79),
    [anon_sym_throw] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_while] = ACTIONS(79),
    [anon_sym_break] = ACTIONS(79),
    [anon_sym_continue] = ACTIONS(79),
    [anon_sym_QMARK_DOT] = ACTIONS(72),
    [anon_sym_BQUOTE] = ACTIONS(70),
    [anon_sym_DOLLARr] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(72),
    [anon_sym_DASH_DASH] = ACTIONS(72),
    [anon_sym_new] = ACTIONS(79),
  },
  [STATE(31)] = {
    [sym_comment] = STATE(31),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(842),
    [sym_ui_control_flow] = STATE(842),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(842),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_ui_if_statement_repeat1] = STATE(32),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(420),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(113),
    [anon_sym_Button] = ACTIONS(115),
    [anon_sym_Image] = ACTIONS(113),
    [anon_sym_TextInput] = ACTIONS(117),
    [anon_sym_TextArea] = ACTIONS(117),
    [anon_sym_Column] = ACTIONS(119),
    [anon_sym_Row] = ACTIONS(119),
    [anon_sym_Stack] = ACTIONS(119),
    [anon_sym_Flex] = ACTIONS(119),
    [anon_sym_Grid] = ACTIONS(119),
    [anon_sym_GridRow] = ACTIONS(119),
    [anon_sym_GridCol] = ACTIONS(119),
    [anon_sym_List] = ACTIONS(119),
    [anon_sym_ScrollList] = ACTIONS(119),
    [anon_sym_ListItem] = ACTIONS(119),
    [anon_sym_GridItem] = ACTIONS(119),
    [anon_sym_ForEach] = ACTIONS(121),
    [sym_identifier] = ACTIONS(336),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(133),
    [anon_sym_false] = ACTIONS(133),
    [anon_sym_null] = ACTIONS(135),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(139),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(32)] = {
    [sym_comment] = STATE(32),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(842),
    [sym_ui_control_flow] = STATE(842),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(842),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_ui_if_statement_repeat1] = STATE(27),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(418),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(113),
    [anon_sym_Button] = ACTIONS(115),
    [anon_sym_Image] = ACTIONS(113),
    [anon_sym_TextInput] = ACTIONS(117),
    [anon_sym_TextArea] = ACTIONS(117),
    [anon_sym_Column] = ACTIONS(119),
    [anon_sym_Row] = ACTIONS(119),
    [anon_sym_Stack] = ACTIONS(119),
    [anon_sym_Flex] = ACTIONS(119),
    [anon_sym_Grid] = ACTIONS(119),
    [anon_sym_GridRow] = ACTIONS(119),
    [anon_sym_GridCol] = ACTIONS(119),
    [anon_sym_List] = ACTIONS(119),
    [anon_sym_ScrollList] = ACTIONS(119),
    [anon_sym_ListItem] = ACTIONS(119),
    [anon_sym_GridItem] = ACTIONS(119),
    [anon_sym_ForEach] = ACTIONS(121),
    [sym_identifier] = ACTIONS(336),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(133),
    [anon_sym_false] = ACTIONS(133),
    [anon_sym_null] = ACTIONS(135),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(139),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(33)] = {
    [sym_comment] = STATE(33),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(842),
    [sym_ui_control_flow] = STATE(842),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(842),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_ui_if_statement_repeat1] = STATE(26),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(422),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(113),
    [anon_sym_Button] = ACTIONS(115),
    [anon_sym_Image] = ACTIONS(113),
    [anon_sym_TextInput] = ACTIONS(117),
    [anon_sym_TextArea] = ACTIONS(117),
    [anon_sym_Column] = ACTIONS(119),
    [anon_sym_Row] = ACTIONS(119),
    [anon_sym_Stack] = ACTIONS(119),
    [anon_sym_Flex] = ACTIONS(119),
    [anon_sym_Grid] = ACTIONS(119),
    [anon_sym_GridRow] = ACTIONS(119),
    [anon_sym_GridCol] = ACTIONS(119),
    [anon_sym_List] = ACTIONS(119),
    [anon_sym_ScrollList] = ACTIONS(119),
    [anon_sym_ListItem] = ACTIONS(119),
    [anon_sym_GridItem] = ACTIONS(119),
    [anon_sym_ForEach] = ACTIONS(121),
    [sym_identifier] = ACTIONS(336),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(133),
    [anon_sym_false] = ACTIONS(133),
    [anon_sym_null] = ACTIONS(135),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(139),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(34)] = {
    [sym_comment] = STATE(34),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_ui_element_with_modifiers] = STATE(845),
    [sym_ui_component] = STATE(820),
    [sym_arkts_ui_element] = STATE(842),
    [sym_ui_control_flow] = STATE(842),
    [sym_for_each_statement] = STATE(840),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(100),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_parameters] = STATE(1861),
    [sym_expression_statement] = STATE(842),
    [sym_ui_if_statement] = STATE(840),
    [sym_parameter_list] = STATE(1922),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [aux_sym_ui_if_statement_repeat1] = STATE(27),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_RBRACE] = ACTIONS(424),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(113),
    [anon_sym_Button] = ACTIONS(115),
    [anon_sym_Image] = ACTIONS(113),
    [anon_sym_TextInput] = ACTIONS(117),
    [anon_sym_TextArea] = ACTIONS(117),
    [anon_sym_Column] = ACTIONS(119),
    [anon_sym_Row] = ACTIONS(119),
    [anon_sym_Stack] = ACTIONS(119),
    [anon_sym_Flex] = ACTIONS(119),
    [anon_sym_Grid] = ACTIONS(119),
    [anon_sym_GridRow] = ACTIONS(119),
    [anon_sym_GridCol] = ACTIONS(119),
    [anon_sym_List] = ACTIONS(119),
    [anon_sym_ScrollList] = ACTIONS(119),
    [anon_sym_ListItem] = ACTIONS(119),
    [anon_sym_GridItem] = ACTIONS(119),
    [anon_sym_ForEach] = ACTIONS(121),
    [sym_identifier] = ACTIONS(336),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(133),
    [anon_sym_false] = ACTIONS(133),
    [anon_sym_null] = ACTIONS(135),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(139),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(147),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(35)] = {
    [sym_comment] = STATE(35),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_COLON] = ACTIONS(97),
    [anon_sym_EQ] = ACTIONS(99),
    [anon_sym_DOT] = ACTIONS(37),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(101),
    [anon_sym_DASH_EQ] = ACTIONS(101),
    [anon_sym_STAR_EQ] = ACTIONS(101),
    [anon_sym_SLASH_EQ] = ACTIONS(101),
    [anon_sym_PERCENT_EQ] = ACTIONS(101),
    [anon_sym_AMP_EQ] = ACTIONS(101),
    [anon_sym_PIPE_EQ] = ACTIONS(101),
    [anon_sym_CARET_EQ] = ACTIONS(101),
    [anon_sym_LT_LT_EQ] = ACTIONS(101),
    [anon_sym_GT_GT_EQ] = ACTIONS(101),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(101),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(103),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(36)] = {
    [sym_comment] = STATE(36),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(70),
    [anon_sym_RBRACE] = ACTIONS(70),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_as] = ACTIONS(67),
    [anon_sym_SEMI] = ACTIONS(70),
    [anon_sym_LPAREN] = ACTIONS(72),
    [anon_sym_COLON] = ACTIONS(75),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(72),
    [sym_identifier] = ACTIONS(79),
    [anon_sym_DQUOTE] = ACTIONS(70),
    [anon_sym_SQUOTE] = ACTIONS(70),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [sym_numeric_literal] = ACTIONS(70),
    [anon_sym_true] = ACTIONS(79),
    [anon_sym_false] = ACTIONS(79),
    [anon_sym_null] = ACTIONS(79),
    [anon_sym_PIPE_PIPE] = ACTIONS(72),
    [anon_sym_AMP_AMP] = ACTIONS(72),
    [anon_sym_PIPE] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [anon_sym_EQ_EQ] = ACTIONS(67),
    [anon_sym_BANG_EQ] = ACTIONS(67),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(72),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(72),
    [anon_sym_LT] = ACTIONS(67),
    [anon_sym_GT] = ACTIONS(67),
    [anon_sym_LT_EQ] = ACTIONS(72),
    [anon_sym_GT_EQ] = ACTIONS(72),
    [anon_sym_instanceof] = ACTIONS(67),
    [anon_sym_in] = ACTIONS(67),
    [anon_sym_LT_LT] = ACTIONS(67),
    [anon_sym_GT_GT] = ACTIONS(67),
    [anon_sym_GT_GT_GT] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_PERCENT] = ACTIONS(67),
    [anon_sym_STAR_STAR] = ACTIONS(72),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(70),
    [anon_sym_typeof] = ACTIONS(79),
    [anon_sym_void] = ACTIONS(79),
    [anon_sym_delete] = ACTIONS(79),
    [anon_sym_PLUS_EQ] = ACTIONS(81),
    [anon_sym_DASH_EQ] = ACTIONS(81),
    [anon_sym_STAR_EQ] = ACTIONS(81),
    [anon_sym_SLASH_EQ] = ACTIONS(81),
    [anon_sym_PERCENT_EQ] = ACTIONS(81),
    [anon_sym_AMP_EQ] = ACTIONS(81),
    [anon_sym_PIPE_EQ] = ACTIONS(81),
    [anon_sym_CARET_EQ] = ACTIONS(81),
    [anon_sym_LT_LT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(79),
    [anon_sym_EQ_GT] = ACTIONS(83),
    [anon_sym_LBRACK] = ACTIONS(72),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_var] = ACTIONS(79),
    [anon_sym_let] = ACTIONS(79),
    [anon_sym_const] = ACTIONS(79),
    [anon_sym_return] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(79),
    [anon_sym_throw] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_while] = ACTIONS(79),
    [anon_sym_break] = ACTIONS(79),
    [anon_sym_continue] = ACTIONS(79),
    [anon_sym_QMARK_DOT] = ACTIONS(72),
    [anon_sym_BQUOTE] = ACTIONS(70),
    [anon_sym_DOLLARr] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(72),
    [anon_sym_DASH_DASH] = ACTIONS(72),
    [anon_sym_new] = ACTIONS(79),
  },
  [STATE(37)] = {
    [sym_comment] = STATE(37),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(93),
    [anon_sym_LBRACE] = ACTIONS(95),
    [anon_sym_RBRACE] = ACTIONS(95),
    [anon_sym_STAR] = ACTIONS(93),
    [anon_sym_as] = ACTIONS(93),
    [anon_sym_SEMI] = ACTIONS(95),
    [anon_sym_LPAREN] = ACTIONS(95),
    [anon_sym_EQ] = ACTIONS(93),
    [anon_sym_DOT] = ACTIONS(95),
    [sym_identifier] = ACTIONS(93),
    [anon_sym_DQUOTE] = ACTIONS(95),
    [anon_sym_SQUOTE] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(93),
    [sym_numeric_literal] = ACTIONS(95),
    [anon_sym_true] = ACTIONS(93),
    [anon_sym_false] = ACTIONS(93),
    [anon_sym_null] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(95),
    [anon_sym_AMP_AMP] = ACTIONS(95),
    [anon_sym_PIPE] = ACTIONS(93),
    [anon_sym_CARET] = ACTIONS(93),
    [anon_sym_AMP] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(95),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(95),
    [anon_sym_LT] = ACTIONS(93),
    [anon_sym_GT] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_EQ] = ACTIONS(95),
    [anon_sym_instanceof] = ACTIONS(93),
    [anon_sym_in] = ACTIONS(93),
    [anon_sym_LT_LT] = ACTIONS(93),
    [anon_sym_GT_GT] = ACTIONS(93),
    [anon_sym_GT_GT_GT] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(93),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(95),
    [anon_sym_BANG] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(95),
    [anon_sym_typeof] = ACTIONS(93),
    [anon_sym_void] = ACTIONS(93),
    [anon_sym_delete] = ACTIONS(93),
    [anon_sym_PLUS_EQ] = ACTIONS(95),
    [anon_sym_DASH_EQ] = ACTIONS(95),
    [anon_sym_STAR_EQ] = ACTIONS(95),
    [anon_sym_SLASH_EQ] = ACTIONS(95),
    [anon_sym_PERCENT_EQ] = ACTIONS(95),
    [anon_sym_AMP_EQ] = ACTIONS(95),
    [anon_sym_PIPE_EQ] = ACTIONS(95),
    [anon_sym_CARET_EQ] = ACTIONS(95),
    [anon_sym_LT_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_GT_EQ] = ACTIONS(95),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(95),
    [anon_sym_QMARK] = ACTIONS(93),
    [anon_sym_await] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(93),
    [anon_sym_else] = ACTIONS(93),
    [anon_sym_async] = ACTIONS(93),
    [anon_sym_var] = ACTIONS(93),
    [anon_sym_let] = ACTIONS(93),
    [anon_sym_const] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_throw] = ACTIONS(93),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(93),
    [anon_sym_QMARK_DOT] = ACTIONS(95),
    [anon_sym_BQUOTE] = ACTIONS(95),
    [anon_sym_DOLLARr] = ACTIONS(93),
    [anon_sym_PLUS_PLUS] = ACTIONS(95),
    [anon_sym_DASH_DASH] = ACTIONS(95),
    [anon_sym_new] = ACTIONS(93),
  },
  [STATE(38)] = {
    [sym_comment] = STATE(38),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(70),
    [anon_sym_RBRACE] = ACTIONS(70),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_as] = ACTIONS(67),
    [anon_sym_SEMI] = ACTIONS(70),
    [anon_sym_LPAREN] = ACTIONS(72),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(72),
    [sym_identifier] = ACTIONS(79),
    [anon_sym_DQUOTE] = ACTIONS(70),
    [anon_sym_SQUOTE] = ACTIONS(70),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [sym_numeric_literal] = ACTIONS(70),
    [anon_sym_true] = ACTIONS(79),
    [anon_sym_false] = ACTIONS(79),
    [anon_sym_null] = ACTIONS(79),
    [anon_sym_PIPE_PIPE] = ACTIONS(72),
    [anon_sym_AMP_AMP] = ACTIONS(72),
    [anon_sym_PIPE] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [anon_sym_EQ_EQ] = ACTIONS(67),
    [anon_sym_BANG_EQ] = ACTIONS(67),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(72),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(72),
    [anon_sym_LT] = ACTIONS(67),
    [anon_sym_GT] = ACTIONS(67),
    [anon_sym_LT_EQ] = ACTIONS(72),
    [anon_sym_GT_EQ] = ACTIONS(72),
    [anon_sym_instanceof] = ACTIONS(67),
    [anon_sym_in] = ACTIONS(67),
    [anon_sym_LT_LT] = ACTIONS(67),
    [anon_sym_GT_GT] = ACTIONS(67),
    [anon_sym_GT_GT_GT] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_PERCENT] = ACTIONS(67),
    [anon_sym_STAR_STAR] = ACTIONS(72),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(70),
    [anon_sym_typeof] = ACTIONS(79),
    [anon_sym_void] = ACTIONS(79),
    [anon_sym_delete] = ACTIONS(79),
    [anon_sym_PLUS_EQ] = ACTIONS(81),
    [anon_sym_DASH_EQ] = ACTIONS(81),
    [anon_sym_STAR_EQ] = ACTIONS(81),
    [anon_sym_SLASH_EQ] = ACTIONS(81),
    [anon_sym_PERCENT_EQ] = ACTIONS(81),
    [anon_sym_AMP_EQ] = ACTIONS(81),
    [anon_sym_PIPE_EQ] = ACTIONS(81),
    [anon_sym_CARET_EQ] = ACTIONS(81),
    [anon_sym_LT_LT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(79),
    [anon_sym_LBRACK] = ACTIONS(72),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_else] = ACTIONS(79),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_var] = ACTIONS(79),
    [anon_sym_let] = ACTIONS(79),
    [anon_sym_const] = ACTIONS(79),
    [anon_sym_return] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(79),
    [anon_sym_throw] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_while] = ACTIONS(79),
    [anon_sym_break] = ACTIONS(79),
    [anon_sym_continue] = ACTIONS(79),
    [anon_sym_QMARK_DOT] = ACTIONS(72),
    [anon_sym_BQUOTE] = ACTIONS(70),
    [anon_sym_DOLLARr] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(72),
    [anon_sym_DASH_DASH] = ACTIONS(72),
    [anon_sym_new] = ACTIONS(79),
  },
  [STATE(39)] = {
    [sym_comment] = STATE(39),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_EQ] = ACTIONS(87),
    [anon_sym_DOT] = ACTIONS(37),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(89),
    [anon_sym_DASH_EQ] = ACTIONS(89),
    [anon_sym_STAR_EQ] = ACTIONS(89),
    [anon_sym_SLASH_EQ] = ACTIONS(89),
    [anon_sym_PERCENT_EQ] = ACTIONS(89),
    [anon_sym_AMP_EQ] = ACTIONS(89),
    [anon_sym_PIPE_EQ] = ACTIONS(89),
    [anon_sym_CARET_EQ] = ACTIONS(89),
    [anon_sym_LT_LT_EQ] = ACTIONS(89),
    [anon_sym_GT_GT_EQ] = ACTIONS(89),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(89),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_else] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(40)] = {
    [sym_comment] = STATE(40),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(61),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(426),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(41)] = {
    [sym_comment] = STATE(41),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(44),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(436),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(42)] = {
    [sym_comment] = STATE(42),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(47),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(438),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(43)] = {
    [sym_comment] = STATE(43),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(440),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(44)] = {
    [sym_comment] = STATE(44),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(442),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(45)] = {
    [sym_comment] = STATE(45),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(50),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(444),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(46)] = {
    [sym_comment] = STATE(46),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(446),
    [anon_sym_RBRACE] = ACTIONS(449),
    [anon_sym_LPAREN] = ACTIONS(451),
    [anon_sym_DOT] = ACTIONS(454),
    [sym_identifier] = ACTIONS(457),
    [anon_sym_DQUOTE] = ACTIONS(460),
    [anon_sym_SQUOTE] = ACTIONS(463),
    [anon_sym_DOLLAR] = ACTIONS(466),
    [sym_numeric_literal] = ACTIONS(469),
    [anon_sym_true] = ACTIONS(472),
    [anon_sym_false] = ACTIONS(472),
    [anon_sym_null] = ACTIONS(475),
    [anon_sym_LT] = ACTIONS(478),
    [anon_sym_PLUS] = ACTIONS(481),
    [anon_sym_DASH] = ACTIONS(481),
    [anon_sym_BANG] = ACTIONS(484),
    [anon_sym_TILDE] = ACTIONS(484),
    [anon_sym_typeof] = ACTIONS(481),
    [anon_sym_void] = ACTIONS(481),
    [anon_sym_delete] = ACTIONS(481),
    [anon_sym_await] = ACTIONS(487),
    [anon_sym_LBRACK] = ACTIONS(490),
    [anon_sym_if] = ACTIONS(493),
    [anon_sym_async] = ACTIONS(496),
    [anon_sym_var] = ACTIONS(499),
    [anon_sym_let] = ACTIONS(499),
    [anon_sym_const] = ACTIONS(499),
    [anon_sym_return] = ACTIONS(502),
    [anon_sym_try] = ACTIONS(505),
    [anon_sym_throw] = ACTIONS(508),
    [anon_sym_for] = ACTIONS(511),
    [anon_sym_while] = ACTIONS(514),
    [anon_sym_break] = ACTIONS(517),
    [anon_sym_continue] = ACTIONS(520),
    [anon_sym_BQUOTE] = ACTIONS(523),
    [anon_sym_DOLLARr] = ACTIONS(526),
    [anon_sym_PLUS_PLUS] = ACTIONS(529),
    [anon_sym_DASH_DASH] = ACTIONS(529),
    [anon_sym_new] = ACTIONS(532),
  },
  [STATE(47)] = {
    [sym_comment] = STATE(47),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(48)] = {
    [sym_comment] = STATE(48),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(56),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(537),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(49)] = {
    [sym_comment] = STATE(49),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_EQ] = ACTIONS(99),
    [anon_sym_DOT] = ACTIONS(37),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_PLUS_EQ] = ACTIONS(101),
    [anon_sym_DASH_EQ] = ACTIONS(101),
    [anon_sym_STAR_EQ] = ACTIONS(101),
    [anon_sym_SLASH_EQ] = ACTIONS(101),
    [anon_sym_PERCENT_EQ] = ACTIONS(101),
    [anon_sym_AMP_EQ] = ACTIONS(101),
    [anon_sym_PIPE_EQ] = ACTIONS(101),
    [anon_sym_CARET_EQ] = ACTIONS(101),
    [anon_sym_LT_LT_EQ] = ACTIONS(101),
    [anon_sym_GT_GT_EQ] = ACTIONS(101),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(101),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(50)] = {
    [sym_comment] = STATE(50),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(539),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(51)] = {
    [sym_comment] = STATE(51),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(59),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(541),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(52)] = {
    [sym_comment] = STATE(52),
    [sym_modifier_chain_expression] = STATE(274),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(43),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(543),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(53)] = {
    [sym_comment] = STATE(53),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(545),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(54)] = {
    [sym_comment] = STATE(54),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(63),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(547),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(55)] = {
    [sym_comment] = STATE(55),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(67),
    [anon_sym_LBRACE] = ACTIONS(70),
    [anon_sym_RBRACE] = ACTIONS(70),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_as] = ACTIONS(67),
    [anon_sym_SEMI] = ACTIONS(70),
    [anon_sym_LPAREN] = ACTIONS(72),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(72),
    [sym_identifier] = ACTIONS(79),
    [anon_sym_DQUOTE] = ACTIONS(70),
    [anon_sym_SQUOTE] = ACTIONS(70),
    [anon_sym_DOLLAR] = ACTIONS(79),
    [sym_numeric_literal] = ACTIONS(70),
    [anon_sym_true] = ACTIONS(79),
    [anon_sym_false] = ACTIONS(79),
    [anon_sym_null] = ACTIONS(79),
    [anon_sym_PIPE_PIPE] = ACTIONS(72),
    [anon_sym_AMP_AMP] = ACTIONS(72),
    [anon_sym_PIPE] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [anon_sym_EQ_EQ] = ACTIONS(67),
    [anon_sym_BANG_EQ] = ACTIONS(67),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(72),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(72),
    [anon_sym_LT] = ACTIONS(67),
    [anon_sym_GT] = ACTIONS(67),
    [anon_sym_LT_EQ] = ACTIONS(72),
    [anon_sym_GT_EQ] = ACTIONS(72),
    [anon_sym_instanceof] = ACTIONS(67),
    [anon_sym_in] = ACTIONS(67),
    [anon_sym_LT_LT] = ACTIONS(67),
    [anon_sym_GT_GT] = ACTIONS(67),
    [anon_sym_GT_GT_GT] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_PERCENT] = ACTIONS(67),
    [anon_sym_STAR_STAR] = ACTIONS(72),
    [anon_sym_BANG] = ACTIONS(79),
    [anon_sym_TILDE] = ACTIONS(70),
    [anon_sym_typeof] = ACTIONS(79),
    [anon_sym_void] = ACTIONS(79),
    [anon_sym_delete] = ACTIONS(79),
    [anon_sym_PLUS_EQ] = ACTIONS(81),
    [anon_sym_DASH_EQ] = ACTIONS(81),
    [anon_sym_STAR_EQ] = ACTIONS(81),
    [anon_sym_SLASH_EQ] = ACTIONS(81),
    [anon_sym_PERCENT_EQ] = ACTIONS(81),
    [anon_sym_AMP_EQ] = ACTIONS(81),
    [anon_sym_PIPE_EQ] = ACTIONS(81),
    [anon_sym_CARET_EQ] = ACTIONS(81),
    [anon_sym_LT_LT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_await] = ACTIONS(79),
    [anon_sym_LBRACK] = ACTIONS(72),
    [anon_sym_if] = ACTIONS(79),
    [anon_sym_async] = ACTIONS(79),
    [anon_sym_var] = ACTIONS(79),
    [anon_sym_let] = ACTIONS(79),
    [anon_sym_const] = ACTIONS(79),
    [anon_sym_return] = ACTIONS(79),
    [anon_sym_try] = ACTIONS(79),
    [anon_sym_throw] = ACTIONS(79),
    [anon_sym_for] = ACTIONS(79),
    [anon_sym_while] = ACTIONS(79),
    [anon_sym_break] = ACTIONS(79),
    [anon_sym_continue] = ACTIONS(79),
    [anon_sym_QMARK_DOT] = ACTIONS(72),
    [anon_sym_BQUOTE] = ACTIONS(70),
    [anon_sym_DOLLARr] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(72),
    [anon_sym_DASH_DASH] = ACTIONS(72),
    [anon_sym_new] = ACTIONS(79),
  },
  [STATE(56)] = {
    [sym_comment] = STATE(56),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(549),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(57)] = {
    [sym_comment] = STATE(57),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(65),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(551),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(58)] = {
    [sym_comment] = STATE(58),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(93),
    [anon_sym_LBRACE] = ACTIONS(95),
    [anon_sym_RBRACE] = ACTIONS(95),
    [anon_sym_STAR] = ACTIONS(93),
    [anon_sym_as] = ACTIONS(93),
    [anon_sym_SEMI] = ACTIONS(95),
    [anon_sym_LPAREN] = ACTIONS(95),
    [anon_sym_EQ] = ACTIONS(93),
    [anon_sym_DOT] = ACTIONS(95),
    [sym_identifier] = ACTIONS(93),
    [anon_sym_DQUOTE] = ACTIONS(95),
    [anon_sym_SQUOTE] = ACTIONS(95),
    [anon_sym_DOLLAR] = ACTIONS(93),
    [sym_numeric_literal] = ACTIONS(95),
    [anon_sym_true] = ACTIONS(93),
    [anon_sym_false] = ACTIONS(93),
    [anon_sym_null] = ACTIONS(93),
    [anon_sym_PIPE_PIPE] = ACTIONS(95),
    [anon_sym_AMP_AMP] = ACTIONS(95),
    [anon_sym_PIPE] = ACTIONS(93),
    [anon_sym_CARET] = ACTIONS(93),
    [anon_sym_AMP] = ACTIONS(93),
    [anon_sym_EQ_EQ] = ACTIONS(93),
    [anon_sym_BANG_EQ] = ACTIONS(93),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(95),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(95),
    [anon_sym_LT] = ACTIONS(93),
    [anon_sym_GT] = ACTIONS(93),
    [anon_sym_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_EQ] = ACTIONS(95),
    [anon_sym_instanceof] = ACTIONS(93),
    [anon_sym_in] = ACTIONS(93),
    [anon_sym_LT_LT] = ACTIONS(93),
    [anon_sym_GT_GT] = ACTIONS(93),
    [anon_sym_GT_GT_GT] = ACTIONS(93),
    [anon_sym_PLUS] = ACTIONS(93),
    [anon_sym_DASH] = ACTIONS(93),
    [anon_sym_PERCENT] = ACTIONS(93),
    [anon_sym_STAR_STAR] = ACTIONS(95),
    [anon_sym_BANG] = ACTIONS(93),
    [anon_sym_TILDE] = ACTIONS(95),
    [anon_sym_typeof] = ACTIONS(93),
    [anon_sym_void] = ACTIONS(93),
    [anon_sym_delete] = ACTIONS(93),
    [anon_sym_PLUS_EQ] = ACTIONS(95),
    [anon_sym_DASH_EQ] = ACTIONS(95),
    [anon_sym_STAR_EQ] = ACTIONS(95),
    [anon_sym_SLASH_EQ] = ACTIONS(95),
    [anon_sym_PERCENT_EQ] = ACTIONS(95),
    [anon_sym_AMP_EQ] = ACTIONS(95),
    [anon_sym_PIPE_EQ] = ACTIONS(95),
    [anon_sym_CARET_EQ] = ACTIONS(95),
    [anon_sym_LT_LT_EQ] = ACTIONS(95),
    [anon_sym_GT_GT_EQ] = ACTIONS(95),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(95),
    [anon_sym_QMARK] = ACTIONS(93),
    [anon_sym_await] = ACTIONS(93),
    [anon_sym_LBRACK] = ACTIONS(95),
    [anon_sym_if] = ACTIONS(93),
    [anon_sym_async] = ACTIONS(93),
    [anon_sym_var] = ACTIONS(93),
    [anon_sym_let] = ACTIONS(93),
    [anon_sym_const] = ACTIONS(93),
    [anon_sym_return] = ACTIONS(93),
    [anon_sym_try] = ACTIONS(93),
    [anon_sym_throw] = ACTIONS(93),
    [anon_sym_for] = ACTIONS(93),
    [anon_sym_while] = ACTIONS(93),
    [anon_sym_break] = ACTIONS(93),
    [anon_sym_continue] = ACTIONS(93),
    [anon_sym_QMARK_DOT] = ACTIONS(95),
    [anon_sym_BQUOTE] = ACTIONS(95),
    [anon_sym_DOLLARr] = ACTIONS(93),
    [anon_sym_PLUS_PLUS] = ACTIONS(95),
    [anon_sym_DASH_DASH] = ACTIONS(95),
    [anon_sym_new] = ACTIONS(93),
  },
  [STATE(59)] = {
    [sym_comment] = STATE(59),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(553),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(60)] = {
    [sym_comment] = STATE(60),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(555),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(61)] = {
    [sym_comment] = STATE(61),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(557),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(62)] = {
    [sym_comment] = STATE(62),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(559),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(63)] = {
    [sym_comment] = STATE(63),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(561),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(64)] = {
    [sym_comment] = STATE(64),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(563),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(65)] = {
    [sym_comment] = STATE(65),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_statement] = STATE(948),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [aux_sym_block_statement_repeat1] = STATE(46),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_RBRACE] = ACTIONS(565),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(66)] = {
    [sym_comment] = STATE(66),
    [sym_modifier_chain_expression] = STATE(372),
    [sym_string_literal] = STATE(372),
    [sym_expression] = STATE(249),
    [sym_state_binding_expression] = STATE(372),
    [sym_boolean_literal] = STATE(372),
    [sym_null_literal] = STATE(372),
    [sym_binary_expression] = STATE(372),
    [sym_unary_expression] = STATE(372),
    [sym_assignment_expression] = STATE(372),
    [sym_conditional_expression] = STATE(372),
    [sym_await_expression] = STATE(372),
    [sym_as_expression] = STATE(372),
    [sym_type_parameters] = STATE(1866),
    [sym_expression_statement] = STATE(863),
    [sym_if_statement] = STATE(863),
    [sym_parameter_list] = STATE(1982),
    [sym_block_statement] = STATE(887),
    [sym_statement] = STATE(887),
    [sym_variable_declaration] = STATE(863),
    [sym_return_statement] = STATE(863),
    [sym_try_statement] = STATE(863),
    [sym_throw_statement] = STATE(863),
    [sym_for_statement] = STATE(863),
    [sym_while_statement] = STATE(863),
    [sym_break_statement] = STATE(863),
    [sym_continue_statement] = STATE(863),
    [sym_arrow_function] = STATE(372),
    [sym_call_expression] = STATE(372),
    [sym_member_expression] = STATE(39),
    [sym_subscript_expression] = STATE(372),
    [sym_parenthesized_expression] = STATE(372),
    [sym_array_literal] = STATE(372),
    [sym_object_literal] = STATE(372),
    [sym_template_literal] = STATE(372),
    [sym_resource_expression] = STATE(372),
    [sym_update_expression] = STATE(372),
    [sym_new_expression] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(573),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [sym_numeric_literal] = ACTIONS(581),
    [anon_sym_true] = ACTIONS(583),
    [anon_sym_false] = ACTIONS(583),
    [anon_sym_null] = ACTIONS(585),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_BANG] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_typeof] = ACTIONS(587),
    [anon_sym_void] = ACTIONS(587),
    [anon_sym_delete] = ACTIONS(587),
    [anon_sym_await] = ACTIONS(591),
    [anon_sym_LBRACK] = ACTIONS(593),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_async] = ACTIONS(597),
    [anon_sym_var] = ACTIONS(599),
    [anon_sym_let] = ACTIONS(599),
    [anon_sym_const] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_throw] = ACTIONS(605),
    [anon_sym_for] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_break] = ACTIONS(611),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_BQUOTE] = ACTIONS(615),
    [anon_sym_DOLLARr] = ACTIONS(617),
    [anon_sym_PLUS_PLUS] = ACTIONS(619),
    [anon_sym_DASH_DASH] = ACTIONS(619),
    [anon_sym_new] = ACTIONS(621),
  },
  [STATE(67)] = {
    [sym_comment] = STATE(67),
    [sym_modifier_chain_expression] = STATE(372),
    [sym_string_literal] = STATE(372),
    [sym_expression] = STATE(249),
    [sym_state_binding_expression] = STATE(372),
    [sym_boolean_literal] = STATE(372),
    [sym_null_literal] = STATE(372),
    [sym_binary_expression] = STATE(372),
    [sym_unary_expression] = STATE(372),
    [sym_assignment_expression] = STATE(372),
    [sym_conditional_expression] = STATE(372),
    [sym_await_expression] = STATE(372),
    [sym_as_expression] = STATE(372),
    [sym_type_parameters] = STATE(1866),
    [sym_expression_statement] = STATE(863),
    [sym_if_statement] = STATE(863),
    [sym_parameter_list] = STATE(1982),
    [sym_block_statement] = STATE(886),
    [sym_statement] = STATE(886),
    [sym_variable_declaration] = STATE(863),
    [sym_return_statement] = STATE(863),
    [sym_try_statement] = STATE(863),
    [sym_throw_statement] = STATE(863),
    [sym_for_statement] = STATE(863),
    [sym_while_statement] = STATE(863),
    [sym_break_statement] = STATE(863),
    [sym_continue_statement] = STATE(863),
    [sym_arrow_function] = STATE(372),
    [sym_call_expression] = STATE(372),
    [sym_member_expression] = STATE(39),
    [sym_subscript_expression] = STATE(372),
    [sym_parenthesized_expression] = STATE(372),
    [sym_array_literal] = STATE(372),
    [sym_object_literal] = STATE(372),
    [sym_template_literal] = STATE(372),
    [sym_resource_expression] = STATE(372),
    [sym_update_expression] = STATE(372),
    [sym_new_expression] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(573),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [sym_numeric_literal] = ACTIONS(581),
    [anon_sym_true] = ACTIONS(583),
    [anon_sym_false] = ACTIONS(583),
    [anon_sym_null] = ACTIONS(585),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_BANG] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_typeof] = ACTIONS(587),
    [anon_sym_void] = ACTIONS(587),
    [anon_sym_delete] = ACTIONS(587),
    [anon_sym_await] = ACTIONS(591),
    [anon_sym_LBRACK] = ACTIONS(593),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_async] = ACTIONS(597),
    [anon_sym_var] = ACTIONS(599),
    [anon_sym_let] = ACTIONS(599),
    [anon_sym_const] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_throw] = ACTIONS(605),
    [anon_sym_for] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_break] = ACTIONS(611),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_BQUOTE] = ACTIONS(615),
    [anon_sym_DOLLARr] = ACTIONS(617),
    [anon_sym_PLUS_PLUS] = ACTIONS(619),
    [anon_sym_DASH_DASH] = ACTIONS(619),
    [anon_sym_new] = ACTIONS(621),
  },
  [STATE(68)] = {
    [sym_comment] = STATE(68),
    [sym_modifier_chain_expression] = STATE(372),
    [sym_string_literal] = STATE(372),
    [sym_expression] = STATE(249),
    [sym_state_binding_expression] = STATE(372),
    [sym_boolean_literal] = STATE(372),
    [sym_null_literal] = STATE(372),
    [sym_binary_expression] = STATE(372),
    [sym_unary_expression] = STATE(372),
    [sym_assignment_expression] = STATE(372),
    [sym_conditional_expression] = STATE(372),
    [sym_await_expression] = STATE(372),
    [sym_as_expression] = STATE(372),
    [sym_type_parameters] = STATE(1866),
    [sym_expression_statement] = STATE(863),
    [sym_if_statement] = STATE(863),
    [sym_parameter_list] = STATE(1982),
    [sym_block_statement] = STATE(901),
    [sym_statement] = STATE(901),
    [sym_variable_declaration] = STATE(863),
    [sym_return_statement] = STATE(863),
    [sym_try_statement] = STATE(863),
    [sym_throw_statement] = STATE(863),
    [sym_for_statement] = STATE(863),
    [sym_while_statement] = STATE(863),
    [sym_break_statement] = STATE(863),
    [sym_continue_statement] = STATE(863),
    [sym_arrow_function] = STATE(372),
    [sym_call_expression] = STATE(372),
    [sym_member_expression] = STATE(39),
    [sym_subscript_expression] = STATE(372),
    [sym_parenthesized_expression] = STATE(372),
    [sym_array_literal] = STATE(372),
    [sym_object_literal] = STATE(372),
    [sym_template_literal] = STATE(372),
    [sym_resource_expression] = STATE(372),
    [sym_update_expression] = STATE(372),
    [sym_new_expression] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(573),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [sym_numeric_literal] = ACTIONS(581),
    [anon_sym_true] = ACTIONS(583),
    [anon_sym_false] = ACTIONS(583),
    [anon_sym_null] = ACTIONS(585),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_BANG] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_typeof] = ACTIONS(587),
    [anon_sym_void] = ACTIONS(587),
    [anon_sym_delete] = ACTIONS(587),
    [anon_sym_await] = ACTIONS(591),
    [anon_sym_LBRACK] = ACTIONS(593),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_async] = ACTIONS(597),
    [anon_sym_var] = ACTIONS(599),
    [anon_sym_let] = ACTIONS(599),
    [anon_sym_const] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_throw] = ACTIONS(605),
    [anon_sym_for] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_break] = ACTIONS(611),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_BQUOTE] = ACTIONS(615),
    [anon_sym_DOLLARr] = ACTIONS(617),
    [anon_sym_PLUS_PLUS] = ACTIONS(619),
    [anon_sym_DASH_DASH] = ACTIONS(619),
    [anon_sym_new] = ACTIONS(621),
  },
  [STATE(69)] = {
    [sym_comment] = STATE(69),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_block_statement] = STATE(923),
    [sym_statement] = STATE(923),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(623),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(70)] = {
    [sym_comment] = STATE(70),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_block_statement] = STATE(940),
    [sym_statement] = STATE(940),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(623),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(71)] = {
    [sym_comment] = STATE(71),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_block_statement] = STATE(919),
    [sym_statement] = STATE(919),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(623),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(72)] = {
    [sym_comment] = STATE(72),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(952),
    [sym_parameter_list] = STATE(1956),
    [sym_block_statement] = STATE(953),
    [sym_statement] = STATE(953),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(623),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(73)] = {
    [sym_comment] = STATE(73),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_block_statement] = STATE(954),
    [sym_statement] = STATE(954),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(623),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(74)] = {
    [sym_comment] = STATE(74),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(276),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_parameters] = STATE(1856),
    [sym_expression_statement] = STATE(947),
    [sym_if_statement] = STATE(947),
    [sym_parameter_list] = STATE(1956),
    [sym_block_statement] = STATE(945),
    [sym_statement] = STATE(945),
    [sym_variable_declaration] = STATE(947),
    [sym_return_statement] = STATE(947),
    [sym_try_statement] = STATE(947),
    [sym_throw_statement] = STATE(947),
    [sym_for_statement] = STATE(947),
    [sym_while_statement] = STATE(947),
    [sym_break_statement] = STATE(947),
    [sym_continue_statement] = STATE(947),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(623),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(430),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(179),
    [anon_sym_false] = ACTIONS(179),
    [anon_sym_null] = ACTIONS(181),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(183),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_LBRACK] = ACTIONS(434),
    [anon_sym_if] = ACTIONS(191),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_var] = ACTIONS(197),
    [anon_sym_let] = ACTIONS(197),
    [anon_sym_const] = ACTIONS(197),
    [anon_sym_return] = ACTIONS(199),
    [anon_sym_try] = ACTIONS(201),
    [anon_sym_throw] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(205),
    [anon_sym_while] = ACTIONS(207),
    [anon_sym_break] = ACTIONS(209),
    [anon_sym_continue] = ACTIONS(211),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(75)] = {
    [sym_comment] = STATE(75),
    [sym_type_arguments] = STATE(123),
    [aux_sym_qualified_type_repeat1] = STATE(108),
    [aux_sym_array_type_repeat1] = STATE(109),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(625),
    [anon_sym_Text] = ACTIONS(61),
    [anon_sym_Button] = ACTIONS(61),
    [anon_sym_Image] = ACTIONS(61),
    [anon_sym_TextInput] = ACTIONS(61),
    [anon_sym_TextArea] = ACTIONS(61),
    [anon_sym_Column] = ACTIONS(61),
    [anon_sym_Row] = ACTIONS(61),
    [anon_sym_Stack] = ACTIONS(61),
    [anon_sym_Flex] = ACTIONS(61),
    [anon_sym_Grid] = ACTIONS(61),
    [anon_sym_GridRow] = ACTIONS(61),
    [anon_sym_GridCol] = ACTIONS(61),
    [anon_sym_List] = ACTIONS(61),
    [anon_sym_ScrollList] = ACTIONS(61),
    [anon_sym_ListItem] = ACTIONS(61),
    [anon_sym_GridItem] = ACTIONS(61),
    [anon_sym_ForEach] = ACTIONS(61),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(628),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(631),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(76)] = {
    [sym_comment] = STATE(76),
    [sym_modifier_chain_expression] = STATE(372),
    [sym_string_literal] = STATE(372),
    [sym_expression] = STATE(249),
    [sym_state_binding_expression] = STATE(372),
    [sym_boolean_literal] = STATE(372),
    [sym_null_literal] = STATE(372),
    [sym_binary_expression] = STATE(372),
    [sym_unary_expression] = STATE(372),
    [sym_assignment_expression] = STATE(372),
    [sym_conditional_expression] = STATE(372),
    [sym_await_expression] = STATE(372),
    [sym_as_expression] = STATE(372),
    [sym_type_parameters] = STATE(1866),
    [sym_expression_statement] = STATE(863),
    [sym_if_statement] = STATE(863),
    [sym_parameter_list] = STATE(1982),
    [sym_block_statement] = STATE(880),
    [sym_statement] = STATE(880),
    [sym_variable_declaration] = STATE(863),
    [sym_return_statement] = STATE(863),
    [sym_try_statement] = STATE(863),
    [sym_throw_statement] = STATE(863),
    [sym_for_statement] = STATE(863),
    [sym_while_statement] = STATE(863),
    [sym_break_statement] = STATE(863),
    [sym_continue_statement] = STATE(863),
    [sym_arrow_function] = STATE(372),
    [sym_call_expression] = STATE(372),
    [sym_member_expression] = STATE(39),
    [sym_subscript_expression] = STATE(372),
    [sym_parenthesized_expression] = STATE(372),
    [sym_array_literal] = STATE(372),
    [sym_object_literal] = STATE(372),
    [sym_template_literal] = STATE(372),
    [sym_resource_expression] = STATE(372),
    [sym_update_expression] = STATE(372),
    [sym_new_expression] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(573),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [sym_numeric_literal] = ACTIONS(581),
    [anon_sym_true] = ACTIONS(583),
    [anon_sym_false] = ACTIONS(583),
    [anon_sym_null] = ACTIONS(585),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_BANG] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_typeof] = ACTIONS(587),
    [anon_sym_void] = ACTIONS(587),
    [anon_sym_delete] = ACTIONS(587),
    [anon_sym_await] = ACTIONS(591),
    [anon_sym_LBRACK] = ACTIONS(593),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_async] = ACTIONS(597),
    [anon_sym_var] = ACTIONS(599),
    [anon_sym_let] = ACTIONS(599),
    [anon_sym_const] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_throw] = ACTIONS(605),
    [anon_sym_for] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_break] = ACTIONS(611),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_BQUOTE] = ACTIONS(615),
    [anon_sym_DOLLARr] = ACTIONS(617),
    [anon_sym_PLUS_PLUS] = ACTIONS(619),
    [anon_sym_DASH_DASH] = ACTIONS(619),
    [anon_sym_new] = ACTIONS(621),
  },
  [STATE(77)] = {
    [sym_comment] = STATE(77),
    [sym_modifier_chain_expression] = STATE(372),
    [sym_string_literal] = STATE(372),
    [sym_expression] = STATE(249),
    [sym_state_binding_expression] = STATE(372),
    [sym_boolean_literal] = STATE(372),
    [sym_null_literal] = STATE(372),
    [sym_binary_expression] = STATE(372),
    [sym_unary_expression] = STATE(372),
    [sym_assignment_expression] = STATE(372),
    [sym_conditional_expression] = STATE(372),
    [sym_await_expression] = STATE(372),
    [sym_as_expression] = STATE(372),
    [sym_type_parameters] = STATE(1866),
    [sym_expression_statement] = STATE(863),
    [sym_if_statement] = STATE(904),
    [sym_parameter_list] = STATE(1982),
    [sym_block_statement] = STATE(883),
    [sym_statement] = STATE(883),
    [sym_variable_declaration] = STATE(863),
    [sym_return_statement] = STATE(863),
    [sym_try_statement] = STATE(863),
    [sym_throw_statement] = STATE(863),
    [sym_for_statement] = STATE(863),
    [sym_while_statement] = STATE(863),
    [sym_break_statement] = STATE(863),
    [sym_continue_statement] = STATE(863),
    [sym_arrow_function] = STATE(372),
    [sym_call_expression] = STATE(372),
    [sym_member_expression] = STATE(39),
    [sym_subscript_expression] = STATE(372),
    [sym_parenthesized_expression] = STATE(372),
    [sym_array_literal] = STATE(372),
    [sym_object_literal] = STATE(372),
    [sym_template_literal] = STATE(372),
    [sym_resource_expression] = STATE(372),
    [sym_update_expression] = STATE(372),
    [sym_new_expression] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(573),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [sym_numeric_literal] = ACTIONS(581),
    [anon_sym_true] = ACTIONS(583),
    [anon_sym_false] = ACTIONS(583),
    [anon_sym_null] = ACTIONS(585),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_BANG] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_typeof] = ACTIONS(587),
    [anon_sym_void] = ACTIONS(587),
    [anon_sym_delete] = ACTIONS(587),
    [anon_sym_await] = ACTIONS(591),
    [anon_sym_LBRACK] = ACTIONS(593),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_async] = ACTIONS(597),
    [anon_sym_var] = ACTIONS(599),
    [anon_sym_let] = ACTIONS(599),
    [anon_sym_const] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_throw] = ACTIONS(605),
    [anon_sym_for] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_break] = ACTIONS(611),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_BQUOTE] = ACTIONS(615),
    [anon_sym_DOLLARr] = ACTIONS(617),
    [anon_sym_PLUS_PLUS] = ACTIONS(619),
    [anon_sym_DASH_DASH] = ACTIONS(619),
    [anon_sym_new] = ACTIONS(621),
  },
  [STATE(78)] = {
    [sym_comment] = STATE(78),
    [sym_modifier_chain_expression] = STATE(372),
    [sym_string_literal] = STATE(372),
    [sym_expression] = STATE(249),
    [sym_state_binding_expression] = STATE(372),
    [sym_boolean_literal] = STATE(372),
    [sym_null_literal] = STATE(372),
    [sym_binary_expression] = STATE(372),
    [sym_unary_expression] = STATE(372),
    [sym_assignment_expression] = STATE(372),
    [sym_conditional_expression] = STATE(372),
    [sym_await_expression] = STATE(372),
    [sym_as_expression] = STATE(372),
    [sym_type_parameters] = STATE(1866),
    [sym_expression_statement] = STATE(863),
    [sym_if_statement] = STATE(863),
    [sym_parameter_list] = STATE(1982),
    [sym_block_statement] = STATE(881),
    [sym_statement] = STATE(881),
    [sym_variable_declaration] = STATE(863),
    [sym_return_statement] = STATE(863),
    [sym_try_statement] = STATE(863),
    [sym_throw_statement] = STATE(863),
    [sym_for_statement] = STATE(863),
    [sym_while_statement] = STATE(863),
    [sym_break_statement] = STATE(863),
    [sym_continue_statement] = STATE(863),
    [sym_arrow_function] = STATE(372),
    [sym_call_expression] = STATE(372),
    [sym_member_expression] = STATE(39),
    [sym_subscript_expression] = STATE(372),
    [sym_parenthesized_expression] = STATE(372),
    [sym_array_literal] = STATE(372),
    [sym_object_literal] = STATE(372),
    [sym_template_literal] = STATE(372),
    [sym_resource_expression] = STATE(372),
    [sym_update_expression] = STATE(372),
    [sym_new_expression] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(573),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [sym_numeric_literal] = ACTIONS(581),
    [anon_sym_true] = ACTIONS(583),
    [anon_sym_false] = ACTIONS(583),
    [anon_sym_null] = ACTIONS(585),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_BANG] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_typeof] = ACTIONS(587),
    [anon_sym_void] = ACTIONS(587),
    [anon_sym_delete] = ACTIONS(587),
    [anon_sym_await] = ACTIONS(591),
    [anon_sym_LBRACK] = ACTIONS(593),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_async] = ACTIONS(597),
    [anon_sym_var] = ACTIONS(599),
    [anon_sym_let] = ACTIONS(599),
    [anon_sym_const] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_throw] = ACTIONS(605),
    [anon_sym_for] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_break] = ACTIONS(611),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_BQUOTE] = ACTIONS(615),
    [anon_sym_DOLLARr] = ACTIONS(617),
    [anon_sym_PLUS_PLUS] = ACTIONS(619),
    [anon_sym_DASH_DASH] = ACTIONS(619),
    [anon_sym_new] = ACTIONS(621),
  },
  [STATE(79)] = {
    [sym_comment] = STATE(79),
    [sym_modifier_chain_expression] = STATE(372),
    [sym_string_literal] = STATE(372),
    [sym_expression] = STATE(249),
    [sym_state_binding_expression] = STATE(372),
    [sym_boolean_literal] = STATE(372),
    [sym_null_literal] = STATE(372),
    [sym_binary_expression] = STATE(372),
    [sym_unary_expression] = STATE(372),
    [sym_assignment_expression] = STATE(372),
    [sym_conditional_expression] = STATE(372),
    [sym_await_expression] = STATE(372),
    [sym_as_expression] = STATE(372),
    [sym_type_parameters] = STATE(1866),
    [sym_expression_statement] = STATE(863),
    [sym_if_statement] = STATE(863),
    [sym_parameter_list] = STATE(1982),
    [sym_block_statement] = STATE(884),
    [sym_statement] = STATE(884),
    [sym_variable_declaration] = STATE(863),
    [sym_return_statement] = STATE(863),
    [sym_try_statement] = STATE(863),
    [sym_throw_statement] = STATE(863),
    [sym_for_statement] = STATE(863),
    [sym_while_statement] = STATE(863),
    [sym_break_statement] = STATE(863),
    [sym_continue_statement] = STATE(863),
    [sym_arrow_function] = STATE(372),
    [sym_call_expression] = STATE(372),
    [sym_member_expression] = STATE(39),
    [sym_subscript_expression] = STATE(372),
    [sym_parenthesized_expression] = STATE(372),
    [sym_array_literal] = STATE(372),
    [sym_object_literal] = STATE(372),
    [sym_template_literal] = STATE(372),
    [sym_resource_expression] = STATE(372),
    [sym_update_expression] = STATE(372),
    [sym_new_expression] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(573),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [sym_numeric_literal] = ACTIONS(581),
    [anon_sym_true] = ACTIONS(583),
    [anon_sym_false] = ACTIONS(583),
    [anon_sym_null] = ACTIONS(585),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_BANG] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_typeof] = ACTIONS(587),
    [anon_sym_void] = ACTIONS(587),
    [anon_sym_delete] = ACTIONS(587),
    [anon_sym_await] = ACTIONS(591),
    [anon_sym_LBRACK] = ACTIONS(593),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_async] = ACTIONS(597),
    [anon_sym_var] = ACTIONS(599),
    [anon_sym_let] = ACTIONS(599),
    [anon_sym_const] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_throw] = ACTIONS(605),
    [anon_sym_for] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_break] = ACTIONS(611),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_BQUOTE] = ACTIONS(615),
    [anon_sym_DOLLARr] = ACTIONS(617),
    [anon_sym_PLUS_PLUS] = ACTIONS(619),
    [anon_sym_DASH_DASH] = ACTIONS(619),
    [anon_sym_new] = ACTIONS(621),
  },
  [STATE(80)] = {
    [sym_comment] = STATE(80),
    [sym_modifier_chain_expression] = STATE(372),
    [sym_string_literal] = STATE(372),
    [sym_expression] = STATE(249),
    [sym_state_binding_expression] = STATE(372),
    [sym_boolean_literal] = STATE(372),
    [sym_null_literal] = STATE(372),
    [sym_binary_expression] = STATE(372),
    [sym_unary_expression] = STATE(372),
    [sym_assignment_expression] = STATE(372),
    [sym_conditional_expression] = STATE(372),
    [sym_await_expression] = STATE(372),
    [sym_as_expression] = STATE(372),
    [sym_type_parameters] = STATE(1866),
    [sym_expression_statement] = STATE(863),
    [sym_if_statement] = STATE(863),
    [sym_parameter_list] = STATE(1982),
    [sym_block_statement] = STATE(885),
    [sym_statement] = STATE(885),
    [sym_variable_declaration] = STATE(863),
    [sym_return_statement] = STATE(863),
    [sym_try_statement] = STATE(863),
    [sym_throw_statement] = STATE(863),
    [sym_for_statement] = STATE(863),
    [sym_while_statement] = STATE(863),
    [sym_break_statement] = STATE(863),
    [sym_continue_statement] = STATE(863),
    [sym_arrow_function] = STATE(372),
    [sym_call_expression] = STATE(372),
    [sym_member_expression] = STATE(39),
    [sym_subscript_expression] = STATE(372),
    [sym_parenthesized_expression] = STATE(372),
    [sym_array_literal] = STATE(372),
    [sym_object_literal] = STATE(372),
    [sym_template_literal] = STATE(372),
    [sym_resource_expression] = STATE(372),
    [sym_update_expression] = STATE(372),
    [sym_new_expression] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(567),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(573),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [sym_numeric_literal] = ACTIONS(581),
    [anon_sym_true] = ACTIONS(583),
    [anon_sym_false] = ACTIONS(583),
    [anon_sym_null] = ACTIONS(585),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_BANG] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_typeof] = ACTIONS(587),
    [anon_sym_void] = ACTIONS(587),
    [anon_sym_delete] = ACTIONS(587),
    [anon_sym_await] = ACTIONS(591),
    [anon_sym_LBRACK] = ACTIONS(593),
    [anon_sym_if] = ACTIONS(595),
    [anon_sym_async] = ACTIONS(597),
    [anon_sym_var] = ACTIONS(599),
    [anon_sym_let] = ACTIONS(599),
    [anon_sym_const] = ACTIONS(599),
    [anon_sym_return] = ACTIONS(601),
    [anon_sym_try] = ACTIONS(603),
    [anon_sym_throw] = ACTIONS(605),
    [anon_sym_for] = ACTIONS(607),
    [anon_sym_while] = ACTIONS(609),
    [anon_sym_break] = ACTIONS(611),
    [anon_sym_continue] = ACTIONS(613),
    [anon_sym_BQUOTE] = ACTIONS(615),
    [anon_sym_DOLLARr] = ACTIONS(617),
    [anon_sym_PLUS_PLUS] = ACTIONS(619),
    [anon_sym_DASH_DASH] = ACTIONS(619),
    [anon_sym_new] = ACTIONS(621),
  },
  [STATE(81)] = {
    [sym_comment] = STATE(81),
    [sym_type_arguments] = STATE(164),
    [aux_sym_qualified_type_repeat1] = STATE(133),
    [aux_sym_array_type_repeat1] = STATE(134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(634),
    [anon_sym_Text] = ACTIONS(61),
    [anon_sym_Button] = ACTIONS(61),
    [anon_sym_Image] = ACTIONS(61),
    [anon_sym_TextInput] = ACTIONS(61),
    [anon_sym_TextArea] = ACTIONS(61),
    [anon_sym_Column] = ACTIONS(61),
    [anon_sym_Row] = ACTIONS(61),
    [anon_sym_Stack] = ACTIONS(61),
    [anon_sym_Flex] = ACTIONS(61),
    [anon_sym_Grid] = ACTIONS(61),
    [anon_sym_GridRow] = ACTIONS(61),
    [anon_sym_GridCol] = ACTIONS(61),
    [anon_sym_List] = ACTIONS(61),
    [anon_sym_ScrollList] = ACTIONS(61),
    [anon_sym_ListItem] = ACTIONS(61),
    [anon_sym_GridItem] = ACTIONS(61),
    [anon_sym_ForEach] = ACTIONS(61),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(637),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(640),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(82)] = {
    [sym_comment] = STATE(82),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(645),
    [anon_sym_RBRACE] = ACTIONS(645),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(647),
    [anon_sym_SEMI] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_DOT] = ACTIONS(645),
    [anon_sym_Text] = ACTIONS(649),
    [anon_sym_Button] = ACTIONS(649),
    [anon_sym_Image] = ACTIONS(649),
    [anon_sym_TextInput] = ACTIONS(649),
    [anon_sym_TextArea] = ACTIONS(649),
    [anon_sym_Column] = ACTIONS(649),
    [anon_sym_Row] = ACTIONS(649),
    [anon_sym_Stack] = ACTIONS(649),
    [anon_sym_Flex] = ACTIONS(649),
    [anon_sym_Grid] = ACTIONS(649),
    [anon_sym_GridRow] = ACTIONS(649),
    [anon_sym_GridCol] = ACTIONS(649),
    [anon_sym_List] = ACTIONS(649),
    [anon_sym_ScrollList] = ACTIONS(649),
    [anon_sym_ListItem] = ACTIONS(649),
    [anon_sym_GridItem] = ACTIONS(649),
    [anon_sym_ForEach] = ACTIONS(649),
    [sym_identifier] = ACTIONS(649),
    [anon_sym_DQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(645),
    [anon_sym_DOLLAR] = ACTIONS(649),
    [sym_numeric_literal] = ACTIONS(645),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_null] = ACTIONS(649),
    [anon_sym_PIPE_PIPE] = ACTIONS(651),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(655),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(665),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(649),
    [anon_sym_TILDE] = ACTIONS(645),
    [anon_sym_typeof] = ACTIONS(649),
    [anon_sym_void] = ACTIONS(649),
    [anon_sym_delete] = ACTIONS(649),
    [anon_sym_QMARK] = ACTIONS(682),
    [anon_sym_await] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(649),
    [anon_sym_async] = ACTIONS(649),
    [anon_sym_QMARK_DOT] = ACTIONS(645),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_DOLLARr] = ACTIONS(649),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(649),
  },
  [STATE(83)] = {
    [sym_comment] = STATE(83),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(688),
    [anon_sym_RBRACE] = ACTIONS(688),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(647),
    [anon_sym_SEMI] = ACTIONS(688),
    [anon_sym_LPAREN] = ACTIONS(690),
    [anon_sym_DOT] = ACTIONS(692),
    [anon_sym_Text] = ACTIONS(694),
    [anon_sym_Button] = ACTIONS(694),
    [anon_sym_Image] = ACTIONS(694),
    [anon_sym_TextInput] = ACTIONS(694),
    [anon_sym_TextArea] = ACTIONS(694),
    [anon_sym_Column] = ACTIONS(694),
    [anon_sym_Row] = ACTIONS(694),
    [anon_sym_Stack] = ACTIONS(694),
    [anon_sym_Flex] = ACTIONS(694),
    [anon_sym_Grid] = ACTIONS(694),
    [anon_sym_GridRow] = ACTIONS(694),
    [anon_sym_GridCol] = ACTIONS(694),
    [anon_sym_List] = ACTIONS(694),
    [anon_sym_ScrollList] = ACTIONS(694),
    [anon_sym_ListItem] = ACTIONS(694),
    [anon_sym_GridItem] = ACTIONS(694),
    [anon_sym_ForEach] = ACTIONS(694),
    [sym_identifier] = ACTIONS(694),
    [anon_sym_DQUOTE] = ACTIONS(688),
    [anon_sym_SQUOTE] = ACTIONS(688),
    [anon_sym_DOLLAR] = ACTIONS(694),
    [sym_numeric_literal] = ACTIONS(688),
    [anon_sym_true] = ACTIONS(694),
    [anon_sym_false] = ACTIONS(694),
    [anon_sym_null] = ACTIONS(694),
    [anon_sym_PIPE_PIPE] = ACTIONS(651),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(655),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(696),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(694),
    [anon_sym_TILDE] = ACTIONS(688),
    [anon_sym_typeof] = ACTIONS(694),
    [anon_sym_void] = ACTIONS(694),
    [anon_sym_delete] = ACTIONS(694),
    [anon_sym_QMARK] = ACTIONS(682),
    [anon_sym_await] = ACTIONS(694),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(694),
    [anon_sym_async] = ACTIONS(694),
    [anon_sym_QMARK_DOT] = ACTIONS(692),
    [anon_sym_BQUOTE] = ACTIONS(688),
    [anon_sym_DOLLARr] = ACTIONS(694),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(694),
  },
  [STATE(84)] = {
    [sym_comment] = STATE(84),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_RBRACE] = ACTIONS(698),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(647),
    [anon_sym_SEMI] = ACTIONS(698),
    [anon_sym_LPAREN] = ACTIONS(690),
    [anon_sym_DOT] = ACTIONS(692),
    [anon_sym_Text] = ACTIONS(700),
    [anon_sym_Button] = ACTIONS(700),
    [anon_sym_Image] = ACTIONS(700),
    [anon_sym_TextInput] = ACTIONS(700),
    [anon_sym_TextArea] = ACTIONS(700),
    [anon_sym_Column] = ACTIONS(700),
    [anon_sym_Row] = ACTIONS(700),
    [anon_sym_Stack] = ACTIONS(700),
    [anon_sym_Flex] = ACTIONS(700),
    [anon_sym_Grid] = ACTIONS(700),
    [anon_sym_GridRow] = ACTIONS(700),
    [anon_sym_GridCol] = ACTIONS(700),
    [anon_sym_List] = ACTIONS(700),
    [anon_sym_ScrollList] = ACTIONS(700),
    [anon_sym_ListItem] = ACTIONS(700),
    [anon_sym_GridItem] = ACTIONS(700),
    [anon_sym_ForEach] = ACTIONS(700),
    [sym_identifier] = ACTIONS(700),
    [anon_sym_DQUOTE] = ACTIONS(698),
    [anon_sym_SQUOTE] = ACTIONS(698),
    [anon_sym_DOLLAR] = ACTIONS(700),
    [sym_numeric_literal] = ACTIONS(698),
    [anon_sym_true] = ACTIONS(700),
    [anon_sym_false] = ACTIONS(700),
    [anon_sym_null] = ACTIONS(700),
    [anon_sym_PIPE_PIPE] = ACTIONS(651),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(655),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(696),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(700),
    [anon_sym_TILDE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(700),
    [anon_sym_void] = ACTIONS(700),
    [anon_sym_delete] = ACTIONS(700),
    [anon_sym_QMARK] = ACTIONS(682),
    [anon_sym_await] = ACTIONS(700),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(700),
    [anon_sym_async] = ACTIONS(700),
    [anon_sym_QMARK_DOT] = ACTIONS(692),
    [anon_sym_BQUOTE] = ACTIONS(698),
    [anon_sym_DOLLARr] = ACTIONS(700),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(700),
  },
  [STATE(85)] = {
    [sym_comment] = STATE(85),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(702),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(702),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(702),
    [anon_sym_DASH] = ACTIONS(702),
    [anon_sym_PERCENT] = ACTIONS(704),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(704),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(86)] = {
    [sym_comment] = STATE(86),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(655),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(706),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(87)] = {
    [sym_comment] = STATE(87),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(655),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(706),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(88)] = {
    [sym_comment] = STATE(88),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(706),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(89)] = {
    [sym_comment] = STATE(89),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(706),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(90)] = {
    [sym_comment] = STATE(90),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(706),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(91)] = {
    [sym_comment] = STATE(91),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(706),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(92)] = {
    [sym_comment] = STATE(92),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(93)] = {
    [sym_comment] = STATE(93),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(94)] = {
    [sym_comment] = STATE(94),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(702),
    [anon_sym_DASH] = ACTIONS(702),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(95)] = {
    [sym_comment] = STATE(95),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(702),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(702),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [anon_sym_Text] = ACTIONS(702),
    [anon_sym_Button] = ACTIONS(702),
    [anon_sym_Image] = ACTIONS(702),
    [anon_sym_TextInput] = ACTIONS(702),
    [anon_sym_TextArea] = ACTIONS(702),
    [anon_sym_Column] = ACTIONS(702),
    [anon_sym_Row] = ACTIONS(702),
    [anon_sym_Stack] = ACTIONS(702),
    [anon_sym_Flex] = ACTIONS(702),
    [anon_sym_Grid] = ACTIONS(702),
    [anon_sym_GridRow] = ACTIONS(702),
    [anon_sym_GridCol] = ACTIONS(702),
    [anon_sym_List] = ACTIONS(702),
    [anon_sym_ScrollList] = ACTIONS(702),
    [anon_sym_ListItem] = ACTIONS(702),
    [anon_sym_GridItem] = ACTIONS(702),
    [anon_sym_ForEach] = ACTIONS(702),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(702),
    [anon_sym_DASH] = ACTIONS(702),
    [anon_sym_PERCENT] = ACTIONS(704),
    [anon_sym_STAR_STAR] = ACTIONS(704),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(704),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(96)] = {
    [sym_comment] = STATE(96),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(647),
    [anon_sym_SEMI] = ACTIONS(709),
    [anon_sym_LPAREN] = ACTIONS(690),
    [anon_sym_DOT] = ACTIONS(692),
    [anon_sym_Text] = ACTIONS(711),
    [anon_sym_Button] = ACTIONS(711),
    [anon_sym_Image] = ACTIONS(711),
    [anon_sym_TextInput] = ACTIONS(711),
    [anon_sym_TextArea] = ACTIONS(711),
    [anon_sym_Column] = ACTIONS(711),
    [anon_sym_Row] = ACTIONS(711),
    [anon_sym_Stack] = ACTIONS(711),
    [anon_sym_Flex] = ACTIONS(711),
    [anon_sym_Grid] = ACTIONS(711),
    [anon_sym_GridRow] = ACTIONS(711),
    [anon_sym_GridCol] = ACTIONS(711),
    [anon_sym_List] = ACTIONS(711),
    [anon_sym_ScrollList] = ACTIONS(711),
    [anon_sym_ListItem] = ACTIONS(711),
    [anon_sym_GridItem] = ACTIONS(711),
    [anon_sym_ForEach] = ACTIONS(711),
    [sym_identifier] = ACTIONS(711),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [anon_sym_SQUOTE] = ACTIONS(709),
    [anon_sym_DOLLAR] = ACTIONS(711),
    [sym_numeric_literal] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_null] = ACTIONS(711),
    [anon_sym_PIPE_PIPE] = ACTIONS(651),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(655),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(696),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(711),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_typeof] = ACTIONS(711),
    [anon_sym_void] = ACTIONS(711),
    [anon_sym_delete] = ACTIONS(711),
    [anon_sym_QMARK] = ACTIONS(682),
    [anon_sym_await] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(711),
    [anon_sym_async] = ACTIONS(711),
    [anon_sym_QMARK_DOT] = ACTIONS(692),
    [anon_sym_BQUOTE] = ACTIONS(709),
    [anon_sym_DOLLARr] = ACTIONS(711),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(711),
  },
  [STATE(97)] = {
    [sym_comment] = STATE(97),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_RBRACE] = ACTIONS(713),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(647),
    [anon_sym_SEMI] = ACTIONS(713),
    [anon_sym_LPAREN] = ACTIONS(690),
    [anon_sym_DOT] = ACTIONS(692),
    [anon_sym_Text] = ACTIONS(715),
    [anon_sym_Button] = ACTIONS(715),
    [anon_sym_Image] = ACTIONS(715),
    [anon_sym_TextInput] = ACTIONS(715),
    [anon_sym_TextArea] = ACTIONS(715),
    [anon_sym_Column] = ACTIONS(715),
    [anon_sym_Row] = ACTIONS(715),
    [anon_sym_Stack] = ACTIONS(715),
    [anon_sym_Flex] = ACTIONS(715),
    [anon_sym_Grid] = ACTIONS(715),
    [anon_sym_GridRow] = ACTIONS(715),
    [anon_sym_GridCol] = ACTIONS(715),
    [anon_sym_List] = ACTIONS(715),
    [anon_sym_ScrollList] = ACTIONS(715),
    [anon_sym_ListItem] = ACTIONS(715),
    [anon_sym_GridItem] = ACTIONS(715),
    [anon_sym_ForEach] = ACTIONS(715),
    [sym_identifier] = ACTIONS(715),
    [anon_sym_DQUOTE] = ACTIONS(713),
    [anon_sym_SQUOTE] = ACTIONS(713),
    [anon_sym_DOLLAR] = ACTIONS(715),
    [sym_numeric_literal] = ACTIONS(713),
    [anon_sym_true] = ACTIONS(715),
    [anon_sym_false] = ACTIONS(715),
    [anon_sym_null] = ACTIONS(715),
    [anon_sym_PIPE_PIPE] = ACTIONS(651),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(655),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(696),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(715),
    [anon_sym_TILDE] = ACTIONS(713),
    [anon_sym_typeof] = ACTIONS(715),
    [anon_sym_void] = ACTIONS(715),
    [anon_sym_delete] = ACTIONS(715),
    [anon_sym_QMARK] = ACTIONS(682),
    [anon_sym_await] = ACTIONS(715),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(715),
    [anon_sym_async] = ACTIONS(715),
    [anon_sym_QMARK_DOT] = ACTIONS(692),
    [anon_sym_BQUOTE] = ACTIONS(713),
    [anon_sym_DOLLARr] = ACTIONS(715),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(715),
  },
  [STATE(98)] = {
    [sym_comment] = STATE(98),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(717),
    [anon_sym_RBRACE] = ACTIONS(717),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(647),
    [anon_sym_SEMI] = ACTIONS(717),
    [anon_sym_LPAREN] = ACTIONS(690),
    [anon_sym_DOT] = ACTIONS(692),
    [anon_sym_Text] = ACTIONS(719),
    [anon_sym_Button] = ACTIONS(719),
    [anon_sym_Image] = ACTIONS(719),
    [anon_sym_TextInput] = ACTIONS(719),
    [anon_sym_TextArea] = ACTIONS(719),
    [anon_sym_Column] = ACTIONS(719),
    [anon_sym_Row] = ACTIONS(719),
    [anon_sym_Stack] = ACTIONS(719),
    [anon_sym_Flex] = ACTIONS(719),
    [anon_sym_Grid] = ACTIONS(719),
    [anon_sym_GridRow] = ACTIONS(719),
    [anon_sym_GridCol] = ACTIONS(719),
    [anon_sym_List] = ACTIONS(719),
    [anon_sym_ScrollList] = ACTIONS(719),
    [anon_sym_ListItem] = ACTIONS(719),
    [anon_sym_GridItem] = ACTIONS(719),
    [anon_sym_ForEach] = ACTIONS(719),
    [sym_identifier] = ACTIONS(719),
    [anon_sym_DQUOTE] = ACTIONS(717),
    [anon_sym_SQUOTE] = ACTIONS(717),
    [anon_sym_DOLLAR] = ACTIONS(719),
    [sym_numeric_literal] = ACTIONS(717),
    [anon_sym_true] = ACTIONS(719),
    [anon_sym_false] = ACTIONS(719),
    [anon_sym_null] = ACTIONS(719),
    [anon_sym_PIPE_PIPE] = ACTIONS(651),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(655),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(696),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(719),
    [anon_sym_TILDE] = ACTIONS(717),
    [anon_sym_typeof] = ACTIONS(719),
    [anon_sym_void] = ACTIONS(719),
    [anon_sym_delete] = ACTIONS(719),
    [anon_sym_QMARK] = ACTIONS(682),
    [anon_sym_await] = ACTIONS(719),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(719),
    [anon_sym_async] = ACTIONS(719),
    [anon_sym_QMARK_DOT] = ACTIONS(692),
    [anon_sym_BQUOTE] = ACTIONS(717),
    [anon_sym_DOLLARr] = ACTIONS(719),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(719),
  },
  [STATE(99)] = {
    [sym_comment] = STATE(99),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(721),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(647),
    [anon_sym_SEMI] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(690),
    [anon_sym_DOT] = ACTIONS(692),
    [anon_sym_Text] = ACTIONS(723),
    [anon_sym_Button] = ACTIONS(723),
    [anon_sym_Image] = ACTIONS(723),
    [anon_sym_TextInput] = ACTIONS(723),
    [anon_sym_TextArea] = ACTIONS(723),
    [anon_sym_Column] = ACTIONS(723),
    [anon_sym_Row] = ACTIONS(723),
    [anon_sym_Stack] = ACTIONS(723),
    [anon_sym_Flex] = ACTIONS(723),
    [anon_sym_Grid] = ACTIONS(723),
    [anon_sym_GridRow] = ACTIONS(723),
    [anon_sym_GridCol] = ACTIONS(723),
    [anon_sym_List] = ACTIONS(723),
    [anon_sym_ScrollList] = ACTIONS(723),
    [anon_sym_ListItem] = ACTIONS(723),
    [anon_sym_GridItem] = ACTIONS(723),
    [anon_sym_ForEach] = ACTIONS(723),
    [sym_identifier] = ACTIONS(723),
    [anon_sym_DQUOTE] = ACTIONS(721),
    [anon_sym_SQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR] = ACTIONS(723),
    [sym_numeric_literal] = ACTIONS(721),
    [anon_sym_true] = ACTIONS(723),
    [anon_sym_false] = ACTIONS(723),
    [anon_sym_null] = ACTIONS(723),
    [anon_sym_PIPE_PIPE] = ACTIONS(651),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(655),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(696),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(723),
    [anon_sym_TILDE] = ACTIONS(721),
    [anon_sym_typeof] = ACTIONS(723),
    [anon_sym_void] = ACTIONS(723),
    [anon_sym_delete] = ACTIONS(723),
    [anon_sym_QMARK] = ACTIONS(682),
    [anon_sym_await] = ACTIONS(723),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(723),
    [anon_sym_async] = ACTIONS(723),
    [anon_sym_QMARK_DOT] = ACTIONS(692),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLARr] = ACTIONS(723),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(723),
  },
  [STATE(100)] = {
    [sym_comment] = STATE(100),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(643),
    [anon_sym_LBRACE] = ACTIONS(725),
    [anon_sym_RBRACE] = ACTIONS(725),
    [anon_sym_STAR] = ACTIONS(643),
    [anon_sym_as] = ACTIONS(647),
    [anon_sym_SEMI] = ACTIONS(727),
    [anon_sym_LPAREN] = ACTIONS(690),
    [anon_sym_DOT] = ACTIONS(692),
    [anon_sym_Text] = ACTIONS(729),
    [anon_sym_Button] = ACTIONS(729),
    [anon_sym_Image] = ACTIONS(729),
    [anon_sym_TextInput] = ACTIONS(729),
    [anon_sym_TextArea] = ACTIONS(729),
    [anon_sym_Column] = ACTIONS(729),
    [anon_sym_Row] = ACTIONS(729),
    [anon_sym_Stack] = ACTIONS(729),
    [anon_sym_Flex] = ACTIONS(729),
    [anon_sym_Grid] = ACTIONS(729),
    [anon_sym_GridRow] = ACTIONS(729),
    [anon_sym_GridCol] = ACTIONS(729),
    [anon_sym_List] = ACTIONS(729),
    [anon_sym_ScrollList] = ACTIONS(729),
    [anon_sym_ListItem] = ACTIONS(729),
    [anon_sym_GridItem] = ACTIONS(729),
    [anon_sym_ForEach] = ACTIONS(729),
    [sym_identifier] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(725),
    [anon_sym_SQUOTE] = ACTIONS(725),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [sym_numeric_literal] = ACTIONS(725),
    [anon_sym_true] = ACTIONS(729),
    [anon_sym_false] = ACTIONS(729),
    [anon_sym_null] = ACTIONS(729),
    [anon_sym_PIPE_PIPE] = ACTIONS(651),
    [anon_sym_AMP_AMP] = ACTIONS(653),
    [anon_sym_PIPE] = ACTIONS(655),
    [anon_sym_CARET] = ACTIONS(657),
    [anon_sym_AMP] = ACTIONS(659),
    [anon_sym_EQ_EQ] = ACTIONS(661),
    [anon_sym_BANG_EQ] = ACTIONS(661),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(663),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(663),
    [anon_sym_LT] = ACTIONS(696),
    [anon_sym_GT] = ACTIONS(668),
    [anon_sym_LT_EQ] = ACTIONS(670),
    [anon_sym_GT_EQ] = ACTIONS(670),
    [anon_sym_instanceof] = ACTIONS(668),
    [anon_sym_in] = ACTIONS(668),
    [anon_sym_LT_LT] = ACTIONS(672),
    [anon_sym_GT_GT] = ACTIONS(674),
    [anon_sym_GT_GT_GT] = ACTIONS(672),
    [anon_sym_PLUS] = ACTIONS(676),
    [anon_sym_DASH] = ACTIONS(676),
    [anon_sym_PERCENT] = ACTIONS(678),
    [anon_sym_STAR_STAR] = ACTIONS(680),
    [anon_sym_BANG] = ACTIONS(729),
    [anon_sym_TILDE] = ACTIONS(725),
    [anon_sym_typeof] = ACTIONS(729),
    [anon_sym_void] = ACTIONS(729),
    [anon_sym_delete] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(682),
    [anon_sym_await] = ACTIONS(729),
    [anon_sym_LBRACK] = ACTIONS(684),
    [anon_sym_if] = ACTIONS(729),
    [anon_sym_async] = ACTIONS(729),
    [anon_sym_QMARK_DOT] = ACTIONS(692),
    [anon_sym_BQUOTE] = ACTIONS(725),
    [anon_sym_DOLLARr] = ACTIONS(729),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(729),
  },
  [STATE(101)] = {
    [sym_comment] = STATE(101),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(731),
    [anon_sym_LBRACE] = ACTIONS(733),
    [anon_sym_COMMA] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(733),
    [anon_sym_STAR] = ACTIONS(731),
    [anon_sym_as] = ACTIONS(731),
    [anon_sym_SEMI] = ACTIONS(733),
    [anon_sym_LPAREN] = ACTIONS(733),
    [anon_sym_DOT] = ACTIONS(733),
    [anon_sym_Text] = ACTIONS(731),
    [anon_sym_Button] = ACTIONS(731),
    [anon_sym_Image] = ACTIONS(731),
    [anon_sym_TextInput] = ACTIONS(731),
    [anon_sym_TextArea] = ACTIONS(731),
    [anon_sym_Column] = ACTIONS(731),
    [anon_sym_Row] = ACTIONS(731),
    [anon_sym_Stack] = ACTIONS(731),
    [anon_sym_Flex] = ACTIONS(731),
    [anon_sym_Grid] = ACTIONS(731),
    [anon_sym_GridRow] = ACTIONS(731),
    [anon_sym_GridCol] = ACTIONS(731),
    [anon_sym_List] = ACTIONS(731),
    [anon_sym_ScrollList] = ACTIONS(731),
    [anon_sym_ListItem] = ACTIONS(731),
    [anon_sym_GridItem] = ACTIONS(731),
    [anon_sym_ForEach] = ACTIONS(731),
    [sym_identifier] = ACTIONS(731),
    [anon_sym_DQUOTE] = ACTIONS(733),
    [anon_sym_SQUOTE] = ACTIONS(733),
    [anon_sym_DOLLAR] = ACTIONS(731),
    [sym_numeric_literal] = ACTIONS(733),
    [anon_sym_true] = ACTIONS(731),
    [anon_sym_false] = ACTIONS(731),
    [anon_sym_null] = ACTIONS(731),
    [anon_sym_PIPE_PIPE] = ACTIONS(733),
    [anon_sym_AMP_AMP] = ACTIONS(733),
    [anon_sym_PIPE] = ACTIONS(735),
    [anon_sym_CARET] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_EQ_EQ] = ACTIONS(731),
    [anon_sym_BANG_EQ] = ACTIONS(731),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(733),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(733),
    [anon_sym_LT] = ACTIONS(731),
    [anon_sym_GT] = ACTIONS(735),
    [anon_sym_LT_EQ] = ACTIONS(733),
    [anon_sym_GT_EQ] = ACTIONS(733),
    [anon_sym_instanceof] = ACTIONS(731),
    [anon_sym_in] = ACTIONS(731),
    [anon_sym_LT_LT] = ACTIONS(733),
    [anon_sym_GT_GT] = ACTIONS(731),
    [anon_sym_GT_GT_GT] = ACTIONS(733),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(731),
    [anon_sym_PERCENT] = ACTIONS(733),
    [anon_sym_STAR_STAR] = ACTIONS(733),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_TILDE] = ACTIONS(733),
    [anon_sym_typeof] = ACTIONS(731),
    [anon_sym_void] = ACTIONS(731),
    [anon_sym_delete] = ACTIONS(731),
    [anon_sym_QMARK] = ACTIONS(731),
    [anon_sym_await] = ACTIONS(731),
    [anon_sym_LBRACK] = ACTIONS(733),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(731),
    [anon_sym_async] = ACTIONS(731),
    [anon_sym_QMARK_DOT] = ACTIONS(733),
    [anon_sym_BQUOTE] = ACTIONS(733),
    [anon_sym_DOLLARr] = ACTIONS(731),
    [anon_sym_PLUS_PLUS] = ACTIONS(733),
    [anon_sym_DASH_DASH] = ACTIONS(733),
    [anon_sym_new] = ACTIONS(731),
  },
  [STATE(102)] = {
    [sym_comment] = STATE(102),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(738),
    [anon_sym_LBRACE] = ACTIONS(740),
    [anon_sym_COMMA] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(740),
    [anon_sym_STAR] = ACTIONS(738),
    [anon_sym_as] = ACTIONS(738),
    [anon_sym_SEMI] = ACTIONS(740),
    [anon_sym_LPAREN] = ACTIONS(740),
    [anon_sym_DOT] = ACTIONS(740),
    [anon_sym_Text] = ACTIONS(738),
    [anon_sym_Button] = ACTIONS(738),
    [anon_sym_Image] = ACTIONS(738),
    [anon_sym_TextInput] = ACTIONS(738),
    [anon_sym_TextArea] = ACTIONS(738),
    [anon_sym_Column] = ACTIONS(738),
    [anon_sym_Row] = ACTIONS(738),
    [anon_sym_Stack] = ACTIONS(738),
    [anon_sym_Flex] = ACTIONS(738),
    [anon_sym_Grid] = ACTIONS(738),
    [anon_sym_GridRow] = ACTIONS(738),
    [anon_sym_GridCol] = ACTIONS(738),
    [anon_sym_List] = ACTIONS(738),
    [anon_sym_ScrollList] = ACTIONS(738),
    [anon_sym_ListItem] = ACTIONS(738),
    [anon_sym_GridItem] = ACTIONS(738),
    [anon_sym_ForEach] = ACTIONS(738),
    [sym_identifier] = ACTIONS(738),
    [anon_sym_DQUOTE] = ACTIONS(740),
    [anon_sym_SQUOTE] = ACTIONS(740),
    [anon_sym_DOLLAR] = ACTIONS(738),
    [sym_numeric_literal] = ACTIONS(740),
    [anon_sym_true] = ACTIONS(738),
    [anon_sym_false] = ACTIONS(738),
    [anon_sym_null] = ACTIONS(738),
    [anon_sym_PIPE_PIPE] = ACTIONS(740),
    [anon_sym_AMP_AMP] = ACTIONS(740),
    [anon_sym_PIPE] = ACTIONS(742),
    [anon_sym_CARET] = ACTIONS(740),
    [anon_sym_AMP] = ACTIONS(738),
    [anon_sym_EQ_EQ] = ACTIONS(738),
    [anon_sym_BANG_EQ] = ACTIONS(738),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(740),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(738),
    [anon_sym_GT] = ACTIONS(742),
    [anon_sym_LT_EQ] = ACTIONS(740),
    [anon_sym_GT_EQ] = ACTIONS(740),
    [anon_sym_instanceof] = ACTIONS(738),
    [anon_sym_in] = ACTIONS(738),
    [anon_sym_LT_LT] = ACTIONS(740),
    [anon_sym_GT_GT] = ACTIONS(738),
    [anon_sym_GT_GT_GT] = ACTIONS(740),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_PERCENT] = ACTIONS(740),
    [anon_sym_STAR_STAR] = ACTIONS(740),
    [anon_sym_BANG] = ACTIONS(738),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_typeof] = ACTIONS(738),
    [anon_sym_void] = ACTIONS(738),
    [anon_sym_delete] = ACTIONS(738),
    [anon_sym_QMARK] = ACTIONS(738),
    [anon_sym_await] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(738),
    [anon_sym_async] = ACTIONS(738),
    [anon_sym_QMARK_DOT] = ACTIONS(740),
    [anon_sym_BQUOTE] = ACTIONS(740),
    [anon_sym_DOLLARr] = ACTIONS(738),
    [anon_sym_PLUS_PLUS] = ACTIONS(740),
    [anon_sym_DASH_DASH] = ACTIONS(740),
    [anon_sym_new] = ACTIONS(738),
  },
  [STATE(103)] = {
    [sym_comment] = STATE(103),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(745),
    [anon_sym_LBRACE] = ACTIONS(747),
    [anon_sym_COMMA] = ACTIONS(749),
    [anon_sym_RBRACE] = ACTIONS(747),
    [anon_sym_STAR] = ACTIONS(745),
    [anon_sym_as] = ACTIONS(745),
    [anon_sym_SEMI] = ACTIONS(747),
    [anon_sym_LPAREN] = ACTIONS(747),
    [anon_sym_DOT] = ACTIONS(747),
    [anon_sym_Text] = ACTIONS(745),
    [anon_sym_Button] = ACTIONS(745),
    [anon_sym_Image] = ACTIONS(745),
    [anon_sym_TextInput] = ACTIONS(745),
    [anon_sym_TextArea] = ACTIONS(745),
    [anon_sym_Column] = ACTIONS(745),
    [anon_sym_Row] = ACTIONS(745),
    [anon_sym_Stack] = ACTIONS(745),
    [anon_sym_Flex] = ACTIONS(745),
    [anon_sym_Grid] = ACTIONS(745),
    [anon_sym_GridRow] = ACTIONS(745),
    [anon_sym_GridCol] = ACTIONS(745),
    [anon_sym_List] = ACTIONS(745),
    [anon_sym_ScrollList] = ACTIONS(745),
    [anon_sym_ListItem] = ACTIONS(745),
    [anon_sym_GridItem] = ACTIONS(745),
    [anon_sym_ForEach] = ACTIONS(745),
    [sym_identifier] = ACTIONS(745),
    [anon_sym_DQUOTE] = ACTIONS(747),
    [anon_sym_SQUOTE] = ACTIONS(747),
    [anon_sym_DOLLAR] = ACTIONS(745),
    [sym_numeric_literal] = ACTIONS(747),
    [anon_sym_true] = ACTIONS(745),
    [anon_sym_false] = ACTIONS(745),
    [anon_sym_null] = ACTIONS(745),
    [anon_sym_PIPE_PIPE] = ACTIONS(747),
    [anon_sym_AMP_AMP] = ACTIONS(747),
    [anon_sym_PIPE] = ACTIONS(751),
    [anon_sym_CARET] = ACTIONS(747),
    [anon_sym_AMP] = ACTIONS(745),
    [anon_sym_EQ_EQ] = ACTIONS(745),
    [anon_sym_BANG_EQ] = ACTIONS(745),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(747),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(747),
    [anon_sym_LT] = ACTIONS(745),
    [anon_sym_GT] = ACTIONS(751),
    [anon_sym_LT_EQ] = ACTIONS(747),
    [anon_sym_GT_EQ] = ACTIONS(747),
    [anon_sym_instanceof] = ACTIONS(745),
    [anon_sym_in] = ACTIONS(745),
    [anon_sym_LT_LT] = ACTIONS(747),
    [anon_sym_GT_GT] = ACTIONS(745),
    [anon_sym_GT_GT_GT] = ACTIONS(747),
    [anon_sym_PLUS] = ACTIONS(745),
    [anon_sym_DASH] = ACTIONS(745),
    [anon_sym_PERCENT] = ACTIONS(747),
    [anon_sym_STAR_STAR] = ACTIONS(747),
    [anon_sym_BANG] = ACTIONS(745),
    [anon_sym_TILDE] = ACTIONS(747),
    [anon_sym_typeof] = ACTIONS(745),
    [anon_sym_void] = ACTIONS(745),
    [anon_sym_delete] = ACTIONS(745),
    [anon_sym_QMARK] = ACTIONS(745),
    [anon_sym_await] = ACTIONS(745),
    [anon_sym_LBRACK] = ACTIONS(747),
    [anon_sym_extends] = ACTIONS(754),
    [anon_sym_if] = ACTIONS(745),
    [anon_sym_async] = ACTIONS(745),
    [anon_sym_QMARK_DOT] = ACTIONS(747),
    [anon_sym_BQUOTE] = ACTIONS(747),
    [anon_sym_DOLLARr] = ACTIONS(745),
    [anon_sym_PLUS_PLUS] = ACTIONS(747),
    [anon_sym_DASH_DASH] = ACTIONS(747),
    [anon_sym_new] = ACTIONS(745),
  },
  [STATE(104)] = {
    [sym_comment] = STATE(104),
    [aux_sym_array_type_repeat1] = STATE(104),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [anon_sym_Text] = ACTIONS(756),
    [anon_sym_Button] = ACTIONS(756),
    [anon_sym_Image] = ACTIONS(756),
    [anon_sym_TextInput] = ACTIONS(756),
    [anon_sym_TextArea] = ACTIONS(756),
    [anon_sym_Column] = ACTIONS(756),
    [anon_sym_Row] = ACTIONS(756),
    [anon_sym_Stack] = ACTIONS(756),
    [anon_sym_Flex] = ACTIONS(756),
    [anon_sym_Grid] = ACTIONS(756),
    [anon_sym_GridRow] = ACTIONS(756),
    [anon_sym_GridCol] = ACTIONS(756),
    [anon_sym_List] = ACTIONS(756),
    [anon_sym_ScrollList] = ACTIONS(756),
    [anon_sym_ListItem] = ACTIONS(756),
    [anon_sym_GridItem] = ACTIONS(756),
    [anon_sym_ForEach] = ACTIONS(756),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(760),
    [anon_sym_extends] = ACTIONS(756),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(105)] = {
    [sym_comment] = STATE(105),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_RBRACE] = ACTIONS(765),
    [anon_sym_STAR] = ACTIONS(763),
    [anon_sym_as] = ACTIONS(763),
    [anon_sym_SEMI] = ACTIONS(765),
    [anon_sym_LPAREN] = ACTIONS(765),
    [anon_sym_DOT] = ACTIONS(765),
    [anon_sym_Text] = ACTIONS(763),
    [anon_sym_Button] = ACTIONS(763),
    [anon_sym_Image] = ACTIONS(763),
    [anon_sym_TextInput] = ACTIONS(763),
    [anon_sym_TextArea] = ACTIONS(763),
    [anon_sym_Column] = ACTIONS(763),
    [anon_sym_Row] = ACTIONS(763),
    [anon_sym_Stack] = ACTIONS(763),
    [anon_sym_Flex] = ACTIONS(763),
    [anon_sym_Grid] = ACTIONS(763),
    [anon_sym_GridRow] = ACTIONS(763),
    [anon_sym_GridCol] = ACTIONS(763),
    [anon_sym_List] = ACTIONS(763),
    [anon_sym_ScrollList] = ACTIONS(763),
    [anon_sym_ListItem] = ACTIONS(763),
    [anon_sym_GridItem] = ACTIONS(763),
    [anon_sym_ForEach] = ACTIONS(763),
    [sym_identifier] = ACTIONS(763),
    [anon_sym_DQUOTE] = ACTIONS(765),
    [anon_sym_SQUOTE] = ACTIONS(765),
    [anon_sym_DOLLAR] = ACTIONS(763),
    [sym_numeric_literal] = ACTIONS(765),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_null] = ACTIONS(763),
    [anon_sym_PIPE_PIPE] = ACTIONS(765),
    [anon_sym_AMP_AMP] = ACTIONS(765),
    [anon_sym_PIPE] = ACTIONS(763),
    [anon_sym_CARET] = ACTIONS(765),
    [anon_sym_AMP] = ACTIONS(763),
    [anon_sym_EQ_EQ] = ACTIONS(763),
    [anon_sym_BANG_EQ] = ACTIONS(763),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(765),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(765),
    [anon_sym_LT] = ACTIONS(763),
    [anon_sym_GT] = ACTIONS(763),
    [anon_sym_LT_EQ] = ACTIONS(765),
    [anon_sym_GT_EQ] = ACTIONS(765),
    [anon_sym_instanceof] = ACTIONS(763),
    [anon_sym_in] = ACTIONS(763),
    [anon_sym_LT_LT] = ACTIONS(765),
    [anon_sym_GT_GT] = ACTIONS(763),
    [anon_sym_GT_GT_GT] = ACTIONS(765),
    [anon_sym_PLUS] = ACTIONS(763),
    [anon_sym_DASH] = ACTIONS(763),
    [anon_sym_PERCENT] = ACTIONS(765),
    [anon_sym_STAR_STAR] = ACTIONS(765),
    [anon_sym_BANG] = ACTIONS(763),
    [anon_sym_TILDE] = ACTIONS(765),
    [anon_sym_typeof] = ACTIONS(763),
    [anon_sym_void] = ACTIONS(763),
    [anon_sym_delete] = ACTIONS(763),
    [anon_sym_QMARK] = ACTIONS(763),
    [anon_sym_await] = ACTIONS(763),
    [anon_sym_LBRACK] = ACTIONS(765),
    [anon_sym_if] = ACTIONS(763),
    [anon_sym_async] = ACTIONS(763),
    [anon_sym_QMARK_DOT] = ACTIONS(765),
    [anon_sym_BQUOTE] = ACTIONS(765),
    [anon_sym_DOLLARr] = ACTIONS(763),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(763),
  },
  [STATE(106)] = {
    [sym_comment] = STATE(106),
    [aux_sym_array_type_repeat1] = STATE(109),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [anon_sym_Text] = ACTIONS(61),
    [anon_sym_Button] = ACTIONS(61),
    [anon_sym_Image] = ACTIONS(61),
    [anon_sym_TextInput] = ACTIONS(61),
    [anon_sym_TextArea] = ACTIONS(61),
    [anon_sym_Column] = ACTIONS(61),
    [anon_sym_Row] = ACTIONS(61),
    [anon_sym_Stack] = ACTIONS(61),
    [anon_sym_Flex] = ACTIONS(61),
    [anon_sym_Grid] = ACTIONS(61),
    [anon_sym_GridRow] = ACTIONS(61),
    [anon_sym_GridCol] = ACTIONS(61),
    [anon_sym_List] = ACTIONS(61),
    [anon_sym_ScrollList] = ACTIONS(61),
    [anon_sym_ListItem] = ACTIONS(61),
    [anon_sym_GridItem] = ACTIONS(61),
    [anon_sym_ForEach] = ACTIONS(61),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(631),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(107)] = {
    [sym_comment] = STATE(107),
    [sym_type_arguments] = STATE(123),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [anon_sym_Text] = ACTIONS(61),
    [anon_sym_Button] = ACTIONS(61),
    [anon_sym_Image] = ACTIONS(61),
    [anon_sym_TextInput] = ACTIONS(61),
    [anon_sym_TextArea] = ACTIONS(61),
    [anon_sym_Column] = ACTIONS(61),
    [anon_sym_Row] = ACTIONS(61),
    [anon_sym_Stack] = ACTIONS(61),
    [anon_sym_Flex] = ACTIONS(61),
    [anon_sym_Grid] = ACTIONS(61),
    [anon_sym_GridRow] = ACTIONS(61),
    [anon_sym_GridCol] = ACTIONS(61),
    [anon_sym_List] = ACTIONS(61),
    [anon_sym_ScrollList] = ACTIONS(61),
    [anon_sym_ListItem] = ACTIONS(61),
    [anon_sym_GridItem] = ACTIONS(61),
    [anon_sym_ForEach] = ACTIONS(61),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(628),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(108)] = {
    [sym_comment] = STATE(108),
    [aux_sym_qualified_type_repeat1] = STATE(110),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(767),
    [anon_sym_LBRACE] = ACTIONS(769),
    [anon_sym_RBRACE] = ACTIONS(769),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_as] = ACTIONS(767),
    [anon_sym_SEMI] = ACTIONS(769),
    [anon_sym_LPAREN] = ACTIONS(769),
    [anon_sym_DOT] = ACTIONS(769),
    [anon_sym_Text] = ACTIONS(767),
    [anon_sym_Button] = ACTIONS(767),
    [anon_sym_Image] = ACTIONS(767),
    [anon_sym_TextInput] = ACTIONS(767),
    [anon_sym_TextArea] = ACTIONS(767),
    [anon_sym_Column] = ACTIONS(767),
    [anon_sym_Row] = ACTIONS(767),
    [anon_sym_Stack] = ACTIONS(767),
    [anon_sym_Flex] = ACTIONS(767),
    [anon_sym_Grid] = ACTIONS(767),
    [anon_sym_GridRow] = ACTIONS(767),
    [anon_sym_GridCol] = ACTIONS(767),
    [anon_sym_List] = ACTIONS(767),
    [anon_sym_ScrollList] = ACTIONS(767),
    [anon_sym_ListItem] = ACTIONS(767),
    [anon_sym_GridItem] = ACTIONS(767),
    [anon_sym_ForEach] = ACTIONS(767),
    [sym_identifier] = ACTIONS(767),
    [anon_sym_DQUOTE] = ACTIONS(769),
    [anon_sym_SQUOTE] = ACTIONS(769),
    [anon_sym_DOLLAR] = ACTIONS(767),
    [sym_numeric_literal] = ACTIONS(769),
    [anon_sym_true] = ACTIONS(767),
    [anon_sym_false] = ACTIONS(767),
    [anon_sym_null] = ACTIONS(767),
    [anon_sym_PIPE_PIPE] = ACTIONS(769),
    [anon_sym_AMP_AMP] = ACTIONS(769),
    [anon_sym_PIPE] = ACTIONS(767),
    [anon_sym_CARET] = ACTIONS(769),
    [anon_sym_AMP] = ACTIONS(767),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(769),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(769),
    [anon_sym_LT] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(769),
    [anon_sym_GT_EQ] = ACTIONS(769),
    [anon_sym_instanceof] = ACTIONS(767),
    [anon_sym_in] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(769),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_GT_GT_GT] = ACTIONS(769),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(767),
    [anon_sym_PERCENT] = ACTIONS(769),
    [anon_sym_STAR_STAR] = ACTIONS(769),
    [anon_sym_BANG] = ACTIONS(767),
    [anon_sym_TILDE] = ACTIONS(769),
    [anon_sym_typeof] = ACTIONS(767),
    [anon_sym_void] = ACTIONS(767),
    [anon_sym_delete] = ACTIONS(767),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_await] = ACTIONS(767),
    [anon_sym_LBRACK] = ACTIONS(769),
    [anon_sym_extends] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(767),
    [anon_sym_async] = ACTIONS(767),
    [anon_sym_QMARK_DOT] = ACTIONS(769),
    [anon_sym_BQUOTE] = ACTIONS(769),
    [anon_sym_DOLLARr] = ACTIONS(767),
    [anon_sym_PLUS_PLUS] = ACTIONS(769),
    [anon_sym_DASH_DASH] = ACTIONS(769),
    [anon_sym_new] = ACTIONS(767),
  },
  [STATE(109)] = {
    [sym_comment] = STATE(109),
    [aux_sym_array_type_repeat1] = STATE(104),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(771),
    [anon_sym_LBRACE] = ACTIONS(773),
    [anon_sym_RBRACE] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(771),
    [anon_sym_as] = ACTIONS(771),
    [anon_sym_SEMI] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(773),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_Text] = ACTIONS(771),
    [anon_sym_Button] = ACTIONS(771),
    [anon_sym_Image] = ACTIONS(771),
    [anon_sym_TextInput] = ACTIONS(771),
    [anon_sym_TextArea] = ACTIONS(771),
    [anon_sym_Column] = ACTIONS(771),
    [anon_sym_Row] = ACTIONS(771),
    [anon_sym_Stack] = ACTIONS(771),
    [anon_sym_Flex] = ACTIONS(771),
    [anon_sym_Grid] = ACTIONS(771),
    [anon_sym_GridRow] = ACTIONS(771),
    [anon_sym_GridCol] = ACTIONS(771),
    [anon_sym_List] = ACTIONS(771),
    [anon_sym_ScrollList] = ACTIONS(771),
    [anon_sym_ListItem] = ACTIONS(771),
    [anon_sym_GridItem] = ACTIONS(771),
    [anon_sym_ForEach] = ACTIONS(771),
    [sym_identifier] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(773),
    [anon_sym_SQUOTE] = ACTIONS(773),
    [anon_sym_DOLLAR] = ACTIONS(771),
    [sym_numeric_literal] = ACTIONS(773),
    [anon_sym_true] = ACTIONS(771),
    [anon_sym_false] = ACTIONS(771),
    [anon_sym_null] = ACTIONS(771),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(771),
    [anon_sym_CARET] = ACTIONS(773),
    [anon_sym_AMP] = ACTIONS(771),
    [anon_sym_EQ_EQ] = ACTIONS(771),
    [anon_sym_BANG_EQ] = ACTIONS(771),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(773),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(773),
    [anon_sym_LT] = ACTIONS(771),
    [anon_sym_GT] = ACTIONS(771),
    [anon_sym_LT_EQ] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(773),
    [anon_sym_instanceof] = ACTIONS(771),
    [anon_sym_in] = ACTIONS(771),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(771),
    [anon_sym_GT_GT_GT] = ACTIONS(773),
    [anon_sym_PLUS] = ACTIONS(771),
    [anon_sym_DASH] = ACTIONS(771),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_STAR_STAR] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(771),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_typeof] = ACTIONS(771),
    [anon_sym_void] = ACTIONS(771),
    [anon_sym_delete] = ACTIONS(771),
    [anon_sym_QMARK] = ACTIONS(771),
    [anon_sym_await] = ACTIONS(771),
    [anon_sym_LBRACK] = ACTIONS(775),
    [anon_sym_extends] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_async] = ACTIONS(771),
    [anon_sym_QMARK_DOT] = ACTIONS(773),
    [anon_sym_BQUOTE] = ACTIONS(773),
    [anon_sym_DOLLARr] = ACTIONS(771),
    [anon_sym_PLUS_PLUS] = ACTIONS(773),
    [anon_sym_DASH_DASH] = ACTIONS(773),
    [anon_sym_new] = ACTIONS(771),
  },
  [STATE(110)] = {
    [sym_comment] = STATE(110),
    [aux_sym_qualified_type_repeat1] = STATE(110),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(782),
    [anon_sym_Text] = ACTIONS(778),
    [anon_sym_Button] = ACTIONS(778),
    [anon_sym_Image] = ACTIONS(778),
    [anon_sym_TextInput] = ACTIONS(778),
    [anon_sym_TextArea] = ACTIONS(778),
    [anon_sym_Column] = ACTIONS(778),
    [anon_sym_Row] = ACTIONS(778),
    [anon_sym_Stack] = ACTIONS(778),
    [anon_sym_Flex] = ACTIONS(778),
    [anon_sym_Grid] = ACTIONS(778),
    [anon_sym_GridRow] = ACTIONS(778),
    [anon_sym_GridCol] = ACTIONS(778),
    [anon_sym_List] = ACTIONS(778),
    [anon_sym_ScrollList] = ACTIONS(778),
    [anon_sym_ListItem] = ACTIONS(778),
    [anon_sym_GridItem] = ACTIONS(778),
    [anon_sym_ForEach] = ACTIONS(778),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_extends] = ACTIONS(778),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(111)] = {
    [sym_comment] = STATE(111),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(785),
    [anon_sym_LBRACE] = ACTIONS(787),
    [anon_sym_RBRACE] = ACTIONS(787),
    [anon_sym_STAR] = ACTIONS(785),
    [anon_sym_as] = ACTIONS(785),
    [anon_sym_SEMI] = ACTIONS(787),
    [anon_sym_LPAREN] = ACTIONS(787),
    [anon_sym_DOT] = ACTIONS(787),
    [anon_sym_Text] = ACTIONS(785),
    [anon_sym_Button] = ACTIONS(785),
    [anon_sym_Image] = ACTIONS(785),
    [anon_sym_TextInput] = ACTIONS(785),
    [anon_sym_TextArea] = ACTIONS(785),
    [anon_sym_Column] = ACTIONS(785),
    [anon_sym_Row] = ACTIONS(785),
    [anon_sym_Stack] = ACTIONS(785),
    [anon_sym_Flex] = ACTIONS(785),
    [anon_sym_Grid] = ACTIONS(785),
    [anon_sym_GridRow] = ACTIONS(785),
    [anon_sym_GridCol] = ACTIONS(785),
    [anon_sym_List] = ACTIONS(785),
    [anon_sym_ScrollList] = ACTIONS(785),
    [anon_sym_ListItem] = ACTIONS(785),
    [anon_sym_GridItem] = ACTIONS(785),
    [anon_sym_ForEach] = ACTIONS(785),
    [sym_identifier] = ACTIONS(785),
    [anon_sym_DQUOTE] = ACTIONS(787),
    [anon_sym_SQUOTE] = ACTIONS(787),
    [anon_sym_DOLLAR] = ACTIONS(785),
    [sym_numeric_literal] = ACTIONS(787),
    [anon_sym_true] = ACTIONS(785),
    [anon_sym_false] = ACTIONS(785),
    [anon_sym_null] = ACTIONS(785),
    [anon_sym_PIPE_PIPE] = ACTIONS(787),
    [anon_sym_AMP_AMP] = ACTIONS(787),
    [anon_sym_PIPE] = ACTIONS(785),
    [anon_sym_CARET] = ACTIONS(787),
    [anon_sym_AMP] = ACTIONS(785),
    [anon_sym_EQ_EQ] = ACTIONS(785),
    [anon_sym_BANG_EQ] = ACTIONS(785),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(787),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(787),
    [anon_sym_LT] = ACTIONS(785),
    [anon_sym_GT] = ACTIONS(785),
    [anon_sym_LT_EQ] = ACTIONS(787),
    [anon_sym_GT_EQ] = ACTIONS(787),
    [anon_sym_instanceof] = ACTIONS(785),
    [anon_sym_in] = ACTIONS(785),
    [anon_sym_LT_LT] = ACTIONS(787),
    [anon_sym_GT_GT] = ACTIONS(785),
    [anon_sym_GT_GT_GT] = ACTIONS(787),
    [anon_sym_PLUS] = ACTIONS(785),
    [anon_sym_DASH] = ACTIONS(785),
    [anon_sym_PERCENT] = ACTIONS(787),
    [anon_sym_STAR_STAR] = ACTIONS(787),
    [anon_sym_BANG] = ACTIONS(785),
    [anon_sym_TILDE] = ACTIONS(787),
    [anon_sym_typeof] = ACTIONS(785),
    [anon_sym_void] = ACTIONS(785),
    [anon_sym_delete] = ACTIONS(785),
    [anon_sym_QMARK] = ACTIONS(785),
    [anon_sym_await] = ACTIONS(785),
    [anon_sym_LBRACK] = ACTIONS(787),
    [anon_sym_if] = ACTIONS(785),
    [anon_sym_async] = ACTIONS(785),
    [anon_sym_QMARK_DOT] = ACTIONS(787),
    [anon_sym_BQUOTE] = ACTIONS(787),
    [anon_sym_DOLLARr] = ACTIONS(785),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(785),
  },
  [STATE(112)] = {
    [sym_comment] = STATE(112),
    [sym_type_arguments] = STATE(1930),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(789),
    [anon_sym_LBRACE] = ACTIONS(791),
    [anon_sym_RBRACE] = ACTIONS(791),
    [anon_sym_STAR] = ACTIONS(789),
    [anon_sym_as] = ACTIONS(789),
    [anon_sym_SEMI] = ACTIONS(791),
    [anon_sym_LPAREN] = ACTIONS(791),
    [anon_sym_DOT] = ACTIONS(791),
    [anon_sym_Text] = ACTIONS(789),
    [anon_sym_Button] = ACTIONS(789),
    [anon_sym_Image] = ACTIONS(789),
    [anon_sym_TextInput] = ACTIONS(789),
    [anon_sym_TextArea] = ACTIONS(789),
    [anon_sym_Column] = ACTIONS(789),
    [anon_sym_Row] = ACTIONS(789),
    [anon_sym_Stack] = ACTIONS(789),
    [anon_sym_Flex] = ACTIONS(789),
    [anon_sym_Grid] = ACTIONS(789),
    [anon_sym_GridRow] = ACTIONS(789),
    [anon_sym_GridCol] = ACTIONS(789),
    [anon_sym_List] = ACTIONS(789),
    [anon_sym_ScrollList] = ACTIONS(789),
    [anon_sym_ListItem] = ACTIONS(789),
    [anon_sym_GridItem] = ACTIONS(789),
    [anon_sym_ForEach] = ACTIONS(789),
    [sym_identifier] = ACTIONS(789),
    [anon_sym_DQUOTE] = ACTIONS(791),
    [anon_sym_SQUOTE] = ACTIONS(791),
    [anon_sym_DOLLAR] = ACTIONS(789),
    [sym_numeric_literal] = ACTIONS(791),
    [anon_sym_true] = ACTIONS(789),
    [anon_sym_false] = ACTIONS(789),
    [anon_sym_null] = ACTIONS(789),
    [anon_sym_PIPE_PIPE] = ACTIONS(791),
    [anon_sym_AMP_AMP] = ACTIONS(791),
    [anon_sym_PIPE] = ACTIONS(789),
    [anon_sym_CARET] = ACTIONS(791),
    [anon_sym_AMP] = ACTIONS(789),
    [anon_sym_EQ_EQ] = ACTIONS(789),
    [anon_sym_BANG_EQ] = ACTIONS(789),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(791),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(791),
    [anon_sym_LT] = ACTIONS(789),
    [anon_sym_GT] = ACTIONS(789),
    [anon_sym_LT_EQ] = ACTIONS(791),
    [anon_sym_GT_EQ] = ACTIONS(791),
    [anon_sym_instanceof] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(789),
    [anon_sym_LT_LT] = ACTIONS(791),
    [anon_sym_GT_GT] = ACTIONS(789),
    [anon_sym_GT_GT_GT] = ACTIONS(791),
    [anon_sym_PLUS] = ACTIONS(789),
    [anon_sym_DASH] = ACTIONS(789),
    [anon_sym_PERCENT] = ACTIONS(791),
    [anon_sym_STAR_STAR] = ACTIONS(791),
    [anon_sym_BANG] = ACTIONS(789),
    [anon_sym_TILDE] = ACTIONS(791),
    [anon_sym_typeof] = ACTIONS(789),
    [anon_sym_void] = ACTIONS(789),
    [anon_sym_delete] = ACTIONS(789),
    [anon_sym_QMARK] = ACTIONS(789),
    [anon_sym_await] = ACTIONS(789),
    [anon_sym_LBRACK] = ACTIONS(791),
    [anon_sym_if] = ACTIONS(789),
    [anon_sym_async] = ACTIONS(789),
    [anon_sym_QMARK_DOT] = ACTIONS(791),
    [anon_sym_BQUOTE] = ACTIONS(791),
    [anon_sym_DOLLARr] = ACTIONS(789),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(789),
  },
  [STATE(113)] = {
    [sym_comment] = STATE(113),
    [sym_type_arguments] = STATE(122),
    [sym_argument_list] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(793),
    [anon_sym_LBRACE] = ACTIONS(795),
    [anon_sym_RBRACE] = ACTIONS(795),
    [anon_sym_STAR] = ACTIONS(793),
    [anon_sym_as] = ACTIONS(793),
    [anon_sym_SEMI] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(795),
    [anon_sym_DOT] = ACTIONS(795),
    [anon_sym_Text] = ACTIONS(793),
    [anon_sym_Button] = ACTIONS(793),
    [anon_sym_Image] = ACTIONS(793),
    [anon_sym_TextInput] = ACTIONS(793),
    [anon_sym_TextArea] = ACTIONS(793),
    [anon_sym_Column] = ACTIONS(793),
    [anon_sym_Row] = ACTIONS(793),
    [anon_sym_Stack] = ACTIONS(793),
    [anon_sym_Flex] = ACTIONS(793),
    [anon_sym_Grid] = ACTIONS(793),
    [anon_sym_GridRow] = ACTIONS(793),
    [anon_sym_GridCol] = ACTIONS(793),
    [anon_sym_List] = ACTIONS(793),
    [anon_sym_ScrollList] = ACTIONS(793),
    [anon_sym_ListItem] = ACTIONS(793),
    [anon_sym_GridItem] = ACTIONS(793),
    [anon_sym_ForEach] = ACTIONS(793),
    [sym_identifier] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DOLLAR] = ACTIONS(793),
    [sym_numeric_literal] = ACTIONS(795),
    [anon_sym_true] = ACTIONS(793),
    [anon_sym_false] = ACTIONS(793),
    [anon_sym_null] = ACTIONS(793),
    [anon_sym_PIPE_PIPE] = ACTIONS(795),
    [anon_sym_AMP_AMP] = ACTIONS(795),
    [anon_sym_PIPE] = ACTIONS(793),
    [anon_sym_CARET] = ACTIONS(795),
    [anon_sym_AMP] = ACTIONS(793),
    [anon_sym_EQ_EQ] = ACTIONS(793),
    [anon_sym_BANG_EQ] = ACTIONS(793),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(795),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(795),
    [anon_sym_LT] = ACTIONS(793),
    [anon_sym_GT] = ACTIONS(793),
    [anon_sym_LT_EQ] = ACTIONS(795),
    [anon_sym_GT_EQ] = ACTIONS(795),
    [anon_sym_instanceof] = ACTIONS(793),
    [anon_sym_in] = ACTIONS(793),
    [anon_sym_LT_LT] = ACTIONS(795),
    [anon_sym_GT_GT] = ACTIONS(793),
    [anon_sym_GT_GT_GT] = ACTIONS(795),
    [anon_sym_PLUS] = ACTIONS(793),
    [anon_sym_DASH] = ACTIONS(793),
    [anon_sym_PERCENT] = ACTIONS(795),
    [anon_sym_STAR_STAR] = ACTIONS(795),
    [anon_sym_BANG] = ACTIONS(793),
    [anon_sym_TILDE] = ACTIONS(795),
    [anon_sym_typeof] = ACTIONS(793),
    [anon_sym_void] = ACTIONS(793),
    [anon_sym_delete] = ACTIONS(793),
    [anon_sym_QMARK] = ACTIONS(793),
    [anon_sym_await] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(795),
    [anon_sym_if] = ACTIONS(793),
    [anon_sym_async] = ACTIONS(793),
    [anon_sym_QMARK_DOT] = ACTIONS(795),
    [anon_sym_BQUOTE] = ACTIONS(795),
    [anon_sym_DOLLARr] = ACTIONS(793),
    [anon_sym_PLUS_PLUS] = ACTIONS(686),
    [anon_sym_DASH_DASH] = ACTIONS(686),
    [anon_sym_new] = ACTIONS(793),
  },
  [STATE(114)] = {
    [sym_comment] = STATE(114),
    [aux_sym_union_type_repeat1] = STATE(117),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(797),
    [anon_sym_LBRACE] = ACTIONS(799),
    [anon_sym_RBRACE] = ACTIONS(799),
    [anon_sym_STAR] = ACTIONS(797),
    [anon_sym_as] = ACTIONS(797),
    [anon_sym_SEMI] = ACTIONS(799),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_DOT] = ACTIONS(799),
    [anon_sym_Text] = ACTIONS(797),
    [anon_sym_Button] = ACTIONS(797),
    [anon_sym_Image] = ACTIONS(797),
    [anon_sym_TextInput] = ACTIONS(797),
    [anon_sym_TextArea] = ACTIONS(797),
    [anon_sym_Column] = ACTIONS(797),
    [anon_sym_Row] = ACTIONS(797),
    [anon_sym_Stack] = ACTIONS(797),
    [anon_sym_Flex] = ACTIONS(797),
    [anon_sym_Grid] = ACTIONS(797),
    [anon_sym_GridRow] = ACTIONS(797),
    [anon_sym_GridCol] = ACTIONS(797),
    [anon_sym_List] = ACTIONS(797),
    [anon_sym_ScrollList] = ACTIONS(797),
    [anon_sym_ListItem] = ACTIONS(797),
    [anon_sym_GridItem] = ACTIONS(797),
    [anon_sym_ForEach] = ACTIONS(797),
    [sym_identifier] = ACTIONS(797),
    [anon_sym_DQUOTE] = ACTIONS(799),
    [anon_sym_SQUOTE] = ACTIONS(799),
    [anon_sym_DOLLAR] = ACTIONS(797),
    [sym_numeric_literal] = ACTIONS(799),
    [anon_sym_true] = ACTIONS(797),
    [anon_sym_false] = ACTIONS(797),
    [anon_sym_null] = ACTIONS(797),
    [anon_sym_PIPE_PIPE] = ACTIONS(799),
    [anon_sym_AMP_AMP] = ACTIONS(799),
    [anon_sym_PIPE] = ACTIONS(801),
    [anon_sym_CARET] = ACTIONS(799),
    [anon_sym_AMP] = ACTIONS(797),
    [anon_sym_EQ_EQ] = ACTIONS(797),
    [anon_sym_BANG_EQ] = ACTIONS(797),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(799),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(799),
    [anon_sym_LT] = ACTIONS(797),
    [anon_sym_GT] = ACTIONS(797),
    [anon_sym_LT_EQ] = ACTIONS(799),
    [anon_sym_GT_EQ] = ACTIONS(799),
    [anon_sym_instanceof] = ACTIONS(797),
    [anon_sym_in] = ACTIONS(797),
    [anon_sym_LT_LT] = ACTIONS(799),
    [anon_sym_GT_GT] = ACTIONS(797),
    [anon_sym_GT_GT_GT] = ACTIONS(799),
    [anon_sym_PLUS] = ACTIONS(797),
    [anon_sym_DASH] = ACTIONS(797),
    [anon_sym_PERCENT] = ACTIONS(799),
    [anon_sym_STAR_STAR] = ACTIONS(799),
    [anon_sym_BANG] = ACTIONS(797),
    [anon_sym_TILDE] = ACTIONS(799),
    [anon_sym_typeof] = ACTIONS(797),
    [anon_sym_void] = ACTIONS(797),
    [anon_sym_delete] = ACTIONS(797),
    [anon_sym_QMARK] = ACTIONS(797),
    [anon_sym_await] = ACTIONS(797),
    [anon_sym_LBRACK] = ACTIONS(799),
    [anon_sym_extends] = ACTIONS(803),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_async] = ACTIONS(797),
    [anon_sym_QMARK_DOT] = ACTIONS(799),
    [anon_sym_BQUOTE] = ACTIONS(799),
    [anon_sym_DOLLARr] = ACTIONS(797),
    [anon_sym_PLUS_PLUS] = ACTIONS(799),
    [anon_sym_DASH_DASH] = ACTIONS(799),
    [anon_sym_new] = ACTIONS(797),
  },
  [STATE(115)] = {
    [sym_comment] = STATE(115),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(805),
    [anon_sym_LBRACE] = ACTIONS(807),
    [anon_sym_RBRACE] = ACTIONS(807),
    [anon_sym_STAR] = ACTIONS(805),
    [anon_sym_as] = ACTIONS(805),
    [anon_sym_SEMI] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(807),
    [anon_sym_DOT] = ACTIONS(807),
    [anon_sym_Text] = ACTIONS(805),
    [anon_sym_Button] = ACTIONS(805),
    [anon_sym_Image] = ACTIONS(805),
    [anon_sym_TextInput] = ACTIONS(805),
    [anon_sym_TextArea] = ACTIONS(805),
    [anon_sym_Column] = ACTIONS(805),
    [anon_sym_Row] = ACTIONS(805),
    [anon_sym_Stack] = ACTIONS(805),
    [anon_sym_Flex] = ACTIONS(805),
    [anon_sym_Grid] = ACTIONS(805),
    [anon_sym_GridRow] = ACTIONS(805),
    [anon_sym_GridCol] = ACTIONS(805),
    [anon_sym_List] = ACTIONS(805),
    [anon_sym_ScrollList] = ACTIONS(805),
    [anon_sym_ListItem] = ACTIONS(805),
    [anon_sym_GridItem] = ACTIONS(805),
    [anon_sym_ForEach] = ACTIONS(805),
    [sym_identifier] = ACTIONS(805),
    [anon_sym_DQUOTE] = ACTIONS(807),
    [anon_sym_SQUOTE] = ACTIONS(807),
    [anon_sym_DOLLAR] = ACTIONS(805),
    [sym_numeric_literal] = ACTIONS(807),
    [anon_sym_true] = ACTIONS(805),
    [anon_sym_false] = ACTIONS(805),
    [anon_sym_null] = ACTIONS(805),
    [anon_sym_PIPE_PIPE] = ACTIONS(807),
    [anon_sym_AMP_AMP] = ACTIONS(807),
    [anon_sym_PIPE] = ACTIONS(805),
    [anon_sym_CARET] = ACTIONS(807),
    [anon_sym_AMP] = ACTIONS(805),
    [anon_sym_EQ_EQ] = ACTIONS(805),
    [anon_sym_BANG_EQ] = ACTIONS(805),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(807),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(807),
    [anon_sym_LT] = ACTIONS(805),
    [anon_sym_GT] = ACTIONS(805),
    [anon_sym_LT_EQ] = ACTIONS(807),
    [anon_sym_GT_EQ] = ACTIONS(807),
    [anon_sym_instanceof] = ACTIONS(805),
    [anon_sym_in] = ACTIONS(805),
    [anon_sym_LT_LT] = ACTIONS(807),
    [anon_sym_GT_GT] = ACTIONS(805),
    [anon_sym_GT_GT_GT] = ACTIONS(807),
    [anon_sym_PLUS] = ACTIONS(805),
    [anon_sym_DASH] = ACTIONS(805),
    [anon_sym_PERCENT] = ACTIONS(807),
    [anon_sym_STAR_STAR] = ACTIONS(807),
    [anon_sym_BANG] = ACTIONS(805),
    [anon_sym_TILDE] = ACTIONS(807),
    [anon_sym_typeof] = ACTIONS(805),
    [anon_sym_void] = ACTIONS(805),
    [anon_sym_delete] = ACTIONS(805),
    [anon_sym_QMARK] = ACTIONS(805),
    [anon_sym_await] = ACTIONS(805),
    [anon_sym_LBRACK] = ACTIONS(807),
    [anon_sym_extends] = ACTIONS(805),
    [anon_sym_if] = ACTIONS(805),
    [anon_sym_async] = ACTIONS(805),
    [anon_sym_QMARK_DOT] = ACTIONS(807),
    [anon_sym_BQUOTE] = ACTIONS(807),
    [anon_sym_DOLLARr] = ACTIONS(805),
    [anon_sym_PLUS_PLUS] = ACTIONS(807),
    [anon_sym_DASH_DASH] = ACTIONS(807),
    [anon_sym_new] = ACTIONS(805),
  },
  [STATE(116)] = {
    [sym_comment] = STATE(116),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(809),
    [anon_sym_LBRACE] = ACTIONS(811),
    [anon_sym_RBRACE] = ACTIONS(811),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_as] = ACTIONS(809),
    [anon_sym_SEMI] = ACTIONS(811),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_DOT] = ACTIONS(811),
    [anon_sym_Text] = ACTIONS(809),
    [anon_sym_Button] = ACTIONS(809),
    [anon_sym_Image] = ACTIONS(809),
    [anon_sym_TextInput] = ACTIONS(809),
    [anon_sym_TextArea] = ACTIONS(809),
    [anon_sym_Column] = ACTIONS(809),
    [anon_sym_Row] = ACTIONS(809),
    [anon_sym_Stack] = ACTIONS(809),
    [anon_sym_Flex] = ACTIONS(809),
    [anon_sym_Grid] = ACTIONS(809),
    [anon_sym_GridRow] = ACTIONS(809),
    [anon_sym_GridCol] = ACTIONS(809),
    [anon_sym_List] = ACTIONS(809),
    [anon_sym_ScrollList] = ACTIONS(809),
    [anon_sym_ListItem] = ACTIONS(809),
    [anon_sym_GridItem] = ACTIONS(809),
    [anon_sym_ForEach] = ACTIONS(809),
    [sym_identifier] = ACTIONS(809),
    [anon_sym_DQUOTE] = ACTIONS(811),
    [anon_sym_SQUOTE] = ACTIONS(811),
    [anon_sym_DOLLAR] = ACTIONS(809),
    [sym_numeric_literal] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(809),
    [anon_sym_false] = ACTIONS(809),
    [anon_sym_null] = ACTIONS(809),
    [anon_sym_PIPE_PIPE] = ACTIONS(811),
    [anon_sym_AMP_AMP] = ACTIONS(811),
    [anon_sym_PIPE] = ACTIONS(809),
    [anon_sym_CARET] = ACTIONS(811),
    [anon_sym_AMP] = ACTIONS(809),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(811),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(811),
    [anon_sym_LT] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(811),
    [anon_sym_GT_EQ] = ACTIONS(811),
    [anon_sym_instanceof] = ACTIONS(809),
    [anon_sym_in] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(811),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_GT_GT_GT] = ACTIONS(811),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(809),
    [anon_sym_PERCENT] = ACTIONS(811),
    [anon_sym_STAR_STAR] = ACTIONS(811),
    [anon_sym_BANG] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(811),
    [anon_sym_typeof] = ACTIONS(809),
    [anon_sym_void] = ACTIONS(809),
    [anon_sym_delete] = ACTIONS(809),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_await] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_extends] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(809),
    [anon_sym_async] = ACTIONS(809),
    [anon_sym_QMARK_DOT] = ACTIONS(811),
    [anon_sym_BQUOTE] = ACTIONS(811),
    [anon_sym_DOLLARr] = ACTIONS(809),
    [anon_sym_PLUS_PLUS] = ACTIONS(811),
    [anon_sym_DASH_DASH] = ACTIONS(811),
    [anon_sym_new] = ACTIONS(809),
  },
  [STATE(117)] = {
    [sym_comment] = STATE(117),
    [aux_sym_union_type_repeat1] = STATE(118),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_RBRACE] = ACTIONS(815),
    [anon_sym_STAR] = ACTIONS(813),
    [anon_sym_as] = ACTIONS(813),
    [anon_sym_SEMI] = ACTIONS(815),
    [anon_sym_LPAREN] = ACTIONS(815),
    [anon_sym_DOT] = ACTIONS(815),
    [anon_sym_Text] = ACTIONS(813),
    [anon_sym_Button] = ACTIONS(813),
    [anon_sym_Image] = ACTIONS(813),
    [anon_sym_TextInput] = ACTIONS(813),
    [anon_sym_TextArea] = ACTIONS(813),
    [anon_sym_Column] = ACTIONS(813),
    [anon_sym_Row] = ACTIONS(813),
    [anon_sym_Stack] = ACTIONS(813),
    [anon_sym_Flex] = ACTIONS(813),
    [anon_sym_Grid] = ACTIONS(813),
    [anon_sym_GridRow] = ACTIONS(813),
    [anon_sym_GridCol] = ACTIONS(813),
    [anon_sym_List] = ACTIONS(813),
    [anon_sym_ScrollList] = ACTIONS(813),
    [anon_sym_ListItem] = ACTIONS(813),
    [anon_sym_GridItem] = ACTIONS(813),
    [anon_sym_ForEach] = ACTIONS(813),
    [sym_identifier] = ACTIONS(813),
    [anon_sym_DQUOTE] = ACTIONS(815),
    [anon_sym_SQUOTE] = ACTIONS(815),
    [anon_sym_DOLLAR] = ACTIONS(813),
    [sym_numeric_literal] = ACTIONS(815),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_null] = ACTIONS(813),
    [anon_sym_PIPE_PIPE] = ACTIONS(815),
    [anon_sym_AMP_AMP] = ACTIONS(815),
    [anon_sym_PIPE] = ACTIONS(813),
    [anon_sym_CARET] = ACTIONS(815),
    [anon_sym_AMP] = ACTIONS(813),
    [anon_sym_EQ_EQ] = ACTIONS(813),
    [anon_sym_BANG_EQ] = ACTIONS(813),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(815),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(815),
    [anon_sym_LT] = ACTIONS(813),
    [anon_sym_GT] = ACTIONS(813),
    [anon_sym_LT_EQ] = ACTIONS(815),
    [anon_sym_GT_EQ] = ACTIONS(815),
    [anon_sym_instanceof] = ACTIONS(813),
    [anon_sym_in] = ACTIONS(813),
    [anon_sym_LT_LT] = ACTIONS(815),
    [anon_sym_GT_GT] = ACTIONS(813),
    [anon_sym_GT_GT_GT] = ACTIONS(815),
    [anon_sym_PLUS] = ACTIONS(813),
    [anon_sym_DASH] = ACTIONS(813),
    [anon_sym_PERCENT] = ACTIONS(815),
    [anon_sym_STAR_STAR] = ACTIONS(815),
    [anon_sym_BANG] = ACTIONS(813),
    [anon_sym_TILDE] = ACTIONS(815),
    [anon_sym_typeof] = ACTIONS(813),
    [anon_sym_void] = ACTIONS(813),
    [anon_sym_delete] = ACTIONS(813),
    [anon_sym_QMARK] = ACTIONS(813),
    [anon_sym_await] = ACTIONS(813),
    [anon_sym_LBRACK] = ACTIONS(815),
    [anon_sym_if] = ACTIONS(813),
    [anon_sym_async] = ACTIONS(813),
    [anon_sym_QMARK_DOT] = ACTIONS(815),
    [anon_sym_BQUOTE] = ACTIONS(815),
    [anon_sym_DOLLARr] = ACTIONS(813),
    [anon_sym_PLUS_PLUS] = ACTIONS(815),
    [anon_sym_DASH_DASH] = ACTIONS(815),
    [anon_sym_new] = ACTIONS(813),
  },
  [STATE(118)] = {
    [sym_comment] = STATE(118),
    [aux_sym_union_type_repeat1] = STATE(118),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(817),
    [anon_sym_LBRACE] = ACTIONS(819),
    [anon_sym_RBRACE] = ACTIONS(819),
    [anon_sym_STAR] = ACTIONS(817),
    [anon_sym_as] = ACTIONS(817),
    [anon_sym_SEMI] = ACTIONS(819),
    [anon_sym_LPAREN] = ACTIONS(819),
    [anon_sym_DOT] = ACTIONS(819),
    [anon_sym_Text] = ACTIONS(817),
    [anon_sym_Button] = ACTIONS(817),
    [anon_sym_Image] = ACTIONS(817),
    [anon_sym_TextInput] = ACTIONS(817),
    [anon_sym_TextArea] = ACTIONS(817),
    [anon_sym_Column] = ACTIONS(817),
    [anon_sym_Row] = ACTIONS(817),
    [anon_sym_Stack] = ACTIONS(817),
    [anon_sym_Flex] = ACTIONS(817),
    [anon_sym_Grid] = ACTIONS(817),
    [anon_sym_GridRow] = ACTIONS(817),
    [anon_sym_GridCol] = ACTIONS(817),
    [anon_sym_List] = ACTIONS(817),
    [anon_sym_ScrollList] = ACTIONS(817),
    [anon_sym_ListItem] = ACTIONS(817),
    [anon_sym_GridItem] = ACTIONS(817),
    [anon_sym_ForEach] = ACTIONS(817),
    [sym_identifier] = ACTIONS(817),
    [anon_sym_DQUOTE] = ACTIONS(819),
    [anon_sym_SQUOTE] = ACTIONS(819),
    [anon_sym_DOLLAR] = ACTIONS(817),
    [sym_numeric_literal] = ACTIONS(819),
    [anon_sym_true] = ACTIONS(817),
    [anon_sym_false] = ACTIONS(817),
    [anon_sym_null] = ACTIONS(817),
    [anon_sym_PIPE_PIPE] = ACTIONS(819),
    [anon_sym_AMP_AMP] = ACTIONS(819),
    [anon_sym_PIPE] = ACTIONS(821),
    [anon_sym_CARET] = ACTIONS(819),
    [anon_sym_AMP] = ACTIONS(817),
    [anon_sym_EQ_EQ] = ACTIONS(817),
    [anon_sym_BANG_EQ] = ACTIONS(817),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(819),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(819),
    [anon_sym_LT] = ACTIONS(817),
    [anon_sym_GT] = ACTIONS(817),
    [anon_sym_LT_EQ] = ACTIONS(819),
    [anon_sym_GT_EQ] = ACTIONS(819),
    [anon_sym_instanceof] = ACTIONS(817),
    [anon_sym_in] = ACTIONS(817),
    [anon_sym_LT_LT] = ACTIONS(819),
    [anon_sym_GT_GT] = ACTIONS(817),
    [anon_sym_GT_GT_GT] = ACTIONS(819),
    [anon_sym_PLUS] = ACTIONS(817),
    [anon_sym_DASH] = ACTIONS(817),
    [anon_sym_PERCENT] = ACTIONS(819),
    [anon_sym_STAR_STAR] = ACTIONS(819),
    [anon_sym_BANG] = ACTIONS(817),
    [anon_sym_TILDE] = ACTIONS(819),
    [anon_sym_typeof] = ACTIONS(817),
    [anon_sym_void] = ACTIONS(817),
    [anon_sym_delete] = ACTIONS(817),
    [anon_sym_QMARK] = ACTIONS(817),
    [anon_sym_await] = ACTIONS(817),
    [anon_sym_LBRACK] = ACTIONS(819),
    [anon_sym_if] = ACTIONS(817),
    [anon_sym_async] = ACTIONS(817),
    [anon_sym_QMARK_DOT] = ACTIONS(819),
    [anon_sym_BQUOTE] = ACTIONS(819),
    [anon_sym_DOLLARr] = ACTIONS(817),
    [anon_sym_PLUS_PLUS] = ACTIONS(819),
    [anon_sym_DASH_DASH] = ACTIONS(819),
    [anon_sym_new] = ACTIONS(817),
  },
  [STATE(119)] = {
    [sym_comment] = STATE(119),
    [sym_modifier_chain_expression] = STATE(165),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(824),
    [anon_sym_LBRACE] = ACTIONS(826),
    [anon_sym_RBRACE] = ACTIONS(826),
    [anon_sym_STAR] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(824),
    [anon_sym_SEMI] = ACTIONS(826),
    [anon_sym_LPAREN] = ACTIONS(826),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(824),
    [anon_sym_Button] = ACTIONS(824),
    [anon_sym_Image] = ACTIONS(824),
    [anon_sym_TextInput] = ACTIONS(824),
    [anon_sym_TextArea] = ACTIONS(824),
    [anon_sym_Column] = ACTIONS(824),
    [anon_sym_Row] = ACTIONS(824),
    [anon_sym_Stack] = ACTIONS(824),
    [anon_sym_Flex] = ACTIONS(824),
    [anon_sym_Grid] = ACTIONS(824),
    [anon_sym_GridRow] = ACTIONS(824),
    [anon_sym_GridCol] = ACTIONS(824),
    [anon_sym_List] = ACTIONS(824),
    [anon_sym_ScrollList] = ACTIONS(824),
    [anon_sym_ListItem] = ACTIONS(824),
    [anon_sym_GridItem] = ACTIONS(824),
    [anon_sym_ForEach] = ACTIONS(824),
    [sym_identifier] = ACTIONS(824),
    [anon_sym_DQUOTE] = ACTIONS(826),
    [anon_sym_SQUOTE] = ACTIONS(826),
    [anon_sym_DOLLAR] = ACTIONS(824),
    [sym_numeric_literal] = ACTIONS(826),
    [anon_sym_true] = ACTIONS(824),
    [anon_sym_false] = ACTIONS(824),
    [anon_sym_null] = ACTIONS(824),
    [anon_sym_PIPE_PIPE] = ACTIONS(826),
    [anon_sym_AMP_AMP] = ACTIONS(826),
    [anon_sym_PIPE] = ACTIONS(824),
    [anon_sym_CARET] = ACTIONS(826),
    [anon_sym_AMP] = ACTIONS(824),
    [anon_sym_EQ_EQ] = ACTIONS(824),
    [anon_sym_BANG_EQ] = ACTIONS(824),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(826),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(826),
    [anon_sym_LT] = ACTIONS(824),
    [anon_sym_GT] = ACTIONS(824),
    [anon_sym_LT_EQ] = ACTIONS(826),
    [anon_sym_GT_EQ] = ACTIONS(826),
    [anon_sym_instanceof] = ACTIONS(824),
    [anon_sym_in] = ACTIONS(824),
    [anon_sym_LT_LT] = ACTIONS(826),
    [anon_sym_GT_GT] = ACTIONS(824),
    [anon_sym_GT_GT_GT] = ACTIONS(826),
    [anon_sym_PLUS] = ACTIONS(824),
    [anon_sym_DASH] = ACTIONS(824),
    [anon_sym_PERCENT] = ACTIONS(826),
    [anon_sym_STAR_STAR] = ACTIONS(826),
    [anon_sym_BANG] = ACTIONS(824),
    [anon_sym_TILDE] = ACTIONS(826),
    [anon_sym_typeof] = ACTIONS(824),
    [anon_sym_void] = ACTIONS(824),
    [anon_sym_delete] = ACTIONS(824),
    [anon_sym_QMARK] = ACTIONS(824),
    [anon_sym_await] = ACTIONS(824),
    [anon_sym_LBRACK] = ACTIONS(826),
    [anon_sym_if] = ACTIONS(824),
    [anon_sym_async] = ACTIONS(824),
    [anon_sym_QMARK_DOT] = ACTIONS(826),
    [anon_sym_BQUOTE] = ACTIONS(826),
    [anon_sym_DOLLARr] = ACTIONS(824),
    [anon_sym_PLUS_PLUS] = ACTIONS(826),
    [anon_sym_DASH_DASH] = ACTIONS(826),
    [anon_sym_new] = ACTIONS(824),
  },
  [STATE(120)] = {
    [sym_comment] = STATE(120),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [anon_sym_Text] = ACTIONS(61),
    [anon_sym_Button] = ACTIONS(61),
    [anon_sym_Image] = ACTIONS(61),
    [anon_sym_TextInput] = ACTIONS(61),
    [anon_sym_TextArea] = ACTIONS(61),
    [anon_sym_Column] = ACTIONS(61),
    [anon_sym_Row] = ACTIONS(61),
    [anon_sym_Stack] = ACTIONS(61),
    [anon_sym_Flex] = ACTIONS(61),
    [anon_sym_Grid] = ACTIONS(61),
    [anon_sym_GridRow] = ACTIONS(61),
    [anon_sym_GridCol] = ACTIONS(61),
    [anon_sym_List] = ACTIONS(61),
    [anon_sym_ScrollList] = ACTIONS(61),
    [anon_sym_ListItem] = ACTIONS(61),
    [anon_sym_GridItem] = ACTIONS(61),
    [anon_sym_ForEach] = ACTIONS(61),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(121)] = {
    [sym_comment] = STATE(121),
    [sym_modifier_chain_expression] = STATE(190),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(828),
    [anon_sym_LBRACE] = ACTIONS(830),
    [anon_sym_RBRACE] = ACTIONS(830),
    [anon_sym_STAR] = ACTIONS(828),
    [anon_sym_as] = ACTIONS(828),
    [anon_sym_SEMI] = ACTIONS(830),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(828),
    [anon_sym_Button] = ACTIONS(828),
    [anon_sym_Image] = ACTIONS(828),
    [anon_sym_TextInput] = ACTIONS(828),
    [anon_sym_TextArea] = ACTIONS(828),
    [anon_sym_Column] = ACTIONS(828),
    [anon_sym_Row] = ACTIONS(828),
    [anon_sym_Stack] = ACTIONS(828),
    [anon_sym_Flex] = ACTIONS(828),
    [anon_sym_Grid] = ACTIONS(828),
    [anon_sym_GridRow] = ACTIONS(828),
    [anon_sym_GridCol] = ACTIONS(828),
    [anon_sym_List] = ACTIONS(828),
    [anon_sym_ScrollList] = ACTIONS(828),
    [anon_sym_ListItem] = ACTIONS(828),
    [anon_sym_GridItem] = ACTIONS(828),
    [anon_sym_ForEach] = ACTIONS(828),
    [sym_identifier] = ACTIONS(828),
    [anon_sym_DQUOTE] = ACTIONS(830),
    [anon_sym_SQUOTE] = ACTIONS(830),
    [anon_sym_DOLLAR] = ACTIONS(828),
    [sym_numeric_literal] = ACTIONS(830),
    [anon_sym_true] = ACTIONS(828),
    [anon_sym_false] = ACTIONS(828),
    [anon_sym_null] = ACTIONS(828),
    [anon_sym_PIPE_PIPE] = ACTIONS(830),
    [anon_sym_AMP_AMP] = ACTIONS(830),
    [anon_sym_PIPE] = ACTIONS(828),
    [anon_sym_CARET] = ACTIONS(830),
    [anon_sym_AMP] = ACTIONS(828),
    [anon_sym_EQ_EQ] = ACTIONS(828),
    [anon_sym_BANG_EQ] = ACTIONS(828),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(830),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(830),
    [anon_sym_LT] = ACTIONS(828),
    [anon_sym_GT] = ACTIONS(828),
    [anon_sym_LT_EQ] = ACTIONS(830),
    [anon_sym_GT_EQ] = ACTIONS(830),
    [anon_sym_instanceof] = ACTIONS(828),
    [anon_sym_in] = ACTIONS(828),
    [anon_sym_LT_LT] = ACTIONS(830),
    [anon_sym_GT_GT] = ACTIONS(828),
    [anon_sym_GT_GT_GT] = ACTIONS(830),
    [anon_sym_PLUS] = ACTIONS(828),
    [anon_sym_DASH] = ACTIONS(828),
    [anon_sym_PERCENT] = ACTIONS(830),
    [anon_sym_STAR_STAR] = ACTIONS(830),
    [anon_sym_BANG] = ACTIONS(828),
    [anon_sym_TILDE] = ACTIONS(830),
    [anon_sym_typeof] = ACTIONS(828),
    [anon_sym_void] = ACTIONS(828),
    [anon_sym_delete] = ACTIONS(828),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_await] = ACTIONS(828),
    [anon_sym_LBRACK] = ACTIONS(830),
    [anon_sym_if] = ACTIONS(828),
    [anon_sym_async] = ACTIONS(828),
    [anon_sym_QMARK_DOT] = ACTIONS(830),
    [anon_sym_BQUOTE] = ACTIONS(830),
    [anon_sym_DOLLARr] = ACTIONS(828),
    [anon_sym_PLUS_PLUS] = ACTIONS(830),
    [anon_sym_DASH_DASH] = ACTIONS(830),
    [anon_sym_new] = ACTIONS(828),
  },
  [STATE(122)] = {
    [sym_comment] = STATE(122),
    [sym_argument_list] = STATE(148),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(832),
    [anon_sym_LBRACE] = ACTIONS(834),
    [anon_sym_RBRACE] = ACTIONS(834),
    [anon_sym_STAR] = ACTIONS(832),
    [anon_sym_as] = ACTIONS(832),
    [anon_sym_SEMI] = ACTIONS(834),
    [anon_sym_LPAREN] = ACTIONS(834),
    [anon_sym_DOT] = ACTIONS(834),
    [anon_sym_Text] = ACTIONS(832),
    [anon_sym_Button] = ACTIONS(832),
    [anon_sym_Image] = ACTIONS(832),
    [anon_sym_TextInput] = ACTIONS(832),
    [anon_sym_TextArea] = ACTIONS(832),
    [anon_sym_Column] = ACTIONS(832),
    [anon_sym_Row] = ACTIONS(832),
    [anon_sym_Stack] = ACTIONS(832),
    [anon_sym_Flex] = ACTIONS(832),
    [anon_sym_Grid] = ACTIONS(832),
    [anon_sym_GridRow] = ACTIONS(832),
    [anon_sym_GridCol] = ACTIONS(832),
    [anon_sym_List] = ACTIONS(832),
    [anon_sym_ScrollList] = ACTIONS(832),
    [anon_sym_ListItem] = ACTIONS(832),
    [anon_sym_GridItem] = ACTIONS(832),
    [anon_sym_ForEach] = ACTIONS(832),
    [sym_identifier] = ACTIONS(832),
    [anon_sym_DQUOTE] = ACTIONS(834),
    [anon_sym_SQUOTE] = ACTIONS(834),
    [anon_sym_DOLLAR] = ACTIONS(832),
    [sym_numeric_literal] = ACTIONS(834),
    [anon_sym_true] = ACTIONS(832),
    [anon_sym_false] = ACTIONS(832),
    [anon_sym_null] = ACTIONS(832),
    [anon_sym_PIPE_PIPE] = ACTIONS(834),
    [anon_sym_AMP_AMP] = ACTIONS(834),
    [anon_sym_PIPE] = ACTIONS(832),
    [anon_sym_CARET] = ACTIONS(834),
    [anon_sym_AMP] = ACTIONS(832),
    [anon_sym_EQ_EQ] = ACTIONS(832),
    [anon_sym_BANG_EQ] = ACTIONS(832),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(834),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(834),
    [anon_sym_LT] = ACTIONS(832),
    [anon_sym_GT] = ACTIONS(832),
    [anon_sym_LT_EQ] = ACTIONS(834),
    [anon_sym_GT_EQ] = ACTIONS(834),
    [anon_sym_instanceof] = ACTIONS(832),
    [anon_sym_in] = ACTIONS(832),
    [anon_sym_LT_LT] = ACTIONS(834),
    [anon_sym_GT_GT] = ACTIONS(832),
    [anon_sym_GT_GT_GT] = ACTIONS(834),
    [anon_sym_PLUS] = ACTIONS(832),
    [anon_sym_DASH] = ACTIONS(832),
    [anon_sym_PERCENT] = ACTIONS(834),
    [anon_sym_STAR_STAR] = ACTIONS(834),
    [anon_sym_BANG] = ACTIONS(832),
    [anon_sym_TILDE] = ACTIONS(834),
    [anon_sym_typeof] = ACTIONS(832),
    [anon_sym_void] = ACTIONS(832),
    [anon_sym_delete] = ACTIONS(832),
    [anon_sym_QMARK] = ACTIONS(832),
    [anon_sym_await] = ACTIONS(832),
    [anon_sym_LBRACK] = ACTIONS(834),
    [anon_sym_if] = ACTIONS(832),
    [anon_sym_async] = ACTIONS(832),
    [anon_sym_QMARK_DOT] = ACTIONS(834),
    [anon_sym_BQUOTE] = ACTIONS(834),
    [anon_sym_DOLLARr] = ACTIONS(832),
    [anon_sym_PLUS_PLUS] = ACTIONS(834),
    [anon_sym_DASH_DASH] = ACTIONS(834),
    [anon_sym_new] = ACTIONS(832),
  },
  [STATE(123)] = {
    [sym_comment] = STATE(123),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_RBRACE] = ACTIONS(838),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_as] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_LPAREN] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(838),
    [anon_sym_Text] = ACTIONS(836),
    [anon_sym_Button] = ACTIONS(836),
    [anon_sym_Image] = ACTIONS(836),
    [anon_sym_TextInput] = ACTIONS(836),
    [anon_sym_TextArea] = ACTIONS(836),
    [anon_sym_Column] = ACTIONS(836),
    [anon_sym_Row] = ACTIONS(836),
    [anon_sym_Stack] = ACTIONS(836),
    [anon_sym_Flex] = ACTIONS(836),
    [anon_sym_Grid] = ACTIONS(836),
    [anon_sym_GridRow] = ACTIONS(836),
    [anon_sym_GridCol] = ACTIONS(836),
    [anon_sym_List] = ACTIONS(836),
    [anon_sym_ScrollList] = ACTIONS(836),
    [anon_sym_ListItem] = ACTIONS(836),
    [anon_sym_GridItem] = ACTIONS(836),
    [anon_sym_ForEach] = ACTIONS(836),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_DQUOTE] = ACTIONS(838),
    [anon_sym_SQUOTE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(836),
    [sym_numeric_literal] = ACTIONS(838),
    [anon_sym_true] = ACTIONS(836),
    [anon_sym_false] = ACTIONS(836),
    [anon_sym_null] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(838),
    [anon_sym_AMP_AMP] = ACTIONS(838),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(838),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(836),
    [anon_sym_BANG_EQ] = ACTIONS(836),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(838),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(838),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_instanceof] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(838),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_GT_GT_GT] = ACTIONS(838),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(838),
    [anon_sym_STAR_STAR] = ACTIONS(838),
    [anon_sym_BANG] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(836),
    [anon_sym_void] = ACTIONS(836),
    [anon_sym_delete] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(836),
    [anon_sym_await] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [anon_sym_extends] = ACTIONS(836),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_async] = ACTIONS(836),
    [anon_sym_QMARK_DOT] = ACTIONS(838),
    [anon_sym_BQUOTE] = ACTIONS(838),
    [anon_sym_DOLLARr] = ACTIONS(836),
    [anon_sym_PLUS_PLUS] = ACTIONS(838),
    [anon_sym_DASH_DASH] = ACTIONS(838),
    [anon_sym_new] = ACTIONS(836),
  },
  [STATE(124)] = {
    [sym_comment] = STATE(124),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(780),
    [anon_sym_Text] = ACTIONS(778),
    [anon_sym_Button] = ACTIONS(778),
    [anon_sym_Image] = ACTIONS(778),
    [anon_sym_TextInput] = ACTIONS(778),
    [anon_sym_TextArea] = ACTIONS(778),
    [anon_sym_Column] = ACTIONS(778),
    [anon_sym_Row] = ACTIONS(778),
    [anon_sym_Stack] = ACTIONS(778),
    [anon_sym_Flex] = ACTIONS(778),
    [anon_sym_Grid] = ACTIONS(778),
    [anon_sym_GridRow] = ACTIONS(778),
    [anon_sym_GridCol] = ACTIONS(778),
    [anon_sym_List] = ACTIONS(778),
    [anon_sym_ScrollList] = ACTIONS(778),
    [anon_sym_ListItem] = ACTIONS(778),
    [anon_sym_GridItem] = ACTIONS(778),
    [anon_sym_ForEach] = ACTIONS(778),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_extends] = ACTIONS(778),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(125)] = {
    [sym_comment] = STATE(125),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(754),
    [anon_sym_LBRACE] = ACTIONS(749),
    [anon_sym_RBRACE] = ACTIONS(749),
    [anon_sym_STAR] = ACTIONS(754),
    [anon_sym_as] = ACTIONS(754),
    [anon_sym_SEMI] = ACTIONS(749),
    [anon_sym_LPAREN] = ACTIONS(749),
    [anon_sym_DOT] = ACTIONS(749),
    [anon_sym_Text] = ACTIONS(754),
    [anon_sym_Button] = ACTIONS(754),
    [anon_sym_Image] = ACTIONS(754),
    [anon_sym_TextInput] = ACTIONS(754),
    [anon_sym_TextArea] = ACTIONS(754),
    [anon_sym_Column] = ACTIONS(754),
    [anon_sym_Row] = ACTIONS(754),
    [anon_sym_Stack] = ACTIONS(754),
    [anon_sym_Flex] = ACTIONS(754),
    [anon_sym_Grid] = ACTIONS(754),
    [anon_sym_GridRow] = ACTIONS(754),
    [anon_sym_GridCol] = ACTIONS(754),
    [anon_sym_List] = ACTIONS(754),
    [anon_sym_ScrollList] = ACTIONS(754),
    [anon_sym_ListItem] = ACTIONS(754),
    [anon_sym_GridItem] = ACTIONS(754),
    [anon_sym_ForEach] = ACTIONS(754),
    [sym_identifier] = ACTIONS(754),
    [anon_sym_DQUOTE] = ACTIONS(749),
    [anon_sym_SQUOTE] = ACTIONS(749),
    [anon_sym_DOLLAR] = ACTIONS(754),
    [sym_numeric_literal] = ACTIONS(749),
    [anon_sym_true] = ACTIONS(754),
    [anon_sym_false] = ACTIONS(754),
    [anon_sym_null] = ACTIONS(754),
    [anon_sym_PIPE_PIPE] = ACTIONS(749),
    [anon_sym_AMP_AMP] = ACTIONS(749),
    [anon_sym_PIPE] = ACTIONS(754),
    [anon_sym_CARET] = ACTIONS(749),
    [anon_sym_AMP] = ACTIONS(754),
    [anon_sym_EQ_EQ] = ACTIONS(754),
    [anon_sym_BANG_EQ] = ACTIONS(754),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(749),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(749),
    [anon_sym_LT] = ACTIONS(754),
    [anon_sym_GT] = ACTIONS(754),
    [anon_sym_LT_EQ] = ACTIONS(749),
    [anon_sym_GT_EQ] = ACTIONS(749),
    [anon_sym_instanceof] = ACTIONS(754),
    [anon_sym_in] = ACTIONS(754),
    [anon_sym_LT_LT] = ACTIONS(749),
    [anon_sym_GT_GT] = ACTIONS(754),
    [anon_sym_GT_GT_GT] = ACTIONS(749),
    [anon_sym_PLUS] = ACTIONS(754),
    [anon_sym_DASH] = ACTIONS(754),
    [anon_sym_PERCENT] = ACTIONS(749),
    [anon_sym_STAR_STAR] = ACTIONS(749),
    [anon_sym_BANG] = ACTIONS(754),
    [anon_sym_TILDE] = ACTIONS(749),
    [anon_sym_typeof] = ACTIONS(754),
    [anon_sym_void] = ACTIONS(754),
    [anon_sym_delete] = ACTIONS(754),
    [anon_sym_QMARK] = ACTIONS(754),
    [anon_sym_await] = ACTIONS(754),
    [anon_sym_LBRACK] = ACTIONS(749),
    [anon_sym_extends] = ACTIONS(754),
    [anon_sym_if] = ACTIONS(754),
    [anon_sym_async] = ACTIONS(754),
    [anon_sym_QMARK_DOT] = ACTIONS(749),
    [anon_sym_BQUOTE] = ACTIONS(749),
    [anon_sym_DOLLARr] = ACTIONS(754),
    [anon_sym_PLUS_PLUS] = ACTIONS(749),
    [anon_sym_DASH_DASH] = ACTIONS(749),
    [anon_sym_new] = ACTIONS(754),
  },
  [STATE(126)] = {
    [sym_comment] = STATE(126),
    [aux_sym_array_type_repeat1] = STATE(126),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [anon_sym_Text] = ACTIONS(756),
    [anon_sym_Button] = ACTIONS(756),
    [anon_sym_Image] = ACTIONS(756),
    [anon_sym_TextInput] = ACTIONS(756),
    [anon_sym_TextArea] = ACTIONS(756),
    [anon_sym_Column] = ACTIONS(756),
    [anon_sym_Row] = ACTIONS(756),
    [anon_sym_Stack] = ACTIONS(756),
    [anon_sym_Flex] = ACTIONS(756),
    [anon_sym_Grid] = ACTIONS(756),
    [anon_sym_GridRow] = ACTIONS(756),
    [anon_sym_GridCol] = ACTIONS(756),
    [anon_sym_List] = ACTIONS(756),
    [anon_sym_ScrollList] = ACTIONS(756),
    [anon_sym_ListItem] = ACTIONS(756),
    [anon_sym_GridItem] = ACTIONS(756),
    [anon_sym_ForEach] = ACTIONS(756),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(840),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(127)] = {
    [sym_comment] = STATE(127),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(843),
    [anon_sym_LBRACE] = ACTIONS(845),
    [anon_sym_RBRACE] = ACTIONS(845),
    [anon_sym_STAR] = ACTIONS(843),
    [anon_sym_as] = ACTIONS(843),
    [anon_sym_SEMI] = ACTIONS(845),
    [anon_sym_LPAREN] = ACTIONS(845),
    [anon_sym_DOT] = ACTIONS(845),
    [anon_sym_Text] = ACTIONS(843),
    [anon_sym_Button] = ACTIONS(843),
    [anon_sym_Image] = ACTIONS(843),
    [anon_sym_TextInput] = ACTIONS(843),
    [anon_sym_TextArea] = ACTIONS(843),
    [anon_sym_Column] = ACTIONS(843),
    [anon_sym_Row] = ACTIONS(843),
    [anon_sym_Stack] = ACTIONS(843),
    [anon_sym_Flex] = ACTIONS(843),
    [anon_sym_Grid] = ACTIONS(843),
    [anon_sym_GridRow] = ACTIONS(843),
    [anon_sym_GridCol] = ACTIONS(843),
    [anon_sym_List] = ACTIONS(843),
    [anon_sym_ScrollList] = ACTIONS(843),
    [anon_sym_ListItem] = ACTIONS(843),
    [anon_sym_GridItem] = ACTIONS(843),
    [anon_sym_ForEach] = ACTIONS(843),
    [sym_identifier] = ACTIONS(843),
    [anon_sym_DQUOTE] = ACTIONS(845),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DOLLAR] = ACTIONS(843),
    [sym_numeric_literal] = ACTIONS(845),
    [anon_sym_true] = ACTIONS(843),
    [anon_sym_false] = ACTIONS(843),
    [anon_sym_null] = ACTIONS(843),
    [anon_sym_PIPE_PIPE] = ACTIONS(845),
    [anon_sym_AMP_AMP] = ACTIONS(845),
    [anon_sym_PIPE] = ACTIONS(843),
    [anon_sym_CARET] = ACTIONS(845),
    [anon_sym_AMP] = ACTIONS(843),
    [anon_sym_EQ_EQ] = ACTIONS(843),
    [anon_sym_BANG_EQ] = ACTIONS(843),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(845),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(845),
    [anon_sym_LT] = ACTIONS(843),
    [anon_sym_GT] = ACTIONS(843),
    [anon_sym_LT_EQ] = ACTIONS(845),
    [anon_sym_GT_EQ] = ACTIONS(845),
    [anon_sym_instanceof] = ACTIONS(843),
    [anon_sym_in] = ACTIONS(843),
    [anon_sym_LT_LT] = ACTIONS(845),
    [anon_sym_GT_GT] = ACTIONS(843),
    [anon_sym_GT_GT_GT] = ACTIONS(845),
    [anon_sym_PLUS] = ACTIONS(843),
    [anon_sym_DASH] = ACTIONS(843),
    [anon_sym_PERCENT] = ACTIONS(845),
    [anon_sym_STAR_STAR] = ACTIONS(845),
    [anon_sym_BANG] = ACTIONS(843),
    [anon_sym_TILDE] = ACTIONS(845),
    [anon_sym_typeof] = ACTIONS(843),
    [anon_sym_void] = ACTIONS(843),
    [anon_sym_delete] = ACTIONS(843),
    [anon_sym_QMARK] = ACTIONS(843),
    [anon_sym_await] = ACTIONS(843),
    [anon_sym_LBRACK] = ACTIONS(845),
    [anon_sym_extends] = ACTIONS(843),
    [anon_sym_if] = ACTIONS(843),
    [anon_sym_async] = ACTIONS(843),
    [anon_sym_QMARK_DOT] = ACTIONS(845),
    [anon_sym_BQUOTE] = ACTIONS(845),
    [anon_sym_DOLLARr] = ACTIONS(843),
    [anon_sym_PLUS_PLUS] = ACTIONS(845),
    [anon_sym_DASH_DASH] = ACTIONS(845),
    [anon_sym_new] = ACTIONS(843),
  },
  [STATE(128)] = {
    [sym_comment] = STATE(128),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(847),
    [anon_sym_LBRACE] = ACTIONS(849),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_STAR] = ACTIONS(847),
    [anon_sym_as] = ACTIONS(847),
    [anon_sym_SEMI] = ACTIONS(849),
    [anon_sym_LPAREN] = ACTIONS(849),
    [anon_sym_DOT] = ACTIONS(849),
    [anon_sym_Text] = ACTIONS(847),
    [anon_sym_Button] = ACTIONS(847),
    [anon_sym_Image] = ACTIONS(847),
    [anon_sym_TextInput] = ACTIONS(847),
    [anon_sym_TextArea] = ACTIONS(847),
    [anon_sym_Column] = ACTIONS(847),
    [anon_sym_Row] = ACTIONS(847),
    [anon_sym_Stack] = ACTIONS(847),
    [anon_sym_Flex] = ACTIONS(847),
    [anon_sym_Grid] = ACTIONS(847),
    [anon_sym_GridRow] = ACTIONS(847),
    [anon_sym_GridCol] = ACTIONS(847),
    [anon_sym_List] = ACTIONS(847),
    [anon_sym_ScrollList] = ACTIONS(847),
    [anon_sym_ListItem] = ACTIONS(847),
    [anon_sym_GridItem] = ACTIONS(847),
    [anon_sym_ForEach] = ACTIONS(847),
    [sym_identifier] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [anon_sym_SQUOTE] = ACTIONS(849),
    [anon_sym_DOLLAR] = ACTIONS(847),
    [sym_numeric_literal] = ACTIONS(849),
    [anon_sym_true] = ACTIONS(847),
    [anon_sym_false] = ACTIONS(847),
    [anon_sym_null] = ACTIONS(847),
    [anon_sym_PIPE_PIPE] = ACTIONS(849),
    [anon_sym_AMP_AMP] = ACTIONS(849),
    [anon_sym_PIPE] = ACTIONS(847),
    [anon_sym_CARET] = ACTIONS(849),
    [anon_sym_AMP] = ACTIONS(847),
    [anon_sym_EQ_EQ] = ACTIONS(847),
    [anon_sym_BANG_EQ] = ACTIONS(847),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(849),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(849),
    [anon_sym_LT] = ACTIONS(847),
    [anon_sym_GT] = ACTIONS(847),
    [anon_sym_LT_EQ] = ACTIONS(849),
    [anon_sym_GT_EQ] = ACTIONS(849),
    [anon_sym_instanceof] = ACTIONS(847),
    [anon_sym_in] = ACTIONS(847),
    [anon_sym_LT_LT] = ACTIONS(849),
    [anon_sym_GT_GT] = ACTIONS(847),
    [anon_sym_GT_GT_GT] = ACTIONS(849),
    [anon_sym_PLUS] = ACTIONS(847),
    [anon_sym_DASH] = ACTIONS(847),
    [anon_sym_PERCENT] = ACTIONS(849),
    [anon_sym_STAR_STAR] = ACTIONS(849),
    [anon_sym_BANG] = ACTIONS(847),
    [anon_sym_TILDE] = ACTIONS(849),
    [anon_sym_typeof] = ACTIONS(847),
    [anon_sym_void] = ACTIONS(847),
    [anon_sym_delete] = ACTIONS(847),
    [anon_sym_QMARK] = ACTIONS(847),
    [anon_sym_await] = ACTIONS(847),
    [anon_sym_LBRACK] = ACTIONS(849),
    [anon_sym_extends] = ACTIONS(847),
    [anon_sym_if] = ACTIONS(847),
    [anon_sym_async] = ACTIONS(847),
    [anon_sym_QMARK_DOT] = ACTIONS(849),
    [anon_sym_BQUOTE] = ACTIONS(849),
    [anon_sym_DOLLARr] = ACTIONS(847),
    [anon_sym_PLUS_PLUS] = ACTIONS(849),
    [anon_sym_DASH_DASH] = ACTIONS(849),
    [anon_sym_new] = ACTIONS(847),
  },
  [STATE(129)] = {
    [sym_comment] = STATE(129),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(851),
    [anon_sym_LBRACE] = ACTIONS(853),
    [anon_sym_RBRACE] = ACTIONS(853),
    [anon_sym_STAR] = ACTIONS(851),
    [anon_sym_as] = ACTIONS(851),
    [anon_sym_SEMI] = ACTIONS(853),
    [anon_sym_LPAREN] = ACTIONS(853),
    [anon_sym_DOT] = ACTIONS(853),
    [anon_sym_Text] = ACTIONS(851),
    [anon_sym_Button] = ACTIONS(851),
    [anon_sym_Image] = ACTIONS(851),
    [anon_sym_TextInput] = ACTIONS(851),
    [anon_sym_TextArea] = ACTIONS(851),
    [anon_sym_Column] = ACTIONS(851),
    [anon_sym_Row] = ACTIONS(851),
    [anon_sym_Stack] = ACTIONS(851),
    [anon_sym_Flex] = ACTIONS(851),
    [anon_sym_Grid] = ACTIONS(851),
    [anon_sym_GridRow] = ACTIONS(851),
    [anon_sym_GridCol] = ACTIONS(851),
    [anon_sym_List] = ACTIONS(851),
    [anon_sym_ScrollList] = ACTIONS(851),
    [anon_sym_ListItem] = ACTIONS(851),
    [anon_sym_GridItem] = ACTIONS(851),
    [anon_sym_ForEach] = ACTIONS(851),
    [sym_identifier] = ACTIONS(851),
    [anon_sym_DQUOTE] = ACTIONS(853),
    [anon_sym_SQUOTE] = ACTIONS(853),
    [anon_sym_DOLLAR] = ACTIONS(851),
    [sym_numeric_literal] = ACTIONS(853),
    [anon_sym_true] = ACTIONS(851),
    [anon_sym_false] = ACTIONS(851),
    [anon_sym_null] = ACTIONS(851),
    [anon_sym_PIPE_PIPE] = ACTIONS(853),
    [anon_sym_AMP_AMP] = ACTIONS(853),
    [anon_sym_PIPE] = ACTIONS(851),
    [anon_sym_CARET] = ACTIONS(853),
    [anon_sym_AMP] = ACTIONS(851),
    [anon_sym_EQ_EQ] = ACTIONS(851),
    [anon_sym_BANG_EQ] = ACTIONS(851),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(853),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(853),
    [anon_sym_LT] = ACTIONS(851),
    [anon_sym_GT] = ACTIONS(851),
    [anon_sym_LT_EQ] = ACTIONS(853),
    [anon_sym_GT_EQ] = ACTIONS(853),
    [anon_sym_instanceof] = ACTIONS(851),
    [anon_sym_in] = ACTIONS(851),
    [anon_sym_LT_LT] = ACTIONS(853),
    [anon_sym_GT_GT] = ACTIONS(851),
    [anon_sym_GT_GT_GT] = ACTIONS(853),
    [anon_sym_PLUS] = ACTIONS(851),
    [anon_sym_DASH] = ACTIONS(851),
    [anon_sym_PERCENT] = ACTIONS(853),
    [anon_sym_STAR_STAR] = ACTIONS(853),
    [anon_sym_BANG] = ACTIONS(851),
    [anon_sym_TILDE] = ACTIONS(853),
    [anon_sym_typeof] = ACTIONS(851),
    [anon_sym_void] = ACTIONS(851),
    [anon_sym_delete] = ACTIONS(851),
    [anon_sym_QMARK] = ACTIONS(851),
    [anon_sym_await] = ACTIONS(851),
    [anon_sym_LBRACK] = ACTIONS(853),
    [anon_sym_extends] = ACTIONS(851),
    [anon_sym_if] = ACTIONS(851),
    [anon_sym_async] = ACTIONS(851),
    [anon_sym_QMARK_DOT] = ACTIONS(853),
    [anon_sym_BQUOTE] = ACTIONS(853),
    [anon_sym_DOLLARr] = ACTIONS(851),
    [anon_sym_PLUS_PLUS] = ACTIONS(853),
    [anon_sym_DASH_DASH] = ACTIONS(853),
    [anon_sym_new] = ACTIONS(851),
  },
  [STATE(130)] = {
    [sym_comment] = STATE(130),
    [sym_modifier_chain_expression] = STATE(180),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(855),
    [anon_sym_LBRACE] = ACTIONS(857),
    [anon_sym_RBRACE] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_as] = ACTIONS(855),
    [anon_sym_SEMI] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(857),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(855),
    [anon_sym_Button] = ACTIONS(855),
    [anon_sym_Image] = ACTIONS(855),
    [anon_sym_TextInput] = ACTIONS(855),
    [anon_sym_TextArea] = ACTIONS(855),
    [anon_sym_Column] = ACTIONS(855),
    [anon_sym_Row] = ACTIONS(855),
    [anon_sym_Stack] = ACTIONS(855),
    [anon_sym_Flex] = ACTIONS(855),
    [anon_sym_Grid] = ACTIONS(855),
    [anon_sym_GridRow] = ACTIONS(855),
    [anon_sym_GridCol] = ACTIONS(855),
    [anon_sym_List] = ACTIONS(855),
    [anon_sym_ScrollList] = ACTIONS(855),
    [anon_sym_ListItem] = ACTIONS(855),
    [anon_sym_GridItem] = ACTIONS(855),
    [anon_sym_ForEach] = ACTIONS(855),
    [sym_identifier] = ACTIONS(855),
    [anon_sym_DQUOTE] = ACTIONS(857),
    [anon_sym_SQUOTE] = ACTIONS(857),
    [anon_sym_DOLLAR] = ACTIONS(855),
    [sym_numeric_literal] = ACTIONS(857),
    [anon_sym_true] = ACTIONS(855),
    [anon_sym_false] = ACTIONS(855),
    [anon_sym_null] = ACTIONS(855),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(855),
    [anon_sym_CARET] = ACTIONS(857),
    [anon_sym_AMP] = ACTIONS(855),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(857),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(857),
    [anon_sym_LT] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(857),
    [anon_sym_instanceof] = ACTIONS(855),
    [anon_sym_in] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_GT_GT_GT] = ACTIONS(857),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(855),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_STAR_STAR] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(855),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_typeof] = ACTIONS(855),
    [anon_sym_void] = ACTIONS(855),
    [anon_sym_delete] = ACTIONS(855),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_await] = ACTIONS(855),
    [anon_sym_LBRACK] = ACTIONS(857),
    [anon_sym_if] = ACTIONS(855),
    [anon_sym_async] = ACTIONS(855),
    [anon_sym_QMARK_DOT] = ACTIONS(857),
    [anon_sym_BQUOTE] = ACTIONS(857),
    [anon_sym_DOLLARr] = ACTIONS(855),
    [anon_sym_PLUS_PLUS] = ACTIONS(857),
    [anon_sym_DASH_DASH] = ACTIONS(857),
    [anon_sym_new] = ACTIONS(855),
  },
  [STATE(131)] = {
    [sym_comment] = STATE(131),
    [aux_sym_array_type_repeat1] = STATE(134),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [anon_sym_Text] = ACTIONS(61),
    [anon_sym_Button] = ACTIONS(61),
    [anon_sym_Image] = ACTIONS(61),
    [anon_sym_TextInput] = ACTIONS(61),
    [anon_sym_TextArea] = ACTIONS(61),
    [anon_sym_Column] = ACTIONS(61),
    [anon_sym_Row] = ACTIONS(61),
    [anon_sym_Stack] = ACTIONS(61),
    [anon_sym_Flex] = ACTIONS(61),
    [anon_sym_Grid] = ACTIONS(61),
    [anon_sym_GridRow] = ACTIONS(61),
    [anon_sym_GridCol] = ACTIONS(61),
    [anon_sym_List] = ACTIONS(61),
    [anon_sym_ScrollList] = ACTIONS(61),
    [anon_sym_ListItem] = ACTIONS(61),
    [anon_sym_GridItem] = ACTIONS(61),
    [anon_sym_ForEach] = ACTIONS(61),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(640),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(132)] = {
    [sym_comment] = STATE(132),
    [sym_type_arguments] = STATE(164),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [anon_sym_Text] = ACTIONS(61),
    [anon_sym_Button] = ACTIONS(61),
    [anon_sym_Image] = ACTIONS(61),
    [anon_sym_TextInput] = ACTIONS(61),
    [anon_sym_TextArea] = ACTIONS(61),
    [anon_sym_Column] = ACTIONS(61),
    [anon_sym_Row] = ACTIONS(61),
    [anon_sym_Stack] = ACTIONS(61),
    [anon_sym_Flex] = ACTIONS(61),
    [anon_sym_Grid] = ACTIONS(61),
    [anon_sym_GridRow] = ACTIONS(61),
    [anon_sym_GridCol] = ACTIONS(61),
    [anon_sym_List] = ACTIONS(61),
    [anon_sym_ScrollList] = ACTIONS(61),
    [anon_sym_ListItem] = ACTIONS(61),
    [anon_sym_GridItem] = ACTIONS(61),
    [anon_sym_ForEach] = ACTIONS(61),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(637),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(133)] = {
    [sym_comment] = STATE(133),
    [aux_sym_qualified_type_repeat1] = STATE(135),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(767),
    [anon_sym_LBRACE] = ACTIONS(769),
    [anon_sym_RBRACE] = ACTIONS(769),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_as] = ACTIONS(767),
    [anon_sym_SEMI] = ACTIONS(769),
    [anon_sym_LPAREN] = ACTIONS(769),
    [anon_sym_DOT] = ACTIONS(769),
    [anon_sym_Text] = ACTIONS(767),
    [anon_sym_Button] = ACTIONS(767),
    [anon_sym_Image] = ACTIONS(767),
    [anon_sym_TextInput] = ACTIONS(767),
    [anon_sym_TextArea] = ACTIONS(767),
    [anon_sym_Column] = ACTIONS(767),
    [anon_sym_Row] = ACTIONS(767),
    [anon_sym_Stack] = ACTIONS(767),
    [anon_sym_Flex] = ACTIONS(767),
    [anon_sym_Grid] = ACTIONS(767),
    [anon_sym_GridRow] = ACTIONS(767),
    [anon_sym_GridCol] = ACTIONS(767),
    [anon_sym_List] = ACTIONS(767),
    [anon_sym_ScrollList] = ACTIONS(767),
    [anon_sym_ListItem] = ACTIONS(767),
    [anon_sym_GridItem] = ACTIONS(767),
    [anon_sym_ForEach] = ACTIONS(767),
    [sym_identifier] = ACTIONS(767),
    [anon_sym_DQUOTE] = ACTIONS(769),
    [anon_sym_SQUOTE] = ACTIONS(769),
    [anon_sym_DOLLAR] = ACTIONS(767),
    [sym_numeric_literal] = ACTIONS(769),
    [anon_sym_true] = ACTIONS(767),
    [anon_sym_false] = ACTIONS(767),
    [anon_sym_null] = ACTIONS(767),
    [anon_sym_PIPE_PIPE] = ACTIONS(769),
    [anon_sym_AMP_AMP] = ACTIONS(769),
    [anon_sym_PIPE] = ACTIONS(767),
    [anon_sym_CARET] = ACTIONS(769),
    [anon_sym_AMP] = ACTIONS(767),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(769),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(769),
    [anon_sym_LT] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(769),
    [anon_sym_GT_EQ] = ACTIONS(769),
    [anon_sym_instanceof] = ACTIONS(767),
    [anon_sym_in] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(769),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_GT_GT_GT] = ACTIONS(769),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(767),
    [anon_sym_PERCENT] = ACTIONS(769),
    [anon_sym_STAR_STAR] = ACTIONS(769),
    [anon_sym_BANG] = ACTIONS(767),
    [anon_sym_TILDE] = ACTIONS(769),
    [anon_sym_typeof] = ACTIONS(767),
    [anon_sym_void] = ACTIONS(767),
    [anon_sym_delete] = ACTIONS(767),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_await] = ACTIONS(767),
    [anon_sym_LBRACK] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(767),
    [anon_sym_async] = ACTIONS(767),
    [anon_sym_QMARK_DOT] = ACTIONS(769),
    [anon_sym_BQUOTE] = ACTIONS(769),
    [anon_sym_DOLLARr] = ACTIONS(767),
    [anon_sym_PLUS_PLUS] = ACTIONS(769),
    [anon_sym_DASH_DASH] = ACTIONS(769),
    [anon_sym_new] = ACTIONS(767),
  },
  [STATE(134)] = {
    [sym_comment] = STATE(134),
    [aux_sym_array_type_repeat1] = STATE(126),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(771),
    [anon_sym_LBRACE] = ACTIONS(773),
    [anon_sym_RBRACE] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(771),
    [anon_sym_as] = ACTIONS(771),
    [anon_sym_SEMI] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(773),
    [anon_sym_DOT] = ACTIONS(773),
    [anon_sym_Text] = ACTIONS(771),
    [anon_sym_Button] = ACTIONS(771),
    [anon_sym_Image] = ACTIONS(771),
    [anon_sym_TextInput] = ACTIONS(771),
    [anon_sym_TextArea] = ACTIONS(771),
    [anon_sym_Column] = ACTIONS(771),
    [anon_sym_Row] = ACTIONS(771),
    [anon_sym_Stack] = ACTIONS(771),
    [anon_sym_Flex] = ACTIONS(771),
    [anon_sym_Grid] = ACTIONS(771),
    [anon_sym_GridRow] = ACTIONS(771),
    [anon_sym_GridCol] = ACTIONS(771),
    [anon_sym_List] = ACTIONS(771),
    [anon_sym_ScrollList] = ACTIONS(771),
    [anon_sym_ListItem] = ACTIONS(771),
    [anon_sym_GridItem] = ACTIONS(771),
    [anon_sym_ForEach] = ACTIONS(771),
    [sym_identifier] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(773),
    [anon_sym_SQUOTE] = ACTIONS(773),
    [anon_sym_DOLLAR] = ACTIONS(771),
    [sym_numeric_literal] = ACTIONS(773),
    [anon_sym_true] = ACTIONS(771),
    [anon_sym_false] = ACTIONS(771),
    [anon_sym_null] = ACTIONS(771),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(771),
    [anon_sym_CARET] = ACTIONS(773),
    [anon_sym_AMP] = ACTIONS(771),
    [anon_sym_EQ_EQ] = ACTIONS(771),
    [anon_sym_BANG_EQ] = ACTIONS(771),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(773),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(773),
    [anon_sym_LT] = ACTIONS(771),
    [anon_sym_GT] = ACTIONS(771),
    [anon_sym_LT_EQ] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(773),
    [anon_sym_instanceof] = ACTIONS(771),
    [anon_sym_in] = ACTIONS(771),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(771),
    [anon_sym_GT_GT_GT] = ACTIONS(773),
    [anon_sym_PLUS] = ACTIONS(771),
    [anon_sym_DASH] = ACTIONS(771),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_STAR_STAR] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(771),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_typeof] = ACTIONS(771),
    [anon_sym_void] = ACTIONS(771),
    [anon_sym_delete] = ACTIONS(771),
    [anon_sym_QMARK] = ACTIONS(771),
    [anon_sym_await] = ACTIONS(771),
    [anon_sym_LBRACK] = ACTIONS(859),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_async] = ACTIONS(771),
    [anon_sym_QMARK_DOT] = ACTIONS(773),
    [anon_sym_BQUOTE] = ACTIONS(773),
    [anon_sym_DOLLARr] = ACTIONS(771),
    [anon_sym_PLUS_PLUS] = ACTIONS(773),
    [anon_sym_DASH_DASH] = ACTIONS(773),
    [anon_sym_new] = ACTIONS(771),
  },
  [STATE(135)] = {
    [sym_comment] = STATE(135),
    [aux_sym_qualified_type_repeat1] = STATE(135),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(862),
    [anon_sym_Text] = ACTIONS(778),
    [anon_sym_Button] = ACTIONS(778),
    [anon_sym_Image] = ACTIONS(778),
    [anon_sym_TextInput] = ACTIONS(778),
    [anon_sym_TextArea] = ACTIONS(778),
    [anon_sym_Column] = ACTIONS(778),
    [anon_sym_Row] = ACTIONS(778),
    [anon_sym_Stack] = ACTIONS(778),
    [anon_sym_Flex] = ACTIONS(778),
    [anon_sym_Grid] = ACTIONS(778),
    [anon_sym_GridRow] = ACTIONS(778),
    [anon_sym_GridCol] = ACTIONS(778),
    [anon_sym_List] = ACTIONS(778),
    [anon_sym_ScrollList] = ACTIONS(778),
    [anon_sym_ListItem] = ACTIONS(778),
    [anon_sym_GridItem] = ACTIONS(778),
    [anon_sym_ForEach] = ACTIONS(778),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(136)] = {
    [sym_comment] = STATE(136),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [anon_sym_Text] = ACTIONS(756),
    [anon_sym_Button] = ACTIONS(756),
    [anon_sym_Image] = ACTIONS(756),
    [anon_sym_TextInput] = ACTIONS(756),
    [anon_sym_TextArea] = ACTIONS(756),
    [anon_sym_Column] = ACTIONS(756),
    [anon_sym_Row] = ACTIONS(756),
    [anon_sym_Stack] = ACTIONS(756),
    [anon_sym_Flex] = ACTIONS(756),
    [anon_sym_Grid] = ACTIONS(756),
    [anon_sym_GridRow] = ACTIONS(756),
    [anon_sym_GridCol] = ACTIONS(756),
    [anon_sym_List] = ACTIONS(756),
    [anon_sym_ScrollList] = ACTIONS(756),
    [anon_sym_ListItem] = ACTIONS(756),
    [anon_sym_GridItem] = ACTIONS(756),
    [anon_sym_ForEach] = ACTIONS(756),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(758),
    [anon_sym_extends] = ACTIONS(756),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(137)] = {
    [sym_comment] = STATE(137),
    [sym_modifier_chain_expression] = STATE(144),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_RBRACE] = ACTIONS(867),
    [anon_sym_STAR] = ACTIONS(865),
    [anon_sym_as] = ACTIONS(865),
    [anon_sym_SEMI] = ACTIONS(867),
    [anon_sym_LPAREN] = ACTIONS(869),
    [anon_sym_DOT] = ACTIONS(111),
    [anon_sym_Text] = ACTIONS(865),
    [anon_sym_Button] = ACTIONS(865),
    [anon_sym_Image] = ACTIONS(865),
    [anon_sym_TextInput] = ACTIONS(865),
    [anon_sym_TextArea] = ACTIONS(865),
    [anon_sym_Column] = ACTIONS(865),
    [anon_sym_Row] = ACTIONS(865),
    [anon_sym_Stack] = ACTIONS(865),
    [anon_sym_Flex] = ACTIONS(865),
    [anon_sym_Grid] = ACTIONS(865),
    [anon_sym_GridRow] = ACTIONS(865),
    [anon_sym_GridCol] = ACTIONS(865),
    [anon_sym_List] = ACTIONS(865),
    [anon_sym_ScrollList] = ACTIONS(865),
    [anon_sym_ListItem] = ACTIONS(865),
    [anon_sym_GridItem] = ACTIONS(865),
    [anon_sym_ForEach] = ACTIONS(865),
    [sym_identifier] = ACTIONS(865),
    [anon_sym_DQUOTE] = ACTIONS(867),
    [anon_sym_SQUOTE] = ACTIONS(867),
    [anon_sym_DOLLAR] = ACTIONS(865),
    [sym_numeric_literal] = ACTIONS(867),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_null] = ACTIONS(865),
    [anon_sym_PIPE_PIPE] = ACTIONS(867),
    [anon_sym_AMP_AMP] = ACTIONS(867),
    [anon_sym_PIPE] = ACTIONS(865),
    [anon_sym_CARET] = ACTIONS(867),
    [anon_sym_AMP] = ACTIONS(865),
    [anon_sym_EQ_EQ] = ACTIONS(865),
    [anon_sym_BANG_EQ] = ACTIONS(865),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(867),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(867),
    [anon_sym_LT] = ACTIONS(865),
    [anon_sym_GT] = ACTIONS(865),
    [anon_sym_LT_EQ] = ACTIONS(867),
    [anon_sym_GT_EQ] = ACTIONS(867),
    [anon_sym_instanceof] = ACTIONS(865),
    [anon_sym_in] = ACTIONS(865),
    [anon_sym_LT_LT] = ACTIONS(867),
    [anon_sym_GT_GT] = ACTIONS(865),
    [anon_sym_GT_GT_GT] = ACTIONS(867),
    [anon_sym_PLUS] = ACTIONS(865),
    [anon_sym_DASH] = ACTIONS(865),
    [anon_sym_PERCENT] = ACTIONS(867),
    [anon_sym_STAR_STAR] = ACTIONS(867),
    [anon_sym_BANG] = ACTIONS(865),
    [anon_sym_TILDE] = ACTIONS(867),
    [anon_sym_typeof] = ACTIONS(865),
    [anon_sym_void] = ACTIONS(865),
    [anon_sym_delete] = ACTIONS(865),
    [anon_sym_QMARK] = ACTIONS(865),
    [anon_sym_await] = ACTIONS(865),
    [anon_sym_LBRACK] = ACTIONS(867),
    [anon_sym_if] = ACTIONS(865),
    [anon_sym_async] = ACTIONS(865),
    [anon_sym_QMARK_DOT] = ACTIONS(867),
    [anon_sym_BQUOTE] = ACTIONS(867),
    [anon_sym_DOLLARr] = ACTIONS(865),
    [anon_sym_PLUS_PLUS] = ACTIONS(867),
    [anon_sym_DASH_DASH] = ACTIONS(867),
    [anon_sym_new] = ACTIONS(865),
  },
  [STATE(138)] = {
    [sym_comment] = STATE(138),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(871),
    [anon_sym_LBRACE] = ACTIONS(873),
    [anon_sym_RBRACE] = ACTIONS(873),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_as] = ACTIONS(871),
    [anon_sym_SEMI] = ACTIONS(873),
    [anon_sym_LPAREN] = ACTIONS(873),
    [anon_sym_DOT] = ACTIONS(873),
    [anon_sym_Text] = ACTIONS(871),
    [anon_sym_Button] = ACTIONS(871),
    [anon_sym_Image] = ACTIONS(871),
    [anon_sym_TextInput] = ACTIONS(871),
    [anon_sym_TextArea] = ACTIONS(871),
    [anon_sym_Column] = ACTIONS(871),
    [anon_sym_Row] = ACTIONS(871),
    [anon_sym_Stack] = ACTIONS(871),
    [anon_sym_Flex] = ACTIONS(871),
    [anon_sym_Grid] = ACTIONS(871),
    [anon_sym_GridRow] = ACTIONS(871),
    [anon_sym_GridCol] = ACTIONS(871),
    [anon_sym_List] = ACTIONS(871),
    [anon_sym_ScrollList] = ACTIONS(871),
    [anon_sym_ListItem] = ACTIONS(871),
    [anon_sym_GridItem] = ACTIONS(871),
    [anon_sym_ForEach] = ACTIONS(871),
    [sym_identifier] = ACTIONS(871),
    [anon_sym_DQUOTE] = ACTIONS(873),
    [anon_sym_SQUOTE] = ACTIONS(873),
    [anon_sym_DOLLAR] = ACTIONS(871),
    [sym_numeric_literal] = ACTIONS(873),
    [anon_sym_true] = ACTIONS(871),
    [anon_sym_false] = ACTIONS(871),
    [anon_sym_null] = ACTIONS(871),
    [anon_sym_PIPE_PIPE] = ACTIONS(873),
    [anon_sym_AMP_AMP] = ACTIONS(873),
    [anon_sym_PIPE] = ACTIONS(871),
    [anon_sym_CARET] = ACTIONS(873),
    [anon_sym_AMP] = ACTIONS(871),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(873),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(873),
    [anon_sym_LT] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(873),
    [anon_sym_GT_EQ] = ACTIONS(873),
    [anon_sym_instanceof] = ACTIONS(871),
    [anon_sym_in] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(873),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_GT_GT_GT] = ACTIONS(873),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(871),
    [anon_sym_PERCENT] = ACTIONS(873),
    [anon_sym_STAR_STAR] = ACTIONS(873),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_TILDE] = ACTIONS(873),
    [anon_sym_typeof] = ACTIONS(871),
    [anon_sym_void] = ACTIONS(871),
    [anon_sym_delete] = ACTIONS(871),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_await] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(871),
    [anon_sym_async] = ACTIONS(871),
    [anon_sym_QMARK_DOT] = ACTIONS(873),
    [anon_sym_BQUOTE] = ACTIONS(873),
    [anon_sym_DOLLARr] = ACTIONS(871),
    [anon_sym_PLUS_PLUS] = ACTIONS(873),
    [anon_sym_DASH_DASH] = ACTIONS(873),
    [anon_sym_new] = ACTIONS(871),
  },
  [STATE(139)] = {
    [sym_comment] = STATE(139),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(723),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(721),
    [anon_sym_STAR] = ACTIONS(723),
    [anon_sym_as] = ACTIONS(723),
    [anon_sym_SEMI] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(721),
    [anon_sym_DOT] = ACTIONS(721),
    [anon_sym_Text] = ACTIONS(723),
    [anon_sym_Button] = ACTIONS(723),
    [anon_sym_Image] = ACTIONS(723),
    [anon_sym_TextInput] = ACTIONS(723),
    [anon_sym_TextArea] = ACTIONS(723),
    [anon_sym_Column] = ACTIONS(723),
    [anon_sym_Row] = ACTIONS(723),
    [anon_sym_Stack] = ACTIONS(723),
    [anon_sym_Flex] = ACTIONS(723),
    [anon_sym_Grid] = ACTIONS(723),
    [anon_sym_GridRow] = ACTIONS(723),
    [anon_sym_GridCol] = ACTIONS(723),
    [anon_sym_List] = ACTIONS(723),
    [anon_sym_ScrollList] = ACTIONS(723),
    [anon_sym_ListItem] = ACTIONS(723),
    [anon_sym_GridItem] = ACTIONS(723),
    [anon_sym_ForEach] = ACTIONS(723),
    [sym_identifier] = ACTIONS(723),
    [anon_sym_DQUOTE] = ACTIONS(721),
    [anon_sym_SQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR] = ACTIONS(723),
    [sym_numeric_literal] = ACTIONS(721),
    [anon_sym_true] = ACTIONS(723),
    [anon_sym_false] = ACTIONS(723),
    [anon_sym_null] = ACTIONS(723),
    [anon_sym_PIPE_PIPE] = ACTIONS(721),
    [anon_sym_AMP_AMP] = ACTIONS(721),
    [anon_sym_PIPE] = ACTIONS(723),
    [anon_sym_CARET] = ACTIONS(721),
    [anon_sym_AMP] = ACTIONS(723),
    [anon_sym_EQ_EQ] = ACTIONS(723),
    [anon_sym_BANG_EQ] = ACTIONS(723),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(721),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(721),
    [anon_sym_LT] = ACTIONS(723),
    [anon_sym_GT] = ACTIONS(723),
    [anon_sym_LT_EQ] = ACTIONS(721),
    [anon_sym_GT_EQ] = ACTIONS(721),
    [anon_sym_instanceof] = ACTIONS(723),
    [anon_sym_in] = ACTIONS(723),
    [anon_sym_LT_LT] = ACTIONS(721),
    [anon_sym_GT_GT] = ACTIONS(723),
    [anon_sym_GT_GT_GT] = ACTIONS(721),
    [anon_sym_PLUS] = ACTIONS(723),
    [anon_sym_DASH] = ACTIONS(723),
    [anon_sym_PERCENT] = ACTIONS(721),
    [anon_sym_STAR_STAR] = ACTIONS(721),
    [anon_sym_BANG] = ACTIONS(723),
    [anon_sym_TILDE] = ACTIONS(721),
    [anon_sym_typeof] = ACTIONS(723),
    [anon_sym_void] = ACTIONS(723),
    [anon_sym_delete] = ACTIONS(723),
    [anon_sym_QMARK] = ACTIONS(723),
    [anon_sym_await] = ACTIONS(723),
    [anon_sym_LBRACK] = ACTIONS(721),
    [anon_sym_if] = ACTIONS(723),
    [anon_sym_async] = ACTIONS(723),
    [anon_sym_QMARK_DOT] = ACTIONS(721),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLARr] = ACTIONS(723),
    [anon_sym_PLUS_PLUS] = ACTIONS(721),
    [anon_sym_DASH_DASH] = ACTIONS(721),
    [anon_sym_new] = ACTIONS(723),
  },
  [STATE(140)] = {
    [sym_comment] = STATE(140),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(875),
    [anon_sym_LBRACE] = ACTIONS(877),
    [anon_sym_RBRACE] = ACTIONS(877),
    [anon_sym_STAR] = ACTIONS(875),
    [anon_sym_as] = ACTIONS(875),
    [anon_sym_SEMI] = ACTIONS(877),
    [anon_sym_LPAREN] = ACTIONS(877),
    [anon_sym_DOT] = ACTIONS(877),
    [anon_sym_Text] = ACTIONS(875),
    [anon_sym_Button] = ACTIONS(875),
    [anon_sym_Image] = ACTIONS(875),
    [anon_sym_TextInput] = ACTIONS(875),
    [anon_sym_TextArea] = ACTIONS(875),
    [anon_sym_Column] = ACTIONS(875),
    [anon_sym_Row] = ACTIONS(875),
    [anon_sym_Stack] = ACTIONS(875),
    [anon_sym_Flex] = ACTIONS(875),
    [anon_sym_Grid] = ACTIONS(875),
    [anon_sym_GridRow] = ACTIONS(875),
    [anon_sym_GridCol] = ACTIONS(875),
    [anon_sym_List] = ACTIONS(875),
    [anon_sym_ScrollList] = ACTIONS(875),
    [anon_sym_ListItem] = ACTIONS(875),
    [anon_sym_GridItem] = ACTIONS(875),
    [anon_sym_ForEach] = ACTIONS(875),
    [sym_identifier] = ACTIONS(875),
    [anon_sym_DQUOTE] = ACTIONS(877),
    [anon_sym_SQUOTE] = ACTIONS(877),
    [anon_sym_DOLLAR] = ACTIONS(875),
    [sym_numeric_literal] = ACTIONS(877),
    [anon_sym_true] = ACTIONS(875),
    [anon_sym_false] = ACTIONS(875),
    [anon_sym_null] = ACTIONS(875),
    [anon_sym_PIPE_PIPE] = ACTIONS(877),
    [anon_sym_AMP_AMP] = ACTIONS(877),
    [anon_sym_PIPE] = ACTIONS(875),
    [anon_sym_CARET] = ACTIONS(877),
    [anon_sym_AMP] = ACTIONS(875),
    [anon_sym_EQ_EQ] = ACTIONS(875),
    [anon_sym_BANG_EQ] = ACTIONS(875),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(877),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(877),
    [anon_sym_LT] = ACTIONS(875),
    [anon_sym_GT] = ACTIONS(875),
    [anon_sym_LT_EQ] = ACTIONS(877),
    [anon_sym_GT_EQ] = ACTIONS(877),
    [anon_sym_instanceof] = ACTIONS(875),
    [anon_sym_in] = ACTIONS(875),
    [anon_sym_LT_LT] = ACTIONS(877),
    [anon_sym_GT_GT] = ACTIONS(875),
    [anon_sym_GT_GT_GT] = ACTIONS(877),
    [anon_sym_PLUS] = ACTIONS(875),
    [anon_sym_DASH] = ACTIONS(875),
    [anon_sym_PERCENT] = ACTIONS(877),
    [anon_sym_STAR_STAR] = ACTIONS(877),
    [anon_sym_BANG] = ACTIONS(875),
    [anon_sym_TILDE] = ACTIONS(877),
    [anon_sym_typeof] = ACTIONS(875),
    [anon_sym_void] = ACTIONS(875),
    [anon_sym_delete] = ACTIONS(875),
    [anon_sym_QMARK] = ACTIONS(875),
    [anon_sym_await] = ACTIONS(875),
    [anon_sym_LBRACK] = ACTIONS(877),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_async] = ACTIONS(875),
    [anon_sym_QMARK_DOT] = ACTIONS(877),
    [anon_sym_BQUOTE] = ACTIONS(877),
    [anon_sym_DOLLARr] = ACTIONS(875),
    [anon_sym_PLUS_PLUS] = ACTIONS(877),
    [anon_sym_DASH_DASH] = ACTIONS(877),
    [anon_sym_new] = ACTIONS(875),
  },
  [STATE(141)] = {
    [sym_comment] = STATE(141),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_DOT] = ACTIONS(37),
    [anon_sym_Text] = ACTIONS(35),
    [anon_sym_Button] = ACTIONS(35),
    [anon_sym_Image] = ACTIONS(35),
    [anon_sym_TextInput] = ACTIONS(35),
    [anon_sym_TextArea] = ACTIONS(35),
    [anon_sym_Column] = ACTIONS(35),
    [anon_sym_Row] = ACTIONS(35),
    [anon_sym_Stack] = ACTIONS(35),
    [anon_sym_Flex] = ACTIONS(35),
    [anon_sym_Grid] = ACTIONS(35),
    [anon_sym_GridRow] = ACTIONS(35),
    [anon_sym_GridCol] = ACTIONS(35),
    [anon_sym_List] = ACTIONS(35),
    [anon_sym_ScrollList] = ACTIONS(35),
    [anon_sym_ListItem] = ACTIONS(35),
    [anon_sym_GridItem] = ACTIONS(35),
    [anon_sym_ForEach] = ACTIONS(35),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(37),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(37),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(37),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(37),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(142)] = {
    [sym_comment] = STATE(142),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(879),
    [anon_sym_LBRACE] = ACTIONS(881),
    [anon_sym_RBRACE] = ACTIONS(881),
    [anon_sym_STAR] = ACTIONS(879),
    [anon_sym_as] = ACTIONS(879),
    [anon_sym_SEMI] = ACTIONS(881),
    [anon_sym_LPAREN] = ACTIONS(881),
    [anon_sym_DOT] = ACTIONS(881),
    [anon_sym_Text] = ACTIONS(879),
    [anon_sym_Button] = ACTIONS(879),
    [anon_sym_Image] = ACTIONS(879),
    [anon_sym_TextInput] = ACTIONS(879),
    [anon_sym_TextArea] = ACTIONS(879),
    [anon_sym_Column] = ACTIONS(879),
    [anon_sym_Row] = ACTIONS(879),
    [anon_sym_Stack] = ACTIONS(879),
    [anon_sym_Flex] = ACTIONS(879),
    [anon_sym_Grid] = ACTIONS(879),
    [anon_sym_GridRow] = ACTIONS(879),
    [anon_sym_GridCol] = ACTIONS(879),
    [anon_sym_List] = ACTIONS(879),
    [anon_sym_ScrollList] = ACTIONS(879),
    [anon_sym_ListItem] = ACTIONS(879),
    [anon_sym_GridItem] = ACTIONS(879),
    [anon_sym_ForEach] = ACTIONS(879),
    [sym_identifier] = ACTIONS(879),
    [anon_sym_DQUOTE] = ACTIONS(881),
    [anon_sym_SQUOTE] = ACTIONS(881),
    [anon_sym_DOLLAR] = ACTIONS(879),
    [sym_numeric_literal] = ACTIONS(881),
    [anon_sym_true] = ACTIONS(879),
    [anon_sym_false] = ACTIONS(879),
    [anon_sym_null] = ACTIONS(879),
    [anon_sym_PIPE_PIPE] = ACTIONS(881),
    [anon_sym_AMP_AMP] = ACTIONS(881),
    [anon_sym_PIPE] = ACTIONS(879),
    [anon_sym_CARET] = ACTIONS(881),
    [anon_sym_AMP] = ACTIONS(879),
    [anon_sym_EQ_EQ] = ACTIONS(879),
    [anon_sym_BANG_EQ] = ACTIONS(879),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(881),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(881),
    [anon_sym_LT] = ACTIONS(879),
    [anon_sym_GT] = ACTIONS(879),
    [anon_sym_LT_EQ] = ACTIONS(881),
    [anon_sym_GT_EQ] = ACTIONS(881),
    [anon_sym_instanceof] = ACTIONS(879),
    [anon_sym_in] = ACTIONS(879),
    [anon_sym_LT_LT] = ACTIONS(881),
    [anon_sym_GT_GT] = ACTIONS(879),
    [anon_sym_GT_GT_GT] = ACTIONS(881),
    [anon_sym_PLUS] = ACTIONS(879),
    [anon_sym_DASH] = ACTIONS(879),
    [anon_sym_PERCENT] = ACTIONS(881),
    [anon_sym_STAR_STAR] = ACTIONS(881),
    [anon_sym_BANG] = ACTIONS(879),
    [anon_sym_TILDE] = ACTIONS(881),
    [anon_sym_typeof] = ACTIONS(879),
    [anon_sym_void] = ACTIONS(879),
    [anon_sym_delete] = ACTIONS(879),
    [anon_sym_QMARK] = ACTIONS(879),
    [anon_sym_await] = ACTIONS(879),
    [anon_sym_LBRACK] = ACTIONS(881),
    [anon_sym_if] = ACTIONS(879),
    [anon_sym_async] = ACTIONS(879),
    [anon_sym_QMARK_DOT] = ACTIONS(881),
    [anon_sym_BQUOTE] = ACTIONS(881),
    [anon_sym_DOLLARr] = ACTIONS(879),
    [anon_sym_PLUS_PLUS] = ACTIONS(881),
    [anon_sym_DASH_DASH] = ACTIONS(881),
    [anon_sym_new] = ACTIONS(879),
  },
  [STATE(143)] = {
    [sym_comment] = STATE(143),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(883),
    [anon_sym_LBRACE] = ACTIONS(885),
    [anon_sym_RBRACE] = ACTIONS(885),
    [anon_sym_STAR] = ACTIONS(883),
    [anon_sym_as] = ACTIONS(883),
    [anon_sym_SEMI] = ACTIONS(885),
    [anon_sym_LPAREN] = ACTIONS(885),
    [anon_sym_DOT] = ACTIONS(885),
    [anon_sym_Text] = ACTIONS(883),
    [anon_sym_Button] = ACTIONS(883),
    [anon_sym_Image] = ACTIONS(883),
    [anon_sym_TextInput] = ACTIONS(883),
    [anon_sym_TextArea] = ACTIONS(883),
    [anon_sym_Column] = ACTIONS(883),
    [anon_sym_Row] = ACTIONS(883),
    [anon_sym_Stack] = ACTIONS(883),
    [anon_sym_Flex] = ACTIONS(883),
    [anon_sym_Grid] = ACTIONS(883),
    [anon_sym_GridRow] = ACTIONS(883),
    [anon_sym_GridCol] = ACTIONS(883),
    [anon_sym_List] = ACTIONS(883),
    [anon_sym_ScrollList] = ACTIONS(883),
    [anon_sym_ListItem] = ACTIONS(883),
    [anon_sym_GridItem] = ACTIONS(883),
    [anon_sym_ForEach] = ACTIONS(883),
    [sym_identifier] = ACTIONS(883),
    [anon_sym_DQUOTE] = ACTIONS(885),
    [anon_sym_SQUOTE] = ACTIONS(885),
    [anon_sym_DOLLAR] = ACTIONS(883),
    [sym_numeric_literal] = ACTIONS(885),
    [anon_sym_true] = ACTIONS(883),
    [anon_sym_false] = ACTIONS(883),
    [anon_sym_null] = ACTIONS(883),
    [anon_sym_PIPE_PIPE] = ACTIONS(885),
    [anon_sym_AMP_AMP] = ACTIONS(885),
    [anon_sym_PIPE] = ACTIONS(883),
    [anon_sym_CARET] = ACTIONS(885),
    [anon_sym_AMP] = ACTIONS(883),
    [anon_sym_EQ_EQ] = ACTIONS(883),
    [anon_sym_BANG_EQ] = ACTIONS(883),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(885),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(885),
    [anon_sym_LT] = ACTIONS(883),
    [anon_sym_GT] = ACTIONS(883),
    [anon_sym_LT_EQ] = ACTIONS(885),
    [anon_sym_GT_EQ] = ACTIONS(885),
    [anon_sym_instanceof] = ACTIONS(883),
    [anon_sym_in] = ACTIONS(883),
    [anon_sym_LT_LT] = ACTIONS(885),
    [anon_sym_GT_GT] = ACTIONS(883),
    [anon_sym_GT_GT_GT] = ACTIONS(885),
    [anon_sym_PLUS] = ACTIONS(883),
    [anon_sym_DASH] = ACTIONS(883),
    [anon_sym_PERCENT] = ACTIONS(885),
    [anon_sym_STAR_STAR] = ACTIONS(885),
    [anon_sym_BANG] = ACTIONS(883),
    [anon_sym_TILDE] = ACTIONS(885),
    [anon_sym_typeof] = ACTIONS(883),
    [anon_sym_void] = ACTIONS(883),
    [anon_sym_delete] = ACTIONS(883),
    [anon_sym_QMARK] = ACTIONS(883),
    [anon_sym_await] = ACTIONS(883),
    [anon_sym_LBRACK] = ACTIONS(885),
    [anon_sym_if] = ACTIONS(883),
    [anon_sym_async] = ACTIONS(883),
    [anon_sym_QMARK_DOT] = ACTIONS(885),
    [anon_sym_BQUOTE] = ACTIONS(885),
    [anon_sym_DOLLARr] = ACTIONS(883),
    [anon_sym_PLUS_PLUS] = ACTIONS(885),
    [anon_sym_DASH_DASH] = ACTIONS(885),
    [anon_sym_new] = ACTIONS(883),
  },
  [STATE(144)] = {
    [sym_comment] = STATE(144),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(887),
    [anon_sym_LBRACE] = ACTIONS(889),
    [anon_sym_RBRACE] = ACTIONS(889),
    [anon_sym_STAR] = ACTIONS(887),
    [anon_sym_as] = ACTIONS(887),
    [anon_sym_SEMI] = ACTIONS(889),
    [anon_sym_LPAREN] = ACTIONS(889),
    [anon_sym_DOT] = ACTIONS(889),
    [anon_sym_Text] = ACTIONS(887),
    [anon_sym_Button] = ACTIONS(887),
    [anon_sym_Image] = ACTIONS(887),
    [anon_sym_TextInput] = ACTIONS(887),
    [anon_sym_TextArea] = ACTIONS(887),
    [anon_sym_Column] = ACTIONS(887),
    [anon_sym_Row] = ACTIONS(887),
    [anon_sym_Stack] = ACTIONS(887),
    [anon_sym_Flex] = ACTIONS(887),
    [anon_sym_Grid] = ACTIONS(887),
    [anon_sym_GridRow] = ACTIONS(887),
    [anon_sym_GridCol] = ACTIONS(887),
    [anon_sym_List] = ACTIONS(887),
    [anon_sym_ScrollList] = ACTIONS(887),
    [anon_sym_ListItem] = ACTIONS(887),
    [anon_sym_GridItem] = ACTIONS(887),
    [anon_sym_ForEach] = ACTIONS(887),
    [sym_identifier] = ACTIONS(887),
    [anon_sym_DQUOTE] = ACTIONS(889),
    [anon_sym_SQUOTE] = ACTIONS(889),
    [anon_sym_DOLLAR] = ACTIONS(887),
    [sym_numeric_literal] = ACTIONS(889),
    [anon_sym_true] = ACTIONS(887),
    [anon_sym_false] = ACTIONS(887),
    [anon_sym_null] = ACTIONS(887),
    [anon_sym_PIPE_PIPE] = ACTIONS(889),
    [anon_sym_AMP_AMP] = ACTIONS(889),
    [anon_sym_PIPE] = ACTIONS(887),
    [anon_sym_CARET] = ACTIONS(889),
    [anon_sym_AMP] = ACTIONS(887),
    [anon_sym_EQ_EQ] = ACTIONS(887),
    [anon_sym_BANG_EQ] = ACTIONS(887),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(889),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(889),
    [anon_sym_LT] = ACTIONS(887),
    [anon_sym_GT] = ACTIONS(887),
    [anon_sym_LT_EQ] = ACTIONS(889),
    [anon_sym_GT_EQ] = ACTIONS(889),
    [anon_sym_instanceof] = ACTIONS(887),
    [anon_sym_in] = ACTIONS(887),
    [anon_sym_LT_LT] = ACTIONS(889),
    [anon_sym_GT_GT] = ACTIONS(887),
    [anon_sym_GT_GT_GT] = ACTIONS(889),
    [anon_sym_PLUS] = ACTIONS(887),
    [anon_sym_DASH] = ACTIONS(887),
    [anon_sym_PERCENT] = ACTIONS(889),
    [anon_sym_STAR_STAR] = ACTIONS(889),
    [anon_sym_BANG] = ACTIONS(887),
    [anon_sym_TILDE] = ACTIONS(889),
    [anon_sym_typeof] = ACTIONS(887),
    [anon_sym_void] = ACTIONS(887),
    [anon_sym_delete] = ACTIONS(887),
    [anon_sym_QMARK] = ACTIONS(887),
    [anon_sym_await] = ACTIONS(887),
    [anon_sym_LBRACK] = ACTIONS(889),
    [anon_sym_if] = ACTIONS(887),
    [anon_sym_async] = ACTIONS(887),
    [anon_sym_QMARK_DOT] = ACTIONS(889),
    [anon_sym_BQUOTE] = ACTIONS(889),
    [anon_sym_DOLLARr] = ACTIONS(887),
    [anon_sym_PLUS_PLUS] = ACTIONS(889),
    [anon_sym_DASH_DASH] = ACTIONS(889),
    [anon_sym_new] = ACTIONS(887),
  },
  [STATE(145)] = {
    [sym_comment] = STATE(145),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(738),
    [anon_sym_LBRACE] = ACTIONS(740),
    [anon_sym_RBRACE] = ACTIONS(740),
    [anon_sym_STAR] = ACTIONS(738),
    [anon_sym_as] = ACTIONS(738),
    [anon_sym_SEMI] = ACTIONS(740),
    [anon_sym_LPAREN] = ACTIONS(740),
    [anon_sym_DOT] = ACTIONS(740),
    [anon_sym_Text] = ACTIONS(738),
    [anon_sym_Button] = ACTIONS(738),
    [anon_sym_Image] = ACTIONS(738),
    [anon_sym_TextInput] = ACTIONS(738),
    [anon_sym_TextArea] = ACTIONS(738),
    [anon_sym_Column] = ACTIONS(738),
    [anon_sym_Row] = ACTIONS(738),
    [anon_sym_Stack] = ACTIONS(738),
    [anon_sym_Flex] = ACTIONS(738),
    [anon_sym_Grid] = ACTIONS(738),
    [anon_sym_GridRow] = ACTIONS(738),
    [anon_sym_GridCol] = ACTIONS(738),
    [anon_sym_List] = ACTIONS(738),
    [anon_sym_ScrollList] = ACTIONS(738),
    [anon_sym_ListItem] = ACTIONS(738),
    [anon_sym_GridItem] = ACTIONS(738),
    [anon_sym_ForEach] = ACTIONS(738),
    [sym_identifier] = ACTIONS(738),
    [anon_sym_DQUOTE] = ACTIONS(740),
    [anon_sym_SQUOTE] = ACTIONS(740),
    [anon_sym_DOLLAR] = ACTIONS(738),
    [sym_numeric_literal] = ACTIONS(740),
    [anon_sym_true] = ACTIONS(738),
    [anon_sym_false] = ACTIONS(738),
    [anon_sym_null] = ACTIONS(738),
    [anon_sym_PIPE_PIPE] = ACTIONS(740),
    [anon_sym_AMP_AMP] = ACTIONS(740),
    [anon_sym_PIPE] = ACTIONS(738),
    [anon_sym_CARET] = ACTIONS(740),
    [anon_sym_AMP] = ACTIONS(738),
    [anon_sym_EQ_EQ] = ACTIONS(738),
    [anon_sym_BANG_EQ] = ACTIONS(738),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(740),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(738),
    [anon_sym_GT] = ACTIONS(738),
    [anon_sym_LT_EQ] = ACTIONS(740),
    [anon_sym_GT_EQ] = ACTIONS(740),
    [anon_sym_instanceof] = ACTIONS(738),
    [anon_sym_in] = ACTIONS(738),
    [anon_sym_LT_LT] = ACTIONS(740),
    [anon_sym_GT_GT] = ACTIONS(738),
    [anon_sym_GT_GT_GT] = ACTIONS(740),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_PERCENT] = ACTIONS(740),
    [anon_sym_STAR_STAR] = ACTIONS(740),
    [anon_sym_BANG] = ACTIONS(738),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_typeof] = ACTIONS(738),
    [anon_sym_void] = ACTIONS(738),
    [anon_sym_delete] = ACTIONS(738),
    [anon_sym_QMARK] = ACTIONS(738),
    [anon_sym_await] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_if] = ACTIONS(738),
    [anon_sym_async] = ACTIONS(738),
    [anon_sym_QMARK_DOT] = ACTIONS(740),
    [anon_sym_BQUOTE] = ACTIONS(740),
    [anon_sym_DOLLARr] = ACTIONS(738),
    [anon_sym_PLUS_PLUS] = ACTIONS(740),
    [anon_sym_DASH_DASH] = ACTIONS(740),
    [anon_sym_new] = ACTIONS(738),
  },
  [STATE(146)] = {
    [sym_comment] = STATE(146),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(891),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(891),
    [anon_sym_as] = ACTIONS(891),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(893),
    [anon_sym_Text] = ACTIONS(891),
    [anon_sym_Button] = ACTIONS(891),
    [anon_sym_Image] = ACTIONS(891),
    [anon_sym_TextInput] = ACTIONS(891),
    [anon_sym_TextArea] = ACTIONS(891),
    [anon_sym_Column] = ACTIONS(891),
    [anon_sym_Row] = ACTIONS(891),
    [anon_sym_Stack] = ACTIONS(891),
    [anon_sym_Flex] = ACTIONS(891),
    [anon_sym_Grid] = ACTIONS(891),
    [anon_sym_GridRow] = ACTIONS(891),
    [anon_sym_GridCol] = ACTIONS(891),
    [anon_sym_List] = ACTIONS(891),
    [anon_sym_ScrollList] = ACTIONS(891),
    [anon_sym_ListItem] = ACTIONS(891),
    [anon_sym_GridItem] = ACTIONS(891),
    [anon_sym_ForEach] = ACTIONS(891),
    [sym_identifier] = ACTIONS(891),
    [anon_sym_DQUOTE] = ACTIONS(893),
    [anon_sym_SQUOTE] = ACTIONS(893),
    [anon_sym_DOLLAR] = ACTIONS(891),
    [sym_numeric_literal] = ACTIONS(893),
    [anon_sym_true] = ACTIONS(891),
    [anon_sym_false] = ACTIONS(891),
    [anon_sym_null] = ACTIONS(891),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_PIPE] = ACTIONS(891),
    [anon_sym_CARET] = ACTIONS(893),
    [anon_sym_AMP] = ACTIONS(891),
    [anon_sym_EQ_EQ] = ACTIONS(891),
    [anon_sym_BANG_EQ] = ACTIONS(891),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(891),
    [anon_sym_GT] = ACTIONS(891),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_instanceof] = ACTIONS(891),
    [anon_sym_in] = ACTIONS(891),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(891),
    [anon_sym_GT_GT_GT] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(891),
    [anon_sym_DASH] = ACTIONS(891),
    [anon_sym_PERCENT] = ACTIONS(893),
    [anon_sym_STAR_STAR] = ACTIONS(893),
    [anon_sym_BANG] = ACTIONS(891),
    [anon_sym_TILDE] = ACTIONS(893),
    [anon_sym_typeof] = ACTIONS(891),
    [anon_sym_void] = ACTIONS(891),
    [anon_sym_delete] = ACTIONS(891),
    [anon_sym_QMARK] = ACTIONS(891),
    [anon_sym_await] = ACTIONS(891),
    [anon_sym_LBRACK] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(891),
    [anon_sym_async] = ACTIONS(891),
    [anon_sym_QMARK_DOT] = ACTIONS(893),
    [anon_sym_BQUOTE] = ACTIONS(893),
    [anon_sym_DOLLARr] = ACTIONS(891),
    [anon_sym_PLUS_PLUS] = ACTIONS(893),
    [anon_sym_DASH_DASH] = ACTIONS(893),
    [anon_sym_new] = ACTIONS(891),
  },
  [STATE(147)] = {
    [sym_comment] = STATE(147),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_LBRACE] = ACTIONS(897),
    [anon_sym_RBRACE] = ACTIONS(897),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_as] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(897),
    [anon_sym_LPAREN] = ACTIONS(897),
    [anon_sym_DOT] = ACTIONS(897),
    [anon_sym_Text] = ACTIONS(895),
    [anon_sym_Button] = ACTIONS(895),
    [anon_sym_Image] = ACTIONS(895),
    [anon_sym_TextInput] = ACTIONS(895),
    [anon_sym_TextArea] = ACTIONS(895),
    [anon_sym_Column] = ACTIONS(895),
    [anon_sym_Row] = ACTIONS(895),
    [anon_sym_Stack] = ACTIONS(895),
    [anon_sym_Flex] = ACTIONS(895),
    [anon_sym_Grid] = ACTIONS(895),
    [anon_sym_GridRow] = ACTIONS(895),
    [anon_sym_GridCol] = ACTIONS(895),
    [anon_sym_List] = ACTIONS(895),
    [anon_sym_ScrollList] = ACTIONS(895),
    [anon_sym_ListItem] = ACTIONS(895),
    [anon_sym_GridItem] = ACTIONS(895),
    [anon_sym_ForEach] = ACTIONS(895),
    [sym_identifier] = ACTIONS(895),
    [anon_sym_DQUOTE] = ACTIONS(897),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DOLLAR] = ACTIONS(895),
    [sym_numeric_literal] = ACTIONS(897),
    [anon_sym_true] = ACTIONS(895),
    [anon_sym_false] = ACTIONS(895),
    [anon_sym_null] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(897),
    [anon_sym_AMP_AMP] = ACTIONS(897),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(897),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(895),
    [anon_sym_BANG_EQ] = ACTIONS(895),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(897),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(897),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_LT_EQ] = ACTIONS(897),
    [anon_sym_GT_EQ] = ACTIONS(897),
    [anon_sym_instanceof] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(897),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_GT_GT_GT] = ACTIONS(897),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(897),
    [anon_sym_STAR_STAR] = ACTIONS(897),
    [anon_sym_BANG] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(897),
    [anon_sym_typeof] = ACTIONS(895),
    [anon_sym_void] = ACTIONS(895),
    [anon_sym_delete] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(895),
    [anon_sym_await] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(897),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_async] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(897),
    [anon_sym_BQUOTE] = ACTIONS(897),
    [anon_sym_DOLLARr] = ACTIONS(895),
    [anon_sym_PLUS_PLUS] = ACTIONS(897),
    [anon_sym_DASH_DASH] = ACTIONS(897),
    [anon_sym_new] = ACTIONS(895),
  },
  [STATE(148)] = {
    [sym_comment] = STATE(148),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(899),
    [anon_sym_LBRACE] = ACTIONS(901),
    [anon_sym_RBRACE] = ACTIONS(901),
    [anon_sym_STAR] = ACTIONS(899),
    [anon_sym_as] = ACTIONS(899),
    [anon_sym_SEMI] = ACTIONS(901),
    [anon_sym_LPAREN] = ACTIONS(901),
    [anon_sym_DOT] = ACTIONS(901),
    [anon_sym_Text] = ACTIONS(899),
    [anon_sym_Button] = ACTIONS(899),
    [anon_sym_Image] = ACTIONS(899),
    [anon_sym_TextInput] = ACTIONS(899),
    [anon_sym_TextArea] = ACTIONS(899),
    [anon_sym_Column] = ACTIONS(899),
    [anon_sym_Row] = ACTIONS(899),
    [anon_sym_Stack] = ACTIONS(899),
    [anon_sym_Flex] = ACTIONS(899),
    [anon_sym_Grid] = ACTIONS(899),
    [anon_sym_GridRow] = ACTIONS(899),
    [anon_sym_GridCol] = ACTIONS(899),
    [anon_sym_List] = ACTIONS(899),
    [anon_sym_ScrollList] = ACTIONS(899),
    [anon_sym_ListItem] = ACTIONS(899),
    [anon_sym_GridItem] = ACTIONS(899),
    [anon_sym_ForEach] = ACTIONS(899),
    [sym_identifier] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [anon_sym_SQUOTE] = ACTIONS(901),
    [anon_sym_DOLLAR] = ACTIONS(899),
    [sym_numeric_literal] = ACTIONS(901),
    [anon_sym_true] = ACTIONS(899),
    [anon_sym_false] = ACTIONS(899),
    [anon_sym_null] = ACTIONS(899),
    [anon_sym_PIPE_PIPE] = ACTIONS(901),
    [anon_sym_AMP_AMP] = ACTIONS(901),
    [anon_sym_PIPE] = ACTIONS(899),
    [anon_sym_CARET] = ACTIONS(901),
    [anon_sym_AMP] = ACTIONS(899),
    [anon_sym_EQ_EQ] = ACTIONS(899),
    [anon_sym_BANG_EQ] = ACTIONS(899),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(901),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(901),
    [anon_sym_LT] = ACTIONS(899),
    [anon_sym_GT] = ACTIONS(899),
    [anon_sym_LT_EQ] = ACTIONS(901),
    [anon_sym_GT_EQ] = ACTIONS(901),
    [anon_sym_instanceof] = ACTIONS(899),
    [anon_sym_in] = ACTIONS(899),
    [anon_sym_LT_LT] = ACTIONS(901),
    [anon_sym_GT_GT] = ACTIONS(899),
    [anon_sym_GT_GT_GT] = ACTIONS(901),
    [anon_sym_PLUS] = ACTIONS(899),
    [anon_sym_DASH] = ACTIONS(899),
    [anon_sym_PERCENT] = ACTIONS(901),
    [anon_sym_STAR_STAR] = ACTIONS(901),
    [anon_sym_BANG] = ACTIONS(899),
    [anon_sym_TILDE] = ACTIONS(901),
    [anon_sym_typeof] = ACTIONS(899),
    [anon_sym_void] = ACTIONS(899),
    [anon_sym_delete] = ACTIONS(899),
    [anon_sym_QMARK] = ACTIONS(899),
    [anon_sym_await] = ACTIONS(899),
    [anon_sym_LBRACK] = ACTIONS(901),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_async] = ACTIONS(899),
    [anon_sym_QMARK_DOT] = ACTIONS(901),
    [anon_sym_BQUOTE] = ACTIONS(901),
    [anon_sym_DOLLARr] = ACTIONS(899),
    [anon_sym_PLUS_PLUS] = ACTIONS(901),
    [anon_sym_DASH_DASH] = ACTIONS(901),
    [anon_sym_new] = ACTIONS(899),
  },
  [STATE(149)] = {
    [sym_comment] = STATE(149),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(903),
    [anon_sym_LBRACE] = ACTIONS(905),
    [anon_sym_RBRACE] = ACTIONS(905),
    [anon_sym_STAR] = ACTIONS(903),
    [anon_sym_as] = ACTIONS(903),
    [anon_sym_SEMI] = ACTIONS(905),
    [anon_sym_LPAREN] = ACTIONS(905),
    [anon_sym_DOT] = ACTIONS(905),
    [anon_sym_Text] = ACTIONS(903),
    [anon_sym_Button] = ACTIONS(903),
    [anon_sym_Image] = ACTIONS(903),
    [anon_sym_TextInput] = ACTIONS(903),
    [anon_sym_TextArea] = ACTIONS(903),
    [anon_sym_Column] = ACTIONS(903),
    [anon_sym_Row] = ACTIONS(903),
    [anon_sym_Stack] = ACTIONS(903),
    [anon_sym_Flex] = ACTIONS(903),
    [anon_sym_Grid] = ACTIONS(903),
    [anon_sym_GridRow] = ACTIONS(903),
    [anon_sym_GridCol] = ACTIONS(903),
    [anon_sym_List] = ACTIONS(903),
    [anon_sym_ScrollList] = ACTIONS(903),
    [anon_sym_ListItem] = ACTIONS(903),
    [anon_sym_GridItem] = ACTIONS(903),
    [anon_sym_ForEach] = ACTIONS(903),
    [sym_identifier] = ACTIONS(903),
    [anon_sym_DQUOTE] = ACTIONS(905),
    [anon_sym_SQUOTE] = ACTIONS(905),
    [anon_sym_DOLLAR] = ACTIONS(903),
    [sym_numeric_literal] = ACTIONS(905),
    [anon_sym_true] = ACTIONS(903),
    [anon_sym_false] = ACTIONS(903),
    [anon_sym_null] = ACTIONS(903),
    [anon_sym_PIPE_PIPE] = ACTIONS(905),
    [anon_sym_AMP_AMP] = ACTIONS(905),
    [anon_sym_PIPE] = ACTIONS(903),
    [anon_sym_CARET] = ACTIONS(905),
    [anon_sym_AMP] = ACTIONS(903),
    [anon_sym_EQ_EQ] = ACTIONS(903),
    [anon_sym_BANG_EQ] = ACTIONS(903),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(905),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(905),
    [anon_sym_LT] = ACTIONS(903),
    [anon_sym_GT] = ACTIONS(903),
    [anon_sym_LT_EQ] = ACTIONS(905),
    [anon_sym_GT_EQ] = ACTIONS(905),
    [anon_sym_instanceof] = ACTIONS(903),
    [anon_sym_in] = ACTIONS(903),
    [anon_sym_LT_LT] = ACTIONS(905),
    [anon_sym_GT_GT] = ACTIONS(903),
    [anon_sym_GT_GT_GT] = ACTIONS(905),
    [anon_sym_PLUS] = ACTIONS(903),
    [anon_sym_DASH] = ACTIONS(903),
    [anon_sym_PERCENT] = ACTIONS(905),
    [anon_sym_STAR_STAR] = ACTIONS(905),
    [anon_sym_BANG] = ACTIONS(903),
    [anon_sym_TILDE] = ACTIONS(905),
    [anon_sym_typeof] = ACTIONS(903),
    [anon_sym_void] = ACTIONS(903),
    [anon_sym_delete] = ACTIONS(903),
    [anon_sym_QMARK] = ACTIONS(903),
    [anon_sym_await] = ACTIONS(903),
    [anon_sym_LBRACK] = ACTIONS(905),
    [anon_sym_if] = ACTIONS(903),
    [anon_sym_async] = ACTIONS(903),
    [anon_sym_QMARK_DOT] = ACTIONS(905),
    [anon_sym_BQUOTE] = ACTIONS(905),
    [anon_sym_DOLLARr] = ACTIONS(903),
    [anon_sym_PLUS_PLUS] = ACTIONS(905),
    [anon_sym_DASH_DASH] = ACTIONS(905),
    [anon_sym_new] = ACTIONS(903),
  },
  [STATE(150)] = {
    [sym_comment] = STATE(150),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(731),
    [anon_sym_LBRACE] = ACTIONS(733),
    [anon_sym_RBRACE] = ACTIONS(733),
    [anon_sym_STAR] = ACTIONS(731),
    [anon_sym_as] = ACTIONS(731),
    [anon_sym_SEMI] = ACTIONS(733),
    [anon_sym_LPAREN] = ACTIONS(733),
    [anon_sym_DOT] = ACTIONS(733),
    [anon_sym_Text] = ACTIONS(731),
    [anon_sym_Button] = ACTIONS(731),
    [anon_sym_Image] = ACTIONS(731),
    [anon_sym_TextInput] = ACTIONS(731),
    [anon_sym_TextArea] = ACTIONS(731),
    [anon_sym_Column] = ACTIONS(731),
    [anon_sym_Row] = ACTIONS(731),
    [anon_sym_Stack] = ACTIONS(731),
    [anon_sym_Flex] = ACTIONS(731),
    [anon_sym_Grid] = ACTIONS(731),
    [anon_sym_GridRow] = ACTIONS(731),
    [anon_sym_GridCol] = ACTIONS(731),
    [anon_sym_List] = ACTIONS(731),
    [anon_sym_ScrollList] = ACTIONS(731),
    [anon_sym_ListItem] = ACTIONS(731),
    [anon_sym_GridItem] = ACTIONS(731),
    [anon_sym_ForEach] = ACTIONS(731),
    [sym_identifier] = ACTIONS(731),
    [anon_sym_DQUOTE] = ACTIONS(733),
    [anon_sym_SQUOTE] = ACTIONS(733),
    [anon_sym_DOLLAR] = ACTIONS(731),
    [sym_numeric_literal] = ACTIONS(733),
    [anon_sym_true] = ACTIONS(731),
    [anon_sym_false] = ACTIONS(731),
    [anon_sym_null] = ACTIONS(731),
    [anon_sym_PIPE_PIPE] = ACTIONS(733),
    [anon_sym_AMP_AMP] = ACTIONS(733),
    [anon_sym_PIPE] = ACTIONS(731),
    [anon_sym_CARET] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_EQ_EQ] = ACTIONS(731),
    [anon_sym_BANG_EQ] = ACTIONS(731),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(733),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(733),
    [anon_sym_LT] = ACTIONS(731),
    [anon_sym_GT] = ACTIONS(731),
    [anon_sym_LT_EQ] = ACTIONS(733),
    [anon_sym_GT_EQ] = ACTIONS(733),
    [anon_sym_instanceof] = ACTIONS(731),
    [anon_sym_in] = ACTIONS(731),
    [anon_sym_LT_LT] = ACTIONS(733),
    [anon_sym_GT_GT] = ACTIONS(731),
    [anon_sym_GT_GT_GT] = ACTIONS(733),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(731),
    [anon_sym_PERCENT] = ACTIONS(733),
    [anon_sym_STAR_STAR] = ACTIONS(733),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_TILDE] = ACTIONS(733),
    [anon_sym_typeof] = ACTIONS(731),
    [anon_sym_void] = ACTIONS(731),
    [anon_sym_delete] = ACTIONS(731),
    [anon_sym_QMARK] = ACTIONS(731),
    [anon_sym_await] = ACTIONS(731),
    [anon_sym_LBRACK] = ACTIONS(733),
    [anon_sym_if] = ACTIONS(731),
    [anon_sym_async] = ACTIONS(731),
    [anon_sym_QMARK_DOT] = ACTIONS(733),
    [anon_sym_BQUOTE] = ACTIONS(733),
    [anon_sym_DOLLARr] = ACTIONS(731),
    [anon_sym_PLUS_PLUS] = ACTIONS(733),
    [anon_sym_DASH_DASH] = ACTIONS(733),
    [anon_sym_new] = ACTIONS(731),
  },
  [STATE(151)] = {
    [sym_comment] = STATE(151),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(907),
    [anon_sym_LBRACE] = ACTIONS(910),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_STAR] = ACTIONS(907),
    [anon_sym_as] = ACTIONS(907),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_LPAREN] = ACTIONS(910),
    [anon_sym_DOT] = ACTIONS(910),
    [anon_sym_Text] = ACTIONS(907),
    [anon_sym_Button] = ACTIONS(907),
    [anon_sym_Image] = ACTIONS(907),
    [anon_sym_TextInput] = ACTIONS(907),
    [anon_sym_TextArea] = ACTIONS(907),
    [anon_sym_Column] = ACTIONS(907),
    [anon_sym_Row] = ACTIONS(907),
    [anon_sym_Stack] = ACTIONS(907),
    [anon_sym_Flex] = ACTIONS(907),
    [anon_sym_Grid] = ACTIONS(907),
    [anon_sym_GridRow] = ACTIONS(907),
    [anon_sym_GridCol] = ACTIONS(907),
    [anon_sym_List] = ACTIONS(907),
    [anon_sym_ScrollList] = ACTIONS(907),
    [anon_sym_ListItem] = ACTIONS(907),
    [anon_sym_GridItem] = ACTIONS(907),
    [anon_sym_ForEach] = ACTIONS(907),
    [sym_identifier] = ACTIONS(907),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [anon_sym_SQUOTE] = ACTIONS(910),
    [anon_sym_DOLLAR] = ACTIONS(907),
    [sym_numeric_literal] = ACTIONS(910),
    [anon_sym_true] = ACTIONS(907),
    [anon_sym_false] = ACTIONS(907),
    [anon_sym_null] = ACTIONS(907),
    [anon_sym_PIPE_PIPE] = ACTIONS(910),
    [anon_sym_AMP_AMP] = ACTIONS(910),
    [anon_sym_PIPE] = ACTIONS(907),
    [anon_sym_CARET] = ACTIONS(910),
    [anon_sym_AMP] = ACTIONS(907),
    [anon_sym_EQ_EQ] = ACTIONS(907),
    [anon_sym_BANG_EQ] = ACTIONS(907),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(910),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(910),
    [anon_sym_LT] = ACTIONS(907),
    [anon_sym_GT] = ACTIONS(907),
    [anon_sym_LT_EQ] = ACTIONS(910),
    [anon_sym_GT_EQ] = ACTIONS(910),
    [anon_sym_instanceof] = ACTIONS(907),
    [anon_sym_in] = ACTIONS(907),
    [anon_sym_LT_LT] = ACTIONS(910),
    [anon_sym_GT_GT] = ACTIONS(907),
    [anon_sym_GT_GT_GT] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(907),
    [anon_sym_PERCENT] = ACTIONS(910),
    [anon_sym_STAR_STAR] = ACTIONS(910),
    [anon_sym_BANG] = ACTIONS(907),
    [anon_sym_TILDE] = ACTIONS(910),
    [anon_sym_typeof] = ACTIONS(907),
    [anon_sym_void] = ACTIONS(907),
    [anon_sym_delete] = ACTIONS(907),
    [anon_sym_QMARK] = ACTIONS(907),
    [anon_sym_await] = ACTIONS(907),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_if] = ACTIONS(907),
    [anon_sym_async] = ACTIONS(907),
    [anon_sym_QMARK_DOT] = ACTIONS(910),
    [anon_sym_BQUOTE] = ACTIONS(910),
    [anon_sym_DOLLARr] = ACTIONS(907),
    [anon_sym_PLUS_PLUS] = ACTIONS(910),
    [anon_sym_DASH_DASH] = ACTIONS(910),
    [anon_sym_new] = ACTIONS(907),
  },
  [STATE(152)] = {
    [sym_comment] = STATE(152),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(913),
    [anon_sym_LBRACE] = ACTIONS(915),
    [anon_sym_RBRACE] = ACTIONS(915),
    [anon_sym_STAR] = ACTIONS(913),
    [anon_sym_as] = ACTIONS(913),
    [anon_sym_SEMI] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_DOT] = ACTIONS(915),
    [anon_sym_Text] = ACTIONS(913),
    [anon_sym_Button] = ACTIONS(913),
    [anon_sym_Image] = ACTIONS(913),
    [anon_sym_TextInput] = ACTIONS(913),
    [anon_sym_TextArea] = ACTIONS(913),
    [anon_sym_Column] = ACTIONS(913),
    [anon_sym_Row] = ACTIONS(913),
    [anon_sym_Stack] = ACTIONS(913),
    [anon_sym_Flex] = ACTIONS(913),
    [anon_sym_Grid] = ACTIONS(913),
    [anon_sym_GridRow] = ACTIONS(913),
    [anon_sym_GridCol] = ACTIONS(913),
    [anon_sym_List] = ACTIONS(913),
    [anon_sym_ScrollList] = ACTIONS(913),
    [anon_sym_ListItem] = ACTIONS(913),
    [anon_sym_GridItem] = ACTIONS(913),
    [anon_sym_ForEach] = ACTIONS(913),
    [sym_identifier] = ACTIONS(913),
    [anon_sym_DQUOTE] = ACTIONS(915),
    [anon_sym_SQUOTE] = ACTIONS(915),
    [anon_sym_DOLLAR] = ACTIONS(913),
    [sym_numeric_literal] = ACTIONS(915),
    [anon_sym_true] = ACTIONS(913),
    [anon_sym_false] = ACTIONS(913),
    [anon_sym_null] = ACTIONS(913),
    [anon_sym_PIPE_PIPE] = ACTIONS(915),
    [anon_sym_AMP_AMP] = ACTIONS(915),
    [anon_sym_PIPE] = ACTIONS(913),
    [anon_sym_CARET] = ACTIONS(915),
    [anon_sym_AMP] = ACTIONS(913),
    [anon_sym_EQ_EQ] = ACTIONS(913),
    [anon_sym_BANG_EQ] = ACTIONS(913),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(915),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(915),
    [anon_sym_LT] = ACTIONS(913),
    [anon_sym_GT] = ACTIONS(913),
    [anon_sym_LT_EQ] = ACTIONS(915),
    [anon_sym_GT_EQ] = ACTIONS(915),
    [anon_sym_instanceof] = ACTIONS(913),
    [anon_sym_in] = ACTIONS(913),
    [anon_sym_LT_LT] = ACTIONS(915),
    [anon_sym_GT_GT] = ACTIONS(913),
    [anon_sym_GT_GT_GT] = ACTIONS(915),
    [anon_sym_PLUS] = ACTIONS(913),
    [anon_sym_DASH] = ACTIONS(913),
    [anon_sym_PERCENT] = ACTIONS(915),
    [anon_sym_STAR_STAR] = ACTIONS(915),
    [anon_sym_BANG] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(915),
    [anon_sym_typeof] = ACTIONS(913),
    [anon_sym_void] = ACTIONS(913),
    [anon_sym_delete] = ACTIONS(913),
    [anon_sym_QMARK] = ACTIONS(913),
    [anon_sym_await] = ACTIONS(913),
    [anon_sym_LBRACK] = ACTIONS(915),
    [anon_sym_if] = ACTIONS(913),
    [anon_sym_async] = ACTIONS(913),
    [anon_sym_QMARK_DOT] = ACTIONS(915),
    [anon_sym_BQUOTE] = ACTIONS(915),
    [anon_sym_DOLLARr] = ACTIONS(913),
    [anon_sym_PLUS_PLUS] = ACTIONS(915),
    [anon_sym_DASH_DASH] = ACTIONS(915),
    [anon_sym_new] = ACTIONS(913),
  },
  [STATE(153)] = {
    [sym_comment] = STATE(153),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(797),
    [anon_sym_LBRACE] = ACTIONS(799),
    [anon_sym_RBRACE] = ACTIONS(799),
    [anon_sym_STAR] = ACTIONS(797),
    [anon_sym_as] = ACTIONS(797),
    [anon_sym_SEMI] = ACTIONS(799),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_DOT] = ACTIONS(799),
    [anon_sym_Text] = ACTIONS(797),
    [anon_sym_Button] = ACTIONS(797),
    [anon_sym_Image] = ACTIONS(797),
    [anon_sym_TextInput] = ACTIONS(797),
    [anon_sym_TextArea] = ACTIONS(797),
    [anon_sym_Column] = ACTIONS(797),
    [anon_sym_Row] = ACTIONS(797),
    [anon_sym_Stack] = ACTIONS(797),
    [anon_sym_Flex] = ACTIONS(797),
    [anon_sym_Grid] = ACTIONS(797),
    [anon_sym_GridRow] = ACTIONS(797),
    [anon_sym_GridCol] = ACTIONS(797),
    [anon_sym_List] = ACTIONS(797),
    [anon_sym_ScrollList] = ACTIONS(797),
    [anon_sym_ListItem] = ACTIONS(797),
    [anon_sym_GridItem] = ACTIONS(797),
    [anon_sym_ForEach] = ACTIONS(797),
    [sym_identifier] = ACTIONS(797),
    [anon_sym_DQUOTE] = ACTIONS(799),
    [anon_sym_SQUOTE] = ACTIONS(799),
    [anon_sym_DOLLAR] = ACTIONS(797),
    [sym_numeric_literal] = ACTIONS(799),
    [anon_sym_true] = ACTIONS(797),
    [anon_sym_false] = ACTIONS(797),
    [anon_sym_null] = ACTIONS(797),
    [anon_sym_PIPE_PIPE] = ACTIONS(799),
    [anon_sym_AMP_AMP] = ACTIONS(799),
    [anon_sym_PIPE] = ACTIONS(797),
    [anon_sym_CARET] = ACTIONS(799),
    [anon_sym_AMP] = ACTIONS(797),
    [anon_sym_EQ_EQ] = ACTIONS(797),
    [anon_sym_BANG_EQ] = ACTIONS(797),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(799),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(799),
    [anon_sym_LT] = ACTIONS(797),
    [anon_sym_GT] = ACTIONS(797),
    [anon_sym_LT_EQ] = ACTIONS(799),
    [anon_sym_GT_EQ] = ACTIONS(799),
    [anon_sym_instanceof] = ACTIONS(797),
    [anon_sym_in] = ACTIONS(797),
    [anon_sym_LT_LT] = ACTIONS(799),
    [anon_sym_GT_GT] = ACTIONS(797),
    [anon_sym_GT_GT_GT] = ACTIONS(799),
    [anon_sym_PLUS] = ACTIONS(797),
    [anon_sym_DASH] = ACTIONS(797),
    [anon_sym_PERCENT] = ACTIONS(799),
    [anon_sym_STAR_STAR] = ACTIONS(799),
    [anon_sym_BANG] = ACTIONS(797),
    [anon_sym_TILDE] = ACTIONS(799),
    [anon_sym_typeof] = ACTIONS(797),
    [anon_sym_void] = ACTIONS(797),
    [anon_sym_delete] = ACTIONS(797),
    [anon_sym_QMARK] = ACTIONS(797),
    [anon_sym_await] = ACTIONS(797),
    [anon_sym_LBRACK] = ACTIONS(799),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_async] = ACTIONS(797),
    [anon_sym_QMARK_DOT] = ACTIONS(799),
    [anon_sym_BQUOTE] = ACTIONS(799),
    [anon_sym_DOLLARr] = ACTIONS(797),
    [anon_sym_PLUS_PLUS] = ACTIONS(799),
    [anon_sym_DASH_DASH] = ACTIONS(799),
    [anon_sym_new] = ACTIONS(797),
  },
  [STATE(154)] = {
    [sym_comment] = STATE(154),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_as] = ACTIONS(711),
    [anon_sym_SEMI] = ACTIONS(709),
    [anon_sym_LPAREN] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(709),
    [anon_sym_Text] = ACTIONS(711),
    [anon_sym_Button] = ACTIONS(711),
    [anon_sym_Image] = ACTIONS(711),
    [anon_sym_TextInput] = ACTIONS(711),
    [anon_sym_TextArea] = ACTIONS(711),
    [anon_sym_Column] = ACTIONS(711),
    [anon_sym_Row] = ACTIONS(711),
    [anon_sym_Stack] = ACTIONS(711),
    [anon_sym_Flex] = ACTIONS(711),
    [anon_sym_Grid] = ACTIONS(711),
    [anon_sym_GridRow] = ACTIONS(711),
    [anon_sym_GridCol] = ACTIONS(711),
    [anon_sym_List] = ACTIONS(711),
    [anon_sym_ScrollList] = ACTIONS(711),
    [anon_sym_ListItem] = ACTIONS(711),
    [anon_sym_GridItem] = ACTIONS(711),
    [anon_sym_ForEach] = ACTIONS(711),
    [sym_identifier] = ACTIONS(711),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [anon_sym_SQUOTE] = ACTIONS(709),
    [anon_sym_DOLLAR] = ACTIONS(711),
    [sym_numeric_literal] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_null] = ACTIONS(711),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE] = ACTIONS(711),
    [anon_sym_CARET] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(711),
    [anon_sym_EQ_EQ] = ACTIONS(711),
    [anon_sym_BANG_EQ] = ACTIONS(711),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(709),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_instanceof] = ACTIONS(711),
    [anon_sym_in] = ACTIONS(711),
    [anon_sym_LT_LT] = ACTIONS(709),
    [anon_sym_GT_GT] = ACTIONS(711),
    [anon_sym_GT_GT_GT] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(711),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_typeof] = ACTIONS(711),
    [anon_sym_void] = ACTIONS(711),
    [anon_sym_delete] = ACTIONS(711),
    [anon_sym_QMARK] = ACTIONS(711),
    [anon_sym_await] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_if] = ACTIONS(711),
    [anon_sym_async] = ACTIONS(711),
    [anon_sym_QMARK_DOT] = ACTIONS(709),
    [anon_sym_BQUOTE] = ACTIONS(709),
    [anon_sym_DOLLARr] = ACTIONS(711),
    [anon_sym_PLUS_PLUS] = ACTIONS(709),
    [anon_sym_DASH_DASH] = ACTIONS(709),
    [anon_sym_new] = ACTIONS(711),
  },
  [STATE(155)] = {
    [sym_comment] = STATE(155),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(917),
    [anon_sym_LBRACE] = ACTIONS(919),
    [anon_sym_RBRACE] = ACTIONS(919),
    [anon_sym_STAR] = ACTIONS(917),
    [anon_sym_as] = ACTIONS(917),
    [anon_sym_SEMI] = ACTIONS(919),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_DOT] = ACTIONS(919),
    [anon_sym_Text] = ACTIONS(917),
    [anon_sym_Button] = ACTIONS(917),
    [anon_sym_Image] = ACTIONS(917),
    [anon_sym_TextInput] = ACTIONS(917),
    [anon_sym_TextArea] = ACTIONS(917),
    [anon_sym_Column] = ACTIONS(917),
    [anon_sym_Row] = ACTIONS(917),
    [anon_sym_Stack] = ACTIONS(917),
    [anon_sym_Flex] = ACTIONS(917),
    [anon_sym_Grid] = ACTIONS(917),
    [anon_sym_GridRow] = ACTIONS(917),
    [anon_sym_GridCol] = ACTIONS(917),
    [anon_sym_List] = ACTIONS(917),
    [anon_sym_ScrollList] = ACTIONS(917),
    [anon_sym_ListItem] = ACTIONS(917),
    [anon_sym_GridItem] = ACTIONS(917),
    [anon_sym_ForEach] = ACTIONS(917),
    [sym_identifier] = ACTIONS(917),
    [anon_sym_DQUOTE] = ACTIONS(919),
    [anon_sym_SQUOTE] = ACTIONS(919),
    [anon_sym_DOLLAR] = ACTIONS(917),
    [sym_numeric_literal] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(917),
    [anon_sym_false] = ACTIONS(917),
    [anon_sym_null] = ACTIONS(917),
    [anon_sym_PIPE_PIPE] = ACTIONS(919),
    [anon_sym_AMP_AMP] = ACTIONS(919),
    [anon_sym_PIPE] = ACTIONS(917),
    [anon_sym_CARET] = ACTIONS(919),
    [anon_sym_AMP] = ACTIONS(917),
    [anon_sym_EQ_EQ] = ACTIONS(917),
    [anon_sym_BANG_EQ] = ACTIONS(917),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(919),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(919),
    [anon_sym_LT] = ACTIONS(917),
    [anon_sym_GT] = ACTIONS(917),
    [anon_sym_LT_EQ] = ACTIONS(919),
    [anon_sym_GT_EQ] = ACTIONS(919),
    [anon_sym_instanceof] = ACTIONS(917),
    [anon_sym_in] = ACTIONS(917),
    [anon_sym_LT_LT] = ACTIONS(919),
    [anon_sym_GT_GT] = ACTIONS(917),
    [anon_sym_GT_GT_GT] = ACTIONS(919),
    [anon_sym_PLUS] = ACTIONS(917),
    [anon_sym_DASH] = ACTIONS(917),
    [anon_sym_PERCENT] = ACTIONS(919),
    [anon_sym_STAR_STAR] = ACTIONS(919),
    [anon_sym_BANG] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(919),
    [anon_sym_typeof] = ACTIONS(917),
    [anon_sym_void] = ACTIONS(917),
    [anon_sym_delete] = ACTIONS(917),
    [anon_sym_QMARK] = ACTIONS(917),
    [anon_sym_await] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_if] = ACTIONS(917),
    [anon_sym_async] = ACTIONS(917),
    [anon_sym_QMARK_DOT] = ACTIONS(919),
    [anon_sym_BQUOTE] = ACTIONS(919),
    [anon_sym_DOLLARr] = ACTIONS(917),
    [anon_sym_PLUS_PLUS] = ACTIONS(919),
    [anon_sym_DASH_DASH] = ACTIONS(919),
    [anon_sym_new] = ACTIONS(917),
  },
  [STATE(156)] = {
    [sym_comment] = STATE(156),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_RBRACE] = ACTIONS(923),
    [anon_sym_STAR] = ACTIONS(921),
    [anon_sym_as] = ACTIONS(921),
    [anon_sym_SEMI] = ACTIONS(923),
    [anon_sym_LPAREN] = ACTIONS(923),
    [anon_sym_DOT] = ACTIONS(923),
    [anon_sym_Text] = ACTIONS(921),
    [anon_sym_Button] = ACTIONS(921),
    [anon_sym_Image] = ACTIONS(921),
    [anon_sym_TextInput] = ACTIONS(921),
    [anon_sym_TextArea] = ACTIONS(921),
    [anon_sym_Column] = ACTIONS(921),
    [anon_sym_Row] = ACTIONS(921),
    [anon_sym_Stack] = ACTIONS(921),
    [anon_sym_Flex] = ACTIONS(921),
    [anon_sym_Grid] = ACTIONS(921),
    [anon_sym_GridRow] = ACTIONS(921),
    [anon_sym_GridCol] = ACTIONS(921),
    [anon_sym_List] = ACTIONS(921),
    [anon_sym_ScrollList] = ACTIONS(921),
    [anon_sym_ListItem] = ACTIONS(921),
    [anon_sym_GridItem] = ACTIONS(921),
    [anon_sym_ForEach] = ACTIONS(921),
    [sym_identifier] = ACTIONS(921),
    [anon_sym_DQUOTE] = ACTIONS(923),
    [anon_sym_SQUOTE] = ACTIONS(923),
    [anon_sym_DOLLAR] = ACTIONS(921),
    [sym_numeric_literal] = ACTIONS(923),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_null] = ACTIONS(921),
    [anon_sym_PIPE_PIPE] = ACTIONS(923),
    [anon_sym_AMP_AMP] = ACTIONS(923),
    [anon_sym_PIPE] = ACTIONS(921),
    [anon_sym_CARET] = ACTIONS(923),
    [anon_sym_AMP] = ACTIONS(921),
    [anon_sym_EQ_EQ] = ACTIONS(921),
    [anon_sym_BANG_EQ] = ACTIONS(921),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(923),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(923),
    [anon_sym_LT] = ACTIONS(921),
    [anon_sym_GT] = ACTIONS(921),
    [anon_sym_LT_EQ] = ACTIONS(923),
    [anon_sym_GT_EQ] = ACTIONS(923),
    [anon_sym_instanceof] = ACTIONS(921),
    [anon_sym_in] = ACTIONS(921),
    [anon_sym_LT_LT] = ACTIONS(923),
    [anon_sym_GT_GT] = ACTIONS(921),
    [anon_sym_GT_GT_GT] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(921),
    [anon_sym_DASH] = ACTIONS(921),
    [anon_sym_PERCENT] = ACTIONS(923),
    [anon_sym_STAR_STAR] = ACTIONS(923),
    [anon_sym_BANG] = ACTIONS(921),
    [anon_sym_TILDE] = ACTIONS(923),
    [anon_sym_typeof] = ACTIONS(921),
    [anon_sym_void] = ACTIONS(921),
    [anon_sym_delete] = ACTIONS(921),
    [anon_sym_QMARK] = ACTIONS(921),
    [anon_sym_await] = ACTIONS(921),
    [anon_sym_LBRACK] = ACTIONS(923),
    [anon_sym_if] = ACTIONS(921),
    [anon_sym_async] = ACTIONS(921),
    [anon_sym_QMARK_DOT] = ACTIONS(923),
    [anon_sym_BQUOTE] = ACTIONS(923),
    [anon_sym_DOLLARr] = ACTIONS(921),
    [anon_sym_PLUS_PLUS] = ACTIONS(923),
    [anon_sym_DASH_DASH] = ACTIONS(923),
    [anon_sym_new] = ACTIONS(921),
  },
  [STATE(157)] = {
    [sym_comment] = STATE(157),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(927),
    [anon_sym_RBRACE] = ACTIONS(927),
    [anon_sym_STAR] = ACTIONS(925),
    [anon_sym_as] = ACTIONS(925),
    [anon_sym_SEMI] = ACTIONS(927),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_DOT] = ACTIONS(927),
    [anon_sym_Text] = ACTIONS(925),
    [anon_sym_Button] = ACTIONS(925),
    [anon_sym_Image] = ACTIONS(925),
    [anon_sym_TextInput] = ACTIONS(925),
    [anon_sym_TextArea] = ACTIONS(925),
    [anon_sym_Column] = ACTIONS(925),
    [anon_sym_Row] = ACTIONS(925),
    [anon_sym_Stack] = ACTIONS(925),
    [anon_sym_Flex] = ACTIONS(925),
    [anon_sym_Grid] = ACTIONS(925),
    [anon_sym_GridRow] = ACTIONS(925),
    [anon_sym_GridCol] = ACTIONS(925),
    [anon_sym_List] = ACTIONS(925),
    [anon_sym_ScrollList] = ACTIONS(925),
    [anon_sym_ListItem] = ACTIONS(925),
    [anon_sym_GridItem] = ACTIONS(925),
    [anon_sym_ForEach] = ACTIONS(925),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_DQUOTE] = ACTIONS(927),
    [anon_sym_SQUOTE] = ACTIONS(927),
    [anon_sym_DOLLAR] = ACTIONS(925),
    [sym_numeric_literal] = ACTIONS(927),
    [anon_sym_true] = ACTIONS(925),
    [anon_sym_false] = ACTIONS(925),
    [anon_sym_null] = ACTIONS(925),
    [anon_sym_PIPE_PIPE] = ACTIONS(927),
    [anon_sym_AMP_AMP] = ACTIONS(927),
    [anon_sym_PIPE] = ACTIONS(925),
    [anon_sym_CARET] = ACTIONS(927),
    [anon_sym_AMP] = ACTIONS(925),
    [anon_sym_EQ_EQ] = ACTIONS(925),
    [anon_sym_BANG_EQ] = ACTIONS(925),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(927),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(927),
    [anon_sym_LT] = ACTIONS(925),
    [anon_sym_GT] = ACTIONS(925),
    [anon_sym_LT_EQ] = ACTIONS(927),
    [anon_sym_GT_EQ] = ACTIONS(927),
    [anon_sym_instanceof] = ACTIONS(925),
    [anon_sym_in] = ACTIONS(925),
    [anon_sym_LT_LT] = ACTIONS(927),
    [anon_sym_GT_GT] = ACTIONS(925),
    [anon_sym_GT_GT_GT] = ACTIONS(927),
    [anon_sym_PLUS] = ACTIONS(925),
    [anon_sym_DASH] = ACTIONS(925),
    [anon_sym_PERCENT] = ACTIONS(927),
    [anon_sym_STAR_STAR] = ACTIONS(927),
    [anon_sym_BANG] = ACTIONS(925),
    [anon_sym_TILDE] = ACTIONS(927),
    [anon_sym_typeof] = ACTIONS(925),
    [anon_sym_void] = ACTIONS(925),
    [anon_sym_delete] = ACTIONS(925),
    [anon_sym_QMARK] = ACTIONS(925),
    [anon_sym_await] = ACTIONS(925),
    [anon_sym_LBRACK] = ACTIONS(927),
    [anon_sym_if] = ACTIONS(925),
    [anon_sym_async] = ACTIONS(925),
    [anon_sym_QMARK_DOT] = ACTIONS(927),
    [anon_sym_BQUOTE] = ACTIONS(927),
    [anon_sym_DOLLARr] = ACTIONS(925),
    [anon_sym_PLUS_PLUS] = ACTIONS(927),
    [anon_sym_DASH_DASH] = ACTIONS(927),
    [anon_sym_new] = ACTIONS(925),
  },
  [STATE(158)] = {
    [sym_comment] = STATE(158),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(929),
    [anon_sym_LBRACE] = ACTIONS(931),
    [anon_sym_RBRACE] = ACTIONS(931),
    [anon_sym_STAR] = ACTIONS(929),
    [anon_sym_as] = ACTIONS(929),
    [anon_sym_SEMI] = ACTIONS(931),
    [anon_sym_LPAREN] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(931),
    [anon_sym_Text] = ACTIONS(929),
    [anon_sym_Button] = ACTIONS(929),
    [anon_sym_Image] = ACTIONS(929),
    [anon_sym_TextInput] = ACTIONS(929),
    [anon_sym_TextArea] = ACTIONS(929),
    [anon_sym_Column] = ACTIONS(929),
    [anon_sym_Row] = ACTIONS(929),
    [anon_sym_Stack] = ACTIONS(929),
    [anon_sym_Flex] = ACTIONS(929),
    [anon_sym_Grid] = ACTIONS(929),
    [anon_sym_GridRow] = ACTIONS(929),
    [anon_sym_GridCol] = ACTIONS(929),
    [anon_sym_List] = ACTIONS(929),
    [anon_sym_ScrollList] = ACTIONS(929),
    [anon_sym_ListItem] = ACTIONS(929),
    [anon_sym_GridItem] = ACTIONS(929),
    [anon_sym_ForEach] = ACTIONS(929),
    [sym_identifier] = ACTIONS(929),
    [anon_sym_DQUOTE] = ACTIONS(931),
    [anon_sym_SQUOTE] = ACTIONS(931),
    [anon_sym_DOLLAR] = ACTIONS(929),
    [sym_numeric_literal] = ACTIONS(931),
    [anon_sym_true] = ACTIONS(929),
    [anon_sym_false] = ACTIONS(929),
    [anon_sym_null] = ACTIONS(929),
    [anon_sym_PIPE_PIPE] = ACTIONS(931),
    [anon_sym_AMP_AMP] = ACTIONS(931),
    [anon_sym_PIPE] = ACTIONS(929),
    [anon_sym_CARET] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(929),
    [anon_sym_EQ_EQ] = ACTIONS(929),
    [anon_sym_BANG_EQ] = ACTIONS(929),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(931),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(931),
    [anon_sym_LT] = ACTIONS(929),
    [anon_sym_GT] = ACTIONS(929),
    [anon_sym_LT_EQ] = ACTIONS(931),
    [anon_sym_GT_EQ] = ACTIONS(931),
    [anon_sym_instanceof] = ACTIONS(929),
    [anon_sym_in] = ACTIONS(929),
    [anon_sym_LT_LT] = ACTIONS(931),
    [anon_sym_GT_GT] = ACTIONS(929),
    [anon_sym_GT_GT_GT] = ACTIONS(931),
    [anon_sym_PLUS] = ACTIONS(929),
    [anon_sym_DASH] = ACTIONS(929),
    [anon_sym_PERCENT] = ACTIONS(931),
    [anon_sym_STAR_STAR] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(929),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_typeof] = ACTIONS(929),
    [anon_sym_void] = ACTIONS(929),
    [anon_sym_delete] = ACTIONS(929),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_await] = ACTIONS(929),
    [anon_sym_LBRACK] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(929),
    [anon_sym_async] = ACTIONS(929),
    [anon_sym_QMARK_DOT] = ACTIONS(931),
    [anon_sym_BQUOTE] = ACTIONS(931),
    [anon_sym_DOLLARr] = ACTIONS(929),
    [anon_sym_PLUS_PLUS] = ACTIONS(931),
    [anon_sym_DASH_DASH] = ACTIONS(931),
    [anon_sym_new] = ACTIONS(929),
  },
  [STATE(159)] = {
    [sym_comment] = STATE(159),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(817),
    [anon_sym_LBRACE] = ACTIONS(819),
    [anon_sym_RBRACE] = ACTIONS(819),
    [anon_sym_STAR] = ACTIONS(817),
    [anon_sym_as] = ACTIONS(817),
    [anon_sym_SEMI] = ACTIONS(819),
    [anon_sym_LPAREN] = ACTIONS(819),
    [anon_sym_DOT] = ACTIONS(819),
    [anon_sym_Text] = ACTIONS(817),
    [anon_sym_Button] = ACTIONS(817),
    [anon_sym_Image] = ACTIONS(817),
    [anon_sym_TextInput] = ACTIONS(817),
    [anon_sym_TextArea] = ACTIONS(817),
    [anon_sym_Column] = ACTIONS(817),
    [anon_sym_Row] = ACTIONS(817),
    [anon_sym_Stack] = ACTIONS(817),
    [anon_sym_Flex] = ACTIONS(817),
    [anon_sym_Grid] = ACTIONS(817),
    [anon_sym_GridRow] = ACTIONS(817),
    [anon_sym_GridCol] = ACTIONS(817),
    [anon_sym_List] = ACTIONS(817),
    [anon_sym_ScrollList] = ACTIONS(817),
    [anon_sym_ListItem] = ACTIONS(817),
    [anon_sym_GridItem] = ACTIONS(817),
    [anon_sym_ForEach] = ACTIONS(817),
    [sym_identifier] = ACTIONS(817),
    [anon_sym_DQUOTE] = ACTIONS(819),
    [anon_sym_SQUOTE] = ACTIONS(819),
    [anon_sym_DOLLAR] = ACTIONS(817),
    [sym_numeric_literal] = ACTIONS(819),
    [anon_sym_true] = ACTIONS(817),
    [anon_sym_false] = ACTIONS(817),
    [anon_sym_null] = ACTIONS(817),
    [anon_sym_PIPE_PIPE] = ACTIONS(819),
    [anon_sym_AMP_AMP] = ACTIONS(819),
    [anon_sym_PIPE] = ACTIONS(817),
    [anon_sym_CARET] = ACTIONS(819),
    [anon_sym_AMP] = ACTIONS(817),
    [anon_sym_EQ_EQ] = ACTIONS(817),
    [anon_sym_BANG_EQ] = ACTIONS(817),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(819),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(819),
    [anon_sym_LT] = ACTIONS(817),
    [anon_sym_GT] = ACTIONS(817),
    [anon_sym_LT_EQ] = ACTIONS(819),
    [anon_sym_GT_EQ] = ACTIONS(819),
    [anon_sym_instanceof] = ACTIONS(817),
    [anon_sym_in] = ACTIONS(817),
    [anon_sym_LT_LT] = ACTIONS(819),
    [anon_sym_GT_GT] = ACTIONS(817),
    [anon_sym_GT_GT_GT] = ACTIONS(819),
    [anon_sym_PLUS] = ACTIONS(817),
    [anon_sym_DASH] = ACTIONS(817),
    [anon_sym_PERCENT] = ACTIONS(819),
    [anon_sym_STAR_STAR] = ACTIONS(819),
    [anon_sym_BANG] = ACTIONS(817),
    [anon_sym_TILDE] = ACTIONS(819),
    [anon_sym_typeof] = ACTIONS(817),
    [anon_sym_void] = ACTIONS(817),
    [anon_sym_delete] = ACTIONS(817),
    [anon_sym_QMARK] = ACTIONS(817),
    [anon_sym_await] = ACTIONS(817),
    [anon_sym_LBRACK] = ACTIONS(819),
    [anon_sym_if] = ACTIONS(817),
    [anon_sym_async] = ACTIONS(817),
    [anon_sym_QMARK_DOT] = ACTIONS(819),
    [anon_sym_BQUOTE] = ACTIONS(819),
    [anon_sym_DOLLARr] = ACTIONS(817),
    [anon_sym_PLUS_PLUS] = ACTIONS(819),
    [anon_sym_DASH_DASH] = ACTIONS(819),
    [anon_sym_new] = ACTIONS(817),
  },
  [STATE(160)] = {
    [sym_comment] = STATE(160),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [anon_sym_Text] = ACTIONS(61),
    [anon_sym_Button] = ACTIONS(61),
    [anon_sym_Image] = ACTIONS(61),
    [anon_sym_TextInput] = ACTIONS(61),
    [anon_sym_TextArea] = ACTIONS(61),
    [anon_sym_Column] = ACTIONS(61),
    [anon_sym_Row] = ACTIONS(61),
    [anon_sym_Stack] = ACTIONS(61),
    [anon_sym_Flex] = ACTIONS(61),
    [anon_sym_Grid] = ACTIONS(61),
    [anon_sym_GridRow] = ACTIONS(61),
    [anon_sym_GridCol] = ACTIONS(61),
    [anon_sym_List] = ACTIONS(61),
    [anon_sym_ScrollList] = ACTIONS(61),
    [anon_sym_ListItem] = ACTIONS(61),
    [anon_sym_GridItem] = ACTIONS(61),
    [anon_sym_ForEach] = ACTIONS(61),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(161)] = {
    [sym_comment] = STATE(161),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(935),
    [anon_sym_STAR] = ACTIONS(933),
    [anon_sym_as] = ACTIONS(933),
    [anon_sym_SEMI] = ACTIONS(935),
    [anon_sym_LPAREN] = ACTIONS(935),
    [anon_sym_DOT] = ACTIONS(935),
    [anon_sym_Text] = ACTIONS(933),
    [anon_sym_Button] = ACTIONS(933),
    [anon_sym_Image] = ACTIONS(933),
    [anon_sym_TextInput] = ACTIONS(933),
    [anon_sym_TextArea] = ACTIONS(933),
    [anon_sym_Column] = ACTIONS(933),
    [anon_sym_Row] = ACTIONS(933),
    [anon_sym_Stack] = ACTIONS(933),
    [anon_sym_Flex] = ACTIONS(933),
    [anon_sym_Grid] = ACTIONS(933),
    [anon_sym_GridRow] = ACTIONS(933),
    [anon_sym_GridCol] = ACTIONS(933),
    [anon_sym_List] = ACTIONS(933),
    [anon_sym_ScrollList] = ACTIONS(933),
    [anon_sym_ListItem] = ACTIONS(933),
    [anon_sym_GridItem] = ACTIONS(933),
    [anon_sym_ForEach] = ACTIONS(933),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_DQUOTE] = ACTIONS(935),
    [anon_sym_SQUOTE] = ACTIONS(935),
    [anon_sym_DOLLAR] = ACTIONS(933),
    [sym_numeric_literal] = ACTIONS(935),
    [anon_sym_true] = ACTIONS(933),
    [anon_sym_false] = ACTIONS(933),
    [anon_sym_null] = ACTIONS(933),
    [anon_sym_PIPE_PIPE] = ACTIONS(935),
    [anon_sym_AMP_AMP] = ACTIONS(935),
    [anon_sym_PIPE] = ACTIONS(933),
    [anon_sym_CARET] = ACTIONS(935),
    [anon_sym_AMP] = ACTIONS(933),
    [anon_sym_EQ_EQ] = ACTIONS(933),
    [anon_sym_BANG_EQ] = ACTIONS(933),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(935),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(935),
    [anon_sym_LT] = ACTIONS(933),
    [anon_sym_GT] = ACTIONS(933),
    [anon_sym_LT_EQ] = ACTIONS(935),
    [anon_sym_GT_EQ] = ACTIONS(935),
    [anon_sym_instanceof] = ACTIONS(933),
    [anon_sym_in] = ACTIONS(933),
    [anon_sym_LT_LT] = ACTIONS(935),
    [anon_sym_GT_GT] = ACTIONS(933),
    [anon_sym_GT_GT_GT] = ACTIONS(935),
    [anon_sym_PLUS] = ACTIONS(933),
    [anon_sym_DASH] = ACTIONS(933),
    [anon_sym_PERCENT] = ACTIONS(935),
    [anon_sym_STAR_STAR] = ACTIONS(935),
    [anon_sym_BANG] = ACTIONS(933),
    [anon_sym_TILDE] = ACTIONS(935),
    [anon_sym_typeof] = ACTIONS(933),
    [anon_sym_void] = ACTIONS(933),
    [anon_sym_delete] = ACTIONS(933),
    [anon_sym_QMARK] = ACTIONS(933),
    [anon_sym_await] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(935),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_async] = ACTIONS(933),
    [anon_sym_QMARK_DOT] = ACTIONS(935),
    [anon_sym_BQUOTE] = ACTIONS(935),
    [anon_sym_DOLLARr] = ACTIONS(933),
    [anon_sym_PLUS_PLUS] = ACTIONS(935),
    [anon_sym_DASH_DASH] = ACTIONS(935),
    [anon_sym_new] = ACTIONS(933),
  },
  [STATE(162)] = {
    [sym_comment] = STATE(162),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(937),
    [anon_sym_LBRACE] = ACTIONS(939),
    [anon_sym_RBRACE] = ACTIONS(939),
    [anon_sym_STAR] = ACTIONS(937),
    [anon_sym_as] = ACTIONS(937),
    [anon_sym_SEMI] = ACTIONS(939),
    [anon_sym_LPAREN] = ACTIONS(939),
    [anon_sym_DOT] = ACTIONS(939),
    [anon_sym_Text] = ACTIONS(937),
    [anon_sym_Button] = ACTIONS(937),
    [anon_sym_Image] = ACTIONS(937),
    [anon_sym_TextInput] = ACTIONS(937),
    [anon_sym_TextArea] = ACTIONS(937),
    [anon_sym_Column] = ACTIONS(937),
    [anon_sym_Row] = ACTIONS(937),
    [anon_sym_Stack] = ACTIONS(937),
    [anon_sym_Flex] = ACTIONS(937),
    [anon_sym_Grid] = ACTIONS(937),
    [anon_sym_GridRow] = ACTIONS(937),
    [anon_sym_GridCol] = ACTIONS(937),
    [anon_sym_List] = ACTIONS(937),
    [anon_sym_ScrollList] = ACTIONS(937),
    [anon_sym_ListItem] = ACTIONS(937),
    [anon_sym_GridItem] = ACTIONS(937),
    [anon_sym_ForEach] = ACTIONS(937),
    [sym_identifier] = ACTIONS(937),
    [anon_sym_DQUOTE] = ACTIONS(939),
    [anon_sym_SQUOTE] = ACTIONS(939),
    [anon_sym_DOLLAR] = ACTIONS(937),
    [sym_numeric_literal] = ACTIONS(939),
    [anon_sym_true] = ACTIONS(937),
    [anon_sym_false] = ACTIONS(937),
    [anon_sym_null] = ACTIONS(937),
    [anon_sym_PIPE_PIPE] = ACTIONS(939),
    [anon_sym_AMP_AMP] = ACTIONS(939),
    [anon_sym_PIPE] = ACTIONS(937),
    [anon_sym_CARET] = ACTIONS(939),
    [anon_sym_AMP] = ACTIONS(937),
    [anon_sym_EQ_EQ] = ACTIONS(937),
    [anon_sym_BANG_EQ] = ACTIONS(937),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(939),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(939),
    [anon_sym_LT] = ACTIONS(937),
    [anon_sym_GT] = ACTIONS(937),
    [anon_sym_LT_EQ] = ACTIONS(939),
    [anon_sym_GT_EQ] = ACTIONS(939),
    [anon_sym_instanceof] = ACTIONS(937),
    [anon_sym_in] = ACTIONS(937),
    [anon_sym_LT_LT] = ACTIONS(939),
    [anon_sym_GT_GT] = ACTIONS(937),
    [anon_sym_GT_GT_GT] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(937),
    [anon_sym_DASH] = ACTIONS(937),
    [anon_sym_PERCENT] = ACTIONS(939),
    [anon_sym_STAR_STAR] = ACTIONS(939),
    [anon_sym_BANG] = ACTIONS(937),
    [anon_sym_TILDE] = ACTIONS(939),
    [anon_sym_typeof] = ACTIONS(937),
    [anon_sym_void] = ACTIONS(937),
    [anon_sym_delete] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(937),
    [anon_sym_await] = ACTIONS(937),
    [anon_sym_LBRACK] = ACTIONS(939),
    [anon_sym_if] = ACTIONS(937),
    [anon_sym_async] = ACTIONS(937),
    [anon_sym_QMARK_DOT] = ACTIONS(939),
    [anon_sym_BQUOTE] = ACTIONS(939),
    [anon_sym_DOLLARr] = ACTIONS(937),
    [anon_sym_PLUS_PLUS] = ACTIONS(939),
    [anon_sym_DASH_DASH] = ACTIONS(939),
    [anon_sym_new] = ACTIONS(937),
  },
  [STATE(163)] = {
    [sym_comment] = STATE(163),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(843),
    [anon_sym_LBRACE] = ACTIONS(845),
    [anon_sym_RBRACE] = ACTIONS(845),
    [anon_sym_STAR] = ACTIONS(843),
    [anon_sym_as] = ACTIONS(843),
    [anon_sym_SEMI] = ACTIONS(845),
    [anon_sym_LPAREN] = ACTIONS(845),
    [anon_sym_DOT] = ACTIONS(845),
    [anon_sym_Text] = ACTIONS(843),
    [anon_sym_Button] = ACTIONS(843),
    [anon_sym_Image] = ACTIONS(843),
    [anon_sym_TextInput] = ACTIONS(843),
    [anon_sym_TextArea] = ACTIONS(843),
    [anon_sym_Column] = ACTIONS(843),
    [anon_sym_Row] = ACTIONS(843),
    [anon_sym_Stack] = ACTIONS(843),
    [anon_sym_Flex] = ACTIONS(843),
    [anon_sym_Grid] = ACTIONS(843),
    [anon_sym_GridRow] = ACTIONS(843),
    [anon_sym_GridCol] = ACTIONS(843),
    [anon_sym_List] = ACTIONS(843),
    [anon_sym_ScrollList] = ACTIONS(843),
    [anon_sym_ListItem] = ACTIONS(843),
    [anon_sym_GridItem] = ACTIONS(843),
    [anon_sym_ForEach] = ACTIONS(843),
    [sym_identifier] = ACTIONS(843),
    [anon_sym_DQUOTE] = ACTIONS(845),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DOLLAR] = ACTIONS(843),
    [sym_numeric_literal] = ACTIONS(845),
    [anon_sym_true] = ACTIONS(843),
    [anon_sym_false] = ACTIONS(843),
    [anon_sym_null] = ACTIONS(843),
    [anon_sym_PIPE_PIPE] = ACTIONS(845),
    [anon_sym_AMP_AMP] = ACTIONS(845),
    [anon_sym_PIPE] = ACTIONS(843),
    [anon_sym_CARET] = ACTIONS(845),
    [anon_sym_AMP] = ACTIONS(843),
    [anon_sym_EQ_EQ] = ACTIONS(843),
    [anon_sym_BANG_EQ] = ACTIONS(843),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(845),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(845),
    [anon_sym_LT] = ACTIONS(843),
    [anon_sym_GT] = ACTIONS(843),
    [anon_sym_LT_EQ] = ACTIONS(845),
    [anon_sym_GT_EQ] = ACTIONS(845),
    [anon_sym_instanceof] = ACTIONS(843),
    [anon_sym_in] = ACTIONS(843),
    [anon_sym_LT_LT] = ACTIONS(845),
    [anon_sym_GT_GT] = ACTIONS(843),
    [anon_sym_GT_GT_GT] = ACTIONS(845),
    [anon_sym_PLUS] = ACTIONS(843),
    [anon_sym_DASH] = ACTIONS(843),
    [anon_sym_PERCENT] = ACTIONS(845),
    [anon_sym_STAR_STAR] = ACTIONS(845),
    [anon_sym_BANG] = ACTIONS(843),
    [anon_sym_TILDE] = ACTIONS(845),
    [anon_sym_typeof] = ACTIONS(843),
    [anon_sym_void] = ACTIONS(843),
    [anon_sym_delete] = ACTIONS(843),
    [anon_sym_QMARK] = ACTIONS(843),
    [anon_sym_await] = ACTIONS(843),
    [anon_sym_LBRACK] = ACTIONS(845),
    [anon_sym_if] = ACTIONS(843),
    [anon_sym_async] = ACTIONS(843),
    [anon_sym_QMARK_DOT] = ACTIONS(845),
    [anon_sym_BQUOTE] = ACTIONS(845),
    [anon_sym_DOLLARr] = ACTIONS(843),
    [anon_sym_PLUS_PLUS] = ACTIONS(845),
    [anon_sym_DASH_DASH] = ACTIONS(845),
    [anon_sym_new] = ACTIONS(843),
  },
  [STATE(164)] = {
    [sym_comment] = STATE(164),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_RBRACE] = ACTIONS(838),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_as] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_LPAREN] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(838),
    [anon_sym_Text] = ACTIONS(836),
    [anon_sym_Button] = ACTIONS(836),
    [anon_sym_Image] = ACTIONS(836),
    [anon_sym_TextInput] = ACTIONS(836),
    [anon_sym_TextArea] = ACTIONS(836),
    [anon_sym_Column] = ACTIONS(836),
    [anon_sym_Row] = ACTIONS(836),
    [anon_sym_Stack] = ACTIONS(836),
    [anon_sym_Flex] = ACTIONS(836),
    [anon_sym_Grid] = ACTIONS(836),
    [anon_sym_GridRow] = ACTIONS(836),
    [anon_sym_GridCol] = ACTIONS(836),
    [anon_sym_List] = ACTIONS(836),
    [anon_sym_ScrollList] = ACTIONS(836),
    [anon_sym_ListItem] = ACTIONS(836),
    [anon_sym_GridItem] = ACTIONS(836),
    [anon_sym_ForEach] = ACTIONS(836),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_DQUOTE] = ACTIONS(838),
    [anon_sym_SQUOTE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(836),
    [sym_numeric_literal] = ACTIONS(838),
    [anon_sym_true] = ACTIONS(836),
    [anon_sym_false] = ACTIONS(836),
    [anon_sym_null] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(838),
    [anon_sym_AMP_AMP] = ACTIONS(838),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(838),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(836),
    [anon_sym_BANG_EQ] = ACTIONS(836),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(838),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(838),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_instanceof] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(838),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_GT_GT_GT] = ACTIONS(838),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(838),
    [anon_sym_STAR_STAR] = ACTIONS(838),
    [anon_sym_BANG] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(836),
    [anon_sym_void] = ACTIONS(836),
    [anon_sym_delete] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(836),
    [anon_sym_await] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_async] = ACTIONS(836),
    [anon_sym_QMARK_DOT] = ACTIONS(838),
    [anon_sym_BQUOTE] = ACTIONS(838),
    [anon_sym_DOLLARr] = ACTIONS(836),
    [anon_sym_PLUS_PLUS] = ACTIONS(838),
    [anon_sym_DASH_DASH] = ACTIONS(838),
    [anon_sym_new] = ACTIONS(836),
  },
  [STATE(165)] = {
    [sym_comment] = STATE(165),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(855),
    [anon_sym_LBRACE] = ACTIONS(857),
    [anon_sym_RBRACE] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_as] = ACTIONS(855),
    [anon_sym_SEMI] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(857),
    [anon_sym_DOT] = ACTIONS(857),
    [anon_sym_Text] = ACTIONS(855),
    [anon_sym_Button] = ACTIONS(855),
    [anon_sym_Image] = ACTIONS(855),
    [anon_sym_TextInput] = ACTIONS(855),
    [anon_sym_TextArea] = ACTIONS(855),
    [anon_sym_Column] = ACTIONS(855),
    [anon_sym_Row] = ACTIONS(855),
    [anon_sym_Stack] = ACTIONS(855),
    [anon_sym_Flex] = ACTIONS(855),
    [anon_sym_Grid] = ACTIONS(855),
    [anon_sym_GridRow] = ACTIONS(855),
    [anon_sym_GridCol] = ACTIONS(855),
    [anon_sym_List] = ACTIONS(855),
    [anon_sym_ScrollList] = ACTIONS(855),
    [anon_sym_ListItem] = ACTIONS(855),
    [anon_sym_GridItem] = ACTIONS(855),
    [anon_sym_ForEach] = ACTIONS(855),
    [sym_identifier] = ACTIONS(855),
    [anon_sym_DQUOTE] = ACTIONS(857),
    [anon_sym_SQUOTE] = ACTIONS(857),
    [anon_sym_DOLLAR] = ACTIONS(855),
    [sym_numeric_literal] = ACTIONS(857),
    [anon_sym_true] = ACTIONS(855),
    [anon_sym_false] = ACTIONS(855),
    [anon_sym_null] = ACTIONS(855),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(855),
    [anon_sym_CARET] = ACTIONS(857),
    [anon_sym_AMP] = ACTIONS(855),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(857),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(857),
    [anon_sym_LT] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(857),
    [anon_sym_instanceof] = ACTIONS(855),
    [anon_sym_in] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_GT_GT_GT] = ACTIONS(857),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(855),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_STAR_STAR] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(855),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_typeof] = ACTIONS(855),
    [anon_sym_void] = ACTIONS(855),
    [anon_sym_delete] = ACTIONS(855),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_await] = ACTIONS(855),
    [anon_sym_LBRACK] = ACTIONS(857),
    [anon_sym_if] = ACTIONS(855),
    [anon_sym_async] = ACTIONS(855),
    [anon_sym_QMARK_DOT] = ACTIONS(857),
    [anon_sym_BQUOTE] = ACTIONS(857),
    [anon_sym_DOLLARr] = ACTIONS(855),
    [anon_sym_PLUS_PLUS] = ACTIONS(857),
    [anon_sym_DASH_DASH] = ACTIONS(857),
    [anon_sym_new] = ACTIONS(855),
  },
  [STATE(166)] = {
    [sym_comment] = STATE(166),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(943),
    [anon_sym_RBRACE] = ACTIONS(943),
    [anon_sym_STAR] = ACTIONS(941),
    [anon_sym_as] = ACTIONS(941),
    [anon_sym_SEMI] = ACTIONS(943),
    [anon_sym_LPAREN] = ACTIONS(943),
    [anon_sym_DOT] = ACTIONS(943),
    [anon_sym_Text] = ACTIONS(941),
    [anon_sym_Button] = ACTIONS(941),
    [anon_sym_Image] = ACTIONS(941),
    [anon_sym_TextInput] = ACTIONS(941),
    [anon_sym_TextArea] = ACTIONS(941),
    [anon_sym_Column] = ACTIONS(941),
    [anon_sym_Row] = ACTIONS(941),
    [anon_sym_Stack] = ACTIONS(941),
    [anon_sym_Flex] = ACTIONS(941),
    [anon_sym_Grid] = ACTIONS(941),
    [anon_sym_GridRow] = ACTIONS(941),
    [anon_sym_GridCol] = ACTIONS(941),
    [anon_sym_List] = ACTIONS(941),
    [anon_sym_ScrollList] = ACTIONS(941),
    [anon_sym_ListItem] = ACTIONS(941),
    [anon_sym_GridItem] = ACTIONS(941),
    [anon_sym_ForEach] = ACTIONS(941),
    [sym_identifier] = ACTIONS(941),
    [anon_sym_DQUOTE] = ACTIONS(943),
    [anon_sym_SQUOTE] = ACTIONS(943),
    [anon_sym_DOLLAR] = ACTIONS(941),
    [sym_numeric_literal] = ACTIONS(943),
    [anon_sym_true] = ACTIONS(941),
    [anon_sym_false] = ACTIONS(941),
    [anon_sym_null] = ACTIONS(941),
    [anon_sym_PIPE_PIPE] = ACTIONS(943),
    [anon_sym_AMP_AMP] = ACTIONS(943),
    [anon_sym_PIPE] = ACTIONS(941),
    [anon_sym_CARET] = ACTIONS(943),
    [anon_sym_AMP] = ACTIONS(941),
    [anon_sym_EQ_EQ] = ACTIONS(941),
    [anon_sym_BANG_EQ] = ACTIONS(941),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(943),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(943),
    [anon_sym_LT] = ACTIONS(941),
    [anon_sym_GT] = ACTIONS(941),
    [anon_sym_LT_EQ] = ACTIONS(943),
    [anon_sym_GT_EQ] = ACTIONS(943),
    [anon_sym_instanceof] = ACTIONS(941),
    [anon_sym_in] = ACTIONS(941),
    [anon_sym_LT_LT] = ACTIONS(943),
    [anon_sym_GT_GT] = ACTIONS(941),
    [anon_sym_GT_GT_GT] = ACTIONS(943),
    [anon_sym_PLUS] = ACTIONS(941),
    [anon_sym_DASH] = ACTIONS(941),
    [anon_sym_PERCENT] = ACTIONS(943),
    [anon_sym_STAR_STAR] = ACTIONS(943),
    [anon_sym_BANG] = ACTIONS(941),
    [anon_sym_TILDE] = ACTIONS(943),
    [anon_sym_typeof] = ACTIONS(941),
    [anon_sym_void] = ACTIONS(941),
    [anon_sym_delete] = ACTIONS(941),
    [anon_sym_QMARK] = ACTIONS(941),
    [anon_sym_await] = ACTIONS(941),
    [anon_sym_LBRACK] = ACTIONS(943),
    [anon_sym_if] = ACTIONS(941),
    [anon_sym_async] = ACTIONS(941),
    [anon_sym_QMARK_DOT] = ACTIONS(943),
    [anon_sym_BQUOTE] = ACTIONS(943),
    [anon_sym_DOLLARr] = ACTIONS(941),
    [anon_sym_PLUS_PLUS] = ACTIONS(943),
    [anon_sym_DASH_DASH] = ACTIONS(943),
    [anon_sym_new] = ACTIONS(941),
  },
  [STATE(167)] = {
    [sym_comment] = STATE(167),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(754),
    [anon_sym_LBRACE] = ACTIONS(749),
    [anon_sym_RBRACE] = ACTIONS(749),
    [anon_sym_STAR] = ACTIONS(754),
    [anon_sym_as] = ACTIONS(754),
    [anon_sym_SEMI] = ACTIONS(749),
    [anon_sym_LPAREN] = ACTIONS(749),
    [anon_sym_DOT] = ACTIONS(749),
    [anon_sym_Text] = ACTIONS(754),
    [anon_sym_Button] = ACTIONS(754),
    [anon_sym_Image] = ACTIONS(754),
    [anon_sym_TextInput] = ACTIONS(754),
    [anon_sym_TextArea] = ACTIONS(754),
    [anon_sym_Column] = ACTIONS(754),
    [anon_sym_Row] = ACTIONS(754),
    [anon_sym_Stack] = ACTIONS(754),
    [anon_sym_Flex] = ACTIONS(754),
    [anon_sym_Grid] = ACTIONS(754),
    [anon_sym_GridRow] = ACTIONS(754),
    [anon_sym_GridCol] = ACTIONS(754),
    [anon_sym_List] = ACTIONS(754),
    [anon_sym_ScrollList] = ACTIONS(754),
    [anon_sym_ListItem] = ACTIONS(754),
    [anon_sym_GridItem] = ACTIONS(754),
    [anon_sym_ForEach] = ACTIONS(754),
    [sym_identifier] = ACTIONS(754),
    [anon_sym_DQUOTE] = ACTIONS(749),
    [anon_sym_SQUOTE] = ACTIONS(749),
    [anon_sym_DOLLAR] = ACTIONS(754),
    [sym_numeric_literal] = ACTIONS(749),
    [anon_sym_true] = ACTIONS(754),
    [anon_sym_false] = ACTIONS(754),
    [anon_sym_null] = ACTIONS(754),
    [anon_sym_PIPE_PIPE] = ACTIONS(749),
    [anon_sym_AMP_AMP] = ACTIONS(749),
    [anon_sym_PIPE] = ACTIONS(754),
    [anon_sym_CARET] = ACTIONS(749),
    [anon_sym_AMP] = ACTIONS(754),
    [anon_sym_EQ_EQ] = ACTIONS(754),
    [anon_sym_BANG_EQ] = ACTIONS(754),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(749),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(749),
    [anon_sym_LT] = ACTIONS(754),
    [anon_sym_GT] = ACTIONS(754),
    [anon_sym_LT_EQ] = ACTIONS(749),
    [anon_sym_GT_EQ] = ACTIONS(749),
    [anon_sym_instanceof] = ACTIONS(754),
    [anon_sym_in] = ACTIONS(754),
    [anon_sym_LT_LT] = ACTIONS(749),
    [anon_sym_GT_GT] = ACTIONS(754),
    [anon_sym_GT_GT_GT] = ACTIONS(749),
    [anon_sym_PLUS] = ACTIONS(754),
    [anon_sym_DASH] = ACTIONS(754),
    [anon_sym_PERCENT] = ACTIONS(749),
    [anon_sym_STAR_STAR] = ACTIONS(749),
    [anon_sym_BANG] = ACTIONS(754),
    [anon_sym_TILDE] = ACTIONS(749),
    [anon_sym_typeof] = ACTIONS(754),
    [anon_sym_void] = ACTIONS(754),
    [anon_sym_delete] = ACTIONS(754),
    [anon_sym_QMARK] = ACTIONS(754),
    [anon_sym_await] = ACTIONS(754),
    [anon_sym_LBRACK] = ACTIONS(749),
    [anon_sym_if] = ACTIONS(754),
    [anon_sym_async] = ACTIONS(754),
    [anon_sym_QMARK_DOT] = ACTIONS(749),
    [anon_sym_BQUOTE] = ACTIONS(749),
    [anon_sym_DOLLARr] = ACTIONS(754),
    [anon_sym_PLUS_PLUS] = ACTIONS(749),
    [anon_sym_DASH_DASH] = ACTIONS(749),
    [anon_sym_new] = ACTIONS(754),
  },
  [STATE(168)] = {
    [sym_comment] = STATE(168),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(847),
    [anon_sym_LBRACE] = ACTIONS(849),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_STAR] = ACTIONS(847),
    [anon_sym_as] = ACTIONS(847),
    [anon_sym_SEMI] = ACTIONS(849),
    [anon_sym_LPAREN] = ACTIONS(849),
    [anon_sym_DOT] = ACTIONS(849),
    [anon_sym_Text] = ACTIONS(847),
    [anon_sym_Button] = ACTIONS(847),
    [anon_sym_Image] = ACTIONS(847),
    [anon_sym_TextInput] = ACTIONS(847),
    [anon_sym_TextArea] = ACTIONS(847),
    [anon_sym_Column] = ACTIONS(847),
    [anon_sym_Row] = ACTIONS(847),
    [anon_sym_Stack] = ACTIONS(847),
    [anon_sym_Flex] = ACTIONS(847),
    [anon_sym_Grid] = ACTIONS(847),
    [anon_sym_GridRow] = ACTIONS(847),
    [anon_sym_GridCol] = ACTIONS(847),
    [anon_sym_List] = ACTIONS(847),
    [anon_sym_ScrollList] = ACTIONS(847),
    [anon_sym_ListItem] = ACTIONS(847),
    [anon_sym_GridItem] = ACTIONS(847),
    [anon_sym_ForEach] = ACTIONS(847),
    [sym_identifier] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [anon_sym_SQUOTE] = ACTIONS(849),
    [anon_sym_DOLLAR] = ACTIONS(847),
    [sym_numeric_literal] = ACTIONS(849),
    [anon_sym_true] = ACTIONS(847),
    [anon_sym_false] = ACTIONS(847),
    [anon_sym_null] = ACTIONS(847),
    [anon_sym_PIPE_PIPE] = ACTIONS(849),
    [anon_sym_AMP_AMP] = ACTIONS(849),
    [anon_sym_PIPE] = ACTIONS(847),
    [anon_sym_CARET] = ACTIONS(849),
    [anon_sym_AMP] = ACTIONS(847),
    [anon_sym_EQ_EQ] = ACTIONS(847),
    [anon_sym_BANG_EQ] = ACTIONS(847),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(849),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(849),
    [anon_sym_LT] = ACTIONS(847),
    [anon_sym_GT] = ACTIONS(847),
    [anon_sym_LT_EQ] = ACTIONS(849),
    [anon_sym_GT_EQ] = ACTIONS(849),
    [anon_sym_instanceof] = ACTIONS(847),
    [anon_sym_in] = ACTIONS(847),
    [anon_sym_LT_LT] = ACTIONS(849),
    [anon_sym_GT_GT] = ACTIONS(847),
    [anon_sym_GT_GT_GT] = ACTIONS(849),
    [anon_sym_PLUS] = ACTIONS(847),
    [anon_sym_DASH] = ACTIONS(847),
    [anon_sym_PERCENT] = ACTIONS(849),
    [anon_sym_STAR_STAR] = ACTIONS(849),
    [anon_sym_BANG] = ACTIONS(847),
    [anon_sym_TILDE] = ACTIONS(849),
    [anon_sym_typeof] = ACTIONS(847),
    [anon_sym_void] = ACTIONS(847),
    [anon_sym_delete] = ACTIONS(847),
    [anon_sym_QMARK] = ACTIONS(847),
    [anon_sym_await] = ACTIONS(847),
    [anon_sym_LBRACK] = ACTIONS(849),
    [anon_sym_if] = ACTIONS(847),
    [anon_sym_async] = ACTIONS(847),
    [anon_sym_QMARK_DOT] = ACTIONS(849),
    [anon_sym_BQUOTE] = ACTIONS(849),
    [anon_sym_DOLLARr] = ACTIONS(847),
    [anon_sym_PLUS_PLUS] = ACTIONS(849),
    [anon_sym_DASH_DASH] = ACTIONS(849),
    [anon_sym_new] = ACTIONS(847),
  },
  [STATE(169)] = {
    [sym_comment] = STATE(169),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(700),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_RBRACE] = ACTIONS(698),
    [anon_sym_STAR] = ACTIONS(700),
    [anon_sym_as] = ACTIONS(700),
    [anon_sym_SEMI] = ACTIONS(698),
    [anon_sym_LPAREN] = ACTIONS(698),
    [anon_sym_DOT] = ACTIONS(698),
    [anon_sym_Text] = ACTIONS(700),
    [anon_sym_Button] = ACTIONS(700),
    [anon_sym_Image] = ACTIONS(700),
    [anon_sym_TextInput] = ACTIONS(700),
    [anon_sym_TextArea] = ACTIONS(700),
    [anon_sym_Column] = ACTIONS(700),
    [anon_sym_Row] = ACTIONS(700),
    [anon_sym_Stack] = ACTIONS(700),
    [anon_sym_Flex] = ACTIONS(700),
    [anon_sym_Grid] = ACTIONS(700),
    [anon_sym_GridRow] = ACTIONS(700),
    [anon_sym_GridCol] = ACTIONS(700),
    [anon_sym_List] = ACTIONS(700),
    [anon_sym_ScrollList] = ACTIONS(700),
    [anon_sym_ListItem] = ACTIONS(700),
    [anon_sym_GridItem] = ACTIONS(700),
    [anon_sym_ForEach] = ACTIONS(700),
    [sym_identifier] = ACTIONS(700),
    [anon_sym_DQUOTE] = ACTIONS(698),
    [anon_sym_SQUOTE] = ACTIONS(698),
    [anon_sym_DOLLAR] = ACTIONS(700),
    [sym_numeric_literal] = ACTIONS(698),
    [anon_sym_true] = ACTIONS(700),
    [anon_sym_false] = ACTIONS(700),
    [anon_sym_null] = ACTIONS(700),
    [anon_sym_PIPE_PIPE] = ACTIONS(698),
    [anon_sym_AMP_AMP] = ACTIONS(698),
    [anon_sym_PIPE] = ACTIONS(700),
    [anon_sym_CARET] = ACTIONS(698),
    [anon_sym_AMP] = ACTIONS(700),
    [anon_sym_EQ_EQ] = ACTIONS(700),
    [anon_sym_BANG_EQ] = ACTIONS(700),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(698),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(698),
    [anon_sym_LT] = ACTIONS(700),
    [anon_sym_GT] = ACTIONS(700),
    [anon_sym_LT_EQ] = ACTIONS(698),
    [anon_sym_GT_EQ] = ACTIONS(698),
    [anon_sym_instanceof] = ACTIONS(700),
    [anon_sym_in] = ACTIONS(700),
    [anon_sym_LT_LT] = ACTIONS(698),
    [anon_sym_GT_GT] = ACTIONS(700),
    [anon_sym_GT_GT_GT] = ACTIONS(698),
    [anon_sym_PLUS] = ACTIONS(700),
    [anon_sym_DASH] = ACTIONS(700),
    [anon_sym_PERCENT] = ACTIONS(698),
    [anon_sym_STAR_STAR] = ACTIONS(698),
    [anon_sym_BANG] = ACTIONS(700),
    [anon_sym_TILDE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(700),
    [anon_sym_void] = ACTIONS(700),
    [anon_sym_delete] = ACTIONS(700),
    [anon_sym_QMARK] = ACTIONS(700),
    [anon_sym_await] = ACTIONS(700),
    [anon_sym_LBRACK] = ACTIONS(698),
    [anon_sym_if] = ACTIONS(700),
    [anon_sym_async] = ACTIONS(700),
    [anon_sym_QMARK_DOT] = ACTIONS(698),
    [anon_sym_BQUOTE] = ACTIONS(698),
    [anon_sym_DOLLARr] = ACTIONS(700),
    [anon_sym_PLUS_PLUS] = ACTIONS(698),
    [anon_sym_DASH_DASH] = ACTIONS(698),
    [anon_sym_new] = ACTIONS(700),
  },
  [STATE(170)] = {
    [sym_comment] = STATE(170),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [anon_sym_Text] = ACTIONS(756),
    [anon_sym_Button] = ACTIONS(756),
    [anon_sym_Image] = ACTIONS(756),
    [anon_sym_TextInput] = ACTIONS(756),
    [anon_sym_TextArea] = ACTIONS(756),
    [anon_sym_Column] = ACTIONS(756),
    [anon_sym_Row] = ACTIONS(756),
    [anon_sym_Stack] = ACTIONS(756),
    [anon_sym_Flex] = ACTIONS(756),
    [anon_sym_Grid] = ACTIONS(756),
    [anon_sym_GridRow] = ACTIONS(756),
    [anon_sym_GridCol] = ACTIONS(756),
    [anon_sym_List] = ACTIONS(756),
    [anon_sym_ScrollList] = ACTIONS(756),
    [anon_sym_ListItem] = ACTIONS(756),
    [anon_sym_GridItem] = ACTIONS(756),
    [anon_sym_ForEach] = ACTIONS(756),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(758),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(171)] = {
    [sym_comment] = STATE(171),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(715),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_RBRACE] = ACTIONS(713),
    [anon_sym_STAR] = ACTIONS(715),
    [anon_sym_as] = ACTIONS(715),
    [anon_sym_SEMI] = ACTIONS(713),
    [anon_sym_LPAREN] = ACTIONS(713),
    [anon_sym_DOT] = ACTIONS(713),
    [anon_sym_Text] = ACTIONS(715),
    [anon_sym_Button] = ACTIONS(715),
    [anon_sym_Image] = ACTIONS(715),
    [anon_sym_TextInput] = ACTIONS(715),
    [anon_sym_TextArea] = ACTIONS(715),
    [anon_sym_Column] = ACTIONS(715),
    [anon_sym_Row] = ACTIONS(715),
    [anon_sym_Stack] = ACTIONS(715),
    [anon_sym_Flex] = ACTIONS(715),
    [anon_sym_Grid] = ACTIONS(715),
    [anon_sym_GridRow] = ACTIONS(715),
    [anon_sym_GridCol] = ACTIONS(715),
    [anon_sym_List] = ACTIONS(715),
    [anon_sym_ScrollList] = ACTIONS(715),
    [anon_sym_ListItem] = ACTIONS(715),
    [anon_sym_GridItem] = ACTIONS(715),
    [anon_sym_ForEach] = ACTIONS(715),
    [sym_identifier] = ACTIONS(715),
    [anon_sym_DQUOTE] = ACTIONS(713),
    [anon_sym_SQUOTE] = ACTIONS(713),
    [anon_sym_DOLLAR] = ACTIONS(715),
    [sym_numeric_literal] = ACTIONS(713),
    [anon_sym_true] = ACTIONS(715),
    [anon_sym_false] = ACTIONS(715),
    [anon_sym_null] = ACTIONS(715),
    [anon_sym_PIPE_PIPE] = ACTIONS(713),
    [anon_sym_AMP_AMP] = ACTIONS(713),
    [anon_sym_PIPE] = ACTIONS(715),
    [anon_sym_CARET] = ACTIONS(713),
    [anon_sym_AMP] = ACTIONS(715),
    [anon_sym_EQ_EQ] = ACTIONS(715),
    [anon_sym_BANG_EQ] = ACTIONS(715),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(713),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(713),
    [anon_sym_LT] = ACTIONS(715),
    [anon_sym_GT] = ACTIONS(715),
    [anon_sym_LT_EQ] = ACTIONS(713),
    [anon_sym_GT_EQ] = ACTIONS(713),
    [anon_sym_instanceof] = ACTIONS(715),
    [anon_sym_in] = ACTIONS(715),
    [anon_sym_LT_LT] = ACTIONS(713),
    [anon_sym_GT_GT] = ACTIONS(715),
    [anon_sym_GT_GT_GT] = ACTIONS(713),
    [anon_sym_PLUS] = ACTIONS(715),
    [anon_sym_DASH] = ACTIONS(715),
    [anon_sym_PERCENT] = ACTIONS(713),
    [anon_sym_STAR_STAR] = ACTIONS(713),
    [anon_sym_BANG] = ACTIONS(715),
    [anon_sym_TILDE] = ACTIONS(713),
    [anon_sym_typeof] = ACTIONS(715),
    [anon_sym_void] = ACTIONS(715),
    [anon_sym_delete] = ACTIONS(715),
    [anon_sym_QMARK] = ACTIONS(715),
    [anon_sym_await] = ACTIONS(715),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_if] = ACTIONS(715),
    [anon_sym_async] = ACTIONS(715),
    [anon_sym_QMARK_DOT] = ACTIONS(713),
    [anon_sym_BQUOTE] = ACTIONS(713),
    [anon_sym_DOLLARr] = ACTIONS(715),
    [anon_sym_PLUS_PLUS] = ACTIONS(713),
    [anon_sym_DASH_DASH] = ACTIONS(713),
    [anon_sym_new] = ACTIONS(715),
  },
  [STATE(172)] = {
    [sym_comment] = STATE(172),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(945),
    [anon_sym_LBRACE] = ACTIONS(947),
    [anon_sym_RBRACE] = ACTIONS(947),
    [anon_sym_STAR] = ACTIONS(945),
    [anon_sym_as] = ACTIONS(945),
    [anon_sym_SEMI] = ACTIONS(947),
    [anon_sym_LPAREN] = ACTIONS(947),
    [anon_sym_DOT] = ACTIONS(947),
    [anon_sym_Text] = ACTIONS(945),
    [anon_sym_Button] = ACTIONS(945),
    [anon_sym_Image] = ACTIONS(945),
    [anon_sym_TextInput] = ACTIONS(945),
    [anon_sym_TextArea] = ACTIONS(945),
    [anon_sym_Column] = ACTIONS(945),
    [anon_sym_Row] = ACTIONS(945),
    [anon_sym_Stack] = ACTIONS(945),
    [anon_sym_Flex] = ACTIONS(945),
    [anon_sym_Grid] = ACTIONS(945),
    [anon_sym_GridRow] = ACTIONS(945),
    [anon_sym_GridCol] = ACTIONS(945),
    [anon_sym_List] = ACTIONS(945),
    [anon_sym_ScrollList] = ACTIONS(945),
    [anon_sym_ListItem] = ACTIONS(945),
    [anon_sym_GridItem] = ACTIONS(945),
    [anon_sym_ForEach] = ACTIONS(945),
    [sym_identifier] = ACTIONS(945),
    [anon_sym_DQUOTE] = ACTIONS(947),
    [anon_sym_SQUOTE] = ACTIONS(947),
    [anon_sym_DOLLAR] = ACTIONS(945),
    [sym_numeric_literal] = ACTIONS(947),
    [anon_sym_true] = ACTIONS(945),
    [anon_sym_false] = ACTIONS(945),
    [anon_sym_null] = ACTIONS(945),
    [anon_sym_PIPE_PIPE] = ACTIONS(947),
    [anon_sym_AMP_AMP] = ACTIONS(947),
    [anon_sym_PIPE] = ACTIONS(945),
    [anon_sym_CARET] = ACTIONS(947),
    [anon_sym_AMP] = ACTIONS(945),
    [anon_sym_EQ_EQ] = ACTIONS(945),
    [anon_sym_BANG_EQ] = ACTIONS(945),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(947),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(947),
    [anon_sym_LT] = ACTIONS(945),
    [anon_sym_GT] = ACTIONS(945),
    [anon_sym_LT_EQ] = ACTIONS(947),
    [anon_sym_GT_EQ] = ACTIONS(947),
    [anon_sym_instanceof] = ACTIONS(945),
    [anon_sym_in] = ACTIONS(945),
    [anon_sym_LT_LT] = ACTIONS(947),
    [anon_sym_GT_GT] = ACTIONS(945),
    [anon_sym_GT_GT_GT] = ACTIONS(947),
    [anon_sym_PLUS] = ACTIONS(945),
    [anon_sym_DASH] = ACTIONS(945),
    [anon_sym_PERCENT] = ACTIONS(947),
    [anon_sym_STAR_STAR] = ACTIONS(947),
    [anon_sym_BANG] = ACTIONS(945),
    [anon_sym_TILDE] = ACTIONS(947),
    [anon_sym_typeof] = ACTIONS(945),
    [anon_sym_void] = ACTIONS(945),
    [anon_sym_delete] = ACTIONS(945),
    [anon_sym_QMARK] = ACTIONS(945),
    [anon_sym_await] = ACTIONS(945),
    [anon_sym_LBRACK] = ACTIONS(947),
    [anon_sym_if] = ACTIONS(945),
    [anon_sym_async] = ACTIONS(945),
    [anon_sym_QMARK_DOT] = ACTIONS(947),
    [anon_sym_BQUOTE] = ACTIONS(947),
    [anon_sym_DOLLARr] = ACTIONS(945),
    [anon_sym_PLUS_PLUS] = ACTIONS(947),
    [anon_sym_DASH_DASH] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(945),
  },
  [STATE(173)] = {
    [sym_comment] = STATE(173),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(805),
    [anon_sym_LBRACE] = ACTIONS(807),
    [anon_sym_RBRACE] = ACTIONS(807),
    [anon_sym_STAR] = ACTIONS(805),
    [anon_sym_as] = ACTIONS(805),
    [anon_sym_SEMI] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(807),
    [anon_sym_DOT] = ACTIONS(807),
    [anon_sym_Text] = ACTIONS(805),
    [anon_sym_Button] = ACTIONS(805),
    [anon_sym_Image] = ACTIONS(805),
    [anon_sym_TextInput] = ACTIONS(805),
    [anon_sym_TextArea] = ACTIONS(805),
    [anon_sym_Column] = ACTIONS(805),
    [anon_sym_Row] = ACTIONS(805),
    [anon_sym_Stack] = ACTIONS(805),
    [anon_sym_Flex] = ACTIONS(805),
    [anon_sym_Grid] = ACTIONS(805),
    [anon_sym_GridRow] = ACTIONS(805),
    [anon_sym_GridCol] = ACTIONS(805),
    [anon_sym_List] = ACTIONS(805),
    [anon_sym_ScrollList] = ACTIONS(805),
    [anon_sym_ListItem] = ACTIONS(805),
    [anon_sym_GridItem] = ACTIONS(805),
    [anon_sym_ForEach] = ACTIONS(805),
    [sym_identifier] = ACTIONS(805),
    [anon_sym_DQUOTE] = ACTIONS(807),
    [anon_sym_SQUOTE] = ACTIONS(807),
    [anon_sym_DOLLAR] = ACTIONS(805),
    [sym_numeric_literal] = ACTIONS(807),
    [anon_sym_true] = ACTIONS(805),
    [anon_sym_false] = ACTIONS(805),
    [anon_sym_null] = ACTIONS(805),
    [anon_sym_PIPE_PIPE] = ACTIONS(807),
    [anon_sym_AMP_AMP] = ACTIONS(807),
    [anon_sym_PIPE] = ACTIONS(805),
    [anon_sym_CARET] = ACTIONS(807),
    [anon_sym_AMP] = ACTIONS(805),
    [anon_sym_EQ_EQ] = ACTIONS(805),
    [anon_sym_BANG_EQ] = ACTIONS(805),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(807),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(807),
    [anon_sym_LT] = ACTIONS(805),
    [anon_sym_GT] = ACTIONS(805),
    [anon_sym_LT_EQ] = ACTIONS(807),
    [anon_sym_GT_EQ] = ACTIONS(807),
    [anon_sym_instanceof] = ACTIONS(805),
    [anon_sym_in] = ACTIONS(805),
    [anon_sym_LT_LT] = ACTIONS(807),
    [anon_sym_GT_GT] = ACTIONS(805),
    [anon_sym_GT_GT_GT] = ACTIONS(807),
    [anon_sym_PLUS] = ACTIONS(805),
    [anon_sym_DASH] = ACTIONS(805),
    [anon_sym_PERCENT] = ACTIONS(807),
    [anon_sym_STAR_STAR] = ACTIONS(807),
    [anon_sym_BANG] = ACTIONS(805),
    [anon_sym_TILDE] = ACTIONS(807),
    [anon_sym_typeof] = ACTIONS(805),
    [anon_sym_void] = ACTIONS(805),
    [anon_sym_delete] = ACTIONS(805),
    [anon_sym_QMARK] = ACTIONS(805),
    [anon_sym_await] = ACTIONS(805),
    [anon_sym_LBRACK] = ACTIONS(807),
    [anon_sym_if] = ACTIONS(805),
    [anon_sym_async] = ACTIONS(805),
    [anon_sym_QMARK_DOT] = ACTIONS(807),
    [anon_sym_BQUOTE] = ACTIONS(807),
    [anon_sym_DOLLARr] = ACTIONS(805),
    [anon_sym_PLUS_PLUS] = ACTIONS(807),
    [anon_sym_DASH_DASH] = ACTIONS(807),
    [anon_sym_new] = ACTIONS(805),
  },
  [STATE(174)] = {
    [sym_comment] = STATE(174),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(851),
    [anon_sym_LBRACE] = ACTIONS(853),
    [anon_sym_RBRACE] = ACTIONS(853),
    [anon_sym_STAR] = ACTIONS(851),
    [anon_sym_as] = ACTIONS(851),
    [anon_sym_SEMI] = ACTIONS(853),
    [anon_sym_LPAREN] = ACTIONS(853),
    [anon_sym_DOT] = ACTIONS(853),
    [anon_sym_Text] = ACTIONS(851),
    [anon_sym_Button] = ACTIONS(851),
    [anon_sym_Image] = ACTIONS(851),
    [anon_sym_TextInput] = ACTIONS(851),
    [anon_sym_TextArea] = ACTIONS(851),
    [anon_sym_Column] = ACTIONS(851),
    [anon_sym_Row] = ACTIONS(851),
    [anon_sym_Stack] = ACTIONS(851),
    [anon_sym_Flex] = ACTIONS(851),
    [anon_sym_Grid] = ACTIONS(851),
    [anon_sym_GridRow] = ACTIONS(851),
    [anon_sym_GridCol] = ACTIONS(851),
    [anon_sym_List] = ACTIONS(851),
    [anon_sym_ScrollList] = ACTIONS(851),
    [anon_sym_ListItem] = ACTIONS(851),
    [anon_sym_GridItem] = ACTIONS(851),
    [anon_sym_ForEach] = ACTIONS(851),
    [sym_identifier] = ACTIONS(851),
    [anon_sym_DQUOTE] = ACTIONS(853),
    [anon_sym_SQUOTE] = ACTIONS(853),
    [anon_sym_DOLLAR] = ACTIONS(851),
    [sym_numeric_literal] = ACTIONS(853),
    [anon_sym_true] = ACTIONS(851),
    [anon_sym_false] = ACTIONS(851),
    [anon_sym_null] = ACTIONS(851),
    [anon_sym_PIPE_PIPE] = ACTIONS(853),
    [anon_sym_AMP_AMP] = ACTIONS(853),
    [anon_sym_PIPE] = ACTIONS(851),
    [anon_sym_CARET] = ACTIONS(853),
    [anon_sym_AMP] = ACTIONS(851),
    [anon_sym_EQ_EQ] = ACTIONS(851),
    [anon_sym_BANG_EQ] = ACTIONS(851),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(853),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(853),
    [anon_sym_LT] = ACTIONS(851),
    [anon_sym_GT] = ACTIONS(851),
    [anon_sym_LT_EQ] = ACTIONS(853),
    [anon_sym_GT_EQ] = ACTIONS(853),
    [anon_sym_instanceof] = ACTIONS(851),
    [anon_sym_in] = ACTIONS(851),
    [anon_sym_LT_LT] = ACTIONS(853),
    [anon_sym_GT_GT] = ACTIONS(851),
    [anon_sym_GT_GT_GT] = ACTIONS(853),
    [anon_sym_PLUS] = ACTIONS(851),
    [anon_sym_DASH] = ACTIONS(851),
    [anon_sym_PERCENT] = ACTIONS(853),
    [anon_sym_STAR_STAR] = ACTIONS(853),
    [anon_sym_BANG] = ACTIONS(851),
    [anon_sym_TILDE] = ACTIONS(853),
    [anon_sym_typeof] = ACTIONS(851),
    [anon_sym_void] = ACTIONS(851),
    [anon_sym_delete] = ACTIONS(851),
    [anon_sym_QMARK] = ACTIONS(851),
    [anon_sym_await] = ACTIONS(851),
    [anon_sym_LBRACK] = ACTIONS(853),
    [anon_sym_if] = ACTIONS(851),
    [anon_sym_async] = ACTIONS(851),
    [anon_sym_QMARK_DOT] = ACTIONS(853),
    [anon_sym_BQUOTE] = ACTIONS(853),
    [anon_sym_DOLLARr] = ACTIONS(851),
    [anon_sym_PLUS_PLUS] = ACTIONS(853),
    [anon_sym_DASH_DASH] = ACTIONS(853),
    [anon_sym_new] = ACTIONS(851),
  },
  [STATE(175)] = {
    [sym_comment] = STATE(175),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(809),
    [anon_sym_LBRACE] = ACTIONS(811),
    [anon_sym_RBRACE] = ACTIONS(811),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_as] = ACTIONS(809),
    [anon_sym_SEMI] = ACTIONS(811),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_DOT] = ACTIONS(811),
    [anon_sym_Text] = ACTIONS(809),
    [anon_sym_Button] = ACTIONS(809),
    [anon_sym_Image] = ACTIONS(809),
    [anon_sym_TextInput] = ACTIONS(809),
    [anon_sym_TextArea] = ACTIONS(809),
    [anon_sym_Column] = ACTIONS(809),
    [anon_sym_Row] = ACTIONS(809),
    [anon_sym_Stack] = ACTIONS(809),
    [anon_sym_Flex] = ACTIONS(809),
    [anon_sym_Grid] = ACTIONS(809),
    [anon_sym_GridRow] = ACTIONS(809),
    [anon_sym_GridCol] = ACTIONS(809),
    [anon_sym_List] = ACTIONS(809),
    [anon_sym_ScrollList] = ACTIONS(809),
    [anon_sym_ListItem] = ACTIONS(809),
    [anon_sym_GridItem] = ACTIONS(809),
    [anon_sym_ForEach] = ACTIONS(809),
    [sym_identifier] = ACTIONS(809),
    [anon_sym_DQUOTE] = ACTIONS(811),
    [anon_sym_SQUOTE] = ACTIONS(811),
    [anon_sym_DOLLAR] = ACTIONS(809),
    [sym_numeric_literal] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(809),
    [anon_sym_false] = ACTIONS(809),
    [anon_sym_null] = ACTIONS(809),
    [anon_sym_PIPE_PIPE] = ACTIONS(811),
    [anon_sym_AMP_AMP] = ACTIONS(811),
    [anon_sym_PIPE] = ACTIONS(809),
    [anon_sym_CARET] = ACTIONS(811),
    [anon_sym_AMP] = ACTIONS(809),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(811),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(811),
    [anon_sym_LT] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(811),
    [anon_sym_GT_EQ] = ACTIONS(811),
    [anon_sym_instanceof] = ACTIONS(809),
    [anon_sym_in] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(811),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_GT_GT_GT] = ACTIONS(811),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(809),
    [anon_sym_PERCENT] = ACTIONS(811),
    [anon_sym_STAR_STAR] = ACTIONS(811),
    [anon_sym_BANG] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(811),
    [anon_sym_typeof] = ACTIONS(809),
    [anon_sym_void] = ACTIONS(809),
    [anon_sym_delete] = ACTIONS(809),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_await] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_if] = ACTIONS(809),
    [anon_sym_async] = ACTIONS(809),
    [anon_sym_QMARK_DOT] = ACTIONS(811),
    [anon_sym_BQUOTE] = ACTIONS(811),
    [anon_sym_DOLLARr] = ACTIONS(809),
    [anon_sym_PLUS_PLUS] = ACTIONS(811),
    [anon_sym_DASH_DASH] = ACTIONS(811),
    [anon_sym_new] = ACTIONS(809),
  },
  [STATE(176)] = {
    [sym_comment] = STATE(176),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(949),
    [anon_sym_LBRACE] = ACTIONS(951),
    [anon_sym_RBRACE] = ACTIONS(951),
    [anon_sym_STAR] = ACTIONS(949),
    [anon_sym_as] = ACTIONS(949),
    [anon_sym_SEMI] = ACTIONS(951),
    [anon_sym_LPAREN] = ACTIONS(951),
    [anon_sym_DOT] = ACTIONS(951),
    [anon_sym_Text] = ACTIONS(949),
    [anon_sym_Button] = ACTIONS(949),
    [anon_sym_Image] = ACTIONS(949),
    [anon_sym_TextInput] = ACTIONS(949),
    [anon_sym_TextArea] = ACTIONS(949),
    [anon_sym_Column] = ACTIONS(949),
    [anon_sym_Row] = ACTIONS(949),
    [anon_sym_Stack] = ACTIONS(949),
    [anon_sym_Flex] = ACTIONS(949),
    [anon_sym_Grid] = ACTIONS(949),
    [anon_sym_GridRow] = ACTIONS(949),
    [anon_sym_GridCol] = ACTIONS(949),
    [anon_sym_List] = ACTIONS(949),
    [anon_sym_ScrollList] = ACTIONS(949),
    [anon_sym_ListItem] = ACTIONS(949),
    [anon_sym_GridItem] = ACTIONS(949),
    [anon_sym_ForEach] = ACTIONS(949),
    [sym_identifier] = ACTIONS(949),
    [anon_sym_DQUOTE] = ACTIONS(951),
    [anon_sym_SQUOTE] = ACTIONS(951),
    [anon_sym_DOLLAR] = ACTIONS(949),
    [sym_numeric_literal] = ACTIONS(951),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_null] = ACTIONS(949),
    [anon_sym_PIPE_PIPE] = ACTIONS(951),
    [anon_sym_AMP_AMP] = ACTIONS(951),
    [anon_sym_PIPE] = ACTIONS(949),
    [anon_sym_CARET] = ACTIONS(951),
    [anon_sym_AMP] = ACTIONS(949),
    [anon_sym_EQ_EQ] = ACTIONS(949),
    [anon_sym_BANG_EQ] = ACTIONS(949),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(951),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(951),
    [anon_sym_LT] = ACTIONS(949),
    [anon_sym_GT] = ACTIONS(949),
    [anon_sym_LT_EQ] = ACTIONS(951),
    [anon_sym_GT_EQ] = ACTIONS(951),
    [anon_sym_instanceof] = ACTIONS(949),
    [anon_sym_in] = ACTIONS(949),
    [anon_sym_LT_LT] = ACTIONS(951),
    [anon_sym_GT_GT] = ACTIONS(949),
    [anon_sym_GT_GT_GT] = ACTIONS(951),
    [anon_sym_PLUS] = ACTIONS(949),
    [anon_sym_DASH] = ACTIONS(949),
    [anon_sym_PERCENT] = ACTIONS(951),
    [anon_sym_STAR_STAR] = ACTIONS(951),
    [anon_sym_BANG] = ACTIONS(949),
    [anon_sym_TILDE] = ACTIONS(951),
    [anon_sym_typeof] = ACTIONS(949),
    [anon_sym_void] = ACTIONS(949),
    [anon_sym_delete] = ACTIONS(949),
    [anon_sym_QMARK] = ACTIONS(949),
    [anon_sym_await] = ACTIONS(949),
    [anon_sym_LBRACK] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(949),
    [anon_sym_async] = ACTIONS(949),
    [anon_sym_QMARK_DOT] = ACTIONS(951),
    [anon_sym_BQUOTE] = ACTIONS(951),
    [anon_sym_DOLLARr] = ACTIONS(949),
    [anon_sym_PLUS_PLUS] = ACTIONS(951),
    [anon_sym_DASH_DASH] = ACTIONS(951),
    [anon_sym_new] = ACTIONS(949),
  },
  [STATE(177)] = {
    [sym_comment] = STATE(177),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(949),
    [anon_sym_LBRACE] = ACTIONS(951),
    [anon_sym_RBRACE] = ACTIONS(951),
    [anon_sym_STAR] = ACTIONS(949),
    [anon_sym_as] = ACTIONS(949),
    [anon_sym_SEMI] = ACTIONS(951),
    [anon_sym_LPAREN] = ACTIONS(951),
    [anon_sym_DOT] = ACTIONS(951),
    [anon_sym_Text] = ACTIONS(949),
    [anon_sym_Button] = ACTIONS(949),
    [anon_sym_Image] = ACTIONS(949),
    [anon_sym_TextInput] = ACTIONS(949),
    [anon_sym_TextArea] = ACTIONS(949),
    [anon_sym_Column] = ACTIONS(949),
    [anon_sym_Row] = ACTIONS(949),
    [anon_sym_Stack] = ACTIONS(949),
    [anon_sym_Flex] = ACTIONS(949),
    [anon_sym_Grid] = ACTIONS(949),
    [anon_sym_GridRow] = ACTIONS(949),
    [anon_sym_GridCol] = ACTIONS(949),
    [anon_sym_List] = ACTIONS(949),
    [anon_sym_ScrollList] = ACTIONS(949),
    [anon_sym_ListItem] = ACTIONS(949),
    [anon_sym_GridItem] = ACTIONS(949),
    [anon_sym_ForEach] = ACTIONS(949),
    [sym_identifier] = ACTIONS(949),
    [anon_sym_DQUOTE] = ACTIONS(951),
    [anon_sym_SQUOTE] = ACTIONS(951),
    [anon_sym_DOLLAR] = ACTIONS(949),
    [sym_numeric_literal] = ACTIONS(951),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_null] = ACTIONS(949),
    [anon_sym_PIPE_PIPE] = ACTIONS(951),
    [anon_sym_AMP_AMP] = ACTIONS(951),
    [anon_sym_PIPE] = ACTIONS(949),
    [anon_sym_CARET] = ACTIONS(951),
    [anon_sym_AMP] = ACTIONS(949),
    [anon_sym_EQ_EQ] = ACTIONS(949),
    [anon_sym_BANG_EQ] = ACTIONS(949),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(951),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(951),
    [anon_sym_LT] = ACTIONS(949),
    [anon_sym_GT] = ACTIONS(949),
    [anon_sym_LT_EQ] = ACTIONS(951),
    [anon_sym_GT_EQ] = ACTIONS(951),
    [anon_sym_instanceof] = ACTIONS(949),
    [anon_sym_in] = ACTIONS(949),
    [anon_sym_LT_LT] = ACTIONS(951),
    [anon_sym_GT_GT] = ACTIONS(949),
    [anon_sym_GT_GT_GT] = ACTIONS(951),
    [anon_sym_PLUS] = ACTIONS(949),
    [anon_sym_DASH] = ACTIONS(949),
    [anon_sym_PERCENT] = ACTIONS(951),
    [anon_sym_STAR_STAR] = ACTIONS(951),
    [anon_sym_BANG] = ACTIONS(949),
    [anon_sym_TILDE] = ACTIONS(951),
    [anon_sym_typeof] = ACTIONS(949),
    [anon_sym_void] = ACTIONS(949),
    [anon_sym_delete] = ACTIONS(949),
    [anon_sym_QMARK] = ACTIONS(949),
    [anon_sym_await] = ACTIONS(949),
    [anon_sym_LBRACK] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(949),
    [anon_sym_async] = ACTIONS(949),
    [anon_sym_QMARK_DOT] = ACTIONS(951),
    [anon_sym_BQUOTE] = ACTIONS(951),
    [anon_sym_DOLLARr] = ACTIONS(949),
    [anon_sym_PLUS_PLUS] = ACTIONS(951),
    [anon_sym_DASH_DASH] = ACTIONS(951),
    [anon_sym_new] = ACTIONS(949),
  },
  [STATE(178)] = {
    [sym_comment] = STATE(178),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(953),
    [anon_sym_LBRACE] = ACTIONS(955),
    [anon_sym_RBRACE] = ACTIONS(955),
    [anon_sym_STAR] = ACTIONS(953),
    [anon_sym_as] = ACTIONS(953),
    [anon_sym_SEMI] = ACTIONS(955),
    [anon_sym_LPAREN] = ACTIONS(955),
    [anon_sym_DOT] = ACTIONS(955),
    [anon_sym_Text] = ACTIONS(953),
    [anon_sym_Button] = ACTIONS(953),
    [anon_sym_Image] = ACTIONS(953),
    [anon_sym_TextInput] = ACTIONS(953),
    [anon_sym_TextArea] = ACTIONS(953),
    [anon_sym_Column] = ACTIONS(953),
    [anon_sym_Row] = ACTIONS(953),
    [anon_sym_Stack] = ACTIONS(953),
    [anon_sym_Flex] = ACTIONS(953),
    [anon_sym_Grid] = ACTIONS(953),
    [anon_sym_GridRow] = ACTIONS(953),
    [anon_sym_GridCol] = ACTIONS(953),
    [anon_sym_List] = ACTIONS(953),
    [anon_sym_ScrollList] = ACTIONS(953),
    [anon_sym_ListItem] = ACTIONS(953),
    [anon_sym_GridItem] = ACTIONS(953),
    [anon_sym_ForEach] = ACTIONS(953),
    [sym_identifier] = ACTIONS(953),
    [anon_sym_DQUOTE] = ACTIONS(955),
    [anon_sym_SQUOTE] = ACTIONS(955),
    [anon_sym_DOLLAR] = ACTIONS(953),
    [sym_numeric_literal] = ACTIONS(955),
    [anon_sym_true] = ACTIONS(953),
    [anon_sym_false] = ACTIONS(953),
    [anon_sym_null] = ACTIONS(953),
    [anon_sym_PIPE_PIPE] = ACTIONS(955),
    [anon_sym_AMP_AMP] = ACTIONS(955),
    [anon_sym_PIPE] = ACTIONS(953),
    [anon_sym_CARET] = ACTIONS(955),
    [anon_sym_AMP] = ACTIONS(953),
    [anon_sym_EQ_EQ] = ACTIONS(953),
    [anon_sym_BANG_EQ] = ACTIONS(953),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(955),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(955),
    [anon_sym_LT] = ACTIONS(953),
    [anon_sym_GT] = ACTIONS(953),
    [anon_sym_LT_EQ] = ACTIONS(955),
    [anon_sym_GT_EQ] = ACTIONS(955),
    [anon_sym_instanceof] = ACTIONS(953),
    [anon_sym_in] = ACTIONS(953),
    [anon_sym_LT_LT] = ACTIONS(955),
    [anon_sym_GT_GT] = ACTIONS(953),
    [anon_sym_GT_GT_GT] = ACTIONS(955),
    [anon_sym_PLUS] = ACTIONS(953),
    [anon_sym_DASH] = ACTIONS(953),
    [anon_sym_PERCENT] = ACTIONS(955),
    [anon_sym_STAR_STAR] = ACTIONS(955),
    [anon_sym_BANG] = ACTIONS(953),
    [anon_sym_TILDE] = ACTIONS(955),
    [anon_sym_typeof] = ACTIONS(953),
    [anon_sym_void] = ACTIONS(953),
    [anon_sym_delete] = ACTIONS(953),
    [anon_sym_QMARK] = ACTIONS(953),
    [anon_sym_await] = ACTIONS(953),
    [anon_sym_LBRACK] = ACTIONS(955),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_async] = ACTIONS(953),
    [anon_sym_QMARK_DOT] = ACTIONS(955),
    [anon_sym_BQUOTE] = ACTIONS(955),
    [anon_sym_DOLLARr] = ACTIONS(953),
    [anon_sym_PLUS_PLUS] = ACTIONS(955),
    [anon_sym_DASH_DASH] = ACTIONS(955),
    [anon_sym_new] = ACTIONS(953),
  },
  [STATE(179)] = {
    [sym_comment] = STATE(179),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(957),
    [anon_sym_LBRACE] = ACTIONS(959),
    [anon_sym_RBRACE] = ACTIONS(959),
    [anon_sym_STAR] = ACTIONS(957),
    [anon_sym_as] = ACTIONS(957),
    [anon_sym_SEMI] = ACTIONS(959),
    [anon_sym_LPAREN] = ACTIONS(959),
    [anon_sym_DOT] = ACTIONS(959),
    [anon_sym_Text] = ACTIONS(957),
    [anon_sym_Button] = ACTIONS(957),
    [anon_sym_Image] = ACTIONS(957),
    [anon_sym_TextInput] = ACTIONS(957),
    [anon_sym_TextArea] = ACTIONS(957),
    [anon_sym_Column] = ACTIONS(957),
    [anon_sym_Row] = ACTIONS(957),
    [anon_sym_Stack] = ACTIONS(957),
    [anon_sym_Flex] = ACTIONS(957),
    [anon_sym_Grid] = ACTIONS(957),
    [anon_sym_GridRow] = ACTIONS(957),
    [anon_sym_GridCol] = ACTIONS(957),
    [anon_sym_List] = ACTIONS(957),
    [anon_sym_ScrollList] = ACTIONS(957),
    [anon_sym_ListItem] = ACTIONS(957),
    [anon_sym_GridItem] = ACTIONS(957),
    [anon_sym_ForEach] = ACTIONS(957),
    [sym_identifier] = ACTIONS(957),
    [anon_sym_DQUOTE] = ACTIONS(959),
    [anon_sym_SQUOTE] = ACTIONS(959),
    [anon_sym_DOLLAR] = ACTIONS(957),
    [sym_numeric_literal] = ACTIONS(959),
    [anon_sym_true] = ACTIONS(957),
    [anon_sym_false] = ACTIONS(957),
    [anon_sym_null] = ACTIONS(957),
    [anon_sym_PIPE_PIPE] = ACTIONS(959),
    [anon_sym_AMP_AMP] = ACTIONS(959),
    [anon_sym_PIPE] = ACTIONS(957),
    [anon_sym_CARET] = ACTIONS(959),
    [anon_sym_AMP] = ACTIONS(957),
    [anon_sym_EQ_EQ] = ACTIONS(957),
    [anon_sym_BANG_EQ] = ACTIONS(957),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(959),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(959),
    [anon_sym_LT] = ACTIONS(957),
    [anon_sym_GT] = ACTIONS(957),
    [anon_sym_LT_EQ] = ACTIONS(959),
    [anon_sym_GT_EQ] = ACTIONS(959),
    [anon_sym_instanceof] = ACTIONS(957),
    [anon_sym_in] = ACTIONS(957),
    [anon_sym_LT_LT] = ACTIONS(959),
    [anon_sym_GT_GT] = ACTIONS(957),
    [anon_sym_GT_GT_GT] = ACTIONS(959),
    [anon_sym_PLUS] = ACTIONS(957),
    [anon_sym_DASH] = ACTIONS(957),
    [anon_sym_PERCENT] = ACTIONS(959),
    [anon_sym_STAR_STAR] = ACTIONS(959),
    [anon_sym_BANG] = ACTIONS(957),
    [anon_sym_TILDE] = ACTIONS(959),
    [anon_sym_typeof] = ACTIONS(957),
    [anon_sym_void] = ACTIONS(957),
    [anon_sym_delete] = ACTIONS(957),
    [anon_sym_QMARK] = ACTIONS(957),
    [anon_sym_await] = ACTIONS(957),
    [anon_sym_LBRACK] = ACTIONS(959),
    [anon_sym_if] = ACTIONS(957),
    [anon_sym_async] = ACTIONS(957),
    [anon_sym_QMARK_DOT] = ACTIONS(959),
    [anon_sym_BQUOTE] = ACTIONS(959),
    [anon_sym_DOLLARr] = ACTIONS(957),
    [anon_sym_PLUS_PLUS] = ACTIONS(959),
    [anon_sym_DASH_DASH] = ACTIONS(959),
    [anon_sym_new] = ACTIONS(957),
  },
  [STATE(180)] = {
    [sym_comment] = STATE(180),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(828),
    [anon_sym_LBRACE] = ACTIONS(830),
    [anon_sym_RBRACE] = ACTIONS(830),
    [anon_sym_STAR] = ACTIONS(828),
    [anon_sym_as] = ACTIONS(828),
    [anon_sym_SEMI] = ACTIONS(830),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_DOT] = ACTIONS(830),
    [anon_sym_Text] = ACTIONS(828),
    [anon_sym_Button] = ACTIONS(828),
    [anon_sym_Image] = ACTIONS(828),
    [anon_sym_TextInput] = ACTIONS(828),
    [anon_sym_TextArea] = ACTIONS(828),
    [anon_sym_Column] = ACTIONS(828),
    [anon_sym_Row] = ACTIONS(828),
    [anon_sym_Stack] = ACTIONS(828),
    [anon_sym_Flex] = ACTIONS(828),
    [anon_sym_Grid] = ACTIONS(828),
    [anon_sym_GridRow] = ACTIONS(828),
    [anon_sym_GridCol] = ACTIONS(828),
    [anon_sym_List] = ACTIONS(828),
    [anon_sym_ScrollList] = ACTIONS(828),
    [anon_sym_ListItem] = ACTIONS(828),
    [anon_sym_GridItem] = ACTIONS(828),
    [anon_sym_ForEach] = ACTIONS(828),
    [sym_identifier] = ACTIONS(828),
    [anon_sym_DQUOTE] = ACTIONS(830),
    [anon_sym_SQUOTE] = ACTIONS(830),
    [anon_sym_DOLLAR] = ACTIONS(828),
    [sym_numeric_literal] = ACTIONS(830),
    [anon_sym_true] = ACTIONS(828),
    [anon_sym_false] = ACTIONS(828),
    [anon_sym_null] = ACTIONS(828),
    [anon_sym_PIPE_PIPE] = ACTIONS(830),
    [anon_sym_AMP_AMP] = ACTIONS(830),
    [anon_sym_PIPE] = ACTIONS(828),
    [anon_sym_CARET] = ACTIONS(830),
    [anon_sym_AMP] = ACTIONS(828),
    [anon_sym_EQ_EQ] = ACTIONS(828),
    [anon_sym_BANG_EQ] = ACTIONS(828),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(830),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(830),
    [anon_sym_LT] = ACTIONS(828),
    [anon_sym_GT] = ACTIONS(828),
    [anon_sym_LT_EQ] = ACTIONS(830),
    [anon_sym_GT_EQ] = ACTIONS(830),
    [anon_sym_instanceof] = ACTIONS(828),
    [anon_sym_in] = ACTIONS(828),
    [anon_sym_LT_LT] = ACTIONS(830),
    [anon_sym_GT_GT] = ACTIONS(828),
    [anon_sym_GT_GT_GT] = ACTIONS(830),
    [anon_sym_PLUS] = ACTIONS(828),
    [anon_sym_DASH] = ACTIONS(828),
    [anon_sym_PERCENT] = ACTIONS(830),
    [anon_sym_STAR_STAR] = ACTIONS(830),
    [anon_sym_BANG] = ACTIONS(828),
    [anon_sym_TILDE] = ACTIONS(830),
    [anon_sym_typeof] = ACTIONS(828),
    [anon_sym_void] = ACTIONS(828),
    [anon_sym_delete] = ACTIONS(828),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_await] = ACTIONS(828),
    [anon_sym_LBRACK] = ACTIONS(830),
    [anon_sym_if] = ACTIONS(828),
    [anon_sym_async] = ACTIONS(828),
    [anon_sym_QMARK_DOT] = ACTIONS(830),
    [anon_sym_BQUOTE] = ACTIONS(830),
    [anon_sym_DOLLARr] = ACTIONS(828),
    [anon_sym_PLUS_PLUS] = ACTIONS(830),
    [anon_sym_DASH_DASH] = ACTIONS(830),
    [anon_sym_new] = ACTIONS(828),
  },
  [STATE(181)] = {
    [sym_comment] = STATE(181),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(961),
    [anon_sym_LBRACE] = ACTIONS(963),
    [anon_sym_RBRACE] = ACTIONS(963),
    [anon_sym_STAR] = ACTIONS(961),
    [anon_sym_as] = ACTIONS(961),
    [anon_sym_SEMI] = ACTIONS(963),
    [anon_sym_LPAREN] = ACTIONS(963),
    [anon_sym_DOT] = ACTIONS(963),
    [anon_sym_Text] = ACTIONS(961),
    [anon_sym_Button] = ACTIONS(961),
    [anon_sym_Image] = ACTIONS(961),
    [anon_sym_TextInput] = ACTIONS(961),
    [anon_sym_TextArea] = ACTIONS(961),
    [anon_sym_Column] = ACTIONS(961),
    [anon_sym_Row] = ACTIONS(961),
    [anon_sym_Stack] = ACTIONS(961),
    [anon_sym_Flex] = ACTIONS(961),
    [anon_sym_Grid] = ACTIONS(961),
    [anon_sym_GridRow] = ACTIONS(961),
    [anon_sym_GridCol] = ACTIONS(961),
    [anon_sym_List] = ACTIONS(961),
    [anon_sym_ScrollList] = ACTIONS(961),
    [anon_sym_ListItem] = ACTIONS(961),
    [anon_sym_GridItem] = ACTIONS(961),
    [anon_sym_ForEach] = ACTIONS(961),
    [sym_identifier] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DOLLAR] = ACTIONS(961),
    [sym_numeric_literal] = ACTIONS(963),
    [anon_sym_true] = ACTIONS(961),
    [anon_sym_false] = ACTIONS(961),
    [anon_sym_null] = ACTIONS(961),
    [anon_sym_PIPE_PIPE] = ACTIONS(963),
    [anon_sym_AMP_AMP] = ACTIONS(963),
    [anon_sym_PIPE] = ACTIONS(961),
    [anon_sym_CARET] = ACTIONS(963),
    [anon_sym_AMP] = ACTIONS(961),
    [anon_sym_EQ_EQ] = ACTIONS(961),
    [anon_sym_BANG_EQ] = ACTIONS(961),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(963),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(963),
    [anon_sym_LT] = ACTIONS(961),
    [anon_sym_GT] = ACTIONS(961),
    [anon_sym_LT_EQ] = ACTIONS(963),
    [anon_sym_GT_EQ] = ACTIONS(963),
    [anon_sym_instanceof] = ACTIONS(961),
    [anon_sym_in] = ACTIONS(961),
    [anon_sym_LT_LT] = ACTIONS(963),
    [anon_sym_GT_GT] = ACTIONS(961),
    [anon_sym_GT_GT_GT] = ACTIONS(963),
    [anon_sym_PLUS] = ACTIONS(961),
    [anon_sym_DASH] = ACTIONS(961),
    [anon_sym_PERCENT] = ACTIONS(963),
    [anon_sym_STAR_STAR] = ACTIONS(963),
    [anon_sym_BANG] = ACTIONS(961),
    [anon_sym_TILDE] = ACTIONS(963),
    [anon_sym_typeof] = ACTIONS(961),
    [anon_sym_void] = ACTIONS(961),
    [anon_sym_delete] = ACTIONS(961),
    [anon_sym_QMARK] = ACTIONS(961),
    [anon_sym_await] = ACTIONS(961),
    [anon_sym_LBRACK] = ACTIONS(963),
    [anon_sym_if] = ACTIONS(961),
    [anon_sym_async] = ACTIONS(961),
    [anon_sym_QMARK_DOT] = ACTIONS(963),
    [anon_sym_BQUOTE] = ACTIONS(963),
    [anon_sym_DOLLARr] = ACTIONS(961),
    [anon_sym_PLUS_PLUS] = ACTIONS(963),
    [anon_sym_DASH_DASH] = ACTIONS(963),
    [anon_sym_new] = ACTIONS(961),
  },
  [STATE(182)] = {
    [sym_comment] = STATE(182),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(965),
    [anon_sym_LBRACE] = ACTIONS(967),
    [anon_sym_RBRACE] = ACTIONS(967),
    [anon_sym_STAR] = ACTIONS(965),
    [anon_sym_as] = ACTIONS(965),
    [anon_sym_SEMI] = ACTIONS(967),
    [anon_sym_LPAREN] = ACTIONS(967),
    [anon_sym_DOT] = ACTIONS(967),
    [anon_sym_Text] = ACTIONS(965),
    [anon_sym_Button] = ACTIONS(965),
    [anon_sym_Image] = ACTIONS(965),
    [anon_sym_TextInput] = ACTIONS(965),
    [anon_sym_TextArea] = ACTIONS(965),
    [anon_sym_Column] = ACTIONS(965),
    [anon_sym_Row] = ACTIONS(965),
    [anon_sym_Stack] = ACTIONS(965),
    [anon_sym_Flex] = ACTIONS(965),
    [anon_sym_Grid] = ACTIONS(965),
    [anon_sym_GridRow] = ACTIONS(965),
    [anon_sym_GridCol] = ACTIONS(965),
    [anon_sym_List] = ACTIONS(965),
    [anon_sym_ScrollList] = ACTIONS(965),
    [anon_sym_ListItem] = ACTIONS(965),
    [anon_sym_GridItem] = ACTIONS(965),
    [anon_sym_ForEach] = ACTIONS(965),
    [sym_identifier] = ACTIONS(965),
    [anon_sym_DQUOTE] = ACTIONS(967),
    [anon_sym_SQUOTE] = ACTIONS(967),
    [anon_sym_DOLLAR] = ACTIONS(965),
    [sym_numeric_literal] = ACTIONS(967),
    [anon_sym_true] = ACTIONS(965),
    [anon_sym_false] = ACTIONS(965),
    [anon_sym_null] = ACTIONS(965),
    [anon_sym_PIPE_PIPE] = ACTIONS(967),
    [anon_sym_AMP_AMP] = ACTIONS(967),
    [anon_sym_PIPE] = ACTIONS(965),
    [anon_sym_CARET] = ACTIONS(967),
    [anon_sym_AMP] = ACTIONS(965),
    [anon_sym_EQ_EQ] = ACTIONS(965),
    [anon_sym_BANG_EQ] = ACTIONS(965),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(967),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(967),
    [anon_sym_LT] = ACTIONS(965),
    [anon_sym_GT] = ACTIONS(965),
    [anon_sym_LT_EQ] = ACTIONS(967),
    [anon_sym_GT_EQ] = ACTIONS(967),
    [anon_sym_instanceof] = ACTIONS(965),
    [anon_sym_in] = ACTIONS(965),
    [anon_sym_LT_LT] = ACTIONS(967),
    [anon_sym_GT_GT] = ACTIONS(965),
    [anon_sym_GT_GT_GT] = ACTIONS(967),
    [anon_sym_PLUS] = ACTIONS(965),
    [anon_sym_DASH] = ACTIONS(965),
    [anon_sym_PERCENT] = ACTIONS(967),
    [anon_sym_STAR_STAR] = ACTIONS(967),
    [anon_sym_BANG] = ACTIONS(965),
    [anon_sym_TILDE] = ACTIONS(967),
    [anon_sym_typeof] = ACTIONS(965),
    [anon_sym_void] = ACTIONS(965),
    [anon_sym_delete] = ACTIONS(965),
    [anon_sym_QMARK] = ACTIONS(965),
    [anon_sym_await] = ACTIONS(965),
    [anon_sym_LBRACK] = ACTIONS(967),
    [anon_sym_if] = ACTIONS(965),
    [anon_sym_async] = ACTIONS(965),
    [anon_sym_QMARK_DOT] = ACTIONS(967),
    [anon_sym_BQUOTE] = ACTIONS(967),
    [anon_sym_DOLLARr] = ACTIONS(965),
    [anon_sym_PLUS_PLUS] = ACTIONS(967),
    [anon_sym_DASH_DASH] = ACTIONS(967),
    [anon_sym_new] = ACTIONS(965),
  },
  [STATE(183)] = {
    [sym_comment] = STATE(183),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(719),
    [anon_sym_LBRACE] = ACTIONS(717),
    [anon_sym_RBRACE] = ACTIONS(717),
    [anon_sym_STAR] = ACTIONS(719),
    [anon_sym_as] = ACTIONS(719),
    [anon_sym_SEMI] = ACTIONS(717),
    [anon_sym_LPAREN] = ACTIONS(717),
    [anon_sym_DOT] = ACTIONS(717),
    [anon_sym_Text] = ACTIONS(719),
    [anon_sym_Button] = ACTIONS(719),
    [anon_sym_Image] = ACTIONS(719),
    [anon_sym_TextInput] = ACTIONS(719),
    [anon_sym_TextArea] = ACTIONS(719),
    [anon_sym_Column] = ACTIONS(719),
    [anon_sym_Row] = ACTIONS(719),
    [anon_sym_Stack] = ACTIONS(719),
    [anon_sym_Flex] = ACTIONS(719),
    [anon_sym_Grid] = ACTIONS(719),
    [anon_sym_GridRow] = ACTIONS(719),
    [anon_sym_GridCol] = ACTIONS(719),
    [anon_sym_List] = ACTIONS(719),
    [anon_sym_ScrollList] = ACTIONS(719),
    [anon_sym_ListItem] = ACTIONS(719),
    [anon_sym_GridItem] = ACTIONS(719),
    [anon_sym_ForEach] = ACTIONS(719),
    [sym_identifier] = ACTIONS(719),
    [anon_sym_DQUOTE] = ACTIONS(717),
    [anon_sym_SQUOTE] = ACTIONS(717),
    [anon_sym_DOLLAR] = ACTIONS(719),
    [sym_numeric_literal] = ACTIONS(717),
    [anon_sym_true] = ACTIONS(719),
    [anon_sym_false] = ACTIONS(719),
    [anon_sym_null] = ACTIONS(719),
    [anon_sym_PIPE_PIPE] = ACTIONS(717),
    [anon_sym_AMP_AMP] = ACTIONS(717),
    [anon_sym_PIPE] = ACTIONS(719),
    [anon_sym_CARET] = ACTIONS(717),
    [anon_sym_AMP] = ACTIONS(719),
    [anon_sym_EQ_EQ] = ACTIONS(719),
    [anon_sym_BANG_EQ] = ACTIONS(719),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(717),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(717),
    [anon_sym_LT] = ACTIONS(719),
    [anon_sym_GT] = ACTIONS(719),
    [anon_sym_LT_EQ] = ACTIONS(717),
    [anon_sym_GT_EQ] = ACTIONS(717),
    [anon_sym_instanceof] = ACTIONS(719),
    [anon_sym_in] = ACTIONS(719),
    [anon_sym_LT_LT] = ACTIONS(717),
    [anon_sym_GT_GT] = ACTIONS(719),
    [anon_sym_GT_GT_GT] = ACTIONS(717),
    [anon_sym_PLUS] = ACTIONS(719),
    [anon_sym_DASH] = ACTIONS(719),
    [anon_sym_PERCENT] = ACTIONS(717),
    [anon_sym_STAR_STAR] = ACTIONS(717),
    [anon_sym_BANG] = ACTIONS(719),
    [anon_sym_TILDE] = ACTIONS(717),
    [anon_sym_typeof] = ACTIONS(719),
    [anon_sym_void] = ACTIONS(719),
    [anon_sym_delete] = ACTIONS(719),
    [anon_sym_QMARK] = ACTIONS(719),
    [anon_sym_await] = ACTIONS(719),
    [anon_sym_LBRACK] = ACTIONS(717),
    [anon_sym_if] = ACTIONS(719),
    [anon_sym_async] = ACTIONS(719),
    [anon_sym_QMARK_DOT] = ACTIONS(717),
    [anon_sym_BQUOTE] = ACTIONS(717),
    [anon_sym_DOLLARr] = ACTIONS(719),
    [anon_sym_PLUS_PLUS] = ACTIONS(717),
    [anon_sym_DASH_DASH] = ACTIONS(717),
    [anon_sym_new] = ACTIONS(719),
  },
  [STATE(184)] = {
    [sym_comment] = STATE(184),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(780),
    [anon_sym_Text] = ACTIONS(778),
    [anon_sym_Button] = ACTIONS(778),
    [anon_sym_Image] = ACTIONS(778),
    [anon_sym_TextInput] = ACTIONS(778),
    [anon_sym_TextArea] = ACTIONS(778),
    [anon_sym_Column] = ACTIONS(778),
    [anon_sym_Row] = ACTIONS(778),
    [anon_sym_Stack] = ACTIONS(778),
    [anon_sym_Flex] = ACTIONS(778),
    [anon_sym_Grid] = ACTIONS(778),
    [anon_sym_GridRow] = ACTIONS(778),
    [anon_sym_GridCol] = ACTIONS(778),
    [anon_sym_List] = ACTIONS(778),
    [anon_sym_ScrollList] = ACTIONS(778),
    [anon_sym_ListItem] = ACTIONS(778),
    [anon_sym_GridItem] = ACTIONS(778),
    [anon_sym_ForEach] = ACTIONS(778),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(185)] = {
    [sym_comment] = STATE(185),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(969),
    [anon_sym_LBRACE] = ACTIONS(971),
    [anon_sym_RBRACE] = ACTIONS(971),
    [anon_sym_STAR] = ACTIONS(969),
    [anon_sym_as] = ACTIONS(969),
    [anon_sym_SEMI] = ACTIONS(971),
    [anon_sym_LPAREN] = ACTIONS(971),
    [anon_sym_DOT] = ACTIONS(971),
    [anon_sym_Text] = ACTIONS(969),
    [anon_sym_Button] = ACTIONS(969),
    [anon_sym_Image] = ACTIONS(969),
    [anon_sym_TextInput] = ACTIONS(969),
    [anon_sym_TextArea] = ACTIONS(969),
    [anon_sym_Column] = ACTIONS(969),
    [anon_sym_Row] = ACTIONS(969),
    [anon_sym_Stack] = ACTIONS(969),
    [anon_sym_Flex] = ACTIONS(969),
    [anon_sym_Grid] = ACTIONS(969),
    [anon_sym_GridRow] = ACTIONS(969),
    [anon_sym_GridCol] = ACTIONS(969),
    [anon_sym_List] = ACTIONS(969),
    [anon_sym_ScrollList] = ACTIONS(969),
    [anon_sym_ListItem] = ACTIONS(969),
    [anon_sym_GridItem] = ACTIONS(969),
    [anon_sym_ForEach] = ACTIONS(969),
    [sym_identifier] = ACTIONS(969),
    [anon_sym_DQUOTE] = ACTIONS(971),
    [anon_sym_SQUOTE] = ACTIONS(971),
    [anon_sym_DOLLAR] = ACTIONS(969),
    [sym_numeric_literal] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(969),
    [anon_sym_false] = ACTIONS(969),
    [anon_sym_null] = ACTIONS(969),
    [anon_sym_PIPE_PIPE] = ACTIONS(971),
    [anon_sym_AMP_AMP] = ACTIONS(971),
    [anon_sym_PIPE] = ACTIONS(969),
    [anon_sym_CARET] = ACTIONS(971),
    [anon_sym_AMP] = ACTIONS(969),
    [anon_sym_EQ_EQ] = ACTIONS(969),
    [anon_sym_BANG_EQ] = ACTIONS(969),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(971),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(971),
    [anon_sym_LT] = ACTIONS(969),
    [anon_sym_GT] = ACTIONS(969),
    [anon_sym_LT_EQ] = ACTIONS(971),
    [anon_sym_GT_EQ] = ACTIONS(971),
    [anon_sym_instanceof] = ACTIONS(969),
    [anon_sym_in] = ACTIONS(969),
    [anon_sym_LT_LT] = ACTIONS(971),
    [anon_sym_GT_GT] = ACTIONS(969),
    [anon_sym_GT_GT_GT] = ACTIONS(971),
    [anon_sym_PLUS] = ACTIONS(969),
    [anon_sym_DASH] = ACTIONS(969),
    [anon_sym_PERCENT] = ACTIONS(971),
    [anon_sym_STAR_STAR] = ACTIONS(971),
    [anon_sym_BANG] = ACTIONS(969),
    [anon_sym_TILDE] = ACTIONS(971),
    [anon_sym_typeof] = ACTIONS(969),
    [anon_sym_void] = ACTIONS(969),
    [anon_sym_delete] = ACTIONS(969),
    [anon_sym_QMARK] = ACTIONS(969),
    [anon_sym_await] = ACTIONS(969),
    [anon_sym_LBRACK] = ACTIONS(971),
    [anon_sym_if] = ACTIONS(969),
    [anon_sym_async] = ACTIONS(969),
    [anon_sym_QMARK_DOT] = ACTIONS(971),
    [anon_sym_BQUOTE] = ACTIONS(971),
    [anon_sym_DOLLARr] = ACTIONS(969),
    [anon_sym_PLUS_PLUS] = ACTIONS(971),
    [anon_sym_DASH_DASH] = ACTIONS(971),
    [anon_sym_new] = ACTIONS(969),
  },
  [STATE(186)] = {
    [sym_comment] = STATE(186),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(973),
    [anon_sym_LBRACE] = ACTIONS(975),
    [anon_sym_RBRACE] = ACTIONS(975),
    [anon_sym_STAR] = ACTIONS(973),
    [anon_sym_as] = ACTIONS(973),
    [anon_sym_SEMI] = ACTIONS(975),
    [anon_sym_LPAREN] = ACTIONS(975),
    [anon_sym_DOT] = ACTIONS(975),
    [anon_sym_Text] = ACTIONS(973),
    [anon_sym_Button] = ACTIONS(973),
    [anon_sym_Image] = ACTIONS(973),
    [anon_sym_TextInput] = ACTIONS(973),
    [anon_sym_TextArea] = ACTIONS(973),
    [anon_sym_Column] = ACTIONS(973),
    [anon_sym_Row] = ACTIONS(973),
    [anon_sym_Stack] = ACTIONS(973),
    [anon_sym_Flex] = ACTIONS(973),
    [anon_sym_Grid] = ACTIONS(973),
    [anon_sym_GridRow] = ACTIONS(973),
    [anon_sym_GridCol] = ACTIONS(973),
    [anon_sym_List] = ACTIONS(973),
    [anon_sym_ScrollList] = ACTIONS(973),
    [anon_sym_ListItem] = ACTIONS(973),
    [anon_sym_GridItem] = ACTIONS(973),
    [anon_sym_ForEach] = ACTIONS(973),
    [sym_identifier] = ACTIONS(973),
    [anon_sym_DQUOTE] = ACTIONS(975),
    [anon_sym_SQUOTE] = ACTIONS(975),
    [anon_sym_DOLLAR] = ACTIONS(973),
    [sym_numeric_literal] = ACTIONS(975),
    [anon_sym_true] = ACTIONS(973),
    [anon_sym_false] = ACTIONS(973),
    [anon_sym_null] = ACTIONS(973),
    [anon_sym_PIPE_PIPE] = ACTIONS(975),
    [anon_sym_AMP_AMP] = ACTIONS(975),
    [anon_sym_PIPE] = ACTIONS(973),
    [anon_sym_CARET] = ACTIONS(975),
    [anon_sym_AMP] = ACTIONS(973),
    [anon_sym_EQ_EQ] = ACTIONS(973),
    [anon_sym_BANG_EQ] = ACTIONS(973),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(975),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(975),
    [anon_sym_LT] = ACTIONS(973),
    [anon_sym_GT] = ACTIONS(973),
    [anon_sym_LT_EQ] = ACTIONS(975),
    [anon_sym_GT_EQ] = ACTIONS(975),
    [anon_sym_instanceof] = ACTIONS(973),
    [anon_sym_in] = ACTIONS(973),
    [anon_sym_LT_LT] = ACTIONS(975),
    [anon_sym_GT_GT] = ACTIONS(973),
    [anon_sym_GT_GT_GT] = ACTIONS(975),
    [anon_sym_PLUS] = ACTIONS(973),
    [anon_sym_DASH] = ACTIONS(973),
    [anon_sym_PERCENT] = ACTIONS(975),
    [anon_sym_STAR_STAR] = ACTIONS(975),
    [anon_sym_BANG] = ACTIONS(973),
    [anon_sym_TILDE] = ACTIONS(975),
    [anon_sym_typeof] = ACTIONS(973),
    [anon_sym_void] = ACTIONS(973),
    [anon_sym_delete] = ACTIONS(973),
    [anon_sym_QMARK] = ACTIONS(973),
    [anon_sym_await] = ACTIONS(973),
    [anon_sym_LBRACK] = ACTIONS(975),
    [anon_sym_if] = ACTIONS(973),
    [anon_sym_async] = ACTIONS(973),
    [anon_sym_QMARK_DOT] = ACTIONS(975),
    [anon_sym_BQUOTE] = ACTIONS(975),
    [anon_sym_DOLLARr] = ACTIONS(973),
    [anon_sym_PLUS_PLUS] = ACTIONS(975),
    [anon_sym_DASH_DASH] = ACTIONS(975),
    [anon_sym_new] = ACTIONS(973),
  },
  [STATE(187)] = {
    [sym_comment] = STATE(187),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(745),
    [anon_sym_LBRACE] = ACTIONS(747),
    [anon_sym_RBRACE] = ACTIONS(747),
    [anon_sym_STAR] = ACTIONS(745),
    [anon_sym_as] = ACTIONS(745),
    [anon_sym_SEMI] = ACTIONS(747),
    [anon_sym_LPAREN] = ACTIONS(747),
    [anon_sym_DOT] = ACTIONS(747),
    [anon_sym_Text] = ACTIONS(745),
    [anon_sym_Button] = ACTIONS(745),
    [anon_sym_Image] = ACTIONS(745),
    [anon_sym_TextInput] = ACTIONS(745),
    [anon_sym_TextArea] = ACTIONS(745),
    [anon_sym_Column] = ACTIONS(745),
    [anon_sym_Row] = ACTIONS(745),
    [anon_sym_Stack] = ACTIONS(745),
    [anon_sym_Flex] = ACTIONS(745),
    [anon_sym_Grid] = ACTIONS(745),
    [anon_sym_GridRow] = ACTIONS(745),
    [anon_sym_GridCol] = ACTIONS(745),
    [anon_sym_List] = ACTIONS(745),
    [anon_sym_ScrollList] = ACTIONS(745),
    [anon_sym_ListItem] = ACTIONS(745),
    [anon_sym_GridItem] = ACTIONS(745),
    [anon_sym_ForEach] = ACTIONS(745),
    [sym_identifier] = ACTIONS(745),
    [anon_sym_DQUOTE] = ACTIONS(747),
    [anon_sym_SQUOTE] = ACTIONS(747),
    [anon_sym_DOLLAR] = ACTIONS(745),
    [sym_numeric_literal] = ACTIONS(747),
    [anon_sym_true] = ACTIONS(745),
    [anon_sym_false] = ACTIONS(745),
    [anon_sym_null] = ACTIONS(745),
    [anon_sym_PIPE_PIPE] = ACTIONS(747),
    [anon_sym_AMP_AMP] = ACTIONS(747),
    [anon_sym_PIPE] = ACTIONS(745),
    [anon_sym_CARET] = ACTIONS(747),
    [anon_sym_AMP] = ACTIONS(745),
    [anon_sym_EQ_EQ] = ACTIONS(745),
    [anon_sym_BANG_EQ] = ACTIONS(745),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(747),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(747),
    [anon_sym_LT] = ACTIONS(745),
    [anon_sym_GT] = ACTIONS(745),
    [anon_sym_LT_EQ] = ACTIONS(747),
    [anon_sym_GT_EQ] = ACTIONS(747),
    [anon_sym_instanceof] = ACTIONS(745),
    [anon_sym_in] = ACTIONS(745),
    [anon_sym_LT_LT] = ACTIONS(747),
    [anon_sym_GT_GT] = ACTIONS(745),
    [anon_sym_GT_GT_GT] = ACTIONS(747),
    [anon_sym_PLUS] = ACTIONS(745),
    [anon_sym_DASH] = ACTIONS(745),
    [anon_sym_PERCENT] = ACTIONS(747),
    [anon_sym_STAR_STAR] = ACTIONS(747),
    [anon_sym_BANG] = ACTIONS(745),
    [anon_sym_TILDE] = ACTIONS(747),
    [anon_sym_typeof] = ACTIONS(745),
    [anon_sym_void] = ACTIONS(745),
    [anon_sym_delete] = ACTIONS(745),
    [anon_sym_QMARK] = ACTIONS(745),
    [anon_sym_await] = ACTIONS(745),
    [anon_sym_LBRACK] = ACTIONS(747),
    [anon_sym_if] = ACTIONS(745),
    [anon_sym_async] = ACTIONS(745),
    [anon_sym_QMARK_DOT] = ACTIONS(747),
    [anon_sym_BQUOTE] = ACTIONS(747),
    [anon_sym_DOLLARr] = ACTIONS(745),
    [anon_sym_PLUS_PLUS] = ACTIONS(747),
    [anon_sym_DASH_DASH] = ACTIONS(747),
    [anon_sym_new] = ACTIONS(745),
  },
  [STATE(188)] = {
    [sym_comment] = STATE(188),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(977),
    [anon_sym_LBRACE] = ACTIONS(979),
    [anon_sym_RBRACE] = ACTIONS(979),
    [anon_sym_STAR] = ACTIONS(977),
    [anon_sym_as] = ACTIONS(977),
    [anon_sym_SEMI] = ACTIONS(979),
    [anon_sym_LPAREN] = ACTIONS(979),
    [anon_sym_DOT] = ACTIONS(979),
    [anon_sym_Text] = ACTIONS(977),
    [anon_sym_Button] = ACTIONS(977),
    [anon_sym_Image] = ACTIONS(977),
    [anon_sym_TextInput] = ACTIONS(977),
    [anon_sym_TextArea] = ACTIONS(977),
    [anon_sym_Column] = ACTIONS(977),
    [anon_sym_Row] = ACTIONS(977),
    [anon_sym_Stack] = ACTIONS(977),
    [anon_sym_Flex] = ACTIONS(977),
    [anon_sym_Grid] = ACTIONS(977),
    [anon_sym_GridRow] = ACTIONS(977),
    [anon_sym_GridCol] = ACTIONS(977),
    [anon_sym_List] = ACTIONS(977),
    [anon_sym_ScrollList] = ACTIONS(977),
    [anon_sym_ListItem] = ACTIONS(977),
    [anon_sym_GridItem] = ACTIONS(977),
    [anon_sym_ForEach] = ACTIONS(977),
    [sym_identifier] = ACTIONS(977),
    [anon_sym_DQUOTE] = ACTIONS(979),
    [anon_sym_SQUOTE] = ACTIONS(979),
    [anon_sym_DOLLAR] = ACTIONS(977),
    [sym_numeric_literal] = ACTIONS(979),
    [anon_sym_true] = ACTIONS(977),
    [anon_sym_false] = ACTIONS(977),
    [anon_sym_null] = ACTIONS(977),
    [anon_sym_PIPE_PIPE] = ACTIONS(979),
    [anon_sym_AMP_AMP] = ACTIONS(979),
    [anon_sym_PIPE] = ACTIONS(977),
    [anon_sym_CARET] = ACTIONS(979),
    [anon_sym_AMP] = ACTIONS(977),
    [anon_sym_EQ_EQ] = ACTIONS(977),
    [anon_sym_BANG_EQ] = ACTIONS(977),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(979),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(979),
    [anon_sym_LT] = ACTIONS(977),
    [anon_sym_GT] = ACTIONS(977),
    [anon_sym_LT_EQ] = ACTIONS(979),
    [anon_sym_GT_EQ] = ACTIONS(979),
    [anon_sym_instanceof] = ACTIONS(977),
    [anon_sym_in] = ACTIONS(977),
    [anon_sym_LT_LT] = ACTIONS(979),
    [anon_sym_GT_GT] = ACTIONS(977),
    [anon_sym_GT_GT_GT] = ACTIONS(979),
    [anon_sym_PLUS] = ACTIONS(977),
    [anon_sym_DASH] = ACTIONS(977),
    [anon_sym_PERCENT] = ACTIONS(979),
    [anon_sym_STAR_STAR] = ACTIONS(979),
    [anon_sym_BANG] = ACTIONS(977),
    [anon_sym_TILDE] = ACTIONS(979),
    [anon_sym_typeof] = ACTIONS(977),
    [anon_sym_void] = ACTIONS(977),
    [anon_sym_delete] = ACTIONS(977),
    [anon_sym_QMARK] = ACTIONS(977),
    [anon_sym_await] = ACTIONS(977),
    [anon_sym_LBRACK] = ACTIONS(979),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_async] = ACTIONS(977),
    [anon_sym_QMARK_DOT] = ACTIONS(979),
    [anon_sym_BQUOTE] = ACTIONS(979),
    [anon_sym_DOLLARr] = ACTIONS(977),
    [anon_sym_PLUS_PLUS] = ACTIONS(979),
    [anon_sym_DASH_DASH] = ACTIONS(979),
    [anon_sym_new] = ACTIONS(977),
  },
  [STATE(189)] = {
    [sym_comment] = STATE(189),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(969),
    [anon_sym_LBRACE] = ACTIONS(971),
    [anon_sym_RBRACE] = ACTIONS(971),
    [anon_sym_STAR] = ACTIONS(969),
    [anon_sym_as] = ACTIONS(969),
    [anon_sym_SEMI] = ACTIONS(971),
    [anon_sym_LPAREN] = ACTIONS(971),
    [anon_sym_DOT] = ACTIONS(971),
    [anon_sym_Text] = ACTIONS(969),
    [anon_sym_Button] = ACTIONS(969),
    [anon_sym_Image] = ACTIONS(969),
    [anon_sym_TextInput] = ACTIONS(969),
    [anon_sym_TextArea] = ACTIONS(969),
    [anon_sym_Column] = ACTIONS(969),
    [anon_sym_Row] = ACTIONS(969),
    [anon_sym_Stack] = ACTIONS(969),
    [anon_sym_Flex] = ACTIONS(969),
    [anon_sym_Grid] = ACTIONS(969),
    [anon_sym_GridRow] = ACTIONS(969),
    [anon_sym_GridCol] = ACTIONS(969),
    [anon_sym_List] = ACTIONS(969),
    [anon_sym_ScrollList] = ACTIONS(969),
    [anon_sym_ListItem] = ACTIONS(969),
    [anon_sym_GridItem] = ACTIONS(969),
    [anon_sym_ForEach] = ACTIONS(969),
    [sym_identifier] = ACTIONS(969),
    [anon_sym_DQUOTE] = ACTIONS(971),
    [anon_sym_SQUOTE] = ACTIONS(971),
    [anon_sym_DOLLAR] = ACTIONS(969),
    [sym_numeric_literal] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(969),
    [anon_sym_false] = ACTIONS(969),
    [anon_sym_null] = ACTIONS(969),
    [anon_sym_PIPE_PIPE] = ACTIONS(971),
    [anon_sym_AMP_AMP] = ACTIONS(971),
    [anon_sym_PIPE] = ACTIONS(969),
    [anon_sym_CARET] = ACTIONS(971),
    [anon_sym_AMP] = ACTIONS(969),
    [anon_sym_EQ_EQ] = ACTIONS(969),
    [anon_sym_BANG_EQ] = ACTIONS(969),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(971),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(971),
    [anon_sym_LT] = ACTIONS(969),
    [anon_sym_GT] = ACTIONS(969),
    [anon_sym_LT_EQ] = ACTIONS(971),
    [anon_sym_GT_EQ] = ACTIONS(971),
    [anon_sym_instanceof] = ACTIONS(969),
    [anon_sym_in] = ACTIONS(969),
    [anon_sym_LT_LT] = ACTIONS(971),
    [anon_sym_GT_GT] = ACTIONS(969),
    [anon_sym_GT_GT_GT] = ACTIONS(971),
    [anon_sym_PLUS] = ACTIONS(969),
    [anon_sym_DASH] = ACTIONS(969),
    [anon_sym_PERCENT] = ACTIONS(971),
    [anon_sym_STAR_STAR] = ACTIONS(971),
    [anon_sym_BANG] = ACTIONS(969),
    [anon_sym_TILDE] = ACTIONS(971),
    [anon_sym_typeof] = ACTIONS(969),
    [anon_sym_void] = ACTIONS(969),
    [anon_sym_delete] = ACTIONS(969),
    [anon_sym_QMARK] = ACTIONS(969),
    [anon_sym_await] = ACTIONS(969),
    [anon_sym_LBRACK] = ACTIONS(971),
    [anon_sym_if] = ACTIONS(969),
    [anon_sym_async] = ACTIONS(969),
    [anon_sym_QMARK_DOT] = ACTIONS(971),
    [anon_sym_BQUOTE] = ACTIONS(971),
    [anon_sym_DOLLARr] = ACTIONS(969),
    [anon_sym_PLUS_PLUS] = ACTIONS(971),
    [anon_sym_DASH_DASH] = ACTIONS(971),
    [anon_sym_new] = ACTIONS(969),
  },
  [STATE(190)] = {
    [sym_comment] = STATE(190),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(981),
    [anon_sym_LBRACE] = ACTIONS(983),
    [anon_sym_RBRACE] = ACTIONS(983),
    [anon_sym_STAR] = ACTIONS(981),
    [anon_sym_as] = ACTIONS(981),
    [anon_sym_SEMI] = ACTIONS(983),
    [anon_sym_LPAREN] = ACTIONS(983),
    [anon_sym_DOT] = ACTIONS(983),
    [anon_sym_Text] = ACTIONS(981),
    [anon_sym_Button] = ACTIONS(981),
    [anon_sym_Image] = ACTIONS(981),
    [anon_sym_TextInput] = ACTIONS(981),
    [anon_sym_TextArea] = ACTIONS(981),
    [anon_sym_Column] = ACTIONS(981),
    [anon_sym_Row] = ACTIONS(981),
    [anon_sym_Stack] = ACTIONS(981),
    [anon_sym_Flex] = ACTIONS(981),
    [anon_sym_Grid] = ACTIONS(981),
    [anon_sym_GridRow] = ACTIONS(981),
    [anon_sym_GridCol] = ACTIONS(981),
    [anon_sym_List] = ACTIONS(981),
    [anon_sym_ScrollList] = ACTIONS(981),
    [anon_sym_ListItem] = ACTIONS(981),
    [anon_sym_GridItem] = ACTIONS(981),
    [anon_sym_ForEach] = ACTIONS(981),
    [sym_identifier] = ACTIONS(981),
    [anon_sym_DQUOTE] = ACTIONS(983),
    [anon_sym_SQUOTE] = ACTIONS(983),
    [anon_sym_DOLLAR] = ACTIONS(981),
    [sym_numeric_literal] = ACTIONS(983),
    [anon_sym_true] = ACTIONS(981),
    [anon_sym_false] = ACTIONS(981),
    [anon_sym_null] = ACTIONS(981),
    [anon_sym_PIPE_PIPE] = ACTIONS(983),
    [anon_sym_AMP_AMP] = ACTIONS(983),
    [anon_sym_PIPE] = ACTIONS(981),
    [anon_sym_CARET] = ACTIONS(983),
    [anon_sym_AMP] = ACTIONS(981),
    [anon_sym_EQ_EQ] = ACTIONS(981),
    [anon_sym_BANG_EQ] = ACTIONS(981),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(983),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(983),
    [anon_sym_LT] = ACTIONS(981),
    [anon_sym_GT] = ACTIONS(981),
    [anon_sym_LT_EQ] = ACTIONS(983),
    [anon_sym_GT_EQ] = ACTIONS(983),
    [anon_sym_instanceof] = ACTIONS(981),
    [anon_sym_in] = ACTIONS(981),
    [anon_sym_LT_LT] = ACTIONS(983),
    [anon_sym_GT_GT] = ACTIONS(981),
    [anon_sym_GT_GT_GT] = ACTIONS(983),
    [anon_sym_PLUS] = ACTIONS(981),
    [anon_sym_DASH] = ACTIONS(981),
    [anon_sym_PERCENT] = ACTIONS(983),
    [anon_sym_STAR_STAR] = ACTIONS(983),
    [anon_sym_BANG] = ACTIONS(981),
    [anon_sym_TILDE] = ACTIONS(983),
    [anon_sym_typeof] = ACTIONS(981),
    [anon_sym_void] = ACTIONS(981),
    [anon_sym_delete] = ACTIONS(981),
    [anon_sym_QMARK] = ACTIONS(981),
    [anon_sym_await] = ACTIONS(981),
    [anon_sym_LBRACK] = ACTIONS(983),
    [anon_sym_if] = ACTIONS(981),
    [anon_sym_async] = ACTIONS(981),
    [anon_sym_QMARK_DOT] = ACTIONS(983),
    [anon_sym_BQUOTE] = ACTIONS(983),
    [anon_sym_DOLLARr] = ACTIONS(981),
    [anon_sym_PLUS_PLUS] = ACTIONS(983),
    [anon_sym_DASH_DASH] = ACTIONS(983),
    [anon_sym_new] = ACTIONS(981),
  },
  [STATE(191)] = {
    [sym_comment] = STATE(191),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(789),
    [anon_sym_LBRACE] = ACTIONS(791),
    [anon_sym_RBRACE] = ACTIONS(791),
    [anon_sym_STAR] = ACTIONS(789),
    [anon_sym_as] = ACTIONS(789),
    [anon_sym_SEMI] = ACTIONS(791),
    [anon_sym_LPAREN] = ACTIONS(791),
    [anon_sym_DOT] = ACTIONS(791),
    [anon_sym_Text] = ACTIONS(789),
    [anon_sym_Button] = ACTIONS(789),
    [anon_sym_Image] = ACTIONS(789),
    [anon_sym_TextInput] = ACTIONS(789),
    [anon_sym_TextArea] = ACTIONS(789),
    [anon_sym_Column] = ACTIONS(789),
    [anon_sym_Row] = ACTIONS(789),
    [anon_sym_Stack] = ACTIONS(789),
    [anon_sym_Flex] = ACTIONS(789),
    [anon_sym_Grid] = ACTIONS(789),
    [anon_sym_GridRow] = ACTIONS(789),
    [anon_sym_GridCol] = ACTIONS(789),
    [anon_sym_List] = ACTIONS(789),
    [anon_sym_ScrollList] = ACTIONS(789),
    [anon_sym_ListItem] = ACTIONS(789),
    [anon_sym_GridItem] = ACTIONS(789),
    [anon_sym_ForEach] = ACTIONS(789),
    [sym_identifier] = ACTIONS(789),
    [anon_sym_DQUOTE] = ACTIONS(791),
    [anon_sym_SQUOTE] = ACTIONS(791),
    [anon_sym_DOLLAR] = ACTIONS(789),
    [sym_numeric_literal] = ACTIONS(791),
    [anon_sym_true] = ACTIONS(789),
    [anon_sym_false] = ACTIONS(789),
    [anon_sym_null] = ACTIONS(789),
    [anon_sym_PIPE_PIPE] = ACTIONS(791),
    [anon_sym_AMP_AMP] = ACTIONS(791),
    [anon_sym_PIPE] = ACTIONS(789),
    [anon_sym_CARET] = ACTIONS(791),
    [anon_sym_AMP] = ACTIONS(789),
    [anon_sym_EQ_EQ] = ACTIONS(789),
    [anon_sym_BANG_EQ] = ACTIONS(789),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(791),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(791),
    [anon_sym_LT] = ACTIONS(789),
    [anon_sym_GT] = ACTIONS(789),
    [anon_sym_LT_EQ] = ACTIONS(791),
    [anon_sym_GT_EQ] = ACTIONS(791),
    [anon_sym_instanceof] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(789),
    [anon_sym_LT_LT] = ACTIONS(791),
    [anon_sym_GT_GT] = ACTIONS(789),
    [anon_sym_GT_GT_GT] = ACTIONS(791),
    [anon_sym_PLUS] = ACTIONS(789),
    [anon_sym_DASH] = ACTIONS(789),
    [anon_sym_PERCENT] = ACTIONS(791),
    [anon_sym_STAR_STAR] = ACTIONS(791),
    [anon_sym_BANG] = ACTIONS(789),
    [anon_sym_TILDE] = ACTIONS(791),
    [anon_sym_typeof] = ACTIONS(789),
    [anon_sym_void] = ACTIONS(789),
    [anon_sym_delete] = ACTIONS(789),
    [anon_sym_QMARK] = ACTIONS(789),
    [anon_sym_await] = ACTIONS(789),
    [anon_sym_LBRACK] = ACTIONS(791),
    [anon_sym_if] = ACTIONS(789),
    [anon_sym_async] = ACTIONS(789),
    [anon_sym_QMARK_DOT] = ACTIONS(791),
    [anon_sym_BQUOTE] = ACTIONS(791),
    [anon_sym_DOLLARr] = ACTIONS(789),
    [anon_sym_PLUS_PLUS] = ACTIONS(791),
    [anon_sym_DASH_DASH] = ACTIONS(791),
    [anon_sym_new] = ACTIONS(789),
  },
  [STATE(192)] = {
    [sym_comment] = STATE(192),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(985),
    [anon_sym_LBRACE] = ACTIONS(987),
    [anon_sym_RBRACE] = ACTIONS(987),
    [anon_sym_STAR] = ACTIONS(985),
    [anon_sym_as] = ACTIONS(985),
    [anon_sym_SEMI] = ACTIONS(987),
    [anon_sym_LPAREN] = ACTIONS(987),
    [anon_sym_DOT] = ACTIONS(987),
    [anon_sym_Text] = ACTIONS(985),
    [anon_sym_Button] = ACTIONS(985),
    [anon_sym_Image] = ACTIONS(985),
    [anon_sym_TextInput] = ACTIONS(985),
    [anon_sym_TextArea] = ACTIONS(985),
    [anon_sym_Column] = ACTIONS(985),
    [anon_sym_Row] = ACTIONS(985),
    [anon_sym_Stack] = ACTIONS(985),
    [anon_sym_Flex] = ACTIONS(985),
    [anon_sym_Grid] = ACTIONS(985),
    [anon_sym_GridRow] = ACTIONS(985),
    [anon_sym_GridCol] = ACTIONS(985),
    [anon_sym_List] = ACTIONS(985),
    [anon_sym_ScrollList] = ACTIONS(985),
    [anon_sym_ListItem] = ACTIONS(985),
    [anon_sym_GridItem] = ACTIONS(985),
    [anon_sym_ForEach] = ACTIONS(985),
    [sym_identifier] = ACTIONS(985),
    [anon_sym_DQUOTE] = ACTIONS(987),
    [anon_sym_SQUOTE] = ACTIONS(987),
    [anon_sym_DOLLAR] = ACTIONS(985),
    [sym_numeric_literal] = ACTIONS(987),
    [anon_sym_true] = ACTIONS(985),
    [anon_sym_false] = ACTIONS(985),
    [anon_sym_null] = ACTIONS(985),
    [anon_sym_PIPE_PIPE] = ACTIONS(987),
    [anon_sym_AMP_AMP] = ACTIONS(987),
    [anon_sym_PIPE] = ACTIONS(985),
    [anon_sym_CARET] = ACTIONS(987),
    [anon_sym_AMP] = ACTIONS(985),
    [anon_sym_EQ_EQ] = ACTIONS(985),
    [anon_sym_BANG_EQ] = ACTIONS(985),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(987),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(987),
    [anon_sym_LT] = ACTIONS(985),
    [anon_sym_GT] = ACTIONS(985),
    [anon_sym_LT_EQ] = ACTIONS(987),
    [anon_sym_GT_EQ] = ACTIONS(987),
    [anon_sym_instanceof] = ACTIONS(985),
    [anon_sym_in] = ACTIONS(985),
    [anon_sym_LT_LT] = ACTIONS(987),
    [anon_sym_GT_GT] = ACTIONS(985),
    [anon_sym_GT_GT_GT] = ACTIONS(987),
    [anon_sym_PLUS] = ACTIONS(985),
    [anon_sym_DASH] = ACTIONS(985),
    [anon_sym_PERCENT] = ACTIONS(987),
    [anon_sym_STAR_STAR] = ACTIONS(987),
    [anon_sym_BANG] = ACTIONS(985),
    [anon_sym_TILDE] = ACTIONS(987),
    [anon_sym_typeof] = ACTIONS(985),
    [anon_sym_void] = ACTIONS(985),
    [anon_sym_delete] = ACTIONS(985),
    [anon_sym_QMARK] = ACTIONS(985),
    [anon_sym_await] = ACTIONS(985),
    [anon_sym_LBRACK] = ACTIONS(987),
    [anon_sym_if] = ACTIONS(985),
    [anon_sym_async] = ACTIONS(985),
    [anon_sym_QMARK_DOT] = ACTIONS(987),
    [anon_sym_BQUOTE] = ACTIONS(987),
    [anon_sym_DOLLARr] = ACTIONS(985),
    [anon_sym_PLUS_PLUS] = ACTIONS(987),
    [anon_sym_DASH_DASH] = ACTIONS(987),
    [anon_sym_new] = ACTIONS(985),
  },
  [STATE(193)] = {
    [sym_comment] = STATE(193),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(989),
    [anon_sym_LBRACE] = ACTIONS(991),
    [anon_sym_RBRACE] = ACTIONS(991),
    [anon_sym_STAR] = ACTIONS(989),
    [anon_sym_as] = ACTIONS(989),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LPAREN] = ACTIONS(991),
    [anon_sym_DOT] = ACTIONS(991),
    [anon_sym_Text] = ACTIONS(989),
    [anon_sym_Button] = ACTIONS(989),
    [anon_sym_Image] = ACTIONS(989),
    [anon_sym_TextInput] = ACTIONS(989),
    [anon_sym_TextArea] = ACTIONS(989),
    [anon_sym_Column] = ACTIONS(989),
    [anon_sym_Row] = ACTIONS(989),
    [anon_sym_Stack] = ACTIONS(989),
    [anon_sym_Flex] = ACTIONS(989),
    [anon_sym_Grid] = ACTIONS(989),
    [anon_sym_GridRow] = ACTIONS(989),
    [anon_sym_GridCol] = ACTIONS(989),
    [anon_sym_List] = ACTIONS(989),
    [anon_sym_ScrollList] = ACTIONS(989),
    [anon_sym_ListItem] = ACTIONS(989),
    [anon_sym_GridItem] = ACTIONS(989),
    [anon_sym_ForEach] = ACTIONS(989),
    [sym_identifier] = ACTIONS(989),
    [anon_sym_DQUOTE] = ACTIONS(991),
    [anon_sym_SQUOTE] = ACTIONS(991),
    [anon_sym_DOLLAR] = ACTIONS(989),
    [sym_numeric_literal] = ACTIONS(991),
    [anon_sym_true] = ACTIONS(989),
    [anon_sym_false] = ACTIONS(989),
    [anon_sym_null] = ACTIONS(989),
    [anon_sym_PIPE_PIPE] = ACTIONS(991),
    [anon_sym_AMP_AMP] = ACTIONS(991),
    [anon_sym_PIPE] = ACTIONS(989),
    [anon_sym_CARET] = ACTIONS(991),
    [anon_sym_AMP] = ACTIONS(989),
    [anon_sym_EQ_EQ] = ACTIONS(989),
    [anon_sym_BANG_EQ] = ACTIONS(989),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(991),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(991),
    [anon_sym_LT] = ACTIONS(989),
    [anon_sym_GT] = ACTIONS(989),
    [anon_sym_LT_EQ] = ACTIONS(991),
    [anon_sym_GT_EQ] = ACTIONS(991),
    [anon_sym_instanceof] = ACTIONS(989),
    [anon_sym_in] = ACTIONS(989),
    [anon_sym_LT_LT] = ACTIONS(991),
    [anon_sym_GT_GT] = ACTIONS(989),
    [anon_sym_GT_GT_GT] = ACTIONS(991),
    [anon_sym_PLUS] = ACTIONS(989),
    [anon_sym_DASH] = ACTIONS(989),
    [anon_sym_PERCENT] = ACTIONS(991),
    [anon_sym_STAR_STAR] = ACTIONS(991),
    [anon_sym_BANG] = ACTIONS(989),
    [anon_sym_TILDE] = ACTIONS(991),
    [anon_sym_typeof] = ACTIONS(989),
    [anon_sym_void] = ACTIONS(989),
    [anon_sym_delete] = ACTIONS(989),
    [anon_sym_QMARK] = ACTIONS(989),
    [anon_sym_await] = ACTIONS(989),
    [anon_sym_LBRACK] = ACTIONS(991),
    [anon_sym_if] = ACTIONS(989),
    [anon_sym_async] = ACTIONS(989),
    [anon_sym_QMARK_DOT] = ACTIONS(991),
    [anon_sym_BQUOTE] = ACTIONS(991),
    [anon_sym_DOLLARr] = ACTIONS(989),
    [anon_sym_PLUS_PLUS] = ACTIONS(991),
    [anon_sym_DASH_DASH] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(989),
  },
  [STATE(194)] = {
    [sym_comment] = STATE(194),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(1051),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1888),
    [sym_primary_type] = STATE(1383),
    [sym_generic_type] = STATE(461),
    [sym_qualified_type] = STATE(1381),
    [sym_union_type] = STATE(475),
    [sym_function_type] = STATE(475),
    [sym_array_type] = STATE(461),
    [sym_tuple_type] = STATE(461),
    [sym_conditional_type] = STATE(475),
    [sym_type_parameters] = STATE(1849),
    [sym_parameter_list] = STATE(1953),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(777),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [aux_sym_array_literal_repeat1] = STATE(1702),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_COMMA] = ACTIONS(995),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(999),
    [sym_identifier] = ACTIONS(1001),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1011),
    [anon_sym_false] = ACTIONS(1011),
    [anon_sym_null] = ACTIONS(1013),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1015),
    [anon_sym_DASH] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1017),
    [anon_sym_TILDE] = ACTIONS(1017),
    [anon_sym_typeof] = ACTIONS(1015),
    [anon_sym_void] = ACTIONS(1019),
    [anon_sym_delete] = ACTIONS(1015),
    [anon_sym_await] = ACTIONS(1021),
    [anon_sym_number] = ACTIONS(1023),
    [anon_sym_string] = ACTIONS(1023),
    [anon_sym_boolean] = ACTIONS(1023),
    [anon_sym_any] = ACTIONS(1023),
    [anon_sym_undefined] = ACTIONS(1025),
    [anon_sym_LBRACK] = ACTIONS(1027),
    [anon_sym_RBRACK] = ACTIONS(1029),
    [anon_sym_async] = ACTIONS(1031),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1033),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
  },
  [STATE(195)] = {
    [sym_comment] = STATE(195),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(1065),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1888),
    [sym_primary_type] = STATE(1383),
    [sym_generic_type] = STATE(461),
    [sym_qualified_type] = STATE(1381),
    [sym_union_type] = STATE(475),
    [sym_function_type] = STATE(475),
    [sym_array_type] = STATE(461),
    [sym_tuple_type] = STATE(461),
    [sym_conditional_type] = STATE(475),
    [sym_type_parameters] = STATE(1849),
    [sym_parameter_list] = STATE(1953),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(777),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [aux_sym_array_literal_repeat1] = STATE(1756),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_COMMA] = ACTIONS(995),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(999),
    [sym_identifier] = ACTIONS(1001),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1011),
    [anon_sym_false] = ACTIONS(1011),
    [anon_sym_null] = ACTIONS(1013),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1015),
    [anon_sym_DASH] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1017),
    [anon_sym_TILDE] = ACTIONS(1017),
    [anon_sym_typeof] = ACTIONS(1015),
    [anon_sym_void] = ACTIONS(1019),
    [anon_sym_delete] = ACTIONS(1015),
    [anon_sym_await] = ACTIONS(1021),
    [anon_sym_number] = ACTIONS(1023),
    [anon_sym_string] = ACTIONS(1023),
    [anon_sym_boolean] = ACTIONS(1023),
    [anon_sym_any] = ACTIONS(1023),
    [anon_sym_undefined] = ACTIONS(1025),
    [anon_sym_LBRACK] = ACTIONS(1027),
    [anon_sym_RBRACK] = ACTIONS(1043),
    [anon_sym_async] = ACTIONS(1031),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1045),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
  },
  [STATE(196)] = {
    [sym_comment] = STATE(196),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(1043),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1752),
    [sym_primary_type] = STATE(1383),
    [sym_generic_type] = STATE(461),
    [sym_qualified_type] = STATE(1381),
    [sym_union_type] = STATE(475),
    [sym_function_type] = STATE(475),
    [sym_array_type] = STATE(461),
    [sym_tuple_type] = STATE(461),
    [sym_conditional_type] = STATE(475),
    [sym_type_parameters] = STATE(1849),
    [sym_parameter_list] = STATE(1953),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(777),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [aux_sym_array_literal_repeat1] = STATE(1855),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_COMMA] = ACTIONS(995),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(999),
    [sym_identifier] = ACTIONS(1001),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1011),
    [anon_sym_false] = ACTIONS(1011),
    [anon_sym_null] = ACTIONS(1013),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1015),
    [anon_sym_DASH] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1017),
    [anon_sym_TILDE] = ACTIONS(1017),
    [anon_sym_typeof] = ACTIONS(1015),
    [anon_sym_void] = ACTIONS(1019),
    [anon_sym_delete] = ACTIONS(1015),
    [anon_sym_await] = ACTIONS(1021),
    [anon_sym_number] = ACTIONS(1023),
    [anon_sym_string] = ACTIONS(1023),
    [anon_sym_boolean] = ACTIONS(1023),
    [anon_sym_any] = ACTIONS(1023),
    [anon_sym_undefined] = ACTIONS(1025),
    [anon_sym_LBRACK] = ACTIONS(1027),
    [anon_sym_RBRACK] = ACTIONS(1047),
    [anon_sym_async] = ACTIONS(1031),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1049),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
  },
  [STATE(197)] = {
    [sym_comment] = STATE(197),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(1045),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1888),
    [sym_primary_type] = STATE(1383),
    [sym_generic_type] = STATE(461),
    [sym_qualified_type] = STATE(1381),
    [sym_union_type] = STATE(475),
    [sym_function_type] = STATE(475),
    [sym_array_type] = STATE(461),
    [sym_tuple_type] = STATE(461),
    [sym_conditional_type] = STATE(475),
    [sym_type_parameters] = STATE(1849),
    [sym_parameter_list] = STATE(1953),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(777),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [aux_sym_array_literal_repeat1] = STATE(1821),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_COMMA] = ACTIONS(995),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(999),
    [sym_identifier] = ACTIONS(1001),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1011),
    [anon_sym_false] = ACTIONS(1011),
    [anon_sym_null] = ACTIONS(1013),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1015),
    [anon_sym_DASH] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1017),
    [anon_sym_TILDE] = ACTIONS(1017),
    [anon_sym_typeof] = ACTIONS(1015),
    [anon_sym_void] = ACTIONS(1019),
    [anon_sym_delete] = ACTIONS(1015),
    [anon_sym_await] = ACTIONS(1021),
    [anon_sym_number] = ACTIONS(1023),
    [anon_sym_string] = ACTIONS(1023),
    [anon_sym_boolean] = ACTIONS(1023),
    [anon_sym_any] = ACTIONS(1023),
    [anon_sym_undefined] = ACTIONS(1025),
    [anon_sym_LBRACK] = ACTIONS(1027),
    [anon_sym_RBRACK] = ACTIONS(1051),
    [anon_sym_async] = ACTIONS(1031),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1053),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
  },
  [STATE(198)] = {
    [sym_comment] = STATE(198),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(1043),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1888),
    [sym_primary_type] = STATE(1383),
    [sym_generic_type] = STATE(461),
    [sym_qualified_type] = STATE(1381),
    [sym_union_type] = STATE(475),
    [sym_function_type] = STATE(475),
    [sym_array_type] = STATE(461),
    [sym_tuple_type] = STATE(461),
    [sym_conditional_type] = STATE(475),
    [sym_type_parameters] = STATE(1849),
    [sym_parameter_list] = STATE(1953),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(777),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [aux_sym_array_literal_repeat1] = STATE(1855),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_COMMA] = ACTIONS(995),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(999),
    [sym_identifier] = ACTIONS(1001),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1011),
    [anon_sym_false] = ACTIONS(1011),
    [anon_sym_null] = ACTIONS(1013),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1015),
    [anon_sym_DASH] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1017),
    [anon_sym_TILDE] = ACTIONS(1017),
    [anon_sym_typeof] = ACTIONS(1015),
    [anon_sym_void] = ACTIONS(1019),
    [anon_sym_delete] = ACTIONS(1015),
    [anon_sym_await] = ACTIONS(1021),
    [anon_sym_number] = ACTIONS(1023),
    [anon_sym_string] = ACTIONS(1023),
    [anon_sym_boolean] = ACTIONS(1023),
    [anon_sym_any] = ACTIONS(1023),
    [anon_sym_undefined] = ACTIONS(1025),
    [anon_sym_LBRACK] = ACTIONS(1027),
    [anon_sym_RBRACK] = ACTIONS(1055),
    [anon_sym_async] = ACTIONS(1031),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1049),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
  },
  [STATE(199)] = {
    [sym_comment] = STATE(199),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(1048),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1888),
    [sym_primary_type] = STATE(1383),
    [sym_generic_type] = STATE(461),
    [sym_qualified_type] = STATE(1381),
    [sym_union_type] = STATE(475),
    [sym_function_type] = STATE(475),
    [sym_array_type] = STATE(461),
    [sym_tuple_type] = STATE(461),
    [sym_conditional_type] = STATE(475),
    [sym_type_parameters] = STATE(1849),
    [sym_parameter_list] = STATE(1953),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(777),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [aux_sym_array_literal_repeat1] = STATE(1732),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_COMMA] = ACTIONS(995),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(999),
    [sym_identifier] = ACTIONS(1001),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1011),
    [anon_sym_false] = ACTIONS(1011),
    [anon_sym_null] = ACTIONS(1013),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1015),
    [anon_sym_DASH] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1017),
    [anon_sym_TILDE] = ACTIONS(1017),
    [anon_sym_typeof] = ACTIONS(1015),
    [anon_sym_void] = ACTIONS(1019),
    [anon_sym_delete] = ACTIONS(1015),
    [anon_sym_await] = ACTIONS(1021),
    [anon_sym_number] = ACTIONS(1023),
    [anon_sym_string] = ACTIONS(1023),
    [anon_sym_boolean] = ACTIONS(1023),
    [anon_sym_any] = ACTIONS(1023),
    [anon_sym_undefined] = ACTIONS(1025),
    [anon_sym_LBRACK] = ACTIONS(1027),
    [anon_sym_RBRACK] = ACTIONS(1057),
    [anon_sym_async] = ACTIONS(1031),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1059),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
  },
  [STATE(200)] = {
    [sym_comment] = STATE(200),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(1043),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1888),
    [sym_primary_type] = STATE(1383),
    [sym_generic_type] = STATE(461),
    [sym_qualified_type] = STATE(1381),
    [sym_union_type] = STATE(475),
    [sym_function_type] = STATE(475),
    [sym_array_type] = STATE(461),
    [sym_tuple_type] = STATE(461),
    [sym_conditional_type] = STATE(475),
    [sym_type_parameters] = STATE(1849),
    [sym_parameter_list] = STATE(1953),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(777),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [aux_sym_array_literal_repeat1] = STATE(1855),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_COMMA] = ACTIONS(995),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(999),
    [sym_identifier] = ACTIONS(1001),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1011),
    [anon_sym_false] = ACTIONS(1011),
    [anon_sym_null] = ACTIONS(1013),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1015),
    [anon_sym_DASH] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1017),
    [anon_sym_TILDE] = ACTIONS(1017),
    [anon_sym_typeof] = ACTIONS(1015),
    [anon_sym_void] = ACTIONS(1019),
    [anon_sym_delete] = ACTIONS(1015),
    [anon_sym_await] = ACTIONS(1021),
    [anon_sym_number] = ACTIONS(1023),
    [anon_sym_string] = ACTIONS(1023),
    [anon_sym_boolean] = ACTIONS(1023),
    [anon_sym_any] = ACTIONS(1023),
    [anon_sym_undefined] = ACTIONS(1025),
    [anon_sym_LBRACK] = ACTIONS(1027),
    [anon_sym_RBRACK] = ACTIONS(1061),
    [anon_sym_async] = ACTIONS(1031),
    [anon_sym_DOT_DOT_DOT] = ACTIONS(1049),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
  },
  [STATE(201)] = {
    [sym_comment] = STATE(201),
    [sym_type_arguments] = STATE(255),
    [aux_sym_qualified_type_repeat1] = STATE(229),
    [aux_sym_array_type_repeat1] = STATE(230),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(1063),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(1066),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_else] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(202)] = {
    [sym_comment] = STATE(202),
    [sym_type_arguments] = STATE(367),
    [aux_sym_qualified_type_repeat1] = STATE(256),
    [aux_sym_array_type_repeat1] = STATE(275),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(1072),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(1075),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(1078),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(203)] = {
    [sym_comment] = STATE(203),
    [sym_type_arguments] = STATE(358),
    [aux_sym_qualified_type_repeat1] = STATE(263),
    [aux_sym_array_type_repeat1] = STATE(264),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(1081),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(1084),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(1087),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_else] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(204)] = {
    [sym_comment] = STATE(204),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_RBRACE] = ACTIONS(713),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(1092),
    [anon_sym_SEMI] = ACTIONS(713),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DOT] = ACTIONS(1096),
    [sym_identifier] = ACTIONS(715),
    [anon_sym_DQUOTE] = ACTIONS(713),
    [anon_sym_SQUOTE] = ACTIONS(713),
    [anon_sym_DOLLAR] = ACTIONS(715),
    [sym_numeric_literal] = ACTIONS(713),
    [anon_sym_true] = ACTIONS(715),
    [anon_sym_false] = ACTIONS(715),
    [anon_sym_null] = ACTIONS(715),
    [anon_sym_PIPE_PIPE] = ACTIONS(1098),
    [anon_sym_AMP_AMP] = ACTIONS(1100),
    [anon_sym_PIPE] = ACTIONS(1102),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1112),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(715),
    [anon_sym_TILDE] = ACTIONS(713),
    [anon_sym_typeof] = ACTIONS(715),
    [anon_sym_void] = ACTIONS(715),
    [anon_sym_delete] = ACTIONS(715),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_await] = ACTIONS(715),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(715),
    [anon_sym_else] = ACTIONS(715),
    [anon_sym_async] = ACTIONS(715),
    [anon_sym_var] = ACTIONS(715),
    [anon_sym_let] = ACTIONS(715),
    [anon_sym_const] = ACTIONS(715),
    [anon_sym_return] = ACTIONS(715),
    [anon_sym_try] = ACTIONS(715),
    [anon_sym_throw] = ACTIONS(715),
    [anon_sym_for] = ACTIONS(715),
    [anon_sym_while] = ACTIONS(715),
    [anon_sym_break] = ACTIONS(715),
    [anon_sym_continue] = ACTIONS(715),
    [anon_sym_QMARK_DOT] = ACTIONS(1096),
    [anon_sym_BQUOTE] = ACTIONS(713),
    [anon_sym_DOLLARr] = ACTIONS(715),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(715),
  },
  [STATE(205)] = {
    [sym_comment] = STATE(205),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(84),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_annotation] = STATE(1498),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1861),
    [sym_parameter_list] = STATE(1905),
    [sym_block_statement] = STATE(169),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(1134),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [sym_identifier] = ACTIONS(1136),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(1138),
    [anon_sym_false] = ACTIONS(1138),
    [anon_sym_null] = ACTIONS(1140),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(1142),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(206)] = {
    [sym_comment] = STATE(206),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(731),
    [anon_sym_LBRACE] = ACTIONS(733),
    [anon_sym_COMMA] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(733),
    [anon_sym_STAR] = ACTIONS(731),
    [anon_sym_as] = ACTIONS(731),
    [anon_sym_SEMI] = ACTIONS(733),
    [anon_sym_LPAREN] = ACTIONS(733),
    [anon_sym_DOT] = ACTIONS(733),
    [sym_identifier] = ACTIONS(731),
    [anon_sym_DQUOTE] = ACTIONS(733),
    [anon_sym_SQUOTE] = ACTIONS(733),
    [anon_sym_DOLLAR] = ACTIONS(731),
    [sym_numeric_literal] = ACTIONS(733),
    [anon_sym_true] = ACTIONS(731),
    [anon_sym_false] = ACTIONS(731),
    [anon_sym_null] = ACTIONS(731),
    [anon_sym_PIPE_PIPE] = ACTIONS(733),
    [anon_sym_AMP_AMP] = ACTIONS(733),
    [anon_sym_PIPE] = ACTIONS(735),
    [anon_sym_CARET] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_EQ_EQ] = ACTIONS(731),
    [anon_sym_BANG_EQ] = ACTIONS(731),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(733),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(733),
    [anon_sym_LT] = ACTIONS(731),
    [anon_sym_GT] = ACTIONS(735),
    [anon_sym_LT_EQ] = ACTIONS(733),
    [anon_sym_GT_EQ] = ACTIONS(733),
    [anon_sym_instanceof] = ACTIONS(731),
    [anon_sym_in] = ACTIONS(731),
    [anon_sym_LT_LT] = ACTIONS(733),
    [anon_sym_GT_GT] = ACTIONS(731),
    [anon_sym_GT_GT_GT] = ACTIONS(733),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(731),
    [anon_sym_PERCENT] = ACTIONS(733),
    [anon_sym_STAR_STAR] = ACTIONS(733),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_TILDE] = ACTIONS(733),
    [anon_sym_typeof] = ACTIONS(731),
    [anon_sym_void] = ACTIONS(731),
    [anon_sym_delete] = ACTIONS(731),
    [anon_sym_QMARK] = ACTIONS(731),
    [anon_sym_await] = ACTIONS(731),
    [anon_sym_LBRACK] = ACTIONS(733),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(731),
    [anon_sym_else] = ACTIONS(731),
    [anon_sym_async] = ACTIONS(731),
    [anon_sym_var] = ACTIONS(731),
    [anon_sym_let] = ACTIONS(731),
    [anon_sym_const] = ACTIONS(731),
    [anon_sym_return] = ACTIONS(731),
    [anon_sym_try] = ACTIONS(731),
    [anon_sym_throw] = ACTIONS(731),
    [anon_sym_for] = ACTIONS(731),
    [anon_sym_while] = ACTIONS(731),
    [anon_sym_break] = ACTIONS(731),
    [anon_sym_continue] = ACTIONS(731),
    [anon_sym_QMARK_DOT] = ACTIONS(733),
    [anon_sym_BQUOTE] = ACTIONS(733),
    [anon_sym_DOLLARr] = ACTIONS(731),
    [anon_sym_PLUS_PLUS] = ACTIONS(733),
    [anon_sym_DASH_DASH] = ACTIONS(733),
    [anon_sym_new] = ACTIONS(731),
  },
  [STATE(207)] = {
    [sym_comment] = STATE(207),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(738),
    [anon_sym_LBRACE] = ACTIONS(740),
    [anon_sym_COMMA] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(740),
    [anon_sym_STAR] = ACTIONS(738),
    [anon_sym_as] = ACTIONS(738),
    [anon_sym_SEMI] = ACTIONS(740),
    [anon_sym_LPAREN] = ACTIONS(740),
    [anon_sym_DOT] = ACTIONS(740),
    [sym_identifier] = ACTIONS(738),
    [anon_sym_DQUOTE] = ACTIONS(740),
    [anon_sym_SQUOTE] = ACTIONS(740),
    [anon_sym_DOLLAR] = ACTIONS(738),
    [sym_numeric_literal] = ACTIONS(740),
    [anon_sym_true] = ACTIONS(738),
    [anon_sym_false] = ACTIONS(738),
    [anon_sym_null] = ACTIONS(738),
    [anon_sym_PIPE_PIPE] = ACTIONS(740),
    [anon_sym_AMP_AMP] = ACTIONS(740),
    [anon_sym_PIPE] = ACTIONS(742),
    [anon_sym_CARET] = ACTIONS(740),
    [anon_sym_AMP] = ACTIONS(738),
    [anon_sym_EQ_EQ] = ACTIONS(738),
    [anon_sym_BANG_EQ] = ACTIONS(738),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(740),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(738),
    [anon_sym_GT] = ACTIONS(742),
    [anon_sym_LT_EQ] = ACTIONS(740),
    [anon_sym_GT_EQ] = ACTIONS(740),
    [anon_sym_instanceof] = ACTIONS(738),
    [anon_sym_in] = ACTIONS(738),
    [anon_sym_LT_LT] = ACTIONS(740),
    [anon_sym_GT_GT] = ACTIONS(738),
    [anon_sym_GT_GT_GT] = ACTIONS(740),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_PERCENT] = ACTIONS(740),
    [anon_sym_STAR_STAR] = ACTIONS(740),
    [anon_sym_BANG] = ACTIONS(738),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_typeof] = ACTIONS(738),
    [anon_sym_void] = ACTIONS(738),
    [anon_sym_delete] = ACTIONS(738),
    [anon_sym_QMARK] = ACTIONS(738),
    [anon_sym_await] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(738),
    [anon_sym_else] = ACTIONS(738),
    [anon_sym_async] = ACTIONS(738),
    [anon_sym_var] = ACTIONS(738),
    [anon_sym_let] = ACTIONS(738),
    [anon_sym_const] = ACTIONS(738),
    [anon_sym_return] = ACTIONS(738),
    [anon_sym_try] = ACTIONS(738),
    [anon_sym_throw] = ACTIONS(738),
    [anon_sym_for] = ACTIONS(738),
    [anon_sym_while] = ACTIONS(738),
    [anon_sym_break] = ACTIONS(738),
    [anon_sym_continue] = ACTIONS(738),
    [anon_sym_QMARK_DOT] = ACTIONS(740),
    [anon_sym_BQUOTE] = ACTIONS(740),
    [anon_sym_DOLLARr] = ACTIONS(738),
    [anon_sym_PLUS_PLUS] = ACTIONS(740),
    [anon_sym_DASH_DASH] = ACTIONS(740),
    [anon_sym_new] = ACTIONS(738),
  },
  [STATE(208)] = {
    [sym_comment] = STATE(208),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(688),
    [anon_sym_RBRACE] = ACTIONS(688),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(1092),
    [anon_sym_SEMI] = ACTIONS(688),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DOT] = ACTIONS(1096),
    [sym_identifier] = ACTIONS(694),
    [anon_sym_DQUOTE] = ACTIONS(688),
    [anon_sym_SQUOTE] = ACTIONS(688),
    [anon_sym_DOLLAR] = ACTIONS(694),
    [sym_numeric_literal] = ACTIONS(688),
    [anon_sym_true] = ACTIONS(694),
    [anon_sym_false] = ACTIONS(694),
    [anon_sym_null] = ACTIONS(694),
    [anon_sym_PIPE_PIPE] = ACTIONS(1098),
    [anon_sym_AMP_AMP] = ACTIONS(1100),
    [anon_sym_PIPE] = ACTIONS(1102),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1112),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(694),
    [anon_sym_TILDE] = ACTIONS(688),
    [anon_sym_typeof] = ACTIONS(694),
    [anon_sym_void] = ACTIONS(694),
    [anon_sym_delete] = ACTIONS(694),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_await] = ACTIONS(694),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(694),
    [anon_sym_else] = ACTIONS(694),
    [anon_sym_async] = ACTIONS(694),
    [anon_sym_var] = ACTIONS(694),
    [anon_sym_let] = ACTIONS(694),
    [anon_sym_const] = ACTIONS(694),
    [anon_sym_return] = ACTIONS(694),
    [anon_sym_try] = ACTIONS(694),
    [anon_sym_throw] = ACTIONS(694),
    [anon_sym_for] = ACTIONS(694),
    [anon_sym_while] = ACTIONS(694),
    [anon_sym_break] = ACTIONS(694),
    [anon_sym_continue] = ACTIONS(694),
    [anon_sym_QMARK_DOT] = ACTIONS(1096),
    [anon_sym_BQUOTE] = ACTIONS(688),
    [anon_sym_DOLLARr] = ACTIONS(694),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(694),
  },
  [STATE(209)] = {
    [sym_comment] = STATE(209),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(745),
    [anon_sym_LBRACE] = ACTIONS(747),
    [anon_sym_COMMA] = ACTIONS(749),
    [anon_sym_RBRACE] = ACTIONS(747),
    [anon_sym_STAR] = ACTIONS(745),
    [anon_sym_as] = ACTIONS(745),
    [anon_sym_SEMI] = ACTIONS(747),
    [anon_sym_LPAREN] = ACTIONS(747),
    [anon_sym_DOT] = ACTIONS(747),
    [sym_identifier] = ACTIONS(745),
    [anon_sym_DQUOTE] = ACTIONS(747),
    [anon_sym_SQUOTE] = ACTIONS(747),
    [anon_sym_DOLLAR] = ACTIONS(745),
    [sym_numeric_literal] = ACTIONS(747),
    [anon_sym_true] = ACTIONS(745),
    [anon_sym_false] = ACTIONS(745),
    [anon_sym_null] = ACTIONS(745),
    [anon_sym_PIPE_PIPE] = ACTIONS(747),
    [anon_sym_AMP_AMP] = ACTIONS(747),
    [anon_sym_PIPE] = ACTIONS(751),
    [anon_sym_CARET] = ACTIONS(747),
    [anon_sym_AMP] = ACTIONS(745),
    [anon_sym_EQ_EQ] = ACTIONS(745),
    [anon_sym_BANG_EQ] = ACTIONS(745),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(747),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(747),
    [anon_sym_LT] = ACTIONS(745),
    [anon_sym_GT] = ACTIONS(751),
    [anon_sym_LT_EQ] = ACTIONS(747),
    [anon_sym_GT_EQ] = ACTIONS(747),
    [anon_sym_instanceof] = ACTIONS(745),
    [anon_sym_in] = ACTIONS(745),
    [anon_sym_LT_LT] = ACTIONS(747),
    [anon_sym_GT_GT] = ACTIONS(745),
    [anon_sym_GT_GT_GT] = ACTIONS(747),
    [anon_sym_PLUS] = ACTIONS(745),
    [anon_sym_DASH] = ACTIONS(745),
    [anon_sym_PERCENT] = ACTIONS(747),
    [anon_sym_STAR_STAR] = ACTIONS(747),
    [anon_sym_BANG] = ACTIONS(745),
    [anon_sym_TILDE] = ACTIONS(747),
    [anon_sym_typeof] = ACTIONS(745),
    [anon_sym_void] = ACTIONS(745),
    [anon_sym_delete] = ACTIONS(745),
    [anon_sym_QMARK] = ACTIONS(745),
    [anon_sym_await] = ACTIONS(745),
    [anon_sym_LBRACK] = ACTIONS(747),
    [anon_sym_extends] = ACTIONS(754),
    [anon_sym_if] = ACTIONS(745),
    [anon_sym_else] = ACTIONS(745),
    [anon_sym_async] = ACTIONS(745),
    [anon_sym_var] = ACTIONS(745),
    [anon_sym_let] = ACTIONS(745),
    [anon_sym_const] = ACTIONS(745),
    [anon_sym_return] = ACTIONS(745),
    [anon_sym_try] = ACTIONS(745),
    [anon_sym_throw] = ACTIONS(745),
    [anon_sym_for] = ACTIONS(745),
    [anon_sym_while] = ACTIONS(745),
    [anon_sym_break] = ACTIONS(745),
    [anon_sym_continue] = ACTIONS(745),
    [anon_sym_QMARK_DOT] = ACTIONS(747),
    [anon_sym_BQUOTE] = ACTIONS(747),
    [anon_sym_DOLLARr] = ACTIONS(745),
    [anon_sym_PLUS_PLUS] = ACTIONS(747),
    [anon_sym_DASH_DASH] = ACTIONS(747),
    [anon_sym_new] = ACTIONS(745),
  },
  [STATE(210)] = {
    [sym_comment] = STATE(210),
    [sym_modifier_chain_expression] = STATE(372),
    [sym_string_literal] = STATE(372),
    [sym_expression] = STATE(212),
    [sym_state_binding_expression] = STATE(372),
    [sym_boolean_literal] = STATE(372),
    [sym_null_literal] = STATE(372),
    [sym_binary_expression] = STATE(372),
    [sym_unary_expression] = STATE(372),
    [sym_assignment_expression] = STATE(372),
    [sym_conditional_expression] = STATE(372),
    [sym_await_expression] = STATE(372),
    [sym_as_expression] = STATE(372),
    [sym_type_annotation] = STATE(1498),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1866),
    [sym_parameter_list] = STATE(1908),
    [sym_block_statement] = STATE(386),
    [sym_arrow_function] = STATE(372),
    [sym_call_expression] = STATE(372),
    [sym_member_expression] = STATE(39),
    [sym_subscript_expression] = STATE(372),
    [sym_parenthesized_expression] = STATE(372),
    [sym_array_literal] = STATE(372),
    [sym_object_literal] = STATE(372),
    [sym_template_literal] = STATE(372),
    [sym_resource_expression] = STATE(372),
    [sym_update_expression] = STATE(372),
    [sym_new_expression] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(1150),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(1152),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [sym_numeric_literal] = ACTIONS(581),
    [anon_sym_true] = ACTIONS(1154),
    [anon_sym_false] = ACTIONS(1154),
    [anon_sym_null] = ACTIONS(1156),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_BANG] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_typeof] = ACTIONS(587),
    [anon_sym_void] = ACTIONS(1158),
    [anon_sym_delete] = ACTIONS(587),
    [anon_sym_await] = ACTIONS(591),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1160),
    [anon_sym_async] = ACTIONS(597),
    [anon_sym_BQUOTE] = ACTIONS(615),
    [anon_sym_DOLLARr] = ACTIONS(617),
    [anon_sym_PLUS_PLUS] = ACTIONS(619),
    [anon_sym_DASH_DASH] = ACTIONS(619),
    [anon_sym_new] = ACTIONS(621),
  },
  [STATE(211)] = {
    [sym_comment] = STATE(211),
    [aux_sym_array_type_repeat1] = STATE(211),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(1162),
    [anon_sym_extends] = ACTIONS(756),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_else] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_var] = ACTIONS(756),
    [anon_sym_let] = ACTIONS(756),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_return] = ACTIONS(756),
    [anon_sym_try] = ACTIONS(756),
    [anon_sym_throw] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_continue] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(212)] = {
    [sym_comment] = STATE(212),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_RBRACE] = ACTIONS(698),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(1092),
    [anon_sym_SEMI] = ACTIONS(698),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DOT] = ACTIONS(1096),
    [sym_identifier] = ACTIONS(700),
    [anon_sym_DQUOTE] = ACTIONS(698),
    [anon_sym_SQUOTE] = ACTIONS(698),
    [anon_sym_DOLLAR] = ACTIONS(700),
    [sym_numeric_literal] = ACTIONS(698),
    [anon_sym_true] = ACTIONS(700),
    [anon_sym_false] = ACTIONS(700),
    [anon_sym_null] = ACTIONS(700),
    [anon_sym_PIPE_PIPE] = ACTIONS(1098),
    [anon_sym_AMP_AMP] = ACTIONS(1100),
    [anon_sym_PIPE] = ACTIONS(1102),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1112),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(700),
    [anon_sym_TILDE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(700),
    [anon_sym_void] = ACTIONS(700),
    [anon_sym_delete] = ACTIONS(700),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_await] = ACTIONS(700),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(700),
    [anon_sym_else] = ACTIONS(700),
    [anon_sym_async] = ACTIONS(700),
    [anon_sym_var] = ACTIONS(700),
    [anon_sym_let] = ACTIONS(700),
    [anon_sym_const] = ACTIONS(700),
    [anon_sym_return] = ACTIONS(700),
    [anon_sym_try] = ACTIONS(700),
    [anon_sym_throw] = ACTIONS(700),
    [anon_sym_for] = ACTIONS(700),
    [anon_sym_while] = ACTIONS(700),
    [anon_sym_break] = ACTIONS(700),
    [anon_sym_continue] = ACTIONS(700),
    [anon_sym_QMARK_DOT] = ACTIONS(1096),
    [anon_sym_BQUOTE] = ACTIONS(698),
    [anon_sym_DOLLARr] = ACTIONS(700),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(700),
  },
  [STATE(213)] = {
    [sym_comment] = STATE(213),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(702),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(702),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(702),
    [anon_sym_DASH] = ACTIONS(702),
    [anon_sym_PERCENT] = ACTIONS(704),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(704),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(214)] = {
    [sym_comment] = STATE(214),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(960),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1498),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1815),
    [sym_parameter_list] = STATE(1989),
    [sym_block_statement] = STATE(1016),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(776),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(1167),
    [sym_identifier] = ACTIONS(1169),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1171),
    [anon_sym_false] = ACTIONS(1171),
    [anon_sym_null] = ACTIONS(1173),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_typeof] = ACTIONS(1175),
    [anon_sym_void] = ACTIONS(1179),
    [anon_sym_delete] = ACTIONS(1175),
    [anon_sym_await] = ACTIONS(1181),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1183),
    [anon_sym_async] = ACTIONS(1185),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1187),
    [anon_sym_DASH_DASH] = ACTIONS(1187),
    [anon_sym_new] = ACTIONS(1189),
  },
  [STATE(215)] = {
    [sym_comment] = STATE(215),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(1100),
    [anon_sym_PIPE] = ACTIONS(1102),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1191),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(216)] = {
    [sym_comment] = STATE(216),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(1102),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1191),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(217)] = {
    [sym_comment] = STATE(217),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1191),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(218)] = {
    [sym_comment] = STATE(218),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1191),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(219)] = {
    [sym_comment] = STATE(219),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1191),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(220)] = {
    [sym_comment] = STATE(220),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(1191),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(221)] = {
    [sym_comment] = STATE(221),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(222)] = {
    [sym_comment] = STATE(222),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(223)] = {
    [sym_comment] = STATE(223),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(702),
    [anon_sym_DASH] = ACTIONS(702),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(224)] = {
    [sym_comment] = STATE(224),
    [sym_type_arguments] = STATE(399),
    [aux_sym_qualified_type_repeat1] = STATE(347),
    [aux_sym_array_type_repeat1] = STATE(348),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(1194),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(1197),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(225)] = {
    [sym_comment] = STATE(225),
    [sym_modifier_chain_expression] = STATE(372),
    [sym_string_literal] = STATE(372),
    [sym_expression] = STATE(221),
    [sym_state_binding_expression] = STATE(372),
    [sym_boolean_literal] = STATE(372),
    [sym_null_literal] = STATE(372),
    [sym_binary_expression] = STATE(372),
    [sym_unary_expression] = STATE(372),
    [sym_assignment_expression] = STATE(372),
    [sym_conditional_expression] = STATE(372),
    [sym_await_expression] = STATE(372),
    [sym_as_expression] = STATE(372),
    [sym_type_annotation] = STATE(1686),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1866),
    [sym_parameter_list] = STATE(1908),
    [sym_arrow_function] = STATE(372),
    [sym_call_expression] = STATE(372),
    [sym_member_expression] = STATE(39),
    [sym_subscript_expression] = STATE(372),
    [sym_parenthesized_expression] = STATE(372),
    [sym_array_literal] = STATE(372),
    [sym_object_literal] = STATE(372),
    [sym_template_literal] = STATE(372),
    [sym_resource_expression] = STATE(372),
    [sym_update_expression] = STATE(372),
    [sym_new_expression] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(1203),
    [anon_sym_LPAREN] = ACTIONS(569),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(1152),
    [anon_sym_DQUOTE] = ACTIONS(575),
    [anon_sym_SQUOTE] = ACTIONS(577),
    [anon_sym_DOLLAR] = ACTIONS(579),
    [sym_numeric_literal] = ACTIONS(581),
    [anon_sym_true] = ACTIONS(1154),
    [anon_sym_false] = ACTIONS(1154),
    [anon_sym_null] = ACTIONS(1156),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_GT] = ACTIONS(1205),
    [anon_sym_PLUS] = ACTIONS(587),
    [anon_sym_DASH] = ACTIONS(587),
    [anon_sym_BANG] = ACTIONS(589),
    [anon_sym_TILDE] = ACTIONS(589),
    [anon_sym_typeof] = ACTIONS(587),
    [anon_sym_void] = ACTIONS(1158),
    [anon_sym_delete] = ACTIONS(587),
    [anon_sym_await] = ACTIONS(591),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1160),
    [anon_sym_async] = ACTIONS(597),
    [anon_sym_BQUOTE] = ACTIONS(615),
    [anon_sym_DOLLARr] = ACTIONS(617),
    [anon_sym_PLUS_PLUS] = ACTIONS(619),
    [anon_sym_DASH_DASH] = ACTIONS(619),
    [anon_sym_new] = ACTIONS(621),
  },
  [STATE(226)] = {
    [sym_comment] = STATE(226),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(295),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_annotation] = STATE(1686),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1856),
    [sym_parameter_list] = STATE(1894),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(159),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(1207),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(1209),
    [anon_sym_false] = ACTIONS(1209),
    [anon_sym_null] = ACTIONS(1211),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_GT] = ACTIONS(1205),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(1213),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1215),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(227)] = {
    [sym_comment] = STATE(227),
    [aux_sym_array_type_repeat1] = STATE(230),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(1069),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_else] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(228)] = {
    [sym_comment] = STATE(228),
    [sym_type_arguments] = STATE(255),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(1066),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_else] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(229)] = {
    [sym_comment] = STATE(229),
    [aux_sym_qualified_type_repeat1] = STATE(232),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(767),
    [anon_sym_LBRACE] = ACTIONS(769),
    [anon_sym_RBRACE] = ACTIONS(769),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_as] = ACTIONS(767),
    [anon_sym_SEMI] = ACTIONS(769),
    [anon_sym_LPAREN] = ACTIONS(769),
    [anon_sym_DOT] = ACTIONS(769),
    [sym_identifier] = ACTIONS(767),
    [anon_sym_DQUOTE] = ACTIONS(769),
    [anon_sym_SQUOTE] = ACTIONS(769),
    [anon_sym_DOLLAR] = ACTIONS(767),
    [sym_numeric_literal] = ACTIONS(769),
    [anon_sym_true] = ACTIONS(767),
    [anon_sym_false] = ACTIONS(767),
    [anon_sym_null] = ACTIONS(767),
    [anon_sym_PIPE_PIPE] = ACTIONS(769),
    [anon_sym_AMP_AMP] = ACTIONS(769),
    [anon_sym_PIPE] = ACTIONS(767),
    [anon_sym_CARET] = ACTIONS(769),
    [anon_sym_AMP] = ACTIONS(767),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(769),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(769),
    [anon_sym_LT] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(769),
    [anon_sym_GT_EQ] = ACTIONS(769),
    [anon_sym_instanceof] = ACTIONS(767),
    [anon_sym_in] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(769),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_GT_GT_GT] = ACTIONS(769),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(767),
    [anon_sym_PERCENT] = ACTIONS(769),
    [anon_sym_STAR_STAR] = ACTIONS(769),
    [anon_sym_BANG] = ACTIONS(767),
    [anon_sym_TILDE] = ACTIONS(769),
    [anon_sym_typeof] = ACTIONS(767),
    [anon_sym_void] = ACTIONS(767),
    [anon_sym_delete] = ACTIONS(767),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_await] = ACTIONS(767),
    [anon_sym_LBRACK] = ACTIONS(769),
    [anon_sym_extends] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(767),
    [anon_sym_async] = ACTIONS(767),
    [anon_sym_var] = ACTIONS(767),
    [anon_sym_let] = ACTIONS(767),
    [anon_sym_const] = ACTIONS(767),
    [anon_sym_return] = ACTIONS(767),
    [anon_sym_try] = ACTIONS(767),
    [anon_sym_throw] = ACTIONS(767),
    [anon_sym_for] = ACTIONS(767),
    [anon_sym_while] = ACTIONS(767),
    [anon_sym_break] = ACTIONS(767),
    [anon_sym_continue] = ACTIONS(767),
    [anon_sym_QMARK_DOT] = ACTIONS(769),
    [anon_sym_BQUOTE] = ACTIONS(769),
    [anon_sym_DOLLARr] = ACTIONS(767),
    [anon_sym_PLUS_PLUS] = ACTIONS(769),
    [anon_sym_DASH_DASH] = ACTIONS(769),
    [anon_sym_new] = ACTIONS(767),
  },
  [STATE(230)] = {
    [sym_comment] = STATE(230),
    [aux_sym_array_type_repeat1] = STATE(211),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(771),
    [anon_sym_LBRACE] = ACTIONS(773),
    [anon_sym_RBRACE] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(771),
    [anon_sym_as] = ACTIONS(771),
    [anon_sym_SEMI] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(773),
    [anon_sym_DOT] = ACTIONS(773),
    [sym_identifier] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(773),
    [anon_sym_SQUOTE] = ACTIONS(773),
    [anon_sym_DOLLAR] = ACTIONS(771),
    [sym_numeric_literal] = ACTIONS(773),
    [anon_sym_true] = ACTIONS(771),
    [anon_sym_false] = ACTIONS(771),
    [anon_sym_null] = ACTIONS(771),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(771),
    [anon_sym_CARET] = ACTIONS(773),
    [anon_sym_AMP] = ACTIONS(771),
    [anon_sym_EQ_EQ] = ACTIONS(771),
    [anon_sym_BANG_EQ] = ACTIONS(771),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(773),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(773),
    [anon_sym_LT] = ACTIONS(771),
    [anon_sym_GT] = ACTIONS(771),
    [anon_sym_LT_EQ] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(773),
    [anon_sym_instanceof] = ACTIONS(771),
    [anon_sym_in] = ACTIONS(771),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(771),
    [anon_sym_GT_GT_GT] = ACTIONS(773),
    [anon_sym_PLUS] = ACTIONS(771),
    [anon_sym_DASH] = ACTIONS(771),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_STAR_STAR] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(771),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_typeof] = ACTIONS(771),
    [anon_sym_void] = ACTIONS(771),
    [anon_sym_delete] = ACTIONS(771),
    [anon_sym_QMARK] = ACTIONS(771),
    [anon_sym_await] = ACTIONS(771),
    [anon_sym_LBRACK] = ACTIONS(1217),
    [anon_sym_extends] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_else] = ACTIONS(771),
    [anon_sym_async] = ACTIONS(771),
    [anon_sym_var] = ACTIONS(771),
    [anon_sym_let] = ACTIONS(771),
    [anon_sym_const] = ACTIONS(771),
    [anon_sym_return] = ACTIONS(771),
    [anon_sym_try] = ACTIONS(771),
    [anon_sym_throw] = ACTIONS(771),
    [anon_sym_for] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(771),
    [anon_sym_break] = ACTIONS(771),
    [anon_sym_continue] = ACTIONS(771),
    [anon_sym_QMARK_DOT] = ACTIONS(773),
    [anon_sym_BQUOTE] = ACTIONS(773),
    [anon_sym_DOLLARr] = ACTIONS(771),
    [anon_sym_PLUS_PLUS] = ACTIONS(773),
    [anon_sym_DASH_DASH] = ACTIONS(773),
    [anon_sym_new] = ACTIONS(771),
  },
  [STATE(231)] = {
    [sym_comment] = STATE(231),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(926),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(476),
    [sym_primary_type] = STATE(1383),
    [sym_generic_type] = STATE(461),
    [sym_qualified_type] = STATE(1381),
    [sym_union_type] = STATE(475),
    [sym_function_type] = STATE(475),
    [sym_array_type] = STATE(461),
    [sym_tuple_type] = STATE(461),
    [sym_conditional_type] = STATE(475),
    [sym_type_parameters] = STATE(1849),
    [sym_parameter_list] = STATE(1953),
    [sym_block_statement] = STATE(1016),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(777),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(1167),
    [sym_identifier] = ACTIONS(1001),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1011),
    [anon_sym_false] = ACTIONS(1011),
    [anon_sym_null] = ACTIONS(1013),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1015),
    [anon_sym_DASH] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1017),
    [anon_sym_TILDE] = ACTIONS(1017),
    [anon_sym_typeof] = ACTIONS(1015),
    [anon_sym_void] = ACTIONS(1019),
    [anon_sym_delete] = ACTIONS(1015),
    [anon_sym_await] = ACTIONS(1021),
    [anon_sym_number] = ACTIONS(1023),
    [anon_sym_string] = ACTIONS(1023),
    [anon_sym_boolean] = ACTIONS(1023),
    [anon_sym_any] = ACTIONS(1023),
    [anon_sym_undefined] = ACTIONS(1025),
    [anon_sym_LBRACK] = ACTIONS(1027),
    [anon_sym_async] = ACTIONS(1031),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
  },
  [STATE(232)] = {
    [sym_comment] = STATE(232),
    [aux_sym_qualified_type_repeat1] = STATE(232),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(1220),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_extends] = ACTIONS(778),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_else] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_var] = ACTIONS(778),
    [anon_sym_let] = ACTIONS(778),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_return] = ACTIONS(778),
    [anon_sym_try] = ACTIONS(778),
    [anon_sym_throw] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_break] = ACTIONS(778),
    [anon_sym_continue] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(233)] = {
    [sym_comment] = STATE(233),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(1092),
    [anon_sym_SEMI] = ACTIONS(709),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DOT] = ACTIONS(1096),
    [sym_identifier] = ACTIONS(711),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [anon_sym_SQUOTE] = ACTIONS(709),
    [anon_sym_DOLLAR] = ACTIONS(711),
    [sym_numeric_literal] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_null] = ACTIONS(711),
    [anon_sym_PIPE_PIPE] = ACTIONS(1098),
    [anon_sym_AMP_AMP] = ACTIONS(1100),
    [anon_sym_PIPE] = ACTIONS(1102),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1112),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(711),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_typeof] = ACTIONS(711),
    [anon_sym_void] = ACTIONS(711),
    [anon_sym_delete] = ACTIONS(711),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_await] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(711),
    [anon_sym_else] = ACTIONS(711),
    [anon_sym_async] = ACTIONS(711),
    [anon_sym_var] = ACTIONS(711),
    [anon_sym_let] = ACTIONS(711),
    [anon_sym_const] = ACTIONS(711),
    [anon_sym_return] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(711),
    [anon_sym_throw] = ACTIONS(711),
    [anon_sym_for] = ACTIONS(711),
    [anon_sym_while] = ACTIONS(711),
    [anon_sym_break] = ACTIONS(711),
    [anon_sym_continue] = ACTIONS(711),
    [anon_sym_QMARK_DOT] = ACTIONS(1096),
    [anon_sym_BQUOTE] = ACTIONS(709),
    [anon_sym_DOLLARr] = ACTIONS(711),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(711),
  },
  [STATE(234)] = {
    [sym_comment] = STATE(234),
    [sym_modifier_chain_expression] = STATE(396),
    [sym_string_literal] = STATE(396),
    [sym_expression] = STATE(283),
    [sym_state_binding_expression] = STATE(396),
    [sym_boolean_literal] = STATE(396),
    [sym_null_literal] = STATE(396),
    [sym_binary_expression] = STATE(396),
    [sym_unary_expression] = STATE(396),
    [sym_assignment_expression] = STATE(396),
    [sym_conditional_expression] = STATE(396),
    [sym_await_expression] = STATE(396),
    [sym_as_expression] = STATE(396),
    [sym_type_annotation] = STATE(1498),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1856),
    [sym_parameter_list] = STATE(1894),
    [sym_block_statement] = STATE(413),
    [sym_arrow_function] = STATE(396),
    [sym_call_expression] = STATE(396),
    [sym_member_expression] = STATE(49),
    [sym_subscript_expression] = STATE(396),
    [sym_parenthesized_expression] = STATE(396),
    [sym_array_literal] = STATE(396),
    [sym_object_literal] = STATE(396),
    [sym_template_literal] = STATE(396),
    [sym_resource_expression] = STATE(396),
    [sym_update_expression] = STATE(396),
    [sym_new_expression] = STATE(396),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(1223),
    [anon_sym_LPAREN] = ACTIONS(165),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(1207),
    [anon_sym_DQUOTE] = ACTIONS(171),
    [anon_sym_SQUOTE] = ACTIONS(173),
    [anon_sym_DOLLAR] = ACTIONS(175),
    [sym_numeric_literal] = ACTIONS(432),
    [anon_sym_true] = ACTIONS(1209),
    [anon_sym_false] = ACTIONS(1209),
    [anon_sym_null] = ACTIONS(1211),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(183),
    [anon_sym_DASH] = ACTIONS(183),
    [anon_sym_BANG] = ACTIONS(185),
    [anon_sym_TILDE] = ACTIONS(185),
    [anon_sym_typeof] = ACTIONS(183),
    [anon_sym_void] = ACTIONS(1213),
    [anon_sym_delete] = ACTIONS(183),
    [anon_sym_await] = ACTIONS(187),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1215),
    [anon_sym_async] = ACTIONS(193),
    [anon_sym_BQUOTE] = ACTIONS(213),
    [anon_sym_DOLLARr] = ACTIONS(215),
    [anon_sym_PLUS_PLUS] = ACTIONS(217),
    [anon_sym_DASH_DASH] = ACTIONS(217),
    [anon_sym_new] = ACTIONS(219),
  },
  [STATE(235)] = {
    [sym_comment] = STATE(235),
    [sym_modifier_chain_expression] = STATE(787),
    [sym_string_literal] = STATE(787),
    [sym_expression] = STATE(751),
    [sym_state_binding_expression] = STATE(787),
    [sym_boolean_literal] = STATE(787),
    [sym_null_literal] = STATE(787),
    [sym_binary_expression] = STATE(787),
    [sym_unary_expression] = STATE(787),
    [sym_assignment_expression] = STATE(787),
    [sym_conditional_expression] = STATE(787),
    [sym_await_expression] = STATE(787),
    [sym_as_expression] = STATE(787),
    [sym_type_annotation] = STATE(1498),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1851),
    [sym_parameter_list] = STATE(1917),
    [sym_block_statement] = STATE(754),
    [sym_arrow_function] = STATE(787),
    [sym_call_expression] = STATE(787),
    [sym_member_expression] = STATE(451),
    [sym_subscript_expression] = STATE(787),
    [sym_parenthesized_expression] = STATE(787),
    [sym_array_literal] = STATE(787),
    [sym_object_literal] = STATE(787),
    [sym_template_literal] = STATE(787),
    [sym_resource_expression] = STATE(787),
    [sym_update_expression] = STATE(787),
    [sym_new_expression] = STATE(787),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(1225),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_DOT] = ACTIONS(1229),
    [sym_identifier] = ACTIONS(1231),
    [anon_sym_DQUOTE] = ACTIONS(1233),
    [anon_sym_SQUOTE] = ACTIONS(1235),
    [anon_sym_DOLLAR] = ACTIONS(1237),
    [sym_numeric_literal] = ACTIONS(1239),
    [anon_sym_true] = ACTIONS(1241),
    [anon_sym_false] = ACTIONS(1241),
    [anon_sym_null] = ACTIONS(1243),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1245),
    [anon_sym_DASH] = ACTIONS(1245),
    [anon_sym_BANG] = ACTIONS(1247),
    [anon_sym_TILDE] = ACTIONS(1247),
    [anon_sym_typeof] = ACTIONS(1245),
    [anon_sym_void] = ACTIONS(1249),
    [anon_sym_delete] = ACTIONS(1245),
    [anon_sym_await] = ACTIONS(1251),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1253),
    [anon_sym_async] = ACTIONS(1255),
    [anon_sym_BQUOTE] = ACTIONS(1257),
    [anon_sym_DOLLARr] = ACTIONS(1259),
    [anon_sym_PLUS_PLUS] = ACTIONS(1261),
    [anon_sym_DASH_DASH] = ACTIONS(1261),
    [anon_sym_new] = ACTIONS(1263),
  },
  [STATE(236)] = {
    [sym_comment] = STATE(236),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(645),
    [anon_sym_RBRACE] = ACTIONS(645),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(1092),
    [anon_sym_SEMI] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_DOT] = ACTIONS(645),
    [sym_identifier] = ACTIONS(649),
    [anon_sym_DQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(645),
    [anon_sym_DOLLAR] = ACTIONS(649),
    [sym_numeric_literal] = ACTIONS(645),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_null] = ACTIONS(649),
    [anon_sym_PIPE_PIPE] = ACTIONS(1098),
    [anon_sym_AMP_AMP] = ACTIONS(1100),
    [anon_sym_PIPE] = ACTIONS(1102),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1265),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(649),
    [anon_sym_TILDE] = ACTIONS(645),
    [anon_sym_typeof] = ACTIONS(649),
    [anon_sym_void] = ACTIONS(649),
    [anon_sym_delete] = ACTIONS(649),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_await] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(649),
    [anon_sym_else] = ACTIONS(649),
    [anon_sym_async] = ACTIONS(649),
    [anon_sym_var] = ACTIONS(649),
    [anon_sym_let] = ACTIONS(649),
    [anon_sym_const] = ACTIONS(649),
    [anon_sym_return] = ACTIONS(649),
    [anon_sym_try] = ACTIONS(649),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_for] = ACTIONS(649),
    [anon_sym_while] = ACTIONS(649),
    [anon_sym_break] = ACTIONS(649),
    [anon_sym_continue] = ACTIONS(649),
    [anon_sym_QMARK_DOT] = ACTIONS(645),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_DOLLARr] = ACTIONS(649),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(649),
  },
  [STATE(237)] = {
    [sym_comment] = STATE(237),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(717),
    [anon_sym_RBRACE] = ACTIONS(717),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(1092),
    [anon_sym_SEMI] = ACTIONS(717),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DOT] = ACTIONS(1096),
    [sym_identifier] = ACTIONS(719),
    [anon_sym_DQUOTE] = ACTIONS(717),
    [anon_sym_SQUOTE] = ACTIONS(717),
    [anon_sym_DOLLAR] = ACTIONS(719),
    [sym_numeric_literal] = ACTIONS(717),
    [anon_sym_true] = ACTIONS(719),
    [anon_sym_false] = ACTIONS(719),
    [anon_sym_null] = ACTIONS(719),
    [anon_sym_PIPE_PIPE] = ACTIONS(1098),
    [anon_sym_AMP_AMP] = ACTIONS(1100),
    [anon_sym_PIPE] = ACTIONS(1102),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1112),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(719),
    [anon_sym_TILDE] = ACTIONS(717),
    [anon_sym_typeof] = ACTIONS(719),
    [anon_sym_void] = ACTIONS(719),
    [anon_sym_delete] = ACTIONS(719),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_await] = ACTIONS(719),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(719),
    [anon_sym_else] = ACTIONS(719),
    [anon_sym_async] = ACTIONS(719),
    [anon_sym_var] = ACTIONS(719),
    [anon_sym_let] = ACTIONS(719),
    [anon_sym_const] = ACTIONS(719),
    [anon_sym_return] = ACTIONS(719),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_throw] = ACTIONS(719),
    [anon_sym_for] = ACTIONS(719),
    [anon_sym_while] = ACTIONS(719),
    [anon_sym_break] = ACTIONS(719),
    [anon_sym_continue] = ACTIONS(719),
    [anon_sym_QMARK_DOT] = ACTIONS(1096),
    [anon_sym_BQUOTE] = ACTIONS(717),
    [anon_sym_DOLLARr] = ACTIONS(719),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(719),
  },
  [STATE(238)] = {
    [sym_comment] = STATE(238),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(721),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(1092),
    [anon_sym_SEMI] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DOT] = ACTIONS(1096),
    [sym_identifier] = ACTIONS(723),
    [anon_sym_DQUOTE] = ACTIONS(721),
    [anon_sym_SQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR] = ACTIONS(723),
    [sym_numeric_literal] = ACTIONS(721),
    [anon_sym_true] = ACTIONS(723),
    [anon_sym_false] = ACTIONS(723),
    [anon_sym_null] = ACTIONS(723),
    [anon_sym_PIPE_PIPE] = ACTIONS(1098),
    [anon_sym_AMP_AMP] = ACTIONS(1100),
    [anon_sym_PIPE] = ACTIONS(1102),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1112),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(723),
    [anon_sym_TILDE] = ACTIONS(721),
    [anon_sym_typeof] = ACTIONS(723),
    [anon_sym_void] = ACTIONS(723),
    [anon_sym_delete] = ACTIONS(723),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_await] = ACTIONS(723),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(723),
    [anon_sym_else] = ACTIONS(723),
    [anon_sym_async] = ACTIONS(723),
    [anon_sym_var] = ACTIONS(723),
    [anon_sym_let] = ACTIONS(723),
    [anon_sym_const] = ACTIONS(723),
    [anon_sym_return] = ACTIONS(723),
    [anon_sym_try] = ACTIONS(723),
    [anon_sym_throw] = ACTIONS(723),
    [anon_sym_for] = ACTIONS(723),
    [anon_sym_while] = ACTIONS(723),
    [anon_sym_break] = ACTIONS(723),
    [anon_sym_continue] = ACTIONS(723),
    [anon_sym_QMARK_DOT] = ACTIONS(1096),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLARr] = ACTIONS(723),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(723),
  },
  [STATE(239)] = {
    [sym_comment] = STATE(239),
    [aux_sym_union_type_repeat1] = STATE(273),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(797),
    [anon_sym_LBRACE] = ACTIONS(799),
    [anon_sym_RBRACE] = ACTIONS(799),
    [anon_sym_STAR] = ACTIONS(797),
    [anon_sym_as] = ACTIONS(797),
    [anon_sym_SEMI] = ACTIONS(799),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_DOT] = ACTIONS(799),
    [sym_identifier] = ACTIONS(797),
    [anon_sym_DQUOTE] = ACTIONS(799),
    [anon_sym_SQUOTE] = ACTIONS(799),
    [anon_sym_DOLLAR] = ACTIONS(797),
    [sym_numeric_literal] = ACTIONS(799),
    [anon_sym_true] = ACTIONS(797),
    [anon_sym_false] = ACTIONS(797),
    [anon_sym_null] = ACTIONS(797),
    [anon_sym_PIPE_PIPE] = ACTIONS(799),
    [anon_sym_AMP_AMP] = ACTIONS(799),
    [anon_sym_PIPE] = ACTIONS(1268),
    [anon_sym_CARET] = ACTIONS(799),
    [anon_sym_AMP] = ACTIONS(797),
    [anon_sym_EQ_EQ] = ACTIONS(797),
    [anon_sym_BANG_EQ] = ACTIONS(797),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(799),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(799),
    [anon_sym_LT] = ACTIONS(797),
    [anon_sym_GT] = ACTIONS(797),
    [anon_sym_LT_EQ] = ACTIONS(799),
    [anon_sym_GT_EQ] = ACTIONS(799),
    [anon_sym_instanceof] = ACTIONS(797),
    [anon_sym_in] = ACTIONS(797),
    [anon_sym_LT_LT] = ACTIONS(799),
    [anon_sym_GT_GT] = ACTIONS(797),
    [anon_sym_GT_GT_GT] = ACTIONS(799),
    [anon_sym_PLUS] = ACTIONS(797),
    [anon_sym_DASH] = ACTIONS(797),
    [anon_sym_PERCENT] = ACTIONS(799),
    [anon_sym_STAR_STAR] = ACTIONS(799),
    [anon_sym_BANG] = ACTIONS(797),
    [anon_sym_TILDE] = ACTIONS(799),
    [anon_sym_typeof] = ACTIONS(797),
    [anon_sym_void] = ACTIONS(797),
    [anon_sym_delete] = ACTIONS(797),
    [anon_sym_QMARK] = ACTIONS(797),
    [anon_sym_await] = ACTIONS(797),
    [anon_sym_LBRACK] = ACTIONS(799),
    [anon_sym_extends] = ACTIONS(1270),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_else] = ACTIONS(797),
    [anon_sym_async] = ACTIONS(797),
    [anon_sym_var] = ACTIONS(797),
    [anon_sym_let] = ACTIONS(797),
    [anon_sym_const] = ACTIONS(797),
    [anon_sym_return] = ACTIONS(797),
    [anon_sym_try] = ACTIONS(797),
    [anon_sym_throw] = ACTIONS(797),
    [anon_sym_for] = ACTIONS(797),
    [anon_sym_while] = ACTIONS(797),
    [anon_sym_break] = ACTIONS(797),
    [anon_sym_continue] = ACTIONS(797),
    [anon_sym_QMARK_DOT] = ACTIONS(799),
    [anon_sym_BQUOTE] = ACTIONS(799),
    [anon_sym_DOLLARr] = ACTIONS(797),
    [anon_sym_PLUS_PLUS] = ACTIONS(799),
    [anon_sym_DASH_DASH] = ACTIONS(799),
    [anon_sym_new] = ACTIONS(797),
  },
  [STATE(240)] = {
    [sym_comment] = STATE(240),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(975),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1686),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1815),
    [sym_parameter_list] = STATE(1989),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(776),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(1167),
    [sym_identifier] = ACTIONS(1169),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1171),
    [anon_sym_false] = ACTIONS(1171),
    [anon_sym_null] = ACTIONS(1173),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_GT] = ACTIONS(1205),
    [anon_sym_PLUS] = ACTIONS(1175),
    [anon_sym_DASH] = ACTIONS(1175),
    [anon_sym_BANG] = ACTIONS(1177),
    [anon_sym_TILDE] = ACTIONS(1177),
    [anon_sym_typeof] = ACTIONS(1175),
    [anon_sym_void] = ACTIONS(1179),
    [anon_sym_delete] = ACTIONS(1175),
    [anon_sym_await] = ACTIONS(1181),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1183),
    [anon_sym_async] = ACTIONS(1185),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1187),
    [anon_sym_DASH_DASH] = ACTIONS(1187),
    [anon_sym_new] = ACTIONS(1189),
  },
  [STATE(241)] = {
    [sym_comment] = STATE(241),
    [sym_type_arguments] = STATE(1519),
    [aux_sym_qualified_type_repeat1] = STATE(1316),
    [aux_sym_array_type_repeat1] = STATE(1469),
    [ts_builtin_sym_end] = ACTIONS(37),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_import] = ACTIONS(37),
    [anon_sym_COMMA] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_export] = ACTIONS(37),
    [anon_sym_AT] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_struct] = ACTIONS(37),
    [anon_sym_COLON] = ACTIONS(1272),
    [anon_sym_EQ] = ACTIONS(1274),
    [anon_sym_DOT] = ACTIONS(45),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(48),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(51),
    [anon_sym_GT] = ACTIONS(48),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(37),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_PLUS_EQ] = ACTIONS(1276),
    [anon_sym_DASH_EQ] = ACTIONS(1276),
    [anon_sym_STAR_EQ] = ACTIONS(1276),
    [anon_sym_SLASH_EQ] = ACTIONS(1276),
    [anon_sym_PERCENT_EQ] = ACTIONS(1276),
    [anon_sym_AMP_EQ] = ACTIONS(1276),
    [anon_sym_PIPE_EQ] = ACTIONS(1276),
    [anon_sym_CARET_EQ] = ACTIONS(1276),
    [anon_sym_LT_LT_EQ] = ACTIONS(1276),
    [anon_sym_GT_GT_EQ] = ACTIONS(1276),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1276),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(1278),
    [anon_sym_LBRACK] = ACTIONS(58),
    [anon_sym_extends] = ACTIONS(39),
    [anon_sym_async] = ACTIONS(37),
    [anon_sym_var] = ACTIONS(37),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(37),
    [anon_sym_type] = ACTIONS(37),
    [anon_sym_enum] = ACTIONS(37),
    [anon_sym_abstract] = ACTIONS(37),
    [anon_sym_class] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(37),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
  },
  [STATE(242)] = {
    [sym_comment] = STATE(242),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_RBRACE] = ACTIONS(765),
    [anon_sym_STAR] = ACTIONS(763),
    [anon_sym_as] = ACTIONS(763),
    [anon_sym_SEMI] = ACTIONS(765),
    [anon_sym_LPAREN] = ACTIONS(765),
    [anon_sym_DOT] = ACTIONS(765),
    [sym_identifier] = ACTIONS(763),
    [anon_sym_DQUOTE] = ACTIONS(765),
    [anon_sym_SQUOTE] = ACTIONS(765),
    [anon_sym_DOLLAR] = ACTIONS(763),
    [sym_numeric_literal] = ACTIONS(765),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_null] = ACTIONS(763),
    [anon_sym_PIPE_PIPE] = ACTIONS(765),
    [anon_sym_AMP_AMP] = ACTIONS(765),
    [anon_sym_PIPE] = ACTIONS(763),
    [anon_sym_CARET] = ACTIONS(765),
    [anon_sym_AMP] = ACTIONS(763),
    [anon_sym_EQ_EQ] = ACTIONS(763),
    [anon_sym_BANG_EQ] = ACTIONS(763),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(765),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(765),
    [anon_sym_LT] = ACTIONS(763),
    [anon_sym_GT] = ACTIONS(763),
    [anon_sym_LT_EQ] = ACTIONS(765),
    [anon_sym_GT_EQ] = ACTIONS(765),
    [anon_sym_instanceof] = ACTIONS(763),
    [anon_sym_in] = ACTIONS(763),
    [anon_sym_LT_LT] = ACTIONS(765),
    [anon_sym_GT_GT] = ACTIONS(763),
    [anon_sym_GT_GT_GT] = ACTIONS(765),
    [anon_sym_PLUS] = ACTIONS(763),
    [anon_sym_DASH] = ACTIONS(763),
    [anon_sym_PERCENT] = ACTIONS(765),
    [anon_sym_STAR_STAR] = ACTIONS(765),
    [anon_sym_BANG] = ACTIONS(763),
    [anon_sym_TILDE] = ACTIONS(765),
    [anon_sym_typeof] = ACTIONS(763),
    [anon_sym_void] = ACTIONS(763),
    [anon_sym_delete] = ACTIONS(763),
    [anon_sym_QMARK] = ACTIONS(763),
    [anon_sym_await] = ACTIONS(763),
    [anon_sym_LBRACK] = ACTIONS(765),
    [anon_sym_if] = ACTIONS(763),
    [anon_sym_else] = ACTIONS(763),
    [anon_sym_async] = ACTIONS(763),
    [anon_sym_var] = ACTIONS(763),
    [anon_sym_let] = ACTIONS(763),
    [anon_sym_const] = ACTIONS(763),
    [anon_sym_return] = ACTIONS(763),
    [anon_sym_try] = ACTIONS(763),
    [anon_sym_throw] = ACTIONS(763),
    [anon_sym_for] = ACTIONS(763),
    [anon_sym_while] = ACTIONS(763),
    [anon_sym_break] = ACTIONS(763),
    [anon_sym_continue] = ACTIONS(763),
    [anon_sym_QMARK_DOT] = ACTIONS(765),
    [anon_sym_BQUOTE] = ACTIONS(765),
    [anon_sym_DOLLARr] = ACTIONS(763),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(763),
  },
  [STATE(243)] = {
    [sym_comment] = STATE(243),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(785),
    [anon_sym_LBRACE] = ACTIONS(787),
    [anon_sym_RBRACE] = ACTIONS(787),
    [anon_sym_STAR] = ACTIONS(785),
    [anon_sym_as] = ACTIONS(785),
    [anon_sym_SEMI] = ACTIONS(787),
    [anon_sym_LPAREN] = ACTIONS(787),
    [anon_sym_DOT] = ACTIONS(787),
    [sym_identifier] = ACTIONS(785),
    [anon_sym_DQUOTE] = ACTIONS(787),
    [anon_sym_SQUOTE] = ACTIONS(787),
    [anon_sym_DOLLAR] = ACTIONS(785),
    [sym_numeric_literal] = ACTIONS(787),
    [anon_sym_true] = ACTIONS(785),
    [anon_sym_false] = ACTIONS(785),
    [anon_sym_null] = ACTIONS(785),
    [anon_sym_PIPE_PIPE] = ACTIONS(787),
    [anon_sym_AMP_AMP] = ACTIONS(787),
    [anon_sym_PIPE] = ACTIONS(785),
    [anon_sym_CARET] = ACTIONS(787),
    [anon_sym_AMP] = ACTIONS(785),
    [anon_sym_EQ_EQ] = ACTIONS(785),
    [anon_sym_BANG_EQ] = ACTIONS(785),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(787),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(787),
    [anon_sym_LT] = ACTIONS(785),
    [anon_sym_GT] = ACTIONS(785),
    [anon_sym_LT_EQ] = ACTIONS(787),
    [anon_sym_GT_EQ] = ACTIONS(787),
    [anon_sym_instanceof] = ACTIONS(785),
    [anon_sym_in] = ACTIONS(785),
    [anon_sym_LT_LT] = ACTIONS(787),
    [anon_sym_GT_GT] = ACTIONS(785),
    [anon_sym_GT_GT_GT] = ACTIONS(787),
    [anon_sym_PLUS] = ACTIONS(785),
    [anon_sym_DASH] = ACTIONS(785),
    [anon_sym_PERCENT] = ACTIONS(787),
    [anon_sym_STAR_STAR] = ACTIONS(787),
    [anon_sym_BANG] = ACTIONS(785),
    [anon_sym_TILDE] = ACTIONS(787),
    [anon_sym_typeof] = ACTIONS(785),
    [anon_sym_void] = ACTIONS(785),
    [anon_sym_delete] = ACTIONS(785),
    [anon_sym_QMARK] = ACTIONS(785),
    [anon_sym_await] = ACTIONS(785),
    [anon_sym_LBRACK] = ACTIONS(787),
    [anon_sym_if] = ACTIONS(785),
    [anon_sym_else] = ACTIONS(785),
    [anon_sym_async] = ACTIONS(785),
    [anon_sym_var] = ACTIONS(785),
    [anon_sym_let] = ACTIONS(785),
    [anon_sym_const] = ACTIONS(785),
    [anon_sym_return] = ACTIONS(785),
    [anon_sym_try] = ACTIONS(785),
    [anon_sym_throw] = ACTIONS(785),
    [anon_sym_for] = ACTIONS(785),
    [anon_sym_while] = ACTIONS(785),
    [anon_sym_break] = ACTIONS(785),
    [anon_sym_continue] = ACTIONS(785),
    [anon_sym_QMARK_DOT] = ACTIONS(787),
    [anon_sym_BQUOTE] = ACTIONS(787),
    [anon_sym_DOLLARr] = ACTIONS(785),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(785),
  },
  [STATE(244)] = {
    [sym_comment] = STATE(244),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(789),
    [anon_sym_LBRACE] = ACTIONS(791),
    [anon_sym_RBRACE] = ACTIONS(791),
    [anon_sym_STAR] = ACTIONS(789),
    [anon_sym_as] = ACTIONS(789),
    [anon_sym_SEMI] = ACTIONS(791),
    [anon_sym_LPAREN] = ACTIONS(791),
    [anon_sym_DOT] = ACTIONS(791),
    [sym_identifier] = ACTIONS(789),
    [anon_sym_DQUOTE] = ACTIONS(791),
    [anon_sym_SQUOTE] = ACTIONS(791),
    [anon_sym_DOLLAR] = ACTIONS(789),
    [sym_numeric_literal] = ACTIONS(791),
    [anon_sym_true] = ACTIONS(789),
    [anon_sym_false] = ACTIONS(789),
    [anon_sym_null] = ACTIONS(789),
    [anon_sym_PIPE_PIPE] = ACTIONS(791),
    [anon_sym_AMP_AMP] = ACTIONS(791),
    [anon_sym_PIPE] = ACTIONS(789),
    [anon_sym_CARET] = ACTIONS(791),
    [anon_sym_AMP] = ACTIONS(789),
    [anon_sym_EQ_EQ] = ACTIONS(789),
    [anon_sym_BANG_EQ] = ACTIONS(789),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(791),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(791),
    [anon_sym_LT] = ACTIONS(789),
    [anon_sym_GT] = ACTIONS(789),
    [anon_sym_LT_EQ] = ACTIONS(791),
    [anon_sym_GT_EQ] = ACTIONS(791),
    [anon_sym_instanceof] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(789),
    [anon_sym_LT_LT] = ACTIONS(791),
    [anon_sym_GT_GT] = ACTIONS(789),
    [anon_sym_GT_GT_GT] = ACTIONS(791),
    [anon_sym_PLUS] = ACTIONS(789),
    [anon_sym_DASH] = ACTIONS(789),
    [anon_sym_PERCENT] = ACTIONS(791),
    [anon_sym_STAR_STAR] = ACTIONS(791),
    [anon_sym_BANG] = ACTIONS(789),
    [anon_sym_TILDE] = ACTIONS(791),
    [anon_sym_typeof] = ACTIONS(789),
    [anon_sym_void] = ACTIONS(789),
    [anon_sym_delete] = ACTIONS(789),
    [anon_sym_QMARK] = ACTIONS(789),
    [anon_sym_await] = ACTIONS(789),
    [anon_sym_LBRACK] = ACTIONS(791),
    [anon_sym_if] = ACTIONS(789),
    [anon_sym_else] = ACTIONS(789),
    [anon_sym_async] = ACTIONS(789),
    [anon_sym_var] = ACTIONS(789),
    [anon_sym_let] = ACTIONS(789),
    [anon_sym_const] = ACTIONS(789),
    [anon_sym_return] = ACTIONS(789),
    [anon_sym_try] = ACTIONS(789),
    [anon_sym_throw] = ACTIONS(789),
    [anon_sym_for] = ACTIONS(789),
    [anon_sym_while] = ACTIONS(789),
    [anon_sym_break] = ACTIONS(789),
    [anon_sym_continue] = ACTIONS(789),
    [anon_sym_QMARK_DOT] = ACTIONS(791),
    [anon_sym_BQUOTE] = ACTIONS(791),
    [anon_sym_DOLLARr] = ACTIONS(789),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(789),
  },
  [STATE(245)] = {
    [sym_comment] = STATE(245),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(980),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1686),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1849),
    [sym_parameter_list] = STATE(1899),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(777),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(1167),
    [sym_identifier] = ACTIONS(1280),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1282),
    [anon_sym_false] = ACTIONS(1282),
    [anon_sym_null] = ACTIONS(1284),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_GT] = ACTIONS(1205),
    [anon_sym_PLUS] = ACTIONS(1015),
    [anon_sym_DASH] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1017),
    [anon_sym_TILDE] = ACTIONS(1017),
    [anon_sym_typeof] = ACTIONS(1015),
    [anon_sym_void] = ACTIONS(1019),
    [anon_sym_delete] = ACTIONS(1015),
    [anon_sym_await] = ACTIONS(1021),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1286),
    [anon_sym_async] = ACTIONS(1031),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
  },
  [STATE(246)] = {
    [sym_comment] = STATE(246),
    [sym_modifier_chain_expression] = STATE(787),
    [sym_string_literal] = STATE(787),
    [sym_expression] = STATE(740),
    [sym_state_binding_expression] = STATE(787),
    [sym_boolean_literal] = STATE(787),
    [sym_null_literal] = STATE(787),
    [sym_binary_expression] = STATE(787),
    [sym_unary_expression] = STATE(787),
    [sym_assignment_expression] = STATE(787),
    [sym_conditional_expression] = STATE(787),
    [sym_await_expression] = STATE(787),
    [sym_as_expression] = STATE(787),
    [sym_type_annotation] = STATE(1686),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1851),
    [sym_parameter_list] = STATE(1917),
    [sym_arrow_function] = STATE(787),
    [sym_call_expression] = STATE(787),
    [sym_member_expression] = STATE(451),
    [sym_subscript_expression] = STATE(787),
    [sym_parenthesized_expression] = STATE(787),
    [sym_array_literal] = STATE(787),
    [sym_object_literal] = STATE(787),
    [sym_template_literal] = STATE(787),
    [sym_resource_expression] = STATE(787),
    [sym_update_expression] = STATE(787),
    [sym_new_expression] = STATE(787),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(1288),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_DOT] = ACTIONS(1229),
    [sym_identifier] = ACTIONS(1231),
    [anon_sym_DQUOTE] = ACTIONS(1233),
    [anon_sym_SQUOTE] = ACTIONS(1235),
    [anon_sym_DOLLAR] = ACTIONS(1237),
    [sym_numeric_literal] = ACTIONS(1239),
    [anon_sym_true] = ACTIONS(1241),
    [anon_sym_false] = ACTIONS(1241),
    [anon_sym_null] = ACTIONS(1243),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_GT] = ACTIONS(1205),
    [anon_sym_PLUS] = ACTIONS(1245),
    [anon_sym_DASH] = ACTIONS(1245),
    [anon_sym_BANG] = ACTIONS(1247),
    [anon_sym_TILDE] = ACTIONS(1247),
    [anon_sym_typeof] = ACTIONS(1245),
    [anon_sym_void] = ACTIONS(1249),
    [anon_sym_delete] = ACTIONS(1245),
    [anon_sym_await] = ACTIONS(1251),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1253),
    [anon_sym_async] = ACTIONS(1255),
    [anon_sym_BQUOTE] = ACTIONS(1257),
    [anon_sym_DOLLARr] = ACTIONS(1259),
    [anon_sym_PLUS_PLUS] = ACTIONS(1261),
    [anon_sym_DASH_DASH] = ACTIONS(1261),
    [anon_sym_new] = ACTIONS(1263),
  },
  [STATE(247)] = {
    [sym_comment] = STATE(247),
    [sym_modifier_chain_expression] = STATE(141),
    [sym_string_literal] = STATE(141),
    [sym_expression] = STATE(92),
    [sym_state_binding_expression] = STATE(141),
    [sym_boolean_literal] = STATE(141),
    [sym_null_literal] = STATE(141),
    [sym_binary_expression] = STATE(141),
    [sym_unary_expression] = STATE(141),
    [sym_assignment_expression] = STATE(141),
    [sym_conditional_expression] = STATE(141),
    [sym_await_expression] = STATE(141),
    [sym_as_expression] = STATE(141),
    [sym_type_annotation] = STATE(1686),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1861),
    [sym_parameter_list] = STATE(1905),
    [sym_arrow_function] = STATE(141),
    [sym_call_expression] = STATE(141),
    [sym_member_expression] = STATE(8),
    [sym_subscript_expression] = STATE(141),
    [sym_parenthesized_expression] = STATE(141),
    [sym_array_literal] = STATE(141),
    [sym_object_literal] = STATE(141),
    [sym_template_literal] = STATE(141),
    [sym_resource_expression] = STATE(141),
    [sym_update_expression] = STATE(141),
    [sym_new_expression] = STATE(141),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(105),
    [anon_sym_LPAREN] = ACTIONS(109),
    [anon_sym_DOT] = ACTIONS(111),
    [sym_identifier] = ACTIONS(1136),
    [anon_sym_DQUOTE] = ACTIONS(125),
    [anon_sym_SQUOTE] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(129),
    [sym_numeric_literal] = ACTIONS(131),
    [anon_sym_true] = ACTIONS(1138),
    [anon_sym_false] = ACTIONS(1138),
    [anon_sym_null] = ACTIONS(1140),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_GT] = ACTIONS(1205),
    [anon_sym_PLUS] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_TILDE] = ACTIONS(141),
    [anon_sym_typeof] = ACTIONS(139),
    [anon_sym_void] = ACTIONS(1142),
    [anon_sym_delete] = ACTIONS(139),
    [anon_sym_await] = ACTIONS(143),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1148),
    [anon_sym_async] = ACTIONS(149),
    [anon_sym_BQUOTE] = ACTIONS(151),
    [anon_sym_DOLLARr] = ACTIONS(153),
    [anon_sym_PLUS_PLUS] = ACTIONS(155),
    [anon_sym_DASH_DASH] = ACTIONS(155),
    [anon_sym_new] = ACTIONS(157),
  },
  [STATE(248)] = {
    [sym_comment] = STATE(248),
    [sym_type_arguments] = STATE(269),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(793),
    [anon_sym_LBRACE] = ACTIONS(795),
    [anon_sym_RBRACE] = ACTIONS(795),
    [anon_sym_STAR] = ACTIONS(793),
    [anon_sym_as] = ACTIONS(793),
    [anon_sym_SEMI] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(795),
    [anon_sym_DOT] = ACTIONS(795),
    [sym_identifier] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DOLLAR] = ACTIONS(793),
    [sym_numeric_literal] = ACTIONS(795),
    [anon_sym_true] = ACTIONS(793),
    [anon_sym_false] = ACTIONS(793),
    [anon_sym_null] = ACTIONS(793),
    [anon_sym_PIPE_PIPE] = ACTIONS(795),
    [anon_sym_AMP_AMP] = ACTIONS(795),
    [anon_sym_PIPE] = ACTIONS(793),
    [anon_sym_CARET] = ACTIONS(795),
    [anon_sym_AMP] = ACTIONS(793),
    [anon_sym_EQ_EQ] = ACTIONS(793),
    [anon_sym_BANG_EQ] = ACTIONS(793),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(795),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(795),
    [anon_sym_LT] = ACTIONS(793),
    [anon_sym_GT] = ACTIONS(793),
    [anon_sym_LT_EQ] = ACTIONS(795),
    [anon_sym_GT_EQ] = ACTIONS(795),
    [anon_sym_instanceof] = ACTIONS(793),
    [anon_sym_in] = ACTIONS(793),
    [anon_sym_LT_LT] = ACTIONS(795),
    [anon_sym_GT_GT] = ACTIONS(793),
    [anon_sym_GT_GT_GT] = ACTIONS(795),
    [anon_sym_PLUS] = ACTIONS(793),
    [anon_sym_DASH] = ACTIONS(793),
    [anon_sym_PERCENT] = ACTIONS(795),
    [anon_sym_STAR_STAR] = ACTIONS(795),
    [anon_sym_BANG] = ACTIONS(793),
    [anon_sym_TILDE] = ACTIONS(795),
    [anon_sym_typeof] = ACTIONS(793),
    [anon_sym_void] = ACTIONS(793),
    [anon_sym_delete] = ACTIONS(793),
    [anon_sym_QMARK] = ACTIONS(793),
    [anon_sym_await] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(795),
    [anon_sym_if] = ACTIONS(793),
    [anon_sym_else] = ACTIONS(793),
    [anon_sym_async] = ACTIONS(793),
    [anon_sym_var] = ACTIONS(793),
    [anon_sym_let] = ACTIONS(793),
    [anon_sym_const] = ACTIONS(793),
    [anon_sym_return] = ACTIONS(793),
    [anon_sym_try] = ACTIONS(793),
    [anon_sym_throw] = ACTIONS(793),
    [anon_sym_for] = ACTIONS(793),
    [anon_sym_while] = ACTIONS(793),
    [anon_sym_break] = ACTIONS(793),
    [anon_sym_continue] = ACTIONS(793),
    [anon_sym_QMARK_DOT] = ACTIONS(795),
    [anon_sym_BQUOTE] = ACTIONS(795),
    [anon_sym_DOLLARr] = ACTIONS(793),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(793),
  },
  [STATE(249)] = {
    [sym_comment] = STATE(249),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1090),
    [anon_sym_LBRACE] = ACTIONS(725),
    [anon_sym_RBRACE] = ACTIONS(725),
    [anon_sym_STAR] = ACTIONS(1090),
    [anon_sym_as] = ACTIONS(1092),
    [anon_sym_SEMI] = ACTIONS(1290),
    [anon_sym_LPAREN] = ACTIONS(1094),
    [anon_sym_DOT] = ACTIONS(1096),
    [sym_identifier] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(725),
    [anon_sym_SQUOTE] = ACTIONS(725),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [sym_numeric_literal] = ACTIONS(725),
    [anon_sym_true] = ACTIONS(729),
    [anon_sym_false] = ACTIONS(729),
    [anon_sym_null] = ACTIONS(729),
    [anon_sym_PIPE_PIPE] = ACTIONS(1098),
    [anon_sym_AMP_AMP] = ACTIONS(1100),
    [anon_sym_PIPE] = ACTIONS(1102),
    [anon_sym_CARET] = ACTIONS(1104),
    [anon_sym_AMP] = ACTIONS(1106),
    [anon_sym_EQ_EQ] = ACTIONS(1108),
    [anon_sym_BANG_EQ] = ACTIONS(1108),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1110),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1110),
    [anon_sym_LT] = ACTIONS(1112),
    [anon_sym_GT] = ACTIONS(1114),
    [anon_sym_LT_EQ] = ACTIONS(1116),
    [anon_sym_GT_EQ] = ACTIONS(1116),
    [anon_sym_instanceof] = ACTIONS(1114),
    [anon_sym_in] = ACTIONS(1114),
    [anon_sym_LT_LT] = ACTIONS(1118),
    [anon_sym_GT_GT] = ACTIONS(1120),
    [anon_sym_GT_GT_GT] = ACTIONS(1118),
    [anon_sym_PLUS] = ACTIONS(1122),
    [anon_sym_DASH] = ACTIONS(1122),
    [anon_sym_PERCENT] = ACTIONS(1124),
    [anon_sym_STAR_STAR] = ACTIONS(1126),
    [anon_sym_BANG] = ACTIONS(729),
    [anon_sym_TILDE] = ACTIONS(725),
    [anon_sym_typeof] = ACTIONS(729),
    [anon_sym_void] = ACTIONS(729),
    [anon_sym_delete] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(1128),
    [anon_sym_await] = ACTIONS(729),
    [anon_sym_LBRACK] = ACTIONS(1130),
    [anon_sym_if] = ACTIONS(729),
    [anon_sym_else] = ACTIONS(729),
    [anon_sym_async] = ACTIONS(729),
    [anon_sym_var] = ACTIONS(729),
    [anon_sym_let] = ACTIONS(729),
    [anon_sym_const] = ACTIONS(729),
    [anon_sym_return] = ACTIONS(729),
    [anon_sym_try] = ACTIONS(729),
    [anon_sym_throw] = ACTIONS(729),
    [anon_sym_for] = ACTIONS(729),
    [anon_sym_while] = ACTIONS(729),
    [anon_sym_break] = ACTIONS(729),
    [anon_sym_continue] = ACTIONS(729),
    [anon_sym_QMARK_DOT] = ACTIONS(1096),
    [anon_sym_BQUOTE] = ACTIONS(725),
    [anon_sym_DOLLARr] = ACTIONS(729),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(729),
  },
  [STATE(250)] = {
    [sym_comment] = STATE(250),
    [sym_modifier_chain_expression] = STATE(1000),
    [sym_string_literal] = STATE(1000),
    [sym_expression] = STATE(926),
    [sym_state_binding_expression] = STATE(1000),
    [sym_boolean_literal] = STATE(1000),
    [sym_null_literal] = STATE(1000),
    [sym_binary_expression] = STATE(1000),
    [sym_unary_expression] = STATE(1000),
    [sym_assignment_expression] = STATE(1000),
    [sym_conditional_expression] = STATE(1000),
    [sym_await_expression] = STATE(1000),
    [sym_as_expression] = STATE(1000),
    [sym_type_annotation] = STATE(1498),
    [sym_primary_type] = STATE(1493),
    [sym_generic_type] = STATE(1532),
    [sym_qualified_type] = STATE(1480),
    [sym_union_type] = STATE(1515),
    [sym_function_type] = STATE(1515),
    [sym_array_type] = STATE(1532),
    [sym_tuple_type] = STATE(1532),
    [sym_conditional_type] = STATE(1515),
    [sym_type_parameters] = STATE(1849),
    [sym_parameter_list] = STATE(1899),
    [sym_block_statement] = STATE(1016),
    [sym_arrow_function] = STATE(1000),
    [sym_call_expression] = STATE(1000),
    [sym_member_expression] = STATE(777),
    [sym_subscript_expression] = STATE(1000),
    [sym_parenthesized_expression] = STATE(1000),
    [sym_array_literal] = STATE(1000),
    [sym_object_literal] = STATE(1000),
    [sym_template_literal] = STATE(1000),
    [sym_resource_expression] = STATE(1000),
    [sym_update_expression] = STATE(1000),
    [sym_new_expression] = STATE(1000),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(1165),
    [anon_sym_LPAREN] = ACTIONS(997),
    [anon_sym_DOT] = ACTIONS(1167),
    [sym_identifier] = ACTIONS(1280),
    [anon_sym_DQUOTE] = ACTIONS(1003),
    [anon_sym_SQUOTE] = ACTIONS(1005),
    [anon_sym_DOLLAR] = ACTIONS(1007),
    [sym_numeric_literal] = ACTIONS(1009),
    [anon_sym_true] = ACTIONS(1282),
    [anon_sym_false] = ACTIONS(1282),
    [anon_sym_null] = ACTIONS(1284),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1015),
    [anon_sym_DASH] = ACTIONS(1015),
    [anon_sym_BANG] = ACTIONS(1017),
    [anon_sym_TILDE] = ACTIONS(1017),
    [anon_sym_typeof] = ACTIONS(1015),
    [anon_sym_void] = ACTIONS(1019),
    [anon_sym_delete] = ACTIONS(1015),
    [anon_sym_await] = ACTIONS(1021),
    [anon_sym_number] = ACTIONS(1144),
    [anon_sym_string] = ACTIONS(1144),
    [anon_sym_boolean] = ACTIONS(1144),
    [anon_sym_any] = ACTIONS(1144),
    [anon_sym_undefined] = ACTIONS(1146),
    [anon_sym_LBRACK] = ACTIONS(1286),
    [anon_sym_async] = ACTIONS(1031),
    [anon_sym_BQUOTE] = ACTIONS(1035),
    [anon_sym_DOLLARr] = ACTIONS(1037),
    [anon_sym_PLUS_PLUS] = ACTIONS(1039),
    [anon_sym_DASH_DASH] = ACTIONS(1039),
    [anon_sym_new] = ACTIONS(1041),
  },
  [STATE(251)] = {
    [sym_comment] = STATE(251),
    [sym_type_arguments] = STATE(1991),
    [sym_argument_list] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(702),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(702),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(702),
    [anon_sym_DASH] = ACTIONS(702),
    [anon_sym_PERCENT] = ACTIONS(704),
    [anon_sym_STAR_STAR] = ACTIONS(704),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(704),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_else] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1132),
    [anon_sym_DASH_DASH] = ACTIONS(1132),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(252)] = {
    [sym_comment] = STATE(252),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(702),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(702),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(702),
    [anon_sym_DASH] = ACTIONS(702),
    [anon_sym_PERCENT] = ACTIONS(704),
    [anon_sym_STAR_STAR] = ACTIONS(704),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(704),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(253)] = {
    [sym_comment] = STATE(253),
    [aux_sym_qualified_type_repeat1] = STATE(253),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(1294),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_extends] = ACTIONS(778),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_var] = ACTIONS(778),
    [anon_sym_let] = ACTIONS(778),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_return] = ACTIONS(778),
    [anon_sym_try] = ACTIONS(778),
    [anon_sym_throw] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_break] = ACTIONS(778),
    [anon_sym_continue] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(254)] = {
    [sym_comment] = STATE(254),
    [aux_sym_union_type_repeat1] = STATE(254),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(817),
    [anon_sym_LBRACE] = ACTIONS(819),
    [anon_sym_RBRACE] = ACTIONS(819),
    [anon_sym_STAR] = ACTIONS(817),
    [anon_sym_as] = ACTIONS(817),
    [anon_sym_SEMI] = ACTIONS(819),
    [anon_sym_LPAREN] = ACTIONS(819),
    [anon_sym_DOT] = ACTIONS(819),
    [sym_identifier] = ACTIONS(817),
    [anon_sym_DQUOTE] = ACTIONS(819),
    [anon_sym_SQUOTE] = ACTIONS(819),
    [anon_sym_DOLLAR] = ACTIONS(817),
    [sym_numeric_literal] = ACTIONS(819),
    [anon_sym_true] = ACTIONS(817),
    [anon_sym_false] = ACTIONS(817),
    [anon_sym_null] = ACTIONS(817),
    [anon_sym_PIPE_PIPE] = ACTIONS(819),
    [anon_sym_AMP_AMP] = ACTIONS(819),
    [anon_sym_PIPE] = ACTIONS(1297),
    [anon_sym_CARET] = ACTIONS(819),
    [anon_sym_AMP] = ACTIONS(817),
    [anon_sym_EQ_EQ] = ACTIONS(817),
    [anon_sym_BANG_EQ] = ACTIONS(817),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(819),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(819),
    [anon_sym_LT] = ACTIONS(817),
    [anon_sym_GT] = ACTIONS(817),
    [anon_sym_LT_EQ] = ACTIONS(819),
    [anon_sym_GT_EQ] = ACTIONS(819),
    [anon_sym_instanceof] = ACTIONS(817),
    [anon_sym_in] = ACTIONS(817),
    [anon_sym_LT_LT] = ACTIONS(819),
    [anon_sym_GT_GT] = ACTIONS(817),
    [anon_sym_GT_GT_GT] = ACTIONS(819),
    [anon_sym_PLUS] = ACTIONS(817),
    [anon_sym_DASH] = ACTIONS(817),
    [anon_sym_PERCENT] = ACTIONS(819),
    [anon_sym_STAR_STAR] = ACTIONS(819),
    [anon_sym_BANG] = ACTIONS(817),
    [anon_sym_TILDE] = ACTIONS(819),
    [anon_sym_typeof] = ACTIONS(817),
    [anon_sym_void] = ACTIONS(817),
    [anon_sym_delete] = ACTIONS(817),
    [anon_sym_QMARK] = ACTIONS(817),
    [anon_sym_await] = ACTIONS(817),
    [anon_sym_LBRACK] = ACTIONS(819),
    [anon_sym_if] = ACTIONS(817),
    [anon_sym_else] = ACTIONS(817),
    [anon_sym_async] = ACTIONS(817),
    [anon_sym_var] = ACTIONS(817),
    [anon_sym_let] = ACTIONS(817),
    [anon_sym_const] = ACTIONS(817),
    [anon_sym_return] = ACTIONS(817),
    [anon_sym_try] = ACTIONS(817),
    [anon_sym_throw] = ACTIONS(817),
    [anon_sym_for] = ACTIONS(817),
    [anon_sym_while] = ACTIONS(817),
    [anon_sym_break] = ACTIONS(817),
    [anon_sym_continue] = ACTIONS(817),
    [anon_sym_QMARK_DOT] = ACTIONS(819),
    [anon_sym_BQUOTE] = ACTIONS(819),
    [anon_sym_DOLLARr] = ACTIONS(817),
    [anon_sym_PLUS_PLUS] = ACTIONS(819),
    [anon_sym_DASH_DASH] = ACTIONS(819),
    [anon_sym_new] = ACTIONS(817),
  },
  [STATE(255)] = {
    [sym_comment] = STATE(255),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_RBRACE] = ACTIONS(838),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_as] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_LPAREN] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(838),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_DQUOTE] = ACTIONS(838),
    [anon_sym_SQUOTE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(836),
    [sym_numeric_literal] = ACTIONS(838),
    [anon_sym_true] = ACTIONS(836),
    [anon_sym_false] = ACTIONS(836),
    [anon_sym_null] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(838),
    [anon_sym_AMP_AMP] = ACTIONS(838),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(838),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(836),
    [anon_sym_BANG_EQ] = ACTIONS(836),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(838),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(838),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_instanceof] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(838),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_GT_GT_GT] = ACTIONS(838),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(838),
    [anon_sym_STAR_STAR] = ACTIONS(838),
    [anon_sym_BANG] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(836),
    [anon_sym_void] = ACTIONS(836),
    [anon_sym_delete] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(836),
    [anon_sym_await] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [anon_sym_extends] = ACTIONS(836),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_async] = ACTIONS(836),
    [anon_sym_var] = ACTIONS(836),
    [anon_sym_let] = ACTIONS(836),
    [anon_sym_const] = ACTIONS(836),
    [anon_sym_return] = ACTIONS(836),
    [anon_sym_try] = ACTIONS(836),
    [anon_sym_throw] = ACTIONS(836),
    [anon_sym_for] = ACTIONS(836),
    [anon_sym_while] = ACTIONS(836),
    [anon_sym_break] = ACTIONS(836),
    [anon_sym_continue] = ACTIONS(836),
    [anon_sym_QMARK_DOT] = ACTIONS(838),
    [anon_sym_BQUOTE] = ACTIONS(838),
    [anon_sym_DOLLARr] = ACTIONS(836),
    [anon_sym_PLUS_PLUS] = ACTIONS(838),
    [anon_sym_DASH_DASH] = ACTIONS(838),
    [anon_sym_new] = ACTIONS(836),
  },
  [STATE(256)] = {
    [sym_comment] = STATE(256),
    [aux_sym_qualified_type_repeat1] = STATE(253),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(767),
    [anon_sym_LBRACE] = ACTIONS(769),
    [anon_sym_RBRACE] = ACTIONS(769),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_as] = ACTIONS(767),
    [anon_sym_SEMI] = ACTIONS(769),
    [anon_sym_LPAREN] = ACTIONS(769),
    [anon_sym_DOT] = ACTIONS(769),
    [sym_identifier] = ACTIONS(767),
    [anon_sym_DQUOTE] = ACTIONS(769),
    [anon_sym_SQUOTE] = ACTIONS(769),
    [anon_sym_DOLLAR] = ACTIONS(767),
    [sym_numeric_literal] = ACTIONS(769),
    [anon_sym_true] = ACTIONS(767),
    [anon_sym_false] = ACTIONS(767),
    [anon_sym_null] = ACTIONS(767),
    [anon_sym_PIPE_PIPE] = ACTIONS(769),
    [anon_sym_AMP_AMP] = ACTIONS(769),
    [anon_sym_PIPE] = ACTIONS(767),
    [anon_sym_CARET] = ACTIONS(769),
    [anon_sym_AMP] = ACTIONS(767),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(769),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(769),
    [anon_sym_LT] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(769),
    [anon_sym_GT_EQ] = ACTIONS(769),
    [anon_sym_instanceof] = ACTIONS(767),
    [anon_sym_in] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(769),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_GT_GT_GT] = ACTIONS(769),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(767),
    [anon_sym_PERCENT] = ACTIONS(769),
    [anon_sym_STAR_STAR] = ACTIONS(769),
    [anon_sym_BANG] = ACTIONS(767),
    [anon_sym_TILDE] = ACTIONS(769),
    [anon_sym_typeof] = ACTIONS(767),
    [anon_sym_void] = ACTIONS(767),
    [anon_sym_delete] = ACTIONS(767),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_await] = ACTIONS(767),
    [anon_sym_LBRACK] = ACTIONS(769),
    [anon_sym_extends] = ACTIONS(767),
    [anon_sym_if] = ACTIONS(767),
    [anon_sym_async] = ACTIONS(767),
    [anon_sym_var] = ACTIONS(767),
    [anon_sym_let] = ACTIONS(767),
    [anon_sym_const] = ACTIONS(767),
    [anon_sym_return] = ACTIONS(767),
    [anon_sym_try] = ACTIONS(767),
    [anon_sym_throw] = ACTIONS(767),
    [anon_sym_for] = ACTIONS(767),
    [anon_sym_while] = ACTIONS(767),
    [anon_sym_break] = ACTIONS(767),
    [anon_sym_continue] = ACTIONS(767),
    [anon_sym_QMARK_DOT] = ACTIONS(769),
    [anon_sym_BQUOTE] = ACTIONS(769),
    [anon_sym_DOLLARr] = ACTIONS(767),
    [anon_sym_PLUS_PLUS] = ACTIONS(769),
    [anon_sym_DASH_DASH] = ACTIONS(769),
    [anon_sym_new] = ACTIONS(767),
  },
  [STATE(257)] = {
    [sym_comment] = STATE(257),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(809),
    [anon_sym_LBRACE] = ACTIONS(811),
    [anon_sym_RBRACE] = ACTIONS(811),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_as] = ACTIONS(809),
    [anon_sym_SEMI] = ACTIONS(811),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_DOT] = ACTIONS(811),
    [sym_identifier] = ACTIONS(809),
    [anon_sym_DQUOTE] = ACTIONS(811),
    [anon_sym_SQUOTE] = ACTIONS(811),
    [anon_sym_DOLLAR] = ACTIONS(809),
    [sym_numeric_literal] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(809),
    [anon_sym_false] = ACTIONS(809),
    [anon_sym_null] = ACTIONS(809),
    [anon_sym_PIPE_PIPE] = ACTIONS(811),
    [anon_sym_AMP_AMP] = ACTIONS(811),
    [anon_sym_PIPE] = ACTIONS(809),
    [anon_sym_CARET] = ACTIONS(811),
    [anon_sym_AMP] = ACTIONS(809),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(811),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(811),
    [anon_sym_LT] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(811),
    [anon_sym_GT_EQ] = ACTIONS(811),
    [anon_sym_instanceof] = ACTIONS(809),
    [anon_sym_in] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(811),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_GT_GT_GT] = ACTIONS(811),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(809),
    [anon_sym_PERCENT] = ACTIONS(811),
    [anon_sym_STAR_STAR] = ACTIONS(811),
    [anon_sym_BANG] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(811),
    [anon_sym_typeof] = ACTIONS(809),
    [anon_sym_void] = ACTIONS(809),
    [anon_sym_delete] = ACTIONS(809),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_await] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_extends] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(809),
    [anon_sym_async] = ACTIONS(809),
    [anon_sym_var] = ACTIONS(809),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_const] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(809),
    [anon_sym_try] = ACTIONS(809),
    [anon_sym_throw] = ACTIONS(809),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_while] = ACTIONS(809),
    [anon_sym_break] = ACTIONS(809),
    [anon_sym_continue] = ACTIONS(809),
    [anon_sym_QMARK_DOT] = ACTIONS(811),
    [anon_sym_BQUOTE] = ACTIONS(811),
    [anon_sym_DOLLARr] = ACTIONS(809),
    [anon_sym_PLUS_PLUS] = ACTIONS(811),
    [anon_sym_DASH_DASH] = ACTIONS(811),
    [anon_sym_new] = ACTIONS(809),
  },
  [STATE(258)] = {
    [sym_comment] = STATE(258),
    [sym_modifier_chain_expression] = STATE(335),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_RBRACE] = ACTIONS(867),
    [anon_sym_STAR] = ACTIONS(865),
    [anon_sym_as] = ACTIONS(865),
    [anon_sym_SEMI] = ACTIONS(867),
    [anon_sym_LPAREN] = ACTIONS(1300),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(865),
    [anon_sym_DQUOTE] = ACTIONS(867),
    [anon_sym_SQUOTE] = ACTIONS(867),
    [anon_sym_DOLLAR] = ACTIONS(865),
    [sym_numeric_literal] = ACTIONS(867),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_null] = ACTIONS(865),
    [anon_sym_PIPE_PIPE] = ACTIONS(867),
    [anon_sym_AMP_AMP] = ACTIONS(867),
    [anon_sym_PIPE] = ACTIONS(865),
    [anon_sym_CARET] = ACTIONS(867),
    [anon_sym_AMP] = ACTIONS(865),
    [anon_sym_EQ_EQ] = ACTIONS(865),
    [anon_sym_BANG_EQ] = ACTIONS(865),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(867),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(867),
    [anon_sym_LT] = ACTIONS(865),
    [anon_sym_GT] = ACTIONS(865),
    [anon_sym_LT_EQ] = ACTIONS(867),
    [anon_sym_GT_EQ] = ACTIONS(867),
    [anon_sym_instanceof] = ACTIONS(865),
    [anon_sym_in] = ACTIONS(865),
    [anon_sym_LT_LT] = ACTIONS(867),
    [anon_sym_GT_GT] = ACTIONS(865),
    [anon_sym_GT_GT_GT] = ACTIONS(867),
    [anon_sym_PLUS] = ACTIONS(865),
    [anon_sym_DASH] = ACTIONS(865),
    [anon_sym_PERCENT] = ACTIONS(867),
    [anon_sym_STAR_STAR] = ACTIONS(867),
    [anon_sym_BANG] = ACTIONS(865),
    [anon_sym_TILDE] = ACTIONS(867),
    [anon_sym_typeof] = ACTIONS(865),
    [anon_sym_void] = ACTIONS(865),
    [anon_sym_delete] = ACTIONS(865),
    [anon_sym_QMARK] = ACTIONS(865),
    [anon_sym_await] = ACTIONS(865),
    [anon_sym_LBRACK] = ACTIONS(867),
    [anon_sym_if] = ACTIONS(865),
    [anon_sym_else] = ACTIONS(865),
    [anon_sym_async] = ACTIONS(865),
    [anon_sym_var] = ACTIONS(865),
    [anon_sym_let] = ACTIONS(865),
    [anon_sym_const] = ACTIONS(865),
    [anon_sym_return] = ACTIONS(865),
    [anon_sym_try] = ACTIONS(865),
    [anon_sym_throw] = ACTIONS(865),
    [anon_sym_for] = ACTIONS(865),
    [anon_sym_while] = ACTIONS(865),
    [anon_sym_break] = ACTIONS(865),
    [anon_sym_continue] = ACTIONS(865),
    [anon_sym_QMARK_DOT] = ACTIONS(867),
    [anon_sym_BQUOTE] = ACTIONS(867),
    [anon_sym_DOLLARr] = ACTIONS(865),
    [anon_sym_PLUS_PLUS] = ACTIONS(867),
    [anon_sym_DASH_DASH] = ACTIONS(867),
    [anon_sym_new] = ACTIONS(865),
  },
  [STATE(259)] = {
    [sym_comment] = STATE(259),
    [aux_sym_array_type_repeat1] = STATE(275),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(1078),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(260)] = {
    [sym_comment] = STATE(260),
    [aux_sym_array_type_repeat1] = STATE(264),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(1087),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_else] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(261)] = {
    [sym_comment] = STATE(261),
    [sym_type_arguments] = STATE(358),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(1084),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_else] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(262)] = {
    [sym_comment] = STATE(262),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(843),
    [anon_sym_LBRACE] = ACTIONS(845),
    [anon_sym_RBRACE] = ACTIONS(845),
    [anon_sym_STAR] = ACTIONS(843),
    [anon_sym_as] = ACTIONS(843),
    [anon_sym_SEMI] = ACTIONS(845),
    [anon_sym_LPAREN] = ACTIONS(845),
    [anon_sym_DOT] = ACTIONS(845),
    [sym_identifier] = ACTIONS(843),
    [anon_sym_DQUOTE] = ACTIONS(845),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DOLLAR] = ACTIONS(843),
    [sym_numeric_literal] = ACTIONS(845),
    [anon_sym_true] = ACTIONS(843),
    [anon_sym_false] = ACTIONS(843),
    [anon_sym_null] = ACTIONS(843),
    [anon_sym_PIPE_PIPE] = ACTIONS(845),
    [anon_sym_AMP_AMP] = ACTIONS(845),
    [anon_sym_PIPE] = ACTIONS(843),
    [anon_sym_CARET] = ACTIONS(845),
    [anon_sym_AMP] = ACTIONS(843),
    [anon_sym_EQ_EQ] = ACTIONS(843),
    [anon_sym_BANG_EQ] = ACTIONS(843),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(845),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(845),
    [anon_sym_LT] = ACTIONS(843),
    [anon_sym_GT] = ACTIONS(843),
    [anon_sym_LT_EQ] = ACTIONS(845),
    [anon_sym_GT_EQ] = ACTIONS(845),
    [anon_sym_instanceof] = ACTIONS(843),
    [anon_sym_in] = ACTIONS(843),
    [anon_sym_LT_LT] = ACTIONS(845),
    [anon_sym_GT_GT] = ACTIONS(843),
    [anon_sym_GT_GT_GT] = ACTIONS(845),
    [anon_sym_PLUS] = ACTIONS(843),
    [anon_sym_DASH] = ACTIONS(843),
    [anon_sym_PERCENT] = ACTIONS(845),
    [anon_sym_STAR_STAR] = ACTIONS(845),
    [anon_sym_BANG] = ACTIONS(843),
    [anon_sym_TILDE] = ACTIONS(845),
    [anon_sym_typeof] = ACTIONS(843),
    [anon_sym_void] = ACTIONS(843),
    [anon_sym_delete] = ACTIONS(843),
    [anon_sym_QMARK] = ACTIONS(843),
    [anon_sym_await] = ACTIONS(843),
    [anon_sym_LBRACK] = ACTIONS(845),
    [anon_sym_extends] = ACTIONS(843),
    [anon_sym_if] = ACTIONS(843),
    [anon_sym_else] = ACTIONS(843),
    [anon_sym_async] = ACTIONS(843),
    [anon_sym_var] = ACTIONS(843),
    [anon_sym_let] = ACTIONS(843),
    [anon_sym_const] = ACTIONS(843),
    [anon_sym_return] = ACTIONS(843),
    [anon_sym_try] = ACTIONS(843),
    [anon_sym_throw] = ACTIONS(843),
    [anon_sym_for] = ACTIONS(843),
    [anon_sym_while] = ACTIONS(843),
    [anon_sym_break] = ACTIONS(843),
    [anon_sym_continue] = ACTIONS(843),
    [anon_sym_QMARK_DOT] = ACTIONS(845),
    [anon_sym_BQUOTE] = ACTIONS(845),
    [anon_sym_DOLLARr] = ACTIONS(843),
    [anon_sym_PLUS_PLUS] = ACTIONS(845),
    [anon_sym_DASH_DASH] = ACTIONS(845),
    [anon_sym_new] = ACTIONS(843),
  },
  [STATE(263)] = {
    [sym_comment] = STATE(263),
    [aux_sym_qualified_type_repeat1] = STATE(266),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(767),
    [anon_sym_LBRACE] = ACTIONS(769),
    [anon_sym_RBRACE] = ACTIONS(769),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_as] = ACTIONS(767),
    [anon_sym_SEMI] = ACTIONS(769),
    [anon_sym_LPAREN] = ACTIONS(769),
    [anon_sym_DOT] = ACTIONS(769),
    [sym_identifier] = ACTIONS(767),
    [anon_sym_DQUOTE] = ACTIONS(769),
    [anon_sym_SQUOTE] = ACTIONS(769),
    [anon_sym_DOLLAR] = ACTIONS(767),
    [sym_numeric_literal] = ACTIONS(769),
    [anon_sym_true] = ACTIONS(767),
    [anon_sym_false] = ACTIONS(767),
    [anon_sym_null] = ACTIONS(767),
    [anon_sym_PIPE_PIPE] = ACTIONS(769),
    [anon_sym_AMP_AMP] = ACTIONS(769),
    [anon_sym_PIPE] = ACTIONS(767),
    [anon_sym_CARET] = ACTIONS(769),
    [anon_sym_AMP] = ACTIONS(767),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(769),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(769),
    [anon_sym_LT] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(769),
    [anon_sym_GT_EQ] = ACTIONS(769),
    [anon_sym_instanceof] = ACTIONS(767),
    [anon_sym_in] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(769),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_GT_GT_GT] = ACTIONS(769),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(767),
    [anon_sym_PERCENT] = ACTIONS(769),
    [anon_sym_STAR_STAR] = ACTIONS(769),
    [anon_sym_BANG] = ACTIONS(767),
    [anon_sym_TILDE] = ACTIONS(769),
    [anon_sym_typeof] = ACTIONS(767),
    [anon_sym_void] = ACTIONS(767),
    [anon_sym_delete] = ACTIONS(767),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_await] = ACTIONS(767),
    [anon_sym_LBRACK] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(767),
    [anon_sym_else] = ACTIONS(767),
    [anon_sym_async] = ACTIONS(767),
    [anon_sym_var] = ACTIONS(767),
    [anon_sym_let] = ACTIONS(767),
    [anon_sym_const] = ACTIONS(767),
    [anon_sym_return] = ACTIONS(767),
    [anon_sym_try] = ACTIONS(767),
    [anon_sym_throw] = ACTIONS(767),
    [anon_sym_for] = ACTIONS(767),
    [anon_sym_while] = ACTIONS(767),
    [anon_sym_break] = ACTIONS(767),
    [anon_sym_continue] = ACTIONS(767),
    [anon_sym_QMARK_DOT] = ACTIONS(769),
    [anon_sym_BQUOTE] = ACTIONS(769),
    [anon_sym_DOLLARr] = ACTIONS(767),
    [anon_sym_PLUS_PLUS] = ACTIONS(769),
    [anon_sym_DASH_DASH] = ACTIONS(769),
    [anon_sym_new] = ACTIONS(767),
  },
  [STATE(264)] = {
    [sym_comment] = STATE(264),
    [aux_sym_array_type_repeat1] = STATE(299),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(771),
    [anon_sym_LBRACE] = ACTIONS(773),
    [anon_sym_RBRACE] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(771),
    [anon_sym_as] = ACTIONS(771),
    [anon_sym_SEMI] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(773),
    [anon_sym_DOT] = ACTIONS(773),
    [sym_identifier] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(773),
    [anon_sym_SQUOTE] = ACTIONS(773),
    [anon_sym_DOLLAR] = ACTIONS(771),
    [sym_numeric_literal] = ACTIONS(773),
    [anon_sym_true] = ACTIONS(771),
    [anon_sym_false] = ACTIONS(771),
    [anon_sym_null] = ACTIONS(771),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(771),
    [anon_sym_CARET] = ACTIONS(773),
    [anon_sym_AMP] = ACTIONS(771),
    [anon_sym_EQ_EQ] = ACTIONS(771),
    [anon_sym_BANG_EQ] = ACTIONS(771),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(773),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(773),
    [anon_sym_LT] = ACTIONS(771),
    [anon_sym_GT] = ACTIONS(771),
    [anon_sym_LT_EQ] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(773),
    [anon_sym_instanceof] = ACTIONS(771),
    [anon_sym_in] = ACTIONS(771),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(771),
    [anon_sym_GT_GT_GT] = ACTIONS(773),
    [anon_sym_PLUS] = ACTIONS(771),
    [anon_sym_DASH] = ACTIONS(771),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_STAR_STAR] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(771),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_typeof] = ACTIONS(771),
    [anon_sym_void] = ACTIONS(771),
    [anon_sym_delete] = ACTIONS(771),
    [anon_sym_QMARK] = ACTIONS(771),
    [anon_sym_await] = ACTIONS(771),
    [anon_sym_LBRACK] = ACTIONS(1302),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_else] = ACTIONS(771),
    [anon_sym_async] = ACTIONS(771),
    [anon_sym_var] = ACTIONS(771),
    [anon_sym_let] = ACTIONS(771),
    [anon_sym_const] = ACTIONS(771),
    [anon_sym_return] = ACTIONS(771),
    [anon_sym_try] = ACTIONS(771),
    [anon_sym_throw] = ACTIONS(771),
    [anon_sym_for] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(771),
    [anon_sym_break] = ACTIONS(771),
    [anon_sym_continue] = ACTIONS(771),
    [anon_sym_QMARK_DOT] = ACTIONS(773),
    [anon_sym_BQUOTE] = ACTIONS(773),
    [anon_sym_DOLLARr] = ACTIONS(771),
    [anon_sym_PLUS_PLUS] = ACTIONS(773),
    [anon_sym_DASH_DASH] = ACTIONS(773),
    [anon_sym_new] = ACTIONS(771),
  },
  [STATE(265)] = {
    [sym_comment] = STATE(265),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(847),
    [anon_sym_LBRACE] = ACTIONS(849),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_STAR] = ACTIONS(847),
    [anon_sym_as] = ACTIONS(847),
    [anon_sym_SEMI] = ACTIONS(849),
    [anon_sym_LPAREN] = ACTIONS(849),
    [anon_sym_DOT] = ACTIONS(849),
    [sym_identifier] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [anon_sym_SQUOTE] = ACTIONS(849),
    [anon_sym_DOLLAR] = ACTIONS(847),
    [sym_numeric_literal] = ACTIONS(849),
    [anon_sym_true] = ACTIONS(847),
    [anon_sym_false] = ACTIONS(847),
    [anon_sym_null] = ACTIONS(847),
    [anon_sym_PIPE_PIPE] = ACTIONS(849),
    [anon_sym_AMP_AMP] = ACTIONS(849),
    [anon_sym_PIPE] = ACTIONS(847),
    [anon_sym_CARET] = ACTIONS(849),
    [anon_sym_AMP] = ACTIONS(847),
    [anon_sym_EQ_EQ] = ACTIONS(847),
    [anon_sym_BANG_EQ] = ACTIONS(847),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(849),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(849),
    [anon_sym_LT] = ACTIONS(847),
    [anon_sym_GT] = ACTIONS(847),
    [anon_sym_LT_EQ] = ACTIONS(849),
    [anon_sym_GT_EQ] = ACTIONS(849),
    [anon_sym_instanceof] = ACTIONS(847),
    [anon_sym_in] = ACTIONS(847),
    [anon_sym_LT_LT] = ACTIONS(849),
    [anon_sym_GT_GT] = ACTIONS(847),
    [anon_sym_GT_GT_GT] = ACTIONS(849),
    [anon_sym_PLUS] = ACTIONS(847),
    [anon_sym_DASH] = ACTIONS(847),
    [anon_sym_PERCENT] = ACTIONS(849),
    [anon_sym_STAR_STAR] = ACTIONS(849),
    [anon_sym_BANG] = ACTIONS(847),
    [anon_sym_TILDE] = ACTIONS(849),
    [anon_sym_typeof] = ACTIONS(847),
    [anon_sym_void] = ACTIONS(847),
    [anon_sym_delete] = ACTIONS(847),
    [anon_sym_QMARK] = ACTIONS(847),
    [anon_sym_await] = ACTIONS(847),
    [anon_sym_LBRACK] = ACTIONS(849),
    [anon_sym_extends] = ACTIONS(847),
    [anon_sym_if] = ACTIONS(847),
    [anon_sym_else] = ACTIONS(847),
    [anon_sym_async] = ACTIONS(847),
    [anon_sym_var] = ACTIONS(847),
    [anon_sym_let] = ACTIONS(847),
    [anon_sym_const] = ACTIONS(847),
    [anon_sym_return] = ACTIONS(847),
    [anon_sym_try] = ACTIONS(847),
    [anon_sym_throw] = ACTIONS(847),
    [anon_sym_for] = ACTIONS(847),
    [anon_sym_while] = ACTIONS(847),
    [anon_sym_break] = ACTIONS(847),
    [anon_sym_continue] = ACTIONS(847),
    [anon_sym_QMARK_DOT] = ACTIONS(849),
    [anon_sym_BQUOTE] = ACTIONS(849),
    [anon_sym_DOLLARr] = ACTIONS(847),
    [anon_sym_PLUS_PLUS] = ACTIONS(849),
    [anon_sym_DASH_DASH] = ACTIONS(849),
    [anon_sym_new] = ACTIONS(847),
  },
  [STATE(266)] = {
    [sym_comment] = STATE(266),
    [aux_sym_qualified_type_repeat1] = STATE(266),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(1305),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_else] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_var] = ACTIONS(778),
    [anon_sym_let] = ACTIONS(778),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_return] = ACTIONS(778),
    [anon_sym_try] = ACTIONS(778),
    [anon_sym_throw] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_break] = ACTIONS(778),
    [anon_sym_continue] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(267)] = {
    [sym_comment] = STATE(267),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(851),
    [anon_sym_LBRACE] = ACTIONS(853),
    [anon_sym_RBRACE] = ACTIONS(853),
    [anon_sym_STAR] = ACTIONS(851),
    [anon_sym_as] = ACTIONS(851),
    [anon_sym_SEMI] = ACTIONS(853),
    [anon_sym_LPAREN] = ACTIONS(853),
    [anon_sym_DOT] = ACTIONS(853),
    [sym_identifier] = ACTIONS(851),
    [anon_sym_DQUOTE] = ACTIONS(853),
    [anon_sym_SQUOTE] = ACTIONS(853),
    [anon_sym_DOLLAR] = ACTIONS(851),
    [sym_numeric_literal] = ACTIONS(853),
    [anon_sym_true] = ACTIONS(851),
    [anon_sym_false] = ACTIONS(851),
    [anon_sym_null] = ACTIONS(851),
    [anon_sym_PIPE_PIPE] = ACTIONS(853),
    [anon_sym_AMP_AMP] = ACTIONS(853),
    [anon_sym_PIPE] = ACTIONS(851),
    [anon_sym_CARET] = ACTIONS(853),
    [anon_sym_AMP] = ACTIONS(851),
    [anon_sym_EQ_EQ] = ACTIONS(851),
    [anon_sym_BANG_EQ] = ACTIONS(851),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(853),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(853),
    [anon_sym_LT] = ACTIONS(851),
    [anon_sym_GT] = ACTIONS(851),
    [anon_sym_LT_EQ] = ACTIONS(853),
    [anon_sym_GT_EQ] = ACTIONS(853),
    [anon_sym_instanceof] = ACTIONS(851),
    [anon_sym_in] = ACTIONS(851),
    [anon_sym_LT_LT] = ACTIONS(853),
    [anon_sym_GT_GT] = ACTIONS(851),
    [anon_sym_GT_GT_GT] = ACTIONS(853),
    [anon_sym_PLUS] = ACTIONS(851),
    [anon_sym_DASH] = ACTIONS(851),
    [anon_sym_PERCENT] = ACTIONS(853),
    [anon_sym_STAR_STAR] = ACTIONS(853),
    [anon_sym_BANG] = ACTIONS(851),
    [anon_sym_TILDE] = ACTIONS(853),
    [anon_sym_typeof] = ACTIONS(851),
    [anon_sym_void] = ACTIONS(851),
    [anon_sym_delete] = ACTIONS(851),
    [anon_sym_QMARK] = ACTIONS(851),
    [anon_sym_await] = ACTIONS(851),
    [anon_sym_LBRACK] = ACTIONS(853),
    [anon_sym_extends] = ACTIONS(851),
    [anon_sym_if] = ACTIONS(851),
    [anon_sym_else] = ACTIONS(851),
    [anon_sym_async] = ACTIONS(851),
    [anon_sym_var] = ACTIONS(851),
    [anon_sym_let] = ACTIONS(851),
    [anon_sym_const] = ACTIONS(851),
    [anon_sym_return] = ACTIONS(851),
    [anon_sym_try] = ACTIONS(851),
    [anon_sym_throw] = ACTIONS(851),
    [anon_sym_for] = ACTIONS(851),
    [anon_sym_while] = ACTIONS(851),
    [anon_sym_break] = ACTIONS(851),
    [anon_sym_continue] = ACTIONS(851),
    [anon_sym_QMARK_DOT] = ACTIONS(853),
    [anon_sym_BQUOTE] = ACTIONS(853),
    [anon_sym_DOLLARr] = ACTIONS(851),
    [anon_sym_PLUS_PLUS] = ACTIONS(853),
    [anon_sym_DASH_DASH] = ACTIONS(853),
    [anon_sym_new] = ACTIONS(851),
  },
  [STATE(268)] = {
    [sym_comment] = STATE(268),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(763),
    [anon_sym_LBRACE] = ACTIONS(765),
    [anon_sym_RBRACE] = ACTIONS(765),
    [anon_sym_STAR] = ACTIONS(763),
    [anon_sym_as] = ACTIONS(763),
    [anon_sym_SEMI] = ACTIONS(765),
    [anon_sym_LPAREN] = ACTIONS(765),
    [anon_sym_DOT] = ACTIONS(765),
    [sym_identifier] = ACTIONS(763),
    [anon_sym_DQUOTE] = ACTIONS(765),
    [anon_sym_SQUOTE] = ACTIONS(765),
    [anon_sym_DOLLAR] = ACTIONS(763),
    [sym_numeric_literal] = ACTIONS(765),
    [anon_sym_true] = ACTIONS(763),
    [anon_sym_false] = ACTIONS(763),
    [anon_sym_null] = ACTIONS(763),
    [anon_sym_PIPE_PIPE] = ACTIONS(765),
    [anon_sym_AMP_AMP] = ACTIONS(765),
    [anon_sym_PIPE] = ACTIONS(763),
    [anon_sym_CARET] = ACTIONS(765),
    [anon_sym_AMP] = ACTIONS(763),
    [anon_sym_EQ_EQ] = ACTIONS(763),
    [anon_sym_BANG_EQ] = ACTIONS(763),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(765),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(765),
    [anon_sym_LT] = ACTIONS(763),
    [anon_sym_GT] = ACTIONS(763),
    [anon_sym_LT_EQ] = ACTIONS(765),
    [anon_sym_GT_EQ] = ACTIONS(765),
    [anon_sym_instanceof] = ACTIONS(763),
    [anon_sym_in] = ACTIONS(763),
    [anon_sym_LT_LT] = ACTIONS(765),
    [anon_sym_GT_GT] = ACTIONS(763),
    [anon_sym_GT_GT_GT] = ACTIONS(765),
    [anon_sym_PLUS] = ACTIONS(763),
    [anon_sym_DASH] = ACTIONS(763),
    [anon_sym_PERCENT] = ACTIONS(765),
    [anon_sym_STAR_STAR] = ACTIONS(765),
    [anon_sym_BANG] = ACTIONS(763),
    [anon_sym_TILDE] = ACTIONS(765),
    [anon_sym_typeof] = ACTIONS(763),
    [anon_sym_void] = ACTIONS(763),
    [anon_sym_delete] = ACTIONS(763),
    [anon_sym_QMARK] = ACTIONS(763),
    [anon_sym_await] = ACTIONS(763),
    [anon_sym_LBRACK] = ACTIONS(765),
    [anon_sym_if] = ACTIONS(763),
    [anon_sym_async] = ACTIONS(763),
    [anon_sym_var] = ACTIONS(763),
    [anon_sym_let] = ACTIONS(763),
    [anon_sym_const] = ACTIONS(763),
    [anon_sym_return] = ACTIONS(763),
    [anon_sym_try] = ACTIONS(763),
    [anon_sym_throw] = ACTIONS(763),
    [anon_sym_for] = ACTIONS(763),
    [anon_sym_while] = ACTIONS(763),
    [anon_sym_break] = ACTIONS(763),
    [anon_sym_continue] = ACTIONS(763),
    [anon_sym_QMARK_DOT] = ACTIONS(765),
    [anon_sym_BQUOTE] = ACTIONS(765),
    [anon_sym_DOLLARr] = ACTIONS(763),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(763),
  },
  [STATE(269)] = {
    [sym_comment] = STATE(269),
    [sym_argument_list] = STATE(312),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(832),
    [anon_sym_LBRACE] = ACTIONS(834),
    [anon_sym_RBRACE] = ACTIONS(834),
    [anon_sym_STAR] = ACTIONS(832),
    [anon_sym_as] = ACTIONS(832),
    [anon_sym_SEMI] = ACTIONS(834),
    [anon_sym_LPAREN] = ACTIONS(834),
    [anon_sym_DOT] = ACTIONS(834),
    [sym_identifier] = ACTIONS(832),
    [anon_sym_DQUOTE] = ACTIONS(834),
    [anon_sym_SQUOTE] = ACTIONS(834),
    [anon_sym_DOLLAR] = ACTIONS(832),
    [sym_numeric_literal] = ACTIONS(834),
    [anon_sym_true] = ACTIONS(832),
    [anon_sym_false] = ACTIONS(832),
    [anon_sym_null] = ACTIONS(832),
    [anon_sym_PIPE_PIPE] = ACTIONS(834),
    [anon_sym_AMP_AMP] = ACTIONS(834),
    [anon_sym_PIPE] = ACTIONS(832),
    [anon_sym_CARET] = ACTIONS(834),
    [anon_sym_AMP] = ACTIONS(832),
    [anon_sym_EQ_EQ] = ACTIONS(832),
    [anon_sym_BANG_EQ] = ACTIONS(832),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(834),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(834),
    [anon_sym_LT] = ACTIONS(832),
    [anon_sym_GT] = ACTIONS(832),
    [anon_sym_LT_EQ] = ACTIONS(834),
    [anon_sym_GT_EQ] = ACTIONS(834),
    [anon_sym_instanceof] = ACTIONS(832),
    [anon_sym_in] = ACTIONS(832),
    [anon_sym_LT_LT] = ACTIONS(834),
    [anon_sym_GT_GT] = ACTIONS(832),
    [anon_sym_GT_GT_GT] = ACTIONS(834),
    [anon_sym_PLUS] = ACTIONS(832),
    [anon_sym_DASH] = ACTIONS(832),
    [anon_sym_PERCENT] = ACTIONS(834),
    [anon_sym_STAR_STAR] = ACTIONS(834),
    [anon_sym_BANG] = ACTIONS(832),
    [anon_sym_TILDE] = ACTIONS(834),
    [anon_sym_typeof] = ACTIONS(832),
    [anon_sym_void] = ACTIONS(832),
    [anon_sym_delete] = ACTIONS(832),
    [anon_sym_QMARK] = ACTIONS(832),
    [anon_sym_await] = ACTIONS(832),
    [anon_sym_LBRACK] = ACTIONS(834),
    [anon_sym_if] = ACTIONS(832),
    [anon_sym_else] = ACTIONS(832),
    [anon_sym_async] = ACTIONS(832),
    [anon_sym_var] = ACTIONS(832),
    [anon_sym_let] = ACTIONS(832),
    [anon_sym_const] = ACTIONS(832),
    [anon_sym_return] = ACTIONS(832),
    [anon_sym_try] = ACTIONS(832),
    [anon_sym_throw] = ACTIONS(832),
    [anon_sym_for] = ACTIONS(832),
    [anon_sym_while] = ACTIONS(832),
    [anon_sym_break] = ACTIONS(832),
    [anon_sym_continue] = ACTIONS(832),
    [anon_sym_QMARK_DOT] = ACTIONS(834),
    [anon_sym_BQUOTE] = ACTIONS(834),
    [anon_sym_DOLLARr] = ACTIONS(832),
    [anon_sym_PLUS_PLUS] = ACTIONS(834),
    [anon_sym_DASH_DASH] = ACTIONS(834),
    [anon_sym_new] = ACTIONS(832),
  },
  [STATE(270)] = {
    [sym_comment] = STATE(270),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(785),
    [anon_sym_LBRACE] = ACTIONS(787),
    [anon_sym_RBRACE] = ACTIONS(787),
    [anon_sym_STAR] = ACTIONS(785),
    [anon_sym_as] = ACTIONS(785),
    [anon_sym_SEMI] = ACTIONS(787),
    [anon_sym_LPAREN] = ACTIONS(787),
    [anon_sym_DOT] = ACTIONS(787),
    [sym_identifier] = ACTIONS(785),
    [anon_sym_DQUOTE] = ACTIONS(787),
    [anon_sym_SQUOTE] = ACTIONS(787),
    [anon_sym_DOLLAR] = ACTIONS(785),
    [sym_numeric_literal] = ACTIONS(787),
    [anon_sym_true] = ACTIONS(785),
    [anon_sym_false] = ACTIONS(785),
    [anon_sym_null] = ACTIONS(785),
    [anon_sym_PIPE_PIPE] = ACTIONS(787),
    [anon_sym_AMP_AMP] = ACTIONS(787),
    [anon_sym_PIPE] = ACTIONS(785),
    [anon_sym_CARET] = ACTIONS(787),
    [anon_sym_AMP] = ACTIONS(785),
    [anon_sym_EQ_EQ] = ACTIONS(785),
    [anon_sym_BANG_EQ] = ACTIONS(785),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(787),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(787),
    [anon_sym_LT] = ACTIONS(785),
    [anon_sym_GT] = ACTIONS(785),
    [anon_sym_LT_EQ] = ACTIONS(787),
    [anon_sym_GT_EQ] = ACTIONS(787),
    [anon_sym_instanceof] = ACTIONS(785),
    [anon_sym_in] = ACTIONS(785),
    [anon_sym_LT_LT] = ACTIONS(787),
    [anon_sym_GT_GT] = ACTIONS(785),
    [anon_sym_GT_GT_GT] = ACTIONS(787),
    [anon_sym_PLUS] = ACTIONS(785),
    [anon_sym_DASH] = ACTIONS(785),
    [anon_sym_PERCENT] = ACTIONS(787),
    [anon_sym_STAR_STAR] = ACTIONS(787),
    [anon_sym_BANG] = ACTIONS(785),
    [anon_sym_TILDE] = ACTIONS(787),
    [anon_sym_typeof] = ACTIONS(785),
    [anon_sym_void] = ACTIONS(785),
    [anon_sym_delete] = ACTIONS(785),
    [anon_sym_QMARK] = ACTIONS(785),
    [anon_sym_await] = ACTIONS(785),
    [anon_sym_LBRACK] = ACTIONS(787),
    [anon_sym_if] = ACTIONS(785),
    [anon_sym_async] = ACTIONS(785),
    [anon_sym_var] = ACTIONS(785),
    [anon_sym_let] = ACTIONS(785),
    [anon_sym_const] = ACTIONS(785),
    [anon_sym_return] = ACTIONS(785),
    [anon_sym_try] = ACTIONS(785),
    [anon_sym_throw] = ACTIONS(785),
    [anon_sym_for] = ACTIONS(785),
    [anon_sym_while] = ACTIONS(785),
    [anon_sym_break] = ACTIONS(785),
    [anon_sym_continue] = ACTIONS(785),
    [anon_sym_QMARK_DOT] = ACTIONS(787),
    [anon_sym_BQUOTE] = ACTIONS(787),
    [anon_sym_DOLLARr] = ACTIONS(785),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(785),
  },
  [STATE(271)] = {
    [sym_comment] = STATE(271),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(789),
    [anon_sym_LBRACE] = ACTIONS(791),
    [anon_sym_RBRACE] = ACTIONS(791),
    [anon_sym_STAR] = ACTIONS(789),
    [anon_sym_as] = ACTIONS(789),
    [anon_sym_SEMI] = ACTIONS(791),
    [anon_sym_LPAREN] = ACTIONS(791),
    [anon_sym_DOT] = ACTIONS(791),
    [sym_identifier] = ACTIONS(789),
    [anon_sym_DQUOTE] = ACTIONS(791),
    [anon_sym_SQUOTE] = ACTIONS(791),
    [anon_sym_DOLLAR] = ACTIONS(789),
    [sym_numeric_literal] = ACTIONS(791),
    [anon_sym_true] = ACTIONS(789),
    [anon_sym_false] = ACTIONS(789),
    [anon_sym_null] = ACTIONS(789),
    [anon_sym_PIPE_PIPE] = ACTIONS(791),
    [anon_sym_AMP_AMP] = ACTIONS(791),
    [anon_sym_PIPE] = ACTIONS(789),
    [anon_sym_CARET] = ACTIONS(791),
    [anon_sym_AMP] = ACTIONS(789),
    [anon_sym_EQ_EQ] = ACTIONS(789),
    [anon_sym_BANG_EQ] = ACTIONS(789),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(791),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(791),
    [anon_sym_LT] = ACTIONS(789),
    [anon_sym_GT] = ACTIONS(789),
    [anon_sym_LT_EQ] = ACTIONS(791),
    [anon_sym_GT_EQ] = ACTIONS(791),
    [anon_sym_instanceof] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(789),
    [anon_sym_LT_LT] = ACTIONS(791),
    [anon_sym_GT_GT] = ACTIONS(789),
    [anon_sym_GT_GT_GT] = ACTIONS(791),
    [anon_sym_PLUS] = ACTIONS(789),
    [anon_sym_DASH] = ACTIONS(789),
    [anon_sym_PERCENT] = ACTIONS(791),
    [anon_sym_STAR_STAR] = ACTIONS(791),
    [anon_sym_BANG] = ACTIONS(789),
    [anon_sym_TILDE] = ACTIONS(791),
    [anon_sym_typeof] = ACTIONS(789),
    [anon_sym_void] = ACTIONS(789),
    [anon_sym_delete] = ACTIONS(789),
    [anon_sym_QMARK] = ACTIONS(789),
    [anon_sym_await] = ACTIONS(789),
    [anon_sym_LBRACK] = ACTIONS(791),
    [anon_sym_if] = ACTIONS(789),
    [anon_sym_async] = ACTIONS(789),
    [anon_sym_var] = ACTIONS(789),
    [anon_sym_let] = ACTIONS(789),
    [anon_sym_const] = ACTIONS(789),
    [anon_sym_return] = ACTIONS(789),
    [anon_sym_try] = ACTIONS(789),
    [anon_sym_throw] = ACTIONS(789),
    [anon_sym_for] = ACTIONS(789),
    [anon_sym_while] = ACTIONS(789),
    [anon_sym_break] = ACTIONS(789),
    [anon_sym_continue] = ACTIONS(789),
    [anon_sym_QMARK_DOT] = ACTIONS(791),
    [anon_sym_BQUOTE] = ACTIONS(791),
    [anon_sym_DOLLARr] = ACTIONS(789),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(789),
  },
  [STATE(272)] = {
    [sym_comment] = STATE(272),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(754),
    [anon_sym_LBRACE] = ACTIONS(749),
    [anon_sym_RBRACE] = ACTIONS(749),
    [anon_sym_STAR] = ACTIONS(754),
    [anon_sym_as] = ACTIONS(754),
    [anon_sym_SEMI] = ACTIONS(749),
    [anon_sym_LPAREN] = ACTIONS(749),
    [anon_sym_DOT] = ACTIONS(749),
    [sym_identifier] = ACTIONS(754),
    [anon_sym_DQUOTE] = ACTIONS(749),
    [anon_sym_SQUOTE] = ACTIONS(749),
    [anon_sym_DOLLAR] = ACTIONS(754),
    [sym_numeric_literal] = ACTIONS(749),
    [anon_sym_true] = ACTIONS(754),
    [anon_sym_false] = ACTIONS(754),
    [anon_sym_null] = ACTIONS(754),
    [anon_sym_PIPE_PIPE] = ACTIONS(749),
    [anon_sym_AMP_AMP] = ACTIONS(749),
    [anon_sym_PIPE] = ACTIONS(754),
    [anon_sym_CARET] = ACTIONS(749),
    [anon_sym_AMP] = ACTIONS(754),
    [anon_sym_EQ_EQ] = ACTIONS(754),
    [anon_sym_BANG_EQ] = ACTIONS(754),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(749),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(749),
    [anon_sym_LT] = ACTIONS(754),
    [anon_sym_GT] = ACTIONS(754),
    [anon_sym_LT_EQ] = ACTIONS(749),
    [anon_sym_GT_EQ] = ACTIONS(749),
    [anon_sym_instanceof] = ACTIONS(754),
    [anon_sym_in] = ACTIONS(754),
    [anon_sym_LT_LT] = ACTIONS(749),
    [anon_sym_GT_GT] = ACTIONS(754),
    [anon_sym_GT_GT_GT] = ACTIONS(749),
    [anon_sym_PLUS] = ACTIONS(754),
    [anon_sym_DASH] = ACTIONS(754),
    [anon_sym_PERCENT] = ACTIONS(749),
    [anon_sym_STAR_STAR] = ACTIONS(749),
    [anon_sym_BANG] = ACTIONS(754),
    [anon_sym_TILDE] = ACTIONS(749),
    [anon_sym_typeof] = ACTIONS(754),
    [anon_sym_void] = ACTIONS(754),
    [anon_sym_delete] = ACTIONS(754),
    [anon_sym_QMARK] = ACTIONS(754),
    [anon_sym_await] = ACTIONS(754),
    [anon_sym_LBRACK] = ACTIONS(749),
    [anon_sym_extends] = ACTIONS(754),
    [anon_sym_if] = ACTIONS(754),
    [anon_sym_else] = ACTIONS(754),
    [anon_sym_async] = ACTIONS(754),
    [anon_sym_var] = ACTIONS(754),
    [anon_sym_let] = ACTIONS(754),
    [anon_sym_const] = ACTIONS(754),
    [anon_sym_return] = ACTIONS(754),
    [anon_sym_try] = ACTIONS(754),
    [anon_sym_throw] = ACTIONS(754),
    [anon_sym_for] = ACTIONS(754),
    [anon_sym_while] = ACTIONS(754),
    [anon_sym_break] = ACTIONS(754),
    [anon_sym_continue] = ACTIONS(754),
    [anon_sym_QMARK_DOT] = ACTIONS(749),
    [anon_sym_BQUOTE] = ACTIONS(749),
    [anon_sym_DOLLARr] = ACTIONS(754),
    [anon_sym_PLUS_PLUS] = ACTIONS(749),
    [anon_sym_DASH_DASH] = ACTIONS(749),
    [anon_sym_new] = ACTIONS(754),
  },
  [STATE(273)] = {
    [sym_comment] = STATE(273),
    [aux_sym_union_type_repeat1] = STATE(254),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_RBRACE] = ACTIONS(815),
    [anon_sym_STAR] = ACTIONS(813),
    [anon_sym_as] = ACTIONS(813),
    [anon_sym_SEMI] = ACTIONS(815),
    [anon_sym_LPAREN] = ACTIONS(815),
    [anon_sym_DOT] = ACTIONS(815),
    [sym_identifier] = ACTIONS(813),
    [anon_sym_DQUOTE] = ACTIONS(815),
    [anon_sym_SQUOTE] = ACTIONS(815),
    [anon_sym_DOLLAR] = ACTIONS(813),
    [sym_numeric_literal] = ACTIONS(815),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_null] = ACTIONS(813),
    [anon_sym_PIPE_PIPE] = ACTIONS(815),
    [anon_sym_AMP_AMP] = ACTIONS(815),
    [anon_sym_PIPE] = ACTIONS(813),
    [anon_sym_CARET] = ACTIONS(815),
    [anon_sym_AMP] = ACTIONS(813),
    [anon_sym_EQ_EQ] = ACTIONS(813),
    [anon_sym_BANG_EQ] = ACTIONS(813),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(815),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(815),
    [anon_sym_LT] = ACTIONS(813),
    [anon_sym_GT] = ACTIONS(813),
    [anon_sym_LT_EQ] = ACTIONS(815),
    [anon_sym_GT_EQ] = ACTIONS(815),
    [anon_sym_instanceof] = ACTIONS(813),
    [anon_sym_in] = ACTIONS(813),
    [anon_sym_LT_LT] = ACTIONS(815),
    [anon_sym_GT_GT] = ACTIONS(813),
    [anon_sym_GT_GT_GT] = ACTIONS(815),
    [anon_sym_PLUS] = ACTIONS(813),
    [anon_sym_DASH] = ACTIONS(813),
    [anon_sym_PERCENT] = ACTIONS(815),
    [anon_sym_STAR_STAR] = ACTIONS(815),
    [anon_sym_BANG] = ACTIONS(813),
    [anon_sym_TILDE] = ACTIONS(815),
    [anon_sym_typeof] = ACTIONS(813),
    [anon_sym_void] = ACTIONS(813),
    [anon_sym_delete] = ACTIONS(813),
    [anon_sym_QMARK] = ACTIONS(813),
    [anon_sym_await] = ACTIONS(813),
    [anon_sym_LBRACK] = ACTIONS(815),
    [anon_sym_if] = ACTIONS(813),
    [anon_sym_else] = ACTIONS(813),
    [anon_sym_async] = ACTIONS(813),
    [anon_sym_var] = ACTIONS(813),
    [anon_sym_let] = ACTIONS(813),
    [anon_sym_const] = ACTIONS(813),
    [anon_sym_return] = ACTIONS(813),
    [anon_sym_try] = ACTIONS(813),
    [anon_sym_throw] = ACTIONS(813),
    [anon_sym_for] = ACTIONS(813),
    [anon_sym_while] = ACTIONS(813),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(813),
    [anon_sym_QMARK_DOT] = ACTIONS(815),
    [anon_sym_BQUOTE] = ACTIONS(815),
    [anon_sym_DOLLARr] = ACTIONS(813),
    [anon_sym_PLUS_PLUS] = ACTIONS(815),
    [anon_sym_DASH_DASH] = ACTIONS(815),
    [anon_sym_new] = ACTIONS(813),
  },
  [STATE(274)] = {
    [sym_comment] = STATE(274),
    [sym_modifier_chain_expression] = STATE(1950),
    [aux_sym_extend_function_body_repeat1] = STATE(1649),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(1308),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_DOT] = ACTIONS(1311),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(37),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(37),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(37),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(37),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(275)] = {
    [sym_comment] = STATE(275),
    [aux_sym_array_type_repeat1] = STATE(303),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(771),
    [anon_sym_LBRACE] = ACTIONS(773),
    [anon_sym_RBRACE] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(771),
    [anon_sym_as] = ACTIONS(771),
    [anon_sym_SEMI] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(773),
    [anon_sym_DOT] = ACTIONS(773),
    [sym_identifier] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(773),
    [anon_sym_SQUOTE] = ACTIONS(773),
    [anon_sym_DOLLAR] = ACTIONS(771),
    [sym_numeric_literal] = ACTIONS(773),
    [anon_sym_true] = ACTIONS(771),
    [anon_sym_false] = ACTIONS(771),
    [anon_sym_null] = ACTIONS(771),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(771),
    [anon_sym_CARET] = ACTIONS(773),
    [anon_sym_AMP] = ACTIONS(771),
    [anon_sym_EQ_EQ] = ACTIONS(771),
    [anon_sym_BANG_EQ] = ACTIONS(771),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(773),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(773),
    [anon_sym_LT] = ACTIONS(771),
    [anon_sym_GT] = ACTIONS(771),
    [anon_sym_LT_EQ] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(773),
    [anon_sym_instanceof] = ACTIONS(771),
    [anon_sym_in] = ACTIONS(771),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(771),
    [anon_sym_GT_GT_GT] = ACTIONS(773),
    [anon_sym_PLUS] = ACTIONS(771),
    [anon_sym_DASH] = ACTIONS(771),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_STAR_STAR] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(771),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_typeof] = ACTIONS(771),
    [anon_sym_void] = ACTIONS(771),
    [anon_sym_delete] = ACTIONS(771),
    [anon_sym_QMARK] = ACTIONS(771),
    [anon_sym_await] = ACTIONS(771),
    [anon_sym_LBRACK] = ACTIONS(1314),
    [anon_sym_extends] = ACTIONS(771),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_async] = ACTIONS(771),
    [anon_sym_var] = ACTIONS(771),
    [anon_sym_let] = ACTIONS(771),
    [anon_sym_const] = ACTIONS(771),
    [anon_sym_return] = ACTIONS(771),
    [anon_sym_try] = ACTIONS(771),
    [anon_sym_throw] = ACTIONS(771),
    [anon_sym_for] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(771),
    [anon_sym_break] = ACTIONS(771),
    [anon_sym_continue] = ACTIONS(771),
    [anon_sym_QMARK_DOT] = ACTIONS(773),
    [anon_sym_BQUOTE] = ACTIONS(773),
    [anon_sym_DOLLARr] = ACTIONS(771),
    [anon_sym_PLUS_PLUS] = ACTIONS(773),
    [anon_sym_DASH_DASH] = ACTIONS(773),
    [anon_sym_new] = ACTIONS(771),
  },
  [STATE(276)] = {
    [sym_comment] = STATE(276),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(725),
    [anon_sym_RBRACE] = ACTIONS(725),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(1319),
    [anon_sym_SEMI] = ACTIONS(1321),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1325),
    [sym_identifier] = ACTIONS(729),
    [anon_sym_DQUOTE] = ACTIONS(725),
    [anon_sym_SQUOTE] = ACTIONS(725),
    [anon_sym_DOLLAR] = ACTIONS(729),
    [sym_numeric_literal] = ACTIONS(725),
    [anon_sym_true] = ACTIONS(729),
    [anon_sym_false] = ACTIONS(729),
    [anon_sym_null] = ACTIONS(729),
    [anon_sym_PIPE_PIPE] = ACTIONS(1327),
    [anon_sym_AMP_AMP] = ACTIONS(1329),
    [anon_sym_PIPE] = ACTIONS(1331),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1341),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(729),
    [anon_sym_TILDE] = ACTIONS(725),
    [anon_sym_typeof] = ACTIONS(729),
    [anon_sym_void] = ACTIONS(729),
    [anon_sym_delete] = ACTIONS(729),
    [anon_sym_QMARK] = ACTIONS(1357),
    [anon_sym_await] = ACTIONS(729),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(729),
    [anon_sym_async] = ACTIONS(729),
    [anon_sym_var] = ACTIONS(729),
    [anon_sym_let] = ACTIONS(729),
    [anon_sym_const] = ACTIONS(729),
    [anon_sym_return] = ACTIONS(729),
    [anon_sym_try] = ACTIONS(729),
    [anon_sym_throw] = ACTIONS(729),
    [anon_sym_for] = ACTIONS(729),
    [anon_sym_while] = ACTIONS(729),
    [anon_sym_break] = ACTIONS(729),
    [anon_sym_continue] = ACTIONS(729),
    [anon_sym_QMARK_DOT] = ACTIONS(1325),
    [anon_sym_BQUOTE] = ACTIONS(725),
    [anon_sym_DOLLARr] = ACTIONS(729),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(729),
  },
  [STATE(277)] = {
    [sym_comment] = STATE(277),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(731),
    [anon_sym_LBRACE] = ACTIONS(733),
    [anon_sym_COMMA] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(733),
    [anon_sym_STAR] = ACTIONS(731),
    [anon_sym_as] = ACTIONS(731),
    [anon_sym_SEMI] = ACTIONS(733),
    [anon_sym_LPAREN] = ACTIONS(733),
    [anon_sym_DOT] = ACTIONS(733),
    [sym_identifier] = ACTIONS(731),
    [anon_sym_DQUOTE] = ACTIONS(733),
    [anon_sym_SQUOTE] = ACTIONS(733),
    [anon_sym_DOLLAR] = ACTIONS(731),
    [sym_numeric_literal] = ACTIONS(733),
    [anon_sym_true] = ACTIONS(731),
    [anon_sym_false] = ACTIONS(731),
    [anon_sym_null] = ACTIONS(731),
    [anon_sym_PIPE_PIPE] = ACTIONS(733),
    [anon_sym_AMP_AMP] = ACTIONS(733),
    [anon_sym_PIPE] = ACTIONS(735),
    [anon_sym_CARET] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_EQ_EQ] = ACTIONS(731),
    [anon_sym_BANG_EQ] = ACTIONS(731),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(733),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(733),
    [anon_sym_LT] = ACTIONS(731),
    [anon_sym_GT] = ACTIONS(735),
    [anon_sym_LT_EQ] = ACTIONS(733),
    [anon_sym_GT_EQ] = ACTIONS(733),
    [anon_sym_instanceof] = ACTIONS(731),
    [anon_sym_in] = ACTIONS(731),
    [anon_sym_LT_LT] = ACTIONS(733),
    [anon_sym_GT_GT] = ACTIONS(731),
    [anon_sym_GT_GT_GT] = ACTIONS(733),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(731),
    [anon_sym_PERCENT] = ACTIONS(733),
    [anon_sym_STAR_STAR] = ACTIONS(733),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_TILDE] = ACTIONS(733),
    [anon_sym_typeof] = ACTIONS(731),
    [anon_sym_void] = ACTIONS(731),
    [anon_sym_delete] = ACTIONS(731),
    [anon_sym_QMARK] = ACTIONS(731),
    [anon_sym_await] = ACTIONS(731),
    [anon_sym_LBRACK] = ACTIONS(733),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(731),
    [anon_sym_async] = ACTIONS(731),
    [anon_sym_var] = ACTIONS(731),
    [anon_sym_let] = ACTIONS(731),
    [anon_sym_const] = ACTIONS(731),
    [anon_sym_return] = ACTIONS(731),
    [anon_sym_try] = ACTIONS(731),
    [anon_sym_throw] = ACTIONS(731),
    [anon_sym_for] = ACTIONS(731),
    [anon_sym_while] = ACTIONS(731),
    [anon_sym_break] = ACTIONS(731),
    [anon_sym_continue] = ACTIONS(731),
    [anon_sym_QMARK_DOT] = ACTIONS(733),
    [anon_sym_BQUOTE] = ACTIONS(733),
    [anon_sym_DOLLARr] = ACTIONS(731),
    [anon_sym_PLUS_PLUS] = ACTIONS(733),
    [anon_sym_DASH_DASH] = ACTIONS(733),
    [anon_sym_new] = ACTIONS(731),
  },
  [STATE(278)] = {
    [sym_comment] = STATE(278),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(738),
    [anon_sym_LBRACE] = ACTIONS(740),
    [anon_sym_COMMA] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(740),
    [anon_sym_STAR] = ACTIONS(738),
    [anon_sym_as] = ACTIONS(738),
    [anon_sym_SEMI] = ACTIONS(740),
    [anon_sym_LPAREN] = ACTIONS(740),
    [anon_sym_DOT] = ACTIONS(740),
    [sym_identifier] = ACTIONS(738),
    [anon_sym_DQUOTE] = ACTIONS(740),
    [anon_sym_SQUOTE] = ACTIONS(740),
    [anon_sym_DOLLAR] = ACTIONS(738),
    [sym_numeric_literal] = ACTIONS(740),
    [anon_sym_true] = ACTIONS(738),
    [anon_sym_false] = ACTIONS(738),
    [anon_sym_null] = ACTIONS(738),
    [anon_sym_PIPE_PIPE] = ACTIONS(740),
    [anon_sym_AMP_AMP] = ACTIONS(740),
    [anon_sym_PIPE] = ACTIONS(742),
    [anon_sym_CARET] = ACTIONS(740),
    [anon_sym_AMP] = ACTIONS(738),
    [anon_sym_EQ_EQ] = ACTIONS(738),
    [anon_sym_BANG_EQ] = ACTIONS(738),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(740),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(738),
    [anon_sym_GT] = ACTIONS(742),
    [anon_sym_LT_EQ] = ACTIONS(740),
    [anon_sym_GT_EQ] = ACTIONS(740),
    [anon_sym_instanceof] = ACTIONS(738),
    [anon_sym_in] = ACTIONS(738),
    [anon_sym_LT_LT] = ACTIONS(740),
    [anon_sym_GT_GT] = ACTIONS(738),
    [anon_sym_GT_GT_GT] = ACTIONS(740),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_PERCENT] = ACTIONS(740),
    [anon_sym_STAR_STAR] = ACTIONS(740),
    [anon_sym_BANG] = ACTIONS(738),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_typeof] = ACTIONS(738),
    [anon_sym_void] = ACTIONS(738),
    [anon_sym_delete] = ACTIONS(738),
    [anon_sym_QMARK] = ACTIONS(738),
    [anon_sym_await] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(738),
    [anon_sym_async] = ACTIONS(738),
    [anon_sym_var] = ACTIONS(738),
    [anon_sym_let] = ACTIONS(738),
    [anon_sym_const] = ACTIONS(738),
    [anon_sym_return] = ACTIONS(738),
    [anon_sym_try] = ACTIONS(738),
    [anon_sym_throw] = ACTIONS(738),
    [anon_sym_for] = ACTIONS(738),
    [anon_sym_while] = ACTIONS(738),
    [anon_sym_break] = ACTIONS(738),
    [anon_sym_continue] = ACTIONS(738),
    [anon_sym_QMARK_DOT] = ACTIONS(740),
    [anon_sym_BQUOTE] = ACTIONS(740),
    [anon_sym_DOLLARr] = ACTIONS(738),
    [anon_sym_PLUS_PLUS] = ACTIONS(740),
    [anon_sym_DASH_DASH] = ACTIONS(740),
    [anon_sym_new] = ACTIONS(738),
  },
  [STATE(279)] = {
    [sym_comment] = STATE(279),
    [sym_type_arguments] = STATE(357),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(793),
    [anon_sym_LBRACE] = ACTIONS(795),
    [anon_sym_RBRACE] = ACTIONS(795),
    [anon_sym_STAR] = ACTIONS(793),
    [anon_sym_as] = ACTIONS(793),
    [anon_sym_SEMI] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(795),
    [anon_sym_DOT] = ACTIONS(795),
    [sym_identifier] = ACTIONS(793),
    [anon_sym_DQUOTE] = ACTIONS(795),
    [anon_sym_SQUOTE] = ACTIONS(795),
    [anon_sym_DOLLAR] = ACTIONS(793),
    [sym_numeric_literal] = ACTIONS(795),
    [anon_sym_true] = ACTIONS(793),
    [anon_sym_false] = ACTIONS(793),
    [anon_sym_null] = ACTIONS(793),
    [anon_sym_PIPE_PIPE] = ACTIONS(795),
    [anon_sym_AMP_AMP] = ACTIONS(795),
    [anon_sym_PIPE] = ACTIONS(793),
    [anon_sym_CARET] = ACTIONS(795),
    [anon_sym_AMP] = ACTIONS(793),
    [anon_sym_EQ_EQ] = ACTIONS(793),
    [anon_sym_BANG_EQ] = ACTIONS(793),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(795),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(795),
    [anon_sym_LT] = ACTIONS(793),
    [anon_sym_GT] = ACTIONS(793),
    [anon_sym_LT_EQ] = ACTIONS(795),
    [anon_sym_GT_EQ] = ACTIONS(795),
    [anon_sym_instanceof] = ACTIONS(793),
    [anon_sym_in] = ACTIONS(793),
    [anon_sym_LT_LT] = ACTIONS(795),
    [anon_sym_GT_GT] = ACTIONS(793),
    [anon_sym_GT_GT_GT] = ACTIONS(795),
    [anon_sym_PLUS] = ACTIONS(793),
    [anon_sym_DASH] = ACTIONS(793),
    [anon_sym_PERCENT] = ACTIONS(795),
    [anon_sym_STAR_STAR] = ACTIONS(795),
    [anon_sym_BANG] = ACTIONS(793),
    [anon_sym_TILDE] = ACTIONS(795),
    [anon_sym_typeof] = ACTIONS(793),
    [anon_sym_void] = ACTIONS(793),
    [anon_sym_delete] = ACTIONS(793),
    [anon_sym_QMARK] = ACTIONS(793),
    [anon_sym_await] = ACTIONS(793),
    [anon_sym_LBRACK] = ACTIONS(795),
    [anon_sym_if] = ACTIONS(793),
    [anon_sym_async] = ACTIONS(793),
    [anon_sym_var] = ACTIONS(793),
    [anon_sym_let] = ACTIONS(793),
    [anon_sym_const] = ACTIONS(793),
    [anon_sym_return] = ACTIONS(793),
    [anon_sym_try] = ACTIONS(793),
    [anon_sym_throw] = ACTIONS(793),
    [anon_sym_for] = ACTIONS(793),
    [anon_sym_while] = ACTIONS(793),
    [anon_sym_break] = ACTIONS(793),
    [anon_sym_continue] = ACTIONS(793),
    [anon_sym_QMARK_DOT] = ACTIONS(795),
    [anon_sym_BQUOTE] = ACTIONS(795),
    [anon_sym_DOLLARr] = ACTIONS(793),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(793),
  },
  [STATE(280)] = {
    [sym_comment] = STATE(280),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(805),
    [anon_sym_LBRACE] = ACTIONS(807),
    [anon_sym_RBRACE] = ACTIONS(807),
    [anon_sym_STAR] = ACTIONS(805),
    [anon_sym_as] = ACTIONS(805),
    [anon_sym_SEMI] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(807),
    [anon_sym_DOT] = ACTIONS(807),
    [sym_identifier] = ACTIONS(805),
    [anon_sym_DQUOTE] = ACTIONS(807),
    [anon_sym_SQUOTE] = ACTIONS(807),
    [anon_sym_DOLLAR] = ACTIONS(805),
    [sym_numeric_literal] = ACTIONS(807),
    [anon_sym_true] = ACTIONS(805),
    [anon_sym_false] = ACTIONS(805),
    [anon_sym_null] = ACTIONS(805),
    [anon_sym_PIPE_PIPE] = ACTIONS(807),
    [anon_sym_AMP_AMP] = ACTIONS(807),
    [anon_sym_PIPE] = ACTIONS(805),
    [anon_sym_CARET] = ACTIONS(807),
    [anon_sym_AMP] = ACTIONS(805),
    [anon_sym_EQ_EQ] = ACTIONS(805),
    [anon_sym_BANG_EQ] = ACTIONS(805),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(807),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(807),
    [anon_sym_LT] = ACTIONS(805),
    [anon_sym_GT] = ACTIONS(805),
    [anon_sym_LT_EQ] = ACTIONS(807),
    [anon_sym_GT_EQ] = ACTIONS(807),
    [anon_sym_instanceof] = ACTIONS(805),
    [anon_sym_in] = ACTIONS(805),
    [anon_sym_LT_LT] = ACTIONS(807),
    [anon_sym_GT_GT] = ACTIONS(805),
    [anon_sym_GT_GT_GT] = ACTIONS(807),
    [anon_sym_PLUS] = ACTIONS(805),
    [anon_sym_DASH] = ACTIONS(805),
    [anon_sym_PERCENT] = ACTIONS(807),
    [anon_sym_STAR_STAR] = ACTIONS(807),
    [anon_sym_BANG] = ACTIONS(805),
    [anon_sym_TILDE] = ACTIONS(807),
    [anon_sym_typeof] = ACTIONS(805),
    [anon_sym_void] = ACTIONS(805),
    [anon_sym_delete] = ACTIONS(805),
    [anon_sym_QMARK] = ACTIONS(805),
    [anon_sym_await] = ACTIONS(805),
    [anon_sym_LBRACK] = ACTIONS(807),
    [anon_sym_extends] = ACTIONS(805),
    [anon_sym_if] = ACTIONS(805),
    [anon_sym_else] = ACTIONS(805),
    [anon_sym_async] = ACTIONS(805),
    [anon_sym_var] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(805),
    [anon_sym_const] = ACTIONS(805),
    [anon_sym_return] = ACTIONS(805),
    [anon_sym_try] = ACTIONS(805),
    [anon_sym_throw] = ACTIONS(805),
    [anon_sym_for] = ACTIONS(805),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_break] = ACTIONS(805),
    [anon_sym_continue] = ACTIONS(805),
    [anon_sym_QMARK_DOT] = ACTIONS(807),
    [anon_sym_BQUOTE] = ACTIONS(807),
    [anon_sym_DOLLARr] = ACTIONS(805),
    [anon_sym_PLUS_PLUS] = ACTIONS(807),
    [anon_sym_DASH_DASH] = ACTIONS(807),
    [anon_sym_new] = ACTIONS(805),
  },
  [STATE(281)] = {
    [sym_comment] = STATE(281),
    [aux_sym_union_type_repeat1] = STATE(338),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(797),
    [anon_sym_LBRACE] = ACTIONS(799),
    [anon_sym_RBRACE] = ACTIONS(799),
    [anon_sym_STAR] = ACTIONS(797),
    [anon_sym_as] = ACTIONS(797),
    [anon_sym_SEMI] = ACTIONS(799),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_DOT] = ACTIONS(799),
    [sym_identifier] = ACTIONS(797),
    [anon_sym_DQUOTE] = ACTIONS(799),
    [anon_sym_SQUOTE] = ACTIONS(799),
    [anon_sym_DOLLAR] = ACTIONS(797),
    [sym_numeric_literal] = ACTIONS(799),
    [anon_sym_true] = ACTIONS(797),
    [anon_sym_false] = ACTIONS(797),
    [anon_sym_null] = ACTIONS(797),
    [anon_sym_PIPE_PIPE] = ACTIONS(799),
    [anon_sym_AMP_AMP] = ACTIONS(799),
    [anon_sym_PIPE] = ACTIONS(1361),
    [anon_sym_CARET] = ACTIONS(799),
    [anon_sym_AMP] = ACTIONS(797),
    [anon_sym_EQ_EQ] = ACTIONS(797),
    [anon_sym_BANG_EQ] = ACTIONS(797),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(799),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(799),
    [anon_sym_LT] = ACTIONS(797),
    [anon_sym_GT] = ACTIONS(797),
    [anon_sym_LT_EQ] = ACTIONS(799),
    [anon_sym_GT_EQ] = ACTIONS(799),
    [anon_sym_instanceof] = ACTIONS(797),
    [anon_sym_in] = ACTIONS(797),
    [anon_sym_LT_LT] = ACTIONS(799),
    [anon_sym_GT_GT] = ACTIONS(797),
    [anon_sym_GT_GT_GT] = ACTIONS(799),
    [anon_sym_PLUS] = ACTIONS(797),
    [anon_sym_DASH] = ACTIONS(797),
    [anon_sym_PERCENT] = ACTIONS(799),
    [anon_sym_STAR_STAR] = ACTIONS(799),
    [anon_sym_BANG] = ACTIONS(797),
    [anon_sym_TILDE] = ACTIONS(799),
    [anon_sym_typeof] = ACTIONS(797),
    [anon_sym_void] = ACTIONS(797),
    [anon_sym_delete] = ACTIONS(797),
    [anon_sym_QMARK] = ACTIONS(797),
    [anon_sym_await] = ACTIONS(797),
    [anon_sym_LBRACK] = ACTIONS(799),
    [anon_sym_extends] = ACTIONS(1363),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_async] = ACTIONS(797),
    [anon_sym_var] = ACTIONS(797),
    [anon_sym_let] = ACTIONS(797),
    [anon_sym_const] = ACTIONS(797),
    [anon_sym_return] = ACTIONS(797),
    [anon_sym_try] = ACTIONS(797),
    [anon_sym_throw] = ACTIONS(797),
    [anon_sym_for] = ACTIONS(797),
    [anon_sym_while] = ACTIONS(797),
    [anon_sym_break] = ACTIONS(797),
    [anon_sym_continue] = ACTIONS(797),
    [anon_sym_QMARK_DOT] = ACTIONS(799),
    [anon_sym_BQUOTE] = ACTIONS(799),
    [anon_sym_DOLLARr] = ACTIONS(797),
    [anon_sym_PLUS_PLUS] = ACTIONS(799),
    [anon_sym_DASH_DASH] = ACTIONS(799),
    [anon_sym_new] = ACTIONS(797),
  },
  [STATE(282)] = {
    [sym_comment] = STATE(282),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(688),
    [anon_sym_RBRACE] = ACTIONS(688),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(1319),
    [anon_sym_SEMI] = ACTIONS(688),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1325),
    [sym_identifier] = ACTIONS(694),
    [anon_sym_DQUOTE] = ACTIONS(688),
    [anon_sym_SQUOTE] = ACTIONS(688),
    [anon_sym_DOLLAR] = ACTIONS(694),
    [sym_numeric_literal] = ACTIONS(688),
    [anon_sym_true] = ACTIONS(694),
    [anon_sym_false] = ACTIONS(694),
    [anon_sym_null] = ACTIONS(694),
    [anon_sym_PIPE_PIPE] = ACTIONS(1327),
    [anon_sym_AMP_AMP] = ACTIONS(1329),
    [anon_sym_PIPE] = ACTIONS(1331),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1341),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(694),
    [anon_sym_TILDE] = ACTIONS(688),
    [anon_sym_typeof] = ACTIONS(694),
    [anon_sym_void] = ACTIONS(694),
    [anon_sym_delete] = ACTIONS(694),
    [anon_sym_QMARK] = ACTIONS(1357),
    [anon_sym_await] = ACTIONS(694),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(694),
    [anon_sym_async] = ACTIONS(694),
    [anon_sym_var] = ACTIONS(694),
    [anon_sym_let] = ACTIONS(694),
    [anon_sym_const] = ACTIONS(694),
    [anon_sym_return] = ACTIONS(694),
    [anon_sym_try] = ACTIONS(694),
    [anon_sym_throw] = ACTIONS(694),
    [anon_sym_for] = ACTIONS(694),
    [anon_sym_while] = ACTIONS(694),
    [anon_sym_break] = ACTIONS(694),
    [anon_sym_continue] = ACTIONS(694),
    [anon_sym_QMARK_DOT] = ACTIONS(1325),
    [anon_sym_BQUOTE] = ACTIONS(688),
    [anon_sym_DOLLARr] = ACTIONS(694),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(694),
  },
  [STATE(283)] = {
    [sym_comment] = STATE(283),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_RBRACE] = ACTIONS(698),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(1319),
    [anon_sym_SEMI] = ACTIONS(698),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1325),
    [sym_identifier] = ACTIONS(700),
    [anon_sym_DQUOTE] = ACTIONS(698),
    [anon_sym_SQUOTE] = ACTIONS(698),
    [anon_sym_DOLLAR] = ACTIONS(700),
    [sym_numeric_literal] = ACTIONS(698),
    [anon_sym_true] = ACTIONS(700),
    [anon_sym_false] = ACTIONS(700),
    [anon_sym_null] = ACTIONS(700),
    [anon_sym_PIPE_PIPE] = ACTIONS(1327),
    [anon_sym_AMP_AMP] = ACTIONS(1329),
    [anon_sym_PIPE] = ACTIONS(1331),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1341),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(700),
    [anon_sym_TILDE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(700),
    [anon_sym_void] = ACTIONS(700),
    [anon_sym_delete] = ACTIONS(700),
    [anon_sym_QMARK] = ACTIONS(1357),
    [anon_sym_await] = ACTIONS(700),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(700),
    [anon_sym_async] = ACTIONS(700),
    [anon_sym_var] = ACTIONS(700),
    [anon_sym_let] = ACTIONS(700),
    [anon_sym_const] = ACTIONS(700),
    [anon_sym_return] = ACTIONS(700),
    [anon_sym_try] = ACTIONS(700),
    [anon_sym_throw] = ACTIONS(700),
    [anon_sym_for] = ACTIONS(700),
    [anon_sym_while] = ACTIONS(700),
    [anon_sym_break] = ACTIONS(700),
    [anon_sym_continue] = ACTIONS(700),
    [anon_sym_QMARK_DOT] = ACTIONS(1325),
    [anon_sym_BQUOTE] = ACTIONS(698),
    [anon_sym_DOLLARr] = ACTIONS(700),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(700),
  },
  [STATE(284)] = {
    [sym_comment] = STATE(284),
    [sym_type_arguments] = STATE(367),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(1075),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(285)] = {
    [sym_comment] = STATE(285),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(702),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(702),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(702),
    [anon_sym_DASH] = ACTIONS(702),
    [anon_sym_PERCENT] = ACTIONS(704),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(704),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(286)] = {
    [sym_comment] = STATE(286),
    [sym_modifier_chain_expression] = STATE(341),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(824),
    [anon_sym_LBRACE] = ACTIONS(826),
    [anon_sym_RBRACE] = ACTIONS(826),
    [anon_sym_STAR] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(824),
    [anon_sym_SEMI] = ACTIONS(826),
    [anon_sym_LPAREN] = ACTIONS(826),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(824),
    [anon_sym_DQUOTE] = ACTIONS(826),
    [anon_sym_SQUOTE] = ACTIONS(826),
    [anon_sym_DOLLAR] = ACTIONS(824),
    [sym_numeric_literal] = ACTIONS(826),
    [anon_sym_true] = ACTIONS(824),
    [anon_sym_false] = ACTIONS(824),
    [anon_sym_null] = ACTIONS(824),
    [anon_sym_PIPE_PIPE] = ACTIONS(826),
    [anon_sym_AMP_AMP] = ACTIONS(826),
    [anon_sym_PIPE] = ACTIONS(824),
    [anon_sym_CARET] = ACTIONS(826),
    [anon_sym_AMP] = ACTIONS(824),
    [anon_sym_EQ_EQ] = ACTIONS(824),
    [anon_sym_BANG_EQ] = ACTIONS(824),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(826),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(826),
    [anon_sym_LT] = ACTIONS(824),
    [anon_sym_GT] = ACTIONS(824),
    [anon_sym_LT_EQ] = ACTIONS(826),
    [anon_sym_GT_EQ] = ACTIONS(826),
    [anon_sym_instanceof] = ACTIONS(824),
    [anon_sym_in] = ACTIONS(824),
    [anon_sym_LT_LT] = ACTIONS(826),
    [anon_sym_GT_GT] = ACTIONS(824),
    [anon_sym_GT_GT_GT] = ACTIONS(826),
    [anon_sym_PLUS] = ACTIONS(824),
    [anon_sym_DASH] = ACTIONS(824),
    [anon_sym_PERCENT] = ACTIONS(826),
    [anon_sym_STAR_STAR] = ACTIONS(826),
    [anon_sym_BANG] = ACTIONS(824),
    [anon_sym_TILDE] = ACTIONS(826),
    [anon_sym_typeof] = ACTIONS(824),
    [anon_sym_void] = ACTIONS(824),
    [anon_sym_delete] = ACTIONS(824),
    [anon_sym_QMARK] = ACTIONS(824),
    [anon_sym_await] = ACTIONS(824),
    [anon_sym_LBRACK] = ACTIONS(826),
    [anon_sym_if] = ACTIONS(824),
    [anon_sym_else] = ACTIONS(824),
    [anon_sym_async] = ACTIONS(824),
    [anon_sym_var] = ACTIONS(824),
    [anon_sym_let] = ACTIONS(824),
    [anon_sym_const] = ACTIONS(824),
    [anon_sym_return] = ACTIONS(824),
    [anon_sym_try] = ACTIONS(824),
    [anon_sym_throw] = ACTIONS(824),
    [anon_sym_for] = ACTIONS(824),
    [anon_sym_while] = ACTIONS(824),
    [anon_sym_break] = ACTIONS(824),
    [anon_sym_continue] = ACTIONS(824),
    [anon_sym_QMARK_DOT] = ACTIONS(826),
    [anon_sym_BQUOTE] = ACTIONS(826),
    [anon_sym_DOLLARr] = ACTIONS(824),
    [anon_sym_PLUS_PLUS] = ACTIONS(826),
    [anon_sym_DASH_DASH] = ACTIONS(826),
    [anon_sym_new] = ACTIONS(824),
  },
  [STATE(287)] = {
    [sym_comment] = STATE(287),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(1329),
    [anon_sym_PIPE] = ACTIONS(1331),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1365),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(288)] = {
    [sym_comment] = STATE(288),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(780),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_extends] = ACTIONS(778),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_else] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_var] = ACTIONS(778),
    [anon_sym_let] = ACTIONS(778),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_return] = ACTIONS(778),
    [anon_sym_try] = ACTIONS(778),
    [anon_sym_throw] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_break] = ACTIONS(778),
    [anon_sym_continue] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(289)] = {
    [sym_comment] = STATE(289),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(1331),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1365),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(290)] = {
    [sym_comment] = STATE(290),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1365),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(291)] = {
    [sym_comment] = STATE(291),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1365),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(292)] = {
    [sym_comment] = STATE(292),
    [sym_modifier_chain_expression] = STATE(344),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(828),
    [anon_sym_LBRACE] = ACTIONS(830),
    [anon_sym_RBRACE] = ACTIONS(830),
    [anon_sym_STAR] = ACTIONS(828),
    [anon_sym_as] = ACTIONS(828),
    [anon_sym_SEMI] = ACTIONS(830),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(828),
    [anon_sym_DQUOTE] = ACTIONS(830),
    [anon_sym_SQUOTE] = ACTIONS(830),
    [anon_sym_DOLLAR] = ACTIONS(828),
    [sym_numeric_literal] = ACTIONS(830),
    [anon_sym_true] = ACTIONS(828),
    [anon_sym_false] = ACTIONS(828),
    [anon_sym_null] = ACTIONS(828),
    [anon_sym_PIPE_PIPE] = ACTIONS(830),
    [anon_sym_AMP_AMP] = ACTIONS(830),
    [anon_sym_PIPE] = ACTIONS(828),
    [anon_sym_CARET] = ACTIONS(830),
    [anon_sym_AMP] = ACTIONS(828),
    [anon_sym_EQ_EQ] = ACTIONS(828),
    [anon_sym_BANG_EQ] = ACTIONS(828),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(830),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(830),
    [anon_sym_LT] = ACTIONS(828),
    [anon_sym_GT] = ACTIONS(828),
    [anon_sym_LT_EQ] = ACTIONS(830),
    [anon_sym_GT_EQ] = ACTIONS(830),
    [anon_sym_instanceof] = ACTIONS(828),
    [anon_sym_in] = ACTIONS(828),
    [anon_sym_LT_LT] = ACTIONS(830),
    [anon_sym_GT_GT] = ACTIONS(828),
    [anon_sym_GT_GT_GT] = ACTIONS(830),
    [anon_sym_PLUS] = ACTIONS(828),
    [anon_sym_DASH] = ACTIONS(828),
    [anon_sym_PERCENT] = ACTIONS(830),
    [anon_sym_STAR_STAR] = ACTIONS(830),
    [anon_sym_BANG] = ACTIONS(828),
    [anon_sym_TILDE] = ACTIONS(830),
    [anon_sym_typeof] = ACTIONS(828),
    [anon_sym_void] = ACTIONS(828),
    [anon_sym_delete] = ACTIONS(828),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_await] = ACTIONS(828),
    [anon_sym_LBRACK] = ACTIONS(830),
    [anon_sym_if] = ACTIONS(828),
    [anon_sym_else] = ACTIONS(828),
    [anon_sym_async] = ACTIONS(828),
    [anon_sym_var] = ACTIONS(828),
    [anon_sym_let] = ACTIONS(828),
    [anon_sym_const] = ACTIONS(828),
    [anon_sym_return] = ACTIONS(828),
    [anon_sym_try] = ACTIONS(828),
    [anon_sym_throw] = ACTIONS(828),
    [anon_sym_for] = ACTIONS(828),
    [anon_sym_while] = ACTIONS(828),
    [anon_sym_break] = ACTIONS(828),
    [anon_sym_continue] = ACTIONS(828),
    [anon_sym_QMARK_DOT] = ACTIONS(830),
    [anon_sym_BQUOTE] = ACTIONS(830),
    [anon_sym_DOLLARr] = ACTIONS(828),
    [anon_sym_PLUS_PLUS] = ACTIONS(830),
    [anon_sym_DASH_DASH] = ACTIONS(830),
    [anon_sym_new] = ACTIONS(828),
  },
  [STATE(293)] = {
    [sym_comment] = STATE(293),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1365),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(294)] = {
    [sym_comment] = STATE(294),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(1365),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(295)] = {
    [sym_comment] = STATE(295),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(296)] = {
    [sym_comment] = STATE(296),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(758),
    [anon_sym_extends] = ACTIONS(756),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_else] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_var] = ACTIONS(756),
    [anon_sym_let] = ACTIONS(756),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_return] = ACTIONS(756),
    [anon_sym_try] = ACTIONS(756),
    [anon_sym_throw] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_continue] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(297)] = {
    [sym_comment] = STATE(297),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(298)] = {
    [sym_comment] = STATE(298),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(704),
    [anon_sym_RBRACE] = ACTIONS(704),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(702),
    [anon_sym_SEMI] = ACTIONS(704),
    [anon_sym_LPAREN] = ACTIONS(704),
    [anon_sym_DOT] = ACTIONS(704),
    [sym_identifier] = ACTIONS(702),
    [anon_sym_DQUOTE] = ACTIONS(704),
    [anon_sym_SQUOTE] = ACTIONS(704),
    [anon_sym_DOLLAR] = ACTIONS(702),
    [sym_numeric_literal] = ACTIONS(704),
    [anon_sym_true] = ACTIONS(702),
    [anon_sym_false] = ACTIONS(702),
    [anon_sym_null] = ACTIONS(702),
    [anon_sym_PIPE_PIPE] = ACTIONS(704),
    [anon_sym_AMP_AMP] = ACTIONS(704),
    [anon_sym_PIPE] = ACTIONS(702),
    [anon_sym_CARET] = ACTIONS(704),
    [anon_sym_AMP] = ACTIONS(702),
    [anon_sym_EQ_EQ] = ACTIONS(702),
    [anon_sym_BANG_EQ] = ACTIONS(702),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(704),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(704),
    [anon_sym_LT] = ACTIONS(702),
    [anon_sym_GT] = ACTIONS(702),
    [anon_sym_LT_EQ] = ACTIONS(704),
    [anon_sym_GT_EQ] = ACTIONS(704),
    [anon_sym_instanceof] = ACTIONS(702),
    [anon_sym_in] = ACTIONS(702),
    [anon_sym_LT_LT] = ACTIONS(704),
    [anon_sym_GT_GT] = ACTIONS(702),
    [anon_sym_GT_GT_GT] = ACTIONS(704),
    [anon_sym_PLUS] = ACTIONS(702),
    [anon_sym_DASH] = ACTIONS(702),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(702),
    [anon_sym_TILDE] = ACTIONS(704),
    [anon_sym_typeof] = ACTIONS(702),
    [anon_sym_void] = ACTIONS(702),
    [anon_sym_delete] = ACTIONS(702),
    [anon_sym_QMARK] = ACTIONS(702),
    [anon_sym_await] = ACTIONS(702),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(702),
    [anon_sym_async] = ACTIONS(702),
    [anon_sym_var] = ACTIONS(702),
    [anon_sym_let] = ACTIONS(702),
    [anon_sym_const] = ACTIONS(702),
    [anon_sym_return] = ACTIONS(702),
    [anon_sym_try] = ACTIONS(702),
    [anon_sym_throw] = ACTIONS(702),
    [anon_sym_for] = ACTIONS(702),
    [anon_sym_while] = ACTIONS(702),
    [anon_sym_break] = ACTIONS(702),
    [anon_sym_continue] = ACTIONS(702),
    [anon_sym_QMARK_DOT] = ACTIONS(704),
    [anon_sym_BQUOTE] = ACTIONS(704),
    [anon_sym_DOLLARr] = ACTIONS(702),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(702),
  },
  [STATE(299)] = {
    [sym_comment] = STATE(299),
    [aux_sym_array_type_repeat1] = STATE(299),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(1368),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_else] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_var] = ACTIONS(756),
    [anon_sym_let] = ACTIONS(756),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_return] = ACTIONS(756),
    [anon_sym_try] = ACTIONS(756),
    [anon_sym_throw] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_continue] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(300)] = {
    [sym_comment] = STATE(300),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_else] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(301)] = {
    [sym_comment] = STATE(301),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(1319),
    [anon_sym_SEMI] = ACTIONS(709),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1325),
    [sym_identifier] = ACTIONS(711),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [anon_sym_SQUOTE] = ACTIONS(709),
    [anon_sym_DOLLAR] = ACTIONS(711),
    [sym_numeric_literal] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_null] = ACTIONS(711),
    [anon_sym_PIPE_PIPE] = ACTIONS(1327),
    [anon_sym_AMP_AMP] = ACTIONS(1329),
    [anon_sym_PIPE] = ACTIONS(1331),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1341),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(711),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_typeof] = ACTIONS(711),
    [anon_sym_void] = ACTIONS(711),
    [anon_sym_delete] = ACTIONS(711),
    [anon_sym_QMARK] = ACTIONS(1357),
    [anon_sym_await] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(711),
    [anon_sym_async] = ACTIONS(711),
    [anon_sym_var] = ACTIONS(711),
    [anon_sym_let] = ACTIONS(711),
    [anon_sym_const] = ACTIONS(711),
    [anon_sym_return] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(711),
    [anon_sym_throw] = ACTIONS(711),
    [anon_sym_for] = ACTIONS(711),
    [anon_sym_while] = ACTIONS(711),
    [anon_sym_break] = ACTIONS(711),
    [anon_sym_continue] = ACTIONS(711),
    [anon_sym_QMARK_DOT] = ACTIONS(1325),
    [anon_sym_BQUOTE] = ACTIONS(709),
    [anon_sym_DOLLARr] = ACTIONS(711),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(711),
  },
  [STATE(302)] = {
    [sym_comment] = STATE(302),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(745),
    [anon_sym_LBRACE] = ACTIONS(747),
    [anon_sym_COMMA] = ACTIONS(749),
    [anon_sym_RBRACE] = ACTIONS(747),
    [anon_sym_STAR] = ACTIONS(745),
    [anon_sym_as] = ACTIONS(745),
    [anon_sym_SEMI] = ACTIONS(747),
    [anon_sym_LPAREN] = ACTIONS(747),
    [anon_sym_DOT] = ACTIONS(747),
    [sym_identifier] = ACTIONS(745),
    [anon_sym_DQUOTE] = ACTIONS(747),
    [anon_sym_SQUOTE] = ACTIONS(747),
    [anon_sym_DOLLAR] = ACTIONS(745),
    [sym_numeric_literal] = ACTIONS(747),
    [anon_sym_true] = ACTIONS(745),
    [anon_sym_false] = ACTIONS(745),
    [anon_sym_null] = ACTIONS(745),
    [anon_sym_PIPE_PIPE] = ACTIONS(747),
    [anon_sym_AMP_AMP] = ACTIONS(747),
    [anon_sym_PIPE] = ACTIONS(751),
    [anon_sym_CARET] = ACTIONS(747),
    [anon_sym_AMP] = ACTIONS(745),
    [anon_sym_EQ_EQ] = ACTIONS(745),
    [anon_sym_BANG_EQ] = ACTIONS(745),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(747),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(747),
    [anon_sym_LT] = ACTIONS(745),
    [anon_sym_GT] = ACTIONS(751),
    [anon_sym_LT_EQ] = ACTIONS(747),
    [anon_sym_GT_EQ] = ACTIONS(747),
    [anon_sym_instanceof] = ACTIONS(745),
    [anon_sym_in] = ACTIONS(745),
    [anon_sym_LT_LT] = ACTIONS(747),
    [anon_sym_GT_GT] = ACTIONS(745),
    [anon_sym_GT_GT_GT] = ACTIONS(747),
    [anon_sym_PLUS] = ACTIONS(745),
    [anon_sym_DASH] = ACTIONS(745),
    [anon_sym_PERCENT] = ACTIONS(747),
    [anon_sym_STAR_STAR] = ACTIONS(747),
    [anon_sym_BANG] = ACTIONS(745),
    [anon_sym_TILDE] = ACTIONS(747),
    [anon_sym_typeof] = ACTIONS(745),
    [anon_sym_void] = ACTIONS(745),
    [anon_sym_delete] = ACTIONS(745),
    [anon_sym_QMARK] = ACTIONS(745),
    [anon_sym_await] = ACTIONS(745),
    [anon_sym_LBRACK] = ACTIONS(747),
    [anon_sym_extends] = ACTIONS(754),
    [anon_sym_if] = ACTIONS(745),
    [anon_sym_async] = ACTIONS(745),
    [anon_sym_var] = ACTIONS(745),
    [anon_sym_let] = ACTIONS(745),
    [anon_sym_const] = ACTIONS(745),
    [anon_sym_return] = ACTIONS(745),
    [anon_sym_try] = ACTIONS(745),
    [anon_sym_throw] = ACTIONS(745),
    [anon_sym_for] = ACTIONS(745),
    [anon_sym_while] = ACTIONS(745),
    [anon_sym_break] = ACTIONS(745),
    [anon_sym_continue] = ACTIONS(745),
    [anon_sym_QMARK_DOT] = ACTIONS(747),
    [anon_sym_BQUOTE] = ACTIONS(747),
    [anon_sym_DOLLARr] = ACTIONS(745),
    [anon_sym_PLUS_PLUS] = ACTIONS(747),
    [anon_sym_DASH_DASH] = ACTIONS(747),
    [anon_sym_new] = ACTIONS(745),
  },
  [STATE(303)] = {
    [sym_comment] = STATE(303),
    [aux_sym_array_type_repeat1] = STATE(303),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(1371),
    [anon_sym_extends] = ACTIONS(756),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_var] = ACTIONS(756),
    [anon_sym_let] = ACTIONS(756),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_return] = ACTIONS(756),
    [anon_sym_try] = ACTIONS(756),
    [anon_sym_throw] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_continue] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(304)] = {
    [sym_comment] = STATE(304),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_RBRACE] = ACTIONS(713),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(1319),
    [anon_sym_SEMI] = ACTIONS(713),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1325),
    [sym_identifier] = ACTIONS(715),
    [anon_sym_DQUOTE] = ACTIONS(713),
    [anon_sym_SQUOTE] = ACTIONS(713),
    [anon_sym_DOLLAR] = ACTIONS(715),
    [sym_numeric_literal] = ACTIONS(713),
    [anon_sym_true] = ACTIONS(715),
    [anon_sym_false] = ACTIONS(715),
    [anon_sym_null] = ACTIONS(715),
    [anon_sym_PIPE_PIPE] = ACTIONS(1327),
    [anon_sym_AMP_AMP] = ACTIONS(1329),
    [anon_sym_PIPE] = ACTIONS(1331),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1341),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(715),
    [anon_sym_TILDE] = ACTIONS(713),
    [anon_sym_typeof] = ACTIONS(715),
    [anon_sym_void] = ACTIONS(715),
    [anon_sym_delete] = ACTIONS(715),
    [anon_sym_QMARK] = ACTIONS(1357),
    [anon_sym_await] = ACTIONS(715),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(715),
    [anon_sym_async] = ACTIONS(715),
    [anon_sym_var] = ACTIONS(715),
    [anon_sym_let] = ACTIONS(715),
    [anon_sym_const] = ACTIONS(715),
    [anon_sym_return] = ACTIONS(715),
    [anon_sym_try] = ACTIONS(715),
    [anon_sym_throw] = ACTIONS(715),
    [anon_sym_for] = ACTIONS(715),
    [anon_sym_while] = ACTIONS(715),
    [anon_sym_break] = ACTIONS(715),
    [anon_sym_continue] = ACTIONS(715),
    [anon_sym_QMARK_DOT] = ACTIONS(1325),
    [anon_sym_BQUOTE] = ACTIONS(713),
    [anon_sym_DOLLARr] = ACTIONS(715),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(715),
  },
  [STATE(305)] = {
    [sym_comment] = STATE(305),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(645),
    [anon_sym_RBRACE] = ACTIONS(645),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(1319),
    [anon_sym_SEMI] = ACTIONS(645),
    [anon_sym_LPAREN] = ACTIONS(645),
    [anon_sym_DOT] = ACTIONS(645),
    [sym_identifier] = ACTIONS(649),
    [anon_sym_DQUOTE] = ACTIONS(645),
    [anon_sym_SQUOTE] = ACTIONS(645),
    [anon_sym_DOLLAR] = ACTIONS(649),
    [sym_numeric_literal] = ACTIONS(645),
    [anon_sym_true] = ACTIONS(649),
    [anon_sym_false] = ACTIONS(649),
    [anon_sym_null] = ACTIONS(649),
    [anon_sym_PIPE_PIPE] = ACTIONS(1327),
    [anon_sym_AMP_AMP] = ACTIONS(1329),
    [anon_sym_PIPE] = ACTIONS(1331),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1374),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(649),
    [anon_sym_TILDE] = ACTIONS(645),
    [anon_sym_typeof] = ACTIONS(649),
    [anon_sym_void] = ACTIONS(649),
    [anon_sym_delete] = ACTIONS(649),
    [anon_sym_QMARK] = ACTIONS(1357),
    [anon_sym_await] = ACTIONS(649),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(649),
    [anon_sym_async] = ACTIONS(649),
    [anon_sym_var] = ACTIONS(649),
    [anon_sym_let] = ACTIONS(649),
    [anon_sym_const] = ACTIONS(649),
    [anon_sym_return] = ACTIONS(649),
    [anon_sym_try] = ACTIONS(649),
    [anon_sym_throw] = ACTIONS(649),
    [anon_sym_for] = ACTIONS(649),
    [anon_sym_while] = ACTIONS(649),
    [anon_sym_break] = ACTIONS(649),
    [anon_sym_continue] = ACTIONS(649),
    [anon_sym_QMARK_DOT] = ACTIONS(645),
    [anon_sym_BQUOTE] = ACTIONS(645),
    [anon_sym_DOLLARr] = ACTIONS(649),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(649),
  },
  [STATE(306)] = {
    [sym_comment] = STATE(306),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(717),
    [anon_sym_RBRACE] = ACTIONS(717),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(1319),
    [anon_sym_SEMI] = ACTIONS(717),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1325),
    [sym_identifier] = ACTIONS(719),
    [anon_sym_DQUOTE] = ACTIONS(717),
    [anon_sym_SQUOTE] = ACTIONS(717),
    [anon_sym_DOLLAR] = ACTIONS(719),
    [sym_numeric_literal] = ACTIONS(717),
    [anon_sym_true] = ACTIONS(719),
    [anon_sym_false] = ACTIONS(719),
    [anon_sym_null] = ACTIONS(719),
    [anon_sym_PIPE_PIPE] = ACTIONS(1327),
    [anon_sym_AMP_AMP] = ACTIONS(1329),
    [anon_sym_PIPE] = ACTIONS(1331),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1341),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(719),
    [anon_sym_TILDE] = ACTIONS(717),
    [anon_sym_typeof] = ACTIONS(719),
    [anon_sym_void] = ACTIONS(719),
    [anon_sym_delete] = ACTIONS(719),
    [anon_sym_QMARK] = ACTIONS(1357),
    [anon_sym_await] = ACTIONS(719),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(719),
    [anon_sym_async] = ACTIONS(719),
    [anon_sym_var] = ACTIONS(719),
    [anon_sym_let] = ACTIONS(719),
    [anon_sym_const] = ACTIONS(719),
    [anon_sym_return] = ACTIONS(719),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_throw] = ACTIONS(719),
    [anon_sym_for] = ACTIONS(719),
    [anon_sym_while] = ACTIONS(719),
    [anon_sym_break] = ACTIONS(719),
    [anon_sym_continue] = ACTIONS(719),
    [anon_sym_QMARK_DOT] = ACTIONS(1325),
    [anon_sym_BQUOTE] = ACTIONS(717),
    [anon_sym_DOLLARr] = ACTIONS(719),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(719),
  },
  [STATE(307)] = {
    [sym_comment] = STATE(307),
    [sym_type_arguments] = STATE(1987),
    [sym_argument_list] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(1317),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(721),
    [anon_sym_STAR] = ACTIONS(1317),
    [anon_sym_as] = ACTIONS(1319),
    [anon_sym_SEMI] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(1323),
    [anon_sym_DOT] = ACTIONS(1325),
    [sym_identifier] = ACTIONS(723),
    [anon_sym_DQUOTE] = ACTIONS(721),
    [anon_sym_SQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR] = ACTIONS(723),
    [sym_numeric_literal] = ACTIONS(721),
    [anon_sym_true] = ACTIONS(723),
    [anon_sym_false] = ACTIONS(723),
    [anon_sym_null] = ACTIONS(723),
    [anon_sym_PIPE_PIPE] = ACTIONS(1327),
    [anon_sym_AMP_AMP] = ACTIONS(1329),
    [anon_sym_PIPE] = ACTIONS(1331),
    [anon_sym_CARET] = ACTIONS(1333),
    [anon_sym_AMP] = ACTIONS(1335),
    [anon_sym_EQ_EQ] = ACTIONS(1337),
    [anon_sym_BANG_EQ] = ACTIONS(1337),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(1339),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(1339),
    [anon_sym_LT] = ACTIONS(1341),
    [anon_sym_GT] = ACTIONS(1343),
    [anon_sym_LT_EQ] = ACTIONS(1345),
    [anon_sym_GT_EQ] = ACTIONS(1345),
    [anon_sym_instanceof] = ACTIONS(1343),
    [anon_sym_in] = ACTIONS(1343),
    [anon_sym_LT_LT] = ACTIONS(1347),
    [anon_sym_GT_GT] = ACTIONS(1349),
    [anon_sym_GT_GT_GT] = ACTIONS(1347),
    [anon_sym_PLUS] = ACTIONS(1351),
    [anon_sym_DASH] = ACTIONS(1351),
    [anon_sym_PERCENT] = ACTIONS(1353),
    [anon_sym_STAR_STAR] = ACTIONS(1355),
    [anon_sym_BANG] = ACTIONS(723),
    [anon_sym_TILDE] = ACTIONS(721),
    [anon_sym_typeof] = ACTIONS(723),
    [anon_sym_void] = ACTIONS(723),
    [anon_sym_delete] = ACTIONS(723),
    [anon_sym_QMARK] = ACTIONS(1357),
    [anon_sym_await] = ACTIONS(723),
    [anon_sym_LBRACK] = ACTIONS(1359),
    [anon_sym_if] = ACTIONS(723),
    [anon_sym_async] = ACTIONS(723),
    [anon_sym_var] = ACTIONS(723),
    [anon_sym_let] = ACTIONS(723),
    [anon_sym_const] = ACTIONS(723),
    [anon_sym_return] = ACTIONS(723),
    [anon_sym_try] = ACTIONS(723),
    [anon_sym_throw] = ACTIONS(723),
    [anon_sym_for] = ACTIONS(723),
    [anon_sym_while] = ACTIONS(723),
    [anon_sym_break] = ACTIONS(723),
    [anon_sym_continue] = ACTIONS(723),
    [anon_sym_QMARK_DOT] = ACTIONS(1325),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLARr] = ACTIONS(723),
    [anon_sym_PLUS_PLUS] = ACTIONS(1292),
    [anon_sym_DASH_DASH] = ACTIONS(1292),
    [anon_sym_new] = ACTIONS(723),
  },
  [STATE(308)] = {
    [sym_comment] = STATE(308),
    [sym_modifier_chain_expression] = STATE(343),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(855),
    [anon_sym_LBRACE] = ACTIONS(857),
    [anon_sym_RBRACE] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_as] = ACTIONS(855),
    [anon_sym_SEMI] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(857),
    [anon_sym_DOT] = ACTIONS(571),
    [sym_identifier] = ACTIONS(855),
    [anon_sym_DQUOTE] = ACTIONS(857),
    [anon_sym_SQUOTE] = ACTIONS(857),
    [anon_sym_DOLLAR] = ACTIONS(855),
    [sym_numeric_literal] = ACTIONS(857),
    [anon_sym_true] = ACTIONS(855),
    [anon_sym_false] = ACTIONS(855),
    [anon_sym_null] = ACTIONS(855),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(855),
    [anon_sym_CARET] = ACTIONS(857),
    [anon_sym_AMP] = ACTIONS(855),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(857),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(857),
    [anon_sym_LT] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(857),
    [anon_sym_instanceof] = ACTIONS(855),
    [anon_sym_in] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_GT_GT_GT] = ACTIONS(857),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(855),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_STAR_STAR] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(855),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_typeof] = ACTIONS(855),
    [anon_sym_void] = ACTIONS(855),
    [anon_sym_delete] = ACTIONS(855),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_await] = ACTIONS(855),
    [anon_sym_LBRACK] = ACTIONS(857),
    [anon_sym_if] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(855),
    [anon_sym_async] = ACTIONS(855),
    [anon_sym_var] = ACTIONS(855),
    [anon_sym_let] = ACTIONS(855),
    [anon_sym_const] = ACTIONS(855),
    [anon_sym_return] = ACTIONS(855),
    [anon_sym_try] = ACTIONS(855),
    [anon_sym_throw] = ACTIONS(855),
    [anon_sym_for] = ACTIONS(855),
    [anon_sym_while] = ACTIONS(855),
    [anon_sym_break] = ACTIONS(855),
    [anon_sym_continue] = ACTIONS(855),
    [anon_sym_QMARK_DOT] = ACTIONS(857),
    [anon_sym_BQUOTE] = ACTIONS(857),
    [anon_sym_DOLLARr] = ACTIONS(855),
    [anon_sym_PLUS_PLUS] = ACTIONS(857),
    [anon_sym_DASH_DASH] = ACTIONS(857),
    [anon_sym_new] = ACTIONS(855),
  },
  [STATE(309)] = {
    [sym_comment] = STATE(309),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(913),
    [anon_sym_LBRACE] = ACTIONS(915),
    [anon_sym_RBRACE] = ACTIONS(915),
    [anon_sym_STAR] = ACTIONS(913),
    [anon_sym_as] = ACTIONS(913),
    [anon_sym_SEMI] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_DOT] = ACTIONS(915),
    [sym_identifier] = ACTIONS(913),
    [anon_sym_DQUOTE] = ACTIONS(915),
    [anon_sym_SQUOTE] = ACTIONS(915),
    [anon_sym_DOLLAR] = ACTIONS(913),
    [sym_numeric_literal] = ACTIONS(915),
    [anon_sym_true] = ACTIONS(913),
    [anon_sym_false] = ACTIONS(913),
    [anon_sym_null] = ACTIONS(913),
    [anon_sym_PIPE_PIPE] = ACTIONS(915),
    [anon_sym_AMP_AMP] = ACTIONS(915),
    [anon_sym_PIPE] = ACTIONS(913),
    [anon_sym_CARET] = ACTIONS(915),
    [anon_sym_AMP] = ACTIONS(913),
    [anon_sym_EQ_EQ] = ACTIONS(913),
    [anon_sym_BANG_EQ] = ACTIONS(913),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(915),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(915),
    [anon_sym_LT] = ACTIONS(913),
    [anon_sym_GT] = ACTIONS(913),
    [anon_sym_LT_EQ] = ACTIONS(915),
    [anon_sym_GT_EQ] = ACTIONS(915),
    [anon_sym_instanceof] = ACTIONS(913),
    [anon_sym_in] = ACTIONS(913),
    [anon_sym_LT_LT] = ACTIONS(915),
    [anon_sym_GT_GT] = ACTIONS(913),
    [anon_sym_GT_GT_GT] = ACTIONS(915),
    [anon_sym_PLUS] = ACTIONS(913),
    [anon_sym_DASH] = ACTIONS(913),
    [anon_sym_PERCENT] = ACTIONS(915),
    [anon_sym_STAR_STAR] = ACTIONS(915),
    [anon_sym_BANG] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(915),
    [anon_sym_typeof] = ACTIONS(913),
    [anon_sym_void] = ACTIONS(913),
    [anon_sym_delete] = ACTIONS(913),
    [anon_sym_QMARK] = ACTIONS(913),
    [anon_sym_await] = ACTIONS(913),
    [anon_sym_LBRACK] = ACTIONS(915),
    [anon_sym_if] = ACTIONS(913),
    [anon_sym_else] = ACTIONS(913),
    [anon_sym_async] = ACTIONS(913),
    [anon_sym_var] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_const] = ACTIONS(913),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_try] = ACTIONS(913),
    [anon_sym_throw] = ACTIONS(913),
    [anon_sym_for] = ACTIONS(913),
    [anon_sym_while] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(913),
    [anon_sym_continue] = ACTIONS(913),
    [anon_sym_QMARK_DOT] = ACTIONS(915),
    [anon_sym_BQUOTE] = ACTIONS(915),
    [anon_sym_DOLLARr] = ACTIONS(913),
    [anon_sym_PLUS_PLUS] = ACTIONS(915),
    [anon_sym_DASH_DASH] = ACTIONS(915),
    [anon_sym_new] = ACTIONS(913),
  },
  [STATE(310)] = {
    [sym_comment] = STATE(310),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(809),
    [anon_sym_LBRACE] = ACTIONS(811),
    [anon_sym_RBRACE] = ACTIONS(811),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_as] = ACTIONS(809),
    [anon_sym_SEMI] = ACTIONS(811),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_DOT] = ACTIONS(811),
    [sym_identifier] = ACTIONS(809),
    [anon_sym_DQUOTE] = ACTIONS(811),
    [anon_sym_SQUOTE] = ACTIONS(811),
    [anon_sym_DOLLAR] = ACTIONS(809),
    [sym_numeric_literal] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(809),
    [anon_sym_false] = ACTIONS(809),
    [anon_sym_null] = ACTIONS(809),
    [anon_sym_PIPE_PIPE] = ACTIONS(811),
    [anon_sym_AMP_AMP] = ACTIONS(811),
    [anon_sym_PIPE] = ACTIONS(809),
    [anon_sym_CARET] = ACTIONS(811),
    [anon_sym_AMP] = ACTIONS(809),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(811),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(811),
    [anon_sym_LT] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(811),
    [anon_sym_GT_EQ] = ACTIONS(811),
    [anon_sym_instanceof] = ACTIONS(809),
    [anon_sym_in] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(811),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_GT_GT_GT] = ACTIONS(811),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(809),
    [anon_sym_PERCENT] = ACTIONS(811),
    [anon_sym_STAR_STAR] = ACTIONS(811),
    [anon_sym_BANG] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(811),
    [anon_sym_typeof] = ACTIONS(809),
    [anon_sym_void] = ACTIONS(809),
    [anon_sym_delete] = ACTIONS(809),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_await] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_extends] = ACTIONS(809),
    [anon_sym_if] = ACTIONS(809),
    [anon_sym_async] = ACTIONS(809),
    [anon_sym_var] = ACTIONS(809),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_const] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(809),
    [anon_sym_try] = ACTIONS(809),
    [anon_sym_throw] = ACTIONS(809),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_while] = ACTIONS(809),
    [anon_sym_break] = ACTIONS(809),
    [anon_sym_continue] = ACTIONS(809),
    [anon_sym_QMARK_DOT] = ACTIONS(811),
    [anon_sym_BQUOTE] = ACTIONS(811),
    [anon_sym_DOLLARr] = ACTIONS(809),
    [anon_sym_PLUS_PLUS] = ACTIONS(811),
    [anon_sym_DASH_DASH] = ACTIONS(811),
    [anon_sym_new] = ACTIONS(809),
  },
  [STATE(311)] = {
    [sym_comment] = STATE(311),
    [sym_modifier_chain_expression] = STATE(421),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(828),
    [anon_sym_LBRACE] = ACTIONS(830),
    [anon_sym_RBRACE] = ACTIONS(830),
    [anon_sym_STAR] = ACTIONS(828),
    [anon_sym_as] = ACTIONS(828),
    [anon_sym_SEMI] = ACTIONS(830),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(828),
    [anon_sym_DQUOTE] = ACTIONS(830),
    [anon_sym_SQUOTE] = ACTIONS(830),
    [anon_sym_DOLLAR] = ACTIONS(828),
    [sym_numeric_literal] = ACTIONS(830),
    [anon_sym_true] = ACTIONS(828),
    [anon_sym_false] = ACTIONS(828),
    [anon_sym_null] = ACTIONS(828),
    [anon_sym_PIPE_PIPE] = ACTIONS(830),
    [anon_sym_AMP_AMP] = ACTIONS(830),
    [anon_sym_PIPE] = ACTIONS(828),
    [anon_sym_CARET] = ACTIONS(830),
    [anon_sym_AMP] = ACTIONS(828),
    [anon_sym_EQ_EQ] = ACTIONS(828),
    [anon_sym_BANG_EQ] = ACTIONS(828),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(830),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(830),
    [anon_sym_LT] = ACTIONS(828),
    [anon_sym_GT] = ACTIONS(828),
    [anon_sym_LT_EQ] = ACTIONS(830),
    [anon_sym_GT_EQ] = ACTIONS(830),
    [anon_sym_instanceof] = ACTIONS(828),
    [anon_sym_in] = ACTIONS(828),
    [anon_sym_LT_LT] = ACTIONS(830),
    [anon_sym_GT_GT] = ACTIONS(828),
    [anon_sym_GT_GT_GT] = ACTIONS(830),
    [anon_sym_PLUS] = ACTIONS(828),
    [anon_sym_DASH] = ACTIONS(828),
    [anon_sym_PERCENT] = ACTIONS(830),
    [anon_sym_STAR_STAR] = ACTIONS(830),
    [anon_sym_BANG] = ACTIONS(828),
    [anon_sym_TILDE] = ACTIONS(830),
    [anon_sym_typeof] = ACTIONS(828),
    [anon_sym_void] = ACTIONS(828),
    [anon_sym_delete] = ACTIONS(828),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_await] = ACTIONS(828),
    [anon_sym_LBRACK] = ACTIONS(830),
    [anon_sym_if] = ACTIONS(828),
    [anon_sym_async] = ACTIONS(828),
    [anon_sym_var] = ACTIONS(828),
    [anon_sym_let] = ACTIONS(828),
    [anon_sym_const] = ACTIONS(828),
    [anon_sym_return] = ACTIONS(828),
    [anon_sym_try] = ACTIONS(828),
    [anon_sym_throw] = ACTIONS(828),
    [anon_sym_for] = ACTIONS(828),
    [anon_sym_while] = ACTIONS(828),
    [anon_sym_break] = ACTIONS(828),
    [anon_sym_continue] = ACTIONS(828),
    [anon_sym_QMARK_DOT] = ACTIONS(830),
    [anon_sym_BQUOTE] = ACTIONS(830),
    [anon_sym_DOLLARr] = ACTIONS(828),
    [anon_sym_PLUS_PLUS] = ACTIONS(830),
    [anon_sym_DASH_DASH] = ACTIONS(830),
    [anon_sym_new] = ACTIONS(828),
  },
  [STATE(312)] = {
    [sym_comment] = STATE(312),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(899),
    [anon_sym_LBRACE] = ACTIONS(901),
    [anon_sym_RBRACE] = ACTIONS(901),
    [anon_sym_STAR] = ACTIONS(899),
    [anon_sym_as] = ACTIONS(899),
    [anon_sym_SEMI] = ACTIONS(901),
    [anon_sym_LPAREN] = ACTIONS(901),
    [anon_sym_DOT] = ACTIONS(901),
    [sym_identifier] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [anon_sym_SQUOTE] = ACTIONS(901),
    [anon_sym_DOLLAR] = ACTIONS(899),
    [sym_numeric_literal] = ACTIONS(901),
    [anon_sym_true] = ACTIONS(899),
    [anon_sym_false] = ACTIONS(899),
    [anon_sym_null] = ACTIONS(899),
    [anon_sym_PIPE_PIPE] = ACTIONS(901),
    [anon_sym_AMP_AMP] = ACTIONS(901),
    [anon_sym_PIPE] = ACTIONS(899),
    [anon_sym_CARET] = ACTIONS(901),
    [anon_sym_AMP] = ACTIONS(899),
    [anon_sym_EQ_EQ] = ACTIONS(899),
    [anon_sym_BANG_EQ] = ACTIONS(899),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(901),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(901),
    [anon_sym_LT] = ACTIONS(899),
    [anon_sym_GT] = ACTIONS(899),
    [anon_sym_LT_EQ] = ACTIONS(901),
    [anon_sym_GT_EQ] = ACTIONS(901),
    [anon_sym_instanceof] = ACTIONS(899),
    [anon_sym_in] = ACTIONS(899),
    [anon_sym_LT_LT] = ACTIONS(901),
    [anon_sym_GT_GT] = ACTIONS(899),
    [anon_sym_GT_GT_GT] = ACTIONS(901),
    [anon_sym_PLUS] = ACTIONS(899),
    [anon_sym_DASH] = ACTIONS(899),
    [anon_sym_PERCENT] = ACTIONS(901),
    [anon_sym_STAR_STAR] = ACTIONS(901),
    [anon_sym_BANG] = ACTIONS(899),
    [anon_sym_TILDE] = ACTIONS(901),
    [anon_sym_typeof] = ACTIONS(899),
    [anon_sym_void] = ACTIONS(899),
    [anon_sym_delete] = ACTIONS(899),
    [anon_sym_QMARK] = ACTIONS(899),
    [anon_sym_await] = ACTIONS(899),
    [anon_sym_LBRACK] = ACTIONS(901),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_else] = ACTIONS(899),
    [anon_sym_async] = ACTIONS(899),
    [anon_sym_var] = ACTIONS(899),
    [anon_sym_let] = ACTIONS(899),
    [anon_sym_const] = ACTIONS(899),
    [anon_sym_return] = ACTIONS(899),
    [anon_sym_try] = ACTIONS(899),
    [anon_sym_throw] = ACTIONS(899),
    [anon_sym_for] = ACTIONS(899),
    [anon_sym_while] = ACTIONS(899),
    [anon_sym_break] = ACTIONS(899),
    [anon_sym_continue] = ACTIONS(899),
    [anon_sym_QMARK_DOT] = ACTIONS(901),
    [anon_sym_BQUOTE] = ACTIONS(901),
    [anon_sym_DOLLARr] = ACTIONS(899),
    [anon_sym_PLUS_PLUS] = ACTIONS(901),
    [anon_sym_DASH_DASH] = ACTIONS(901),
    [anon_sym_new] = ACTIONS(899),
  },
  [STATE(313)] = {
    [sym_comment] = STATE(313),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(903),
    [anon_sym_LBRACE] = ACTIONS(905),
    [anon_sym_RBRACE] = ACTIONS(905),
    [anon_sym_STAR] = ACTIONS(903),
    [anon_sym_as] = ACTIONS(903),
    [anon_sym_SEMI] = ACTIONS(905),
    [anon_sym_LPAREN] = ACTIONS(905),
    [anon_sym_DOT] = ACTIONS(905),
    [sym_identifier] = ACTIONS(903),
    [anon_sym_DQUOTE] = ACTIONS(905),
    [anon_sym_SQUOTE] = ACTIONS(905),
    [anon_sym_DOLLAR] = ACTIONS(903),
    [sym_numeric_literal] = ACTIONS(905),
    [anon_sym_true] = ACTIONS(903),
    [anon_sym_false] = ACTIONS(903),
    [anon_sym_null] = ACTIONS(903),
    [anon_sym_PIPE_PIPE] = ACTIONS(905),
    [anon_sym_AMP_AMP] = ACTIONS(905),
    [anon_sym_PIPE] = ACTIONS(903),
    [anon_sym_CARET] = ACTIONS(905),
    [anon_sym_AMP] = ACTIONS(903),
    [anon_sym_EQ_EQ] = ACTIONS(903),
    [anon_sym_BANG_EQ] = ACTIONS(903),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(905),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(905),
    [anon_sym_LT] = ACTIONS(903),
    [anon_sym_GT] = ACTIONS(903),
    [anon_sym_LT_EQ] = ACTIONS(905),
    [anon_sym_GT_EQ] = ACTIONS(905),
    [anon_sym_instanceof] = ACTIONS(903),
    [anon_sym_in] = ACTIONS(903),
    [anon_sym_LT_LT] = ACTIONS(905),
    [anon_sym_GT_GT] = ACTIONS(903),
    [anon_sym_GT_GT_GT] = ACTIONS(905),
    [anon_sym_PLUS] = ACTIONS(903),
    [anon_sym_DASH] = ACTIONS(903),
    [anon_sym_PERCENT] = ACTIONS(905),
    [anon_sym_STAR_STAR] = ACTIONS(905),
    [anon_sym_BANG] = ACTIONS(903),
    [anon_sym_TILDE] = ACTIONS(905),
    [anon_sym_typeof] = ACTIONS(903),
    [anon_sym_void] = ACTIONS(903),
    [anon_sym_delete] = ACTIONS(903),
    [anon_sym_QMARK] = ACTIONS(903),
    [anon_sym_await] = ACTIONS(903),
    [anon_sym_LBRACK] = ACTIONS(905),
    [anon_sym_if] = ACTIONS(903),
    [anon_sym_else] = ACTIONS(903),
    [anon_sym_async] = ACTIONS(903),
    [anon_sym_var] = ACTIONS(903),
    [anon_sym_let] = ACTIONS(903),
    [anon_sym_const] = ACTIONS(903),
    [anon_sym_return] = ACTIONS(903),
    [anon_sym_try] = ACTIONS(903),
    [anon_sym_throw] = ACTIONS(903),
    [anon_sym_for] = ACTIONS(903),
    [anon_sym_while] = ACTIONS(903),
    [anon_sym_break] = ACTIONS(903),
    [anon_sym_continue] = ACTIONS(903),
    [anon_sym_QMARK_DOT] = ACTIONS(905),
    [anon_sym_BQUOTE] = ACTIONS(905),
    [anon_sym_DOLLARr] = ACTIONS(903),
    [anon_sym_PLUS_PLUS] = ACTIONS(905),
    [anon_sym_DASH_DASH] = ACTIONS(905),
    [anon_sym_new] = ACTIONS(903),
  },
  [STATE(314)] = {
    [sym_comment] = STATE(314),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_as] = ACTIONS(711),
    [anon_sym_SEMI] = ACTIONS(709),
    [anon_sym_LPAREN] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(709),
    [sym_identifier] = ACTIONS(711),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [anon_sym_SQUOTE] = ACTIONS(709),
    [anon_sym_DOLLAR] = ACTIONS(711),
    [sym_numeric_literal] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_null] = ACTIONS(711),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE] = ACTIONS(711),
    [anon_sym_CARET] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(711),
    [anon_sym_EQ_EQ] = ACTIONS(711),
    [anon_sym_BANG_EQ] = ACTIONS(711),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(709),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_instanceof] = ACTIONS(711),
    [anon_sym_in] = ACTIONS(711),
    [anon_sym_LT_LT] = ACTIONS(709),
    [anon_sym_GT_GT] = ACTIONS(711),
    [anon_sym_GT_GT_GT] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(711),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_typeof] = ACTIONS(711),
    [anon_sym_void] = ACTIONS(711),
    [anon_sym_delete] = ACTIONS(711),
    [anon_sym_QMARK] = ACTIONS(711),
    [anon_sym_await] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_if] = ACTIONS(711),
    [anon_sym_else] = ACTIONS(711),
    [anon_sym_async] = ACTIONS(711),
    [anon_sym_var] = ACTIONS(711),
    [anon_sym_let] = ACTIONS(711),
    [anon_sym_const] = ACTIONS(711),
    [anon_sym_return] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(711),
    [anon_sym_throw] = ACTIONS(711),
    [anon_sym_for] = ACTIONS(711),
    [anon_sym_while] = ACTIONS(711),
    [anon_sym_break] = ACTIONS(711),
    [anon_sym_continue] = ACTIONS(711),
    [anon_sym_QMARK_DOT] = ACTIONS(709),
    [anon_sym_BQUOTE] = ACTIONS(709),
    [anon_sym_DOLLARr] = ACTIONS(711),
    [anon_sym_PLUS_PLUS] = ACTIONS(709),
    [anon_sym_DASH_DASH] = ACTIONS(709),
    [anon_sym_new] = ACTIONS(711),
  },
  [STATE(315)] = {
    [sym_comment] = STATE(315),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(917),
    [anon_sym_LBRACE] = ACTIONS(919),
    [anon_sym_RBRACE] = ACTIONS(919),
    [anon_sym_STAR] = ACTIONS(917),
    [anon_sym_as] = ACTIONS(917),
    [anon_sym_SEMI] = ACTIONS(919),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_DOT] = ACTIONS(919),
    [sym_identifier] = ACTIONS(917),
    [anon_sym_DQUOTE] = ACTIONS(919),
    [anon_sym_SQUOTE] = ACTIONS(919),
    [anon_sym_DOLLAR] = ACTIONS(917),
    [sym_numeric_literal] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(917),
    [anon_sym_false] = ACTIONS(917),
    [anon_sym_null] = ACTIONS(917),
    [anon_sym_PIPE_PIPE] = ACTIONS(919),
    [anon_sym_AMP_AMP] = ACTIONS(919),
    [anon_sym_PIPE] = ACTIONS(917),
    [anon_sym_CARET] = ACTIONS(919),
    [anon_sym_AMP] = ACTIONS(917),
    [anon_sym_EQ_EQ] = ACTIONS(917),
    [anon_sym_BANG_EQ] = ACTIONS(917),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(919),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(919),
    [anon_sym_LT] = ACTIONS(917),
    [anon_sym_GT] = ACTIONS(917),
    [anon_sym_LT_EQ] = ACTIONS(919),
    [anon_sym_GT_EQ] = ACTIONS(919),
    [anon_sym_instanceof] = ACTIONS(917),
    [anon_sym_in] = ACTIONS(917),
    [anon_sym_LT_LT] = ACTIONS(919),
    [anon_sym_GT_GT] = ACTIONS(917),
    [anon_sym_GT_GT_GT] = ACTIONS(919),
    [anon_sym_PLUS] = ACTIONS(917),
    [anon_sym_DASH] = ACTIONS(917),
    [anon_sym_PERCENT] = ACTIONS(919),
    [anon_sym_STAR_STAR] = ACTIONS(919),
    [anon_sym_BANG] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(919),
    [anon_sym_typeof] = ACTIONS(917),
    [anon_sym_void] = ACTIONS(917),
    [anon_sym_delete] = ACTIONS(917),
    [anon_sym_QMARK] = ACTIONS(917),
    [anon_sym_await] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_if] = ACTIONS(917),
    [anon_sym_else] = ACTIONS(917),
    [anon_sym_async] = ACTIONS(917),
    [anon_sym_var] = ACTIONS(917),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_const] = ACTIONS(917),
    [anon_sym_return] = ACTIONS(917),
    [anon_sym_try] = ACTIONS(917),
    [anon_sym_throw] = ACTIONS(917),
    [anon_sym_for] = ACTIONS(917),
    [anon_sym_while] = ACTIONS(917),
    [anon_sym_break] = ACTIONS(917),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_QMARK_DOT] = ACTIONS(919),
    [anon_sym_BQUOTE] = ACTIONS(919),
    [anon_sym_DOLLARr] = ACTIONS(917),
    [anon_sym_PLUS_PLUS] = ACTIONS(919),
    [anon_sym_DASH_DASH] = ACTIONS(919),
    [anon_sym_new] = ACTIONS(917),
  },
  [STATE(316)] = {
    [sym_comment] = STATE(316),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_RBRACE] = ACTIONS(923),
    [anon_sym_STAR] = ACTIONS(921),
    [anon_sym_as] = ACTIONS(921),
    [anon_sym_SEMI] = ACTIONS(923),
    [anon_sym_LPAREN] = ACTIONS(923),
    [anon_sym_DOT] = ACTIONS(923),
    [sym_identifier] = ACTIONS(921),
    [anon_sym_DQUOTE] = ACTIONS(923),
    [anon_sym_SQUOTE] = ACTIONS(923),
    [anon_sym_DOLLAR] = ACTIONS(921),
    [sym_numeric_literal] = ACTIONS(923),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_null] = ACTIONS(921),
    [anon_sym_PIPE_PIPE] = ACTIONS(923),
    [anon_sym_AMP_AMP] = ACTIONS(923),
    [anon_sym_PIPE] = ACTIONS(921),
    [anon_sym_CARET] = ACTIONS(923),
    [anon_sym_AMP] = ACTIONS(921),
    [anon_sym_EQ_EQ] = ACTIONS(921),
    [anon_sym_BANG_EQ] = ACTIONS(921),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(923),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(923),
    [anon_sym_LT] = ACTIONS(921),
    [anon_sym_GT] = ACTIONS(921),
    [anon_sym_LT_EQ] = ACTIONS(923),
    [anon_sym_GT_EQ] = ACTIONS(923),
    [anon_sym_instanceof] = ACTIONS(921),
    [anon_sym_in] = ACTIONS(921),
    [anon_sym_LT_LT] = ACTIONS(923),
    [anon_sym_GT_GT] = ACTIONS(921),
    [anon_sym_GT_GT_GT] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(921),
    [anon_sym_DASH] = ACTIONS(921),
    [anon_sym_PERCENT] = ACTIONS(923),
    [anon_sym_STAR_STAR] = ACTIONS(923),
    [anon_sym_BANG] = ACTIONS(921),
    [anon_sym_TILDE] = ACTIONS(923),
    [anon_sym_typeof] = ACTIONS(921),
    [anon_sym_void] = ACTIONS(921),
    [anon_sym_delete] = ACTIONS(921),
    [anon_sym_QMARK] = ACTIONS(921),
    [anon_sym_await] = ACTIONS(921),
    [anon_sym_LBRACK] = ACTIONS(923),
    [anon_sym_if] = ACTIONS(921),
    [anon_sym_else] = ACTIONS(921),
    [anon_sym_async] = ACTIONS(921),
    [anon_sym_var] = ACTIONS(921),
    [anon_sym_let] = ACTIONS(921),
    [anon_sym_const] = ACTIONS(921),
    [anon_sym_return] = ACTIONS(921),
    [anon_sym_try] = ACTIONS(921),
    [anon_sym_throw] = ACTIONS(921),
    [anon_sym_for] = ACTIONS(921),
    [anon_sym_while] = ACTIONS(921),
    [anon_sym_break] = ACTIONS(921),
    [anon_sym_continue] = ACTIONS(921),
    [anon_sym_QMARK_DOT] = ACTIONS(923),
    [anon_sym_BQUOTE] = ACTIONS(923),
    [anon_sym_DOLLARr] = ACTIONS(921),
    [anon_sym_PLUS_PLUS] = ACTIONS(923),
    [anon_sym_DASH_DASH] = ACTIONS(923),
    [anon_sym_new] = ACTIONS(921),
  },
  [STATE(317)] = {
    [sym_comment] = STATE(317),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(927),
    [anon_sym_RBRACE] = ACTIONS(927),
    [anon_sym_STAR] = ACTIONS(925),
    [anon_sym_as] = ACTIONS(925),
    [anon_sym_SEMI] = ACTIONS(927),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_DOT] = ACTIONS(927),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_DQUOTE] = ACTIONS(927),
    [anon_sym_SQUOTE] = ACTIONS(927),
    [anon_sym_DOLLAR] = ACTIONS(925),
    [sym_numeric_literal] = ACTIONS(927),
    [anon_sym_true] = ACTIONS(925),
    [anon_sym_false] = ACTIONS(925),
    [anon_sym_null] = ACTIONS(925),
    [anon_sym_PIPE_PIPE] = ACTIONS(927),
    [anon_sym_AMP_AMP] = ACTIONS(927),
    [anon_sym_PIPE] = ACTIONS(925),
    [anon_sym_CARET] = ACTIONS(927),
    [anon_sym_AMP] = ACTIONS(925),
    [anon_sym_EQ_EQ] = ACTIONS(925),
    [anon_sym_BANG_EQ] = ACTIONS(925),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(927),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(927),
    [anon_sym_LT] = ACTIONS(925),
    [anon_sym_GT] = ACTIONS(925),
    [anon_sym_LT_EQ] = ACTIONS(927),
    [anon_sym_GT_EQ] = ACTIONS(927),
    [anon_sym_instanceof] = ACTIONS(925),
    [anon_sym_in] = ACTIONS(925),
    [anon_sym_LT_LT] = ACTIONS(927),
    [anon_sym_GT_GT] = ACTIONS(925),
    [anon_sym_GT_GT_GT] = ACTIONS(927),
    [anon_sym_PLUS] = ACTIONS(925),
    [anon_sym_DASH] = ACTIONS(925),
    [anon_sym_PERCENT] = ACTIONS(927),
    [anon_sym_STAR_STAR] = ACTIONS(927),
    [anon_sym_BANG] = ACTIONS(925),
    [anon_sym_TILDE] = ACTIONS(927),
    [anon_sym_typeof] = ACTIONS(925),
    [anon_sym_void] = ACTIONS(925),
    [anon_sym_delete] = ACTIONS(925),
    [anon_sym_QMARK] = ACTIONS(925),
    [anon_sym_await] = ACTIONS(925),
    [anon_sym_LBRACK] = ACTIONS(927),
    [anon_sym_if] = ACTIONS(925),
    [anon_sym_else] = ACTIONS(925),
    [anon_sym_async] = ACTIONS(925),
    [anon_sym_var] = ACTIONS(925),
    [anon_sym_let] = ACTIONS(925),
    [anon_sym_const] = ACTIONS(925),
    [anon_sym_return] = ACTIONS(925),
    [anon_sym_try] = ACTIONS(925),
    [anon_sym_throw] = ACTIONS(925),
    [anon_sym_for] = ACTIONS(925),
    [anon_sym_while] = ACTIONS(925),
    [anon_sym_break] = ACTIONS(925),
    [anon_sym_continue] = ACTIONS(925),
    [anon_sym_QMARK_DOT] = ACTIONS(927),
    [anon_sym_BQUOTE] = ACTIONS(927),
    [anon_sym_DOLLARr] = ACTIONS(925),
    [anon_sym_PLUS_PLUS] = ACTIONS(927),
    [anon_sym_DASH_DASH] = ACTIONS(927),
    [anon_sym_new] = ACTIONS(925),
  },
  [STATE(318)] = {
    [sym_comment] = STATE(318),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(929),
    [anon_sym_LBRACE] = ACTIONS(931),
    [anon_sym_RBRACE] = ACTIONS(931),
    [anon_sym_STAR] = ACTIONS(929),
    [anon_sym_as] = ACTIONS(929),
    [anon_sym_SEMI] = ACTIONS(931),
    [anon_sym_LPAREN] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(931),
    [sym_identifier] = ACTIONS(929),
    [anon_sym_DQUOTE] = ACTIONS(931),
    [anon_sym_SQUOTE] = ACTIONS(931),
    [anon_sym_DOLLAR] = ACTIONS(929),
    [sym_numeric_literal] = ACTIONS(931),
    [anon_sym_true] = ACTIONS(929),
    [anon_sym_false] = ACTIONS(929),
    [anon_sym_null] = ACTIONS(929),
    [anon_sym_PIPE_PIPE] = ACTIONS(931),
    [anon_sym_AMP_AMP] = ACTIONS(931),
    [anon_sym_PIPE] = ACTIONS(929),
    [anon_sym_CARET] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(929),
    [anon_sym_EQ_EQ] = ACTIONS(929),
    [anon_sym_BANG_EQ] = ACTIONS(929),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(931),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(931),
    [anon_sym_LT] = ACTIONS(929),
    [anon_sym_GT] = ACTIONS(929),
    [anon_sym_LT_EQ] = ACTIONS(931),
    [anon_sym_GT_EQ] = ACTIONS(931),
    [anon_sym_instanceof] = ACTIONS(929),
    [anon_sym_in] = ACTIONS(929),
    [anon_sym_LT_LT] = ACTIONS(931),
    [anon_sym_GT_GT] = ACTIONS(929),
    [anon_sym_GT_GT_GT] = ACTIONS(931),
    [anon_sym_PLUS] = ACTIONS(929),
    [anon_sym_DASH] = ACTIONS(929),
    [anon_sym_PERCENT] = ACTIONS(931),
    [anon_sym_STAR_STAR] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(929),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_typeof] = ACTIONS(929),
    [anon_sym_void] = ACTIONS(929),
    [anon_sym_delete] = ACTIONS(929),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_await] = ACTIONS(929),
    [anon_sym_LBRACK] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(929),
    [anon_sym_else] = ACTIONS(929),
    [anon_sym_async] = ACTIONS(929),
    [anon_sym_var] = ACTIONS(929),
    [anon_sym_let] = ACTIONS(929),
    [anon_sym_const] = ACTIONS(929),
    [anon_sym_return] = ACTIONS(929),
    [anon_sym_try] = ACTIONS(929),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_for] = ACTIONS(929),
    [anon_sym_while] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(929),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_QMARK_DOT] = ACTIONS(931),
    [anon_sym_BQUOTE] = ACTIONS(931),
    [anon_sym_DOLLARr] = ACTIONS(929),
    [anon_sym_PLUS_PLUS] = ACTIONS(931),
    [anon_sym_DASH_DASH] = ACTIONS(931),
    [anon_sym_new] = ACTIONS(929),
  },
  [STATE(319)] = {
    [sym_comment] = STATE(319),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(780),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_extends] = ACTIONS(778),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_var] = ACTIONS(778),
    [anon_sym_let] = ACTIONS(778),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_return] = ACTIONS(778),
    [anon_sym_try] = ACTIONS(778),
    [anon_sym_throw] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_break] = ACTIONS(778),
    [anon_sym_continue] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(320)] = {
    [sym_comment] = STATE(320),
    [aux_sym_array_type_repeat1] = STATE(320),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(1377),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_var] = ACTIONS(756),
    [anon_sym_let] = ACTIONS(756),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_return] = ACTIONS(756),
    [anon_sym_try] = ACTIONS(756),
    [anon_sym_throw] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_continue] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(321)] = {
    [sym_comment] = STATE(321),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(817),
    [anon_sym_LBRACE] = ACTIONS(819),
    [anon_sym_RBRACE] = ACTIONS(819),
    [anon_sym_STAR] = ACTIONS(817),
    [anon_sym_as] = ACTIONS(817),
    [anon_sym_SEMI] = ACTIONS(819),
    [anon_sym_LPAREN] = ACTIONS(819),
    [anon_sym_DOT] = ACTIONS(819),
    [sym_identifier] = ACTIONS(817),
    [anon_sym_DQUOTE] = ACTIONS(819),
    [anon_sym_SQUOTE] = ACTIONS(819),
    [anon_sym_DOLLAR] = ACTIONS(817),
    [sym_numeric_literal] = ACTIONS(819),
    [anon_sym_true] = ACTIONS(817),
    [anon_sym_false] = ACTIONS(817),
    [anon_sym_null] = ACTIONS(817),
    [anon_sym_PIPE_PIPE] = ACTIONS(819),
    [anon_sym_AMP_AMP] = ACTIONS(819),
    [anon_sym_PIPE] = ACTIONS(817),
    [anon_sym_CARET] = ACTIONS(819),
    [anon_sym_AMP] = ACTIONS(817),
    [anon_sym_EQ_EQ] = ACTIONS(817),
    [anon_sym_BANG_EQ] = ACTIONS(817),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(819),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(819),
    [anon_sym_LT] = ACTIONS(817),
    [anon_sym_GT] = ACTIONS(817),
    [anon_sym_LT_EQ] = ACTIONS(819),
    [anon_sym_GT_EQ] = ACTIONS(819),
    [anon_sym_instanceof] = ACTIONS(817),
    [anon_sym_in] = ACTIONS(817),
    [anon_sym_LT_LT] = ACTIONS(819),
    [anon_sym_GT_GT] = ACTIONS(817),
    [anon_sym_GT_GT_GT] = ACTIONS(819),
    [anon_sym_PLUS] = ACTIONS(817),
    [anon_sym_DASH] = ACTIONS(817),
    [anon_sym_PERCENT] = ACTIONS(819),
    [anon_sym_STAR_STAR] = ACTIONS(819),
    [anon_sym_BANG] = ACTIONS(817),
    [anon_sym_TILDE] = ACTIONS(819),
    [anon_sym_typeof] = ACTIONS(817),
    [anon_sym_void] = ACTIONS(817),
    [anon_sym_delete] = ACTIONS(817),
    [anon_sym_QMARK] = ACTIONS(817),
    [anon_sym_await] = ACTIONS(817),
    [anon_sym_LBRACK] = ACTIONS(819),
    [anon_sym_if] = ACTIONS(817),
    [anon_sym_else] = ACTIONS(817),
    [anon_sym_async] = ACTIONS(817),
    [anon_sym_var] = ACTIONS(817),
    [anon_sym_let] = ACTIONS(817),
    [anon_sym_const] = ACTIONS(817),
    [anon_sym_return] = ACTIONS(817),
    [anon_sym_try] = ACTIONS(817),
    [anon_sym_throw] = ACTIONS(817),
    [anon_sym_for] = ACTIONS(817),
    [anon_sym_while] = ACTIONS(817),
    [anon_sym_break] = ACTIONS(817),
    [anon_sym_continue] = ACTIONS(817),
    [anon_sym_QMARK_DOT] = ACTIONS(819),
    [anon_sym_BQUOTE] = ACTIONS(819),
    [anon_sym_DOLLARr] = ACTIONS(817),
    [anon_sym_PLUS_PLUS] = ACTIONS(819),
    [anon_sym_DASH_DASH] = ACTIONS(819),
    [anon_sym_new] = ACTIONS(817),
  },
  [STATE(322)] = {
    [sym_comment] = STATE(322),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(935),
    [anon_sym_STAR] = ACTIONS(933),
    [anon_sym_as] = ACTIONS(933),
    [anon_sym_SEMI] = ACTIONS(935),
    [anon_sym_LPAREN] = ACTIONS(935),
    [anon_sym_DOT] = ACTIONS(935),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_DQUOTE] = ACTIONS(935),
    [anon_sym_SQUOTE] = ACTIONS(935),
    [anon_sym_DOLLAR] = ACTIONS(933),
    [sym_numeric_literal] = ACTIONS(935),
    [anon_sym_true] = ACTIONS(933),
    [anon_sym_false] = ACTIONS(933),
    [anon_sym_null] = ACTIONS(933),
    [anon_sym_PIPE_PIPE] = ACTIONS(935),
    [anon_sym_AMP_AMP] = ACTIONS(935),
    [anon_sym_PIPE] = ACTIONS(933),
    [anon_sym_CARET] = ACTIONS(935),
    [anon_sym_AMP] = ACTIONS(933),
    [anon_sym_EQ_EQ] = ACTIONS(933),
    [anon_sym_BANG_EQ] = ACTIONS(933),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(935),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(935),
    [anon_sym_LT] = ACTIONS(933),
    [anon_sym_GT] = ACTIONS(933),
    [anon_sym_LT_EQ] = ACTIONS(935),
    [anon_sym_GT_EQ] = ACTIONS(935),
    [anon_sym_instanceof] = ACTIONS(933),
    [anon_sym_in] = ACTIONS(933),
    [anon_sym_LT_LT] = ACTIONS(935),
    [anon_sym_GT_GT] = ACTIONS(933),
    [anon_sym_GT_GT_GT] = ACTIONS(935),
    [anon_sym_PLUS] = ACTIONS(933),
    [anon_sym_DASH] = ACTIONS(933),
    [anon_sym_PERCENT] = ACTIONS(935),
    [anon_sym_STAR_STAR] = ACTIONS(935),
    [anon_sym_BANG] = ACTIONS(933),
    [anon_sym_TILDE] = ACTIONS(935),
    [anon_sym_typeof] = ACTIONS(933),
    [anon_sym_void] = ACTIONS(933),
    [anon_sym_delete] = ACTIONS(933),
    [anon_sym_QMARK] = ACTIONS(933),
    [anon_sym_await] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(935),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_else] = ACTIONS(933),
    [anon_sym_async] = ACTIONS(933),
    [anon_sym_var] = ACTIONS(933),
    [anon_sym_let] = ACTIONS(933),
    [anon_sym_const] = ACTIONS(933),
    [anon_sym_return] = ACTIONS(933),
    [anon_sym_try] = ACTIONS(933),
    [anon_sym_throw] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_break] = ACTIONS(933),
    [anon_sym_continue] = ACTIONS(933),
    [anon_sym_QMARK_DOT] = ACTIONS(935),
    [anon_sym_BQUOTE] = ACTIONS(935),
    [anon_sym_DOLLARr] = ACTIONS(933),
    [anon_sym_PLUS_PLUS] = ACTIONS(935),
    [anon_sym_DASH_DASH] = ACTIONS(935),
    [anon_sym_new] = ACTIONS(933),
  },
  [STATE(323)] = {
    [sym_comment] = STATE(323),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(989),
    [anon_sym_LBRACE] = ACTIONS(991),
    [anon_sym_RBRACE] = ACTIONS(991),
    [anon_sym_STAR] = ACTIONS(989),
    [anon_sym_as] = ACTIONS(989),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LPAREN] = ACTIONS(991),
    [anon_sym_DOT] = ACTIONS(991),
    [sym_identifier] = ACTIONS(989),
    [anon_sym_DQUOTE] = ACTIONS(991),
    [anon_sym_SQUOTE] = ACTIONS(991),
    [anon_sym_DOLLAR] = ACTIONS(989),
    [sym_numeric_literal] = ACTIONS(991),
    [anon_sym_true] = ACTIONS(989),
    [anon_sym_false] = ACTIONS(989),
    [anon_sym_null] = ACTIONS(989),
    [anon_sym_PIPE_PIPE] = ACTIONS(991),
    [anon_sym_AMP_AMP] = ACTIONS(991),
    [anon_sym_PIPE] = ACTIONS(989),
    [anon_sym_CARET] = ACTIONS(991),
    [anon_sym_AMP] = ACTIONS(989),
    [anon_sym_EQ_EQ] = ACTIONS(989),
    [anon_sym_BANG_EQ] = ACTIONS(989),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(991),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(991),
    [anon_sym_LT] = ACTIONS(989),
    [anon_sym_GT] = ACTIONS(989),
    [anon_sym_LT_EQ] = ACTIONS(991),
    [anon_sym_GT_EQ] = ACTIONS(991),
    [anon_sym_instanceof] = ACTIONS(989),
    [anon_sym_in] = ACTIONS(989),
    [anon_sym_LT_LT] = ACTIONS(991),
    [anon_sym_GT_GT] = ACTIONS(989),
    [anon_sym_GT_GT_GT] = ACTIONS(991),
    [anon_sym_PLUS] = ACTIONS(989),
    [anon_sym_DASH] = ACTIONS(989),
    [anon_sym_PERCENT] = ACTIONS(991),
    [anon_sym_STAR_STAR] = ACTIONS(991),
    [anon_sym_BANG] = ACTIONS(989),
    [anon_sym_TILDE] = ACTIONS(991),
    [anon_sym_typeof] = ACTIONS(989),
    [anon_sym_void] = ACTIONS(989),
    [anon_sym_delete] = ACTIONS(989),
    [anon_sym_QMARK] = ACTIONS(989),
    [anon_sym_await] = ACTIONS(989),
    [anon_sym_LBRACK] = ACTIONS(991),
    [anon_sym_if] = ACTIONS(989),
    [anon_sym_else] = ACTIONS(989),
    [anon_sym_async] = ACTIONS(989),
    [anon_sym_var] = ACTIONS(989),
    [anon_sym_let] = ACTIONS(989),
    [anon_sym_const] = ACTIONS(989),
    [anon_sym_return] = ACTIONS(989),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_throw] = ACTIONS(989),
    [anon_sym_for] = ACTIONS(989),
    [anon_sym_while] = ACTIONS(989),
    [anon_sym_break] = ACTIONS(989),
    [anon_sym_continue] = ACTIONS(989),
    [anon_sym_QMARK_DOT] = ACTIONS(991),
    [anon_sym_BQUOTE] = ACTIONS(991),
    [anon_sym_DOLLARr] = ACTIONS(989),
    [anon_sym_PLUS_PLUS] = ACTIONS(991),
    [anon_sym_DASH_DASH] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(989),
  },
  [STATE(324)] = {
    [sym_comment] = STATE(324),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(715),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_RBRACE] = ACTIONS(713),
    [anon_sym_STAR] = ACTIONS(715),
    [anon_sym_as] = ACTIONS(715),
    [anon_sym_SEMI] = ACTIONS(713),
    [anon_sym_LPAREN] = ACTIONS(713),
    [anon_sym_DOT] = ACTIONS(713),
    [sym_identifier] = ACTIONS(715),
    [anon_sym_DQUOTE] = ACTIONS(713),
    [anon_sym_SQUOTE] = ACTIONS(713),
    [anon_sym_DOLLAR] = ACTIONS(715),
    [sym_numeric_literal] = ACTIONS(713),
    [anon_sym_true] = ACTIONS(715),
    [anon_sym_false] = ACTIONS(715),
    [anon_sym_null] = ACTIONS(715),
    [anon_sym_PIPE_PIPE] = ACTIONS(713),
    [anon_sym_AMP_AMP] = ACTIONS(713),
    [anon_sym_PIPE] = ACTIONS(715),
    [anon_sym_CARET] = ACTIONS(713),
    [anon_sym_AMP] = ACTIONS(715),
    [anon_sym_EQ_EQ] = ACTIONS(715),
    [anon_sym_BANG_EQ] = ACTIONS(715),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(713),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(713),
    [anon_sym_LT] = ACTIONS(715),
    [anon_sym_GT] = ACTIONS(715),
    [anon_sym_LT_EQ] = ACTIONS(713),
    [anon_sym_GT_EQ] = ACTIONS(713),
    [anon_sym_instanceof] = ACTIONS(715),
    [anon_sym_in] = ACTIONS(715),
    [anon_sym_LT_LT] = ACTIONS(713),
    [anon_sym_GT_GT] = ACTIONS(715),
    [anon_sym_GT_GT_GT] = ACTIONS(713),
    [anon_sym_PLUS] = ACTIONS(715),
    [anon_sym_DASH] = ACTIONS(715),
    [anon_sym_PERCENT] = ACTIONS(713),
    [anon_sym_STAR_STAR] = ACTIONS(713),
    [anon_sym_BANG] = ACTIONS(715),
    [anon_sym_TILDE] = ACTIONS(713),
    [anon_sym_typeof] = ACTIONS(715),
    [anon_sym_void] = ACTIONS(715),
    [anon_sym_delete] = ACTIONS(715),
    [anon_sym_QMARK] = ACTIONS(715),
    [anon_sym_await] = ACTIONS(715),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_if] = ACTIONS(715),
    [anon_sym_else] = ACTIONS(715),
    [anon_sym_async] = ACTIONS(715),
    [anon_sym_var] = ACTIONS(715),
    [anon_sym_let] = ACTIONS(715),
    [anon_sym_const] = ACTIONS(715),
    [anon_sym_return] = ACTIONS(715),
    [anon_sym_try] = ACTIONS(715),
    [anon_sym_throw] = ACTIONS(715),
    [anon_sym_for] = ACTIONS(715),
    [anon_sym_while] = ACTIONS(715),
    [anon_sym_break] = ACTIONS(715),
    [anon_sym_continue] = ACTIONS(715),
    [anon_sym_QMARK_DOT] = ACTIONS(713),
    [anon_sym_BQUOTE] = ACTIONS(713),
    [anon_sym_DOLLARr] = ACTIONS(715),
    [anon_sym_PLUS_PLUS] = ACTIONS(713),
    [anon_sym_DASH_DASH] = ACTIONS(713),
    [anon_sym_new] = ACTIONS(715),
  },
  [STATE(325)] = {
    [sym_comment] = STATE(325),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(945),
    [anon_sym_LBRACE] = ACTIONS(947),
    [anon_sym_RBRACE] = ACTIONS(947),
    [anon_sym_STAR] = ACTIONS(945),
    [anon_sym_as] = ACTIONS(945),
    [anon_sym_SEMI] = ACTIONS(947),
    [anon_sym_LPAREN] = ACTIONS(947),
    [anon_sym_DOT] = ACTIONS(947),
    [sym_identifier] = ACTIONS(945),
    [anon_sym_DQUOTE] = ACTIONS(947),
    [anon_sym_SQUOTE] = ACTIONS(947),
    [anon_sym_DOLLAR] = ACTIONS(945),
    [sym_numeric_literal] = ACTIONS(947),
    [anon_sym_true] = ACTIONS(945),
    [anon_sym_false] = ACTIONS(945),
    [anon_sym_null] = ACTIONS(945),
    [anon_sym_PIPE_PIPE] = ACTIONS(947),
    [anon_sym_AMP_AMP] = ACTIONS(947),
    [anon_sym_PIPE] = ACTIONS(945),
    [anon_sym_CARET] = ACTIONS(947),
    [anon_sym_AMP] = ACTIONS(945),
    [anon_sym_EQ_EQ] = ACTIONS(945),
    [anon_sym_BANG_EQ] = ACTIONS(945),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(947),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(947),
    [anon_sym_LT] = ACTIONS(945),
    [anon_sym_GT] = ACTIONS(945),
    [anon_sym_LT_EQ] = ACTIONS(947),
    [anon_sym_GT_EQ] = ACTIONS(947),
    [anon_sym_instanceof] = ACTIONS(945),
    [anon_sym_in] = ACTIONS(945),
    [anon_sym_LT_LT] = ACTIONS(947),
    [anon_sym_GT_GT] = ACTIONS(945),
    [anon_sym_GT_GT_GT] = ACTIONS(947),
    [anon_sym_PLUS] = ACTIONS(945),
    [anon_sym_DASH] = ACTIONS(945),
    [anon_sym_PERCENT] = ACTIONS(947),
    [anon_sym_STAR_STAR] = ACTIONS(947),
    [anon_sym_BANG] = ACTIONS(945),
    [anon_sym_TILDE] = ACTIONS(947),
    [anon_sym_typeof] = ACTIONS(945),
    [anon_sym_void] = ACTIONS(945),
    [anon_sym_delete] = ACTIONS(945),
    [anon_sym_QMARK] = ACTIONS(945),
    [anon_sym_await] = ACTIONS(945),
    [anon_sym_LBRACK] = ACTIONS(947),
    [anon_sym_if] = ACTIONS(945),
    [anon_sym_else] = ACTIONS(945),
    [anon_sym_async] = ACTIONS(945),
    [anon_sym_var] = ACTIONS(945),
    [anon_sym_let] = ACTIONS(945),
    [anon_sym_const] = ACTIONS(945),
    [anon_sym_return] = ACTIONS(945),
    [anon_sym_try] = ACTIONS(945),
    [anon_sym_throw] = ACTIONS(945),
    [anon_sym_for] = ACTIONS(945),
    [anon_sym_while] = ACTIONS(945),
    [anon_sym_break] = ACTIONS(945),
    [anon_sym_continue] = ACTIONS(945),
    [anon_sym_QMARK_DOT] = ACTIONS(947),
    [anon_sym_BQUOTE] = ACTIONS(947),
    [anon_sym_DOLLARr] = ACTIONS(945),
    [anon_sym_PLUS_PLUS] = ACTIONS(947),
    [anon_sym_DASH_DASH] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(945),
  },
  [STATE(326)] = {
    [sym_comment] = STATE(326),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(949),
    [anon_sym_LBRACE] = ACTIONS(951),
    [anon_sym_RBRACE] = ACTIONS(951),
    [anon_sym_STAR] = ACTIONS(949),
    [anon_sym_as] = ACTIONS(949),
    [anon_sym_SEMI] = ACTIONS(951),
    [anon_sym_LPAREN] = ACTIONS(951),
    [anon_sym_DOT] = ACTIONS(951),
    [sym_identifier] = ACTIONS(949),
    [anon_sym_DQUOTE] = ACTIONS(951),
    [anon_sym_SQUOTE] = ACTIONS(951),
    [anon_sym_DOLLAR] = ACTIONS(949),
    [sym_numeric_literal] = ACTIONS(951),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_null] = ACTIONS(949),
    [anon_sym_PIPE_PIPE] = ACTIONS(951),
    [anon_sym_AMP_AMP] = ACTIONS(951),
    [anon_sym_PIPE] = ACTIONS(949),
    [anon_sym_CARET] = ACTIONS(951),
    [anon_sym_AMP] = ACTIONS(949),
    [anon_sym_EQ_EQ] = ACTIONS(949),
    [anon_sym_BANG_EQ] = ACTIONS(949),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(951),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(951),
    [anon_sym_LT] = ACTIONS(949),
    [anon_sym_GT] = ACTIONS(949),
    [anon_sym_LT_EQ] = ACTIONS(951),
    [anon_sym_GT_EQ] = ACTIONS(951),
    [anon_sym_instanceof] = ACTIONS(949),
    [anon_sym_in] = ACTIONS(949),
    [anon_sym_LT_LT] = ACTIONS(951),
    [anon_sym_GT_GT] = ACTIONS(949),
    [anon_sym_GT_GT_GT] = ACTIONS(951),
    [anon_sym_PLUS] = ACTIONS(949),
    [anon_sym_DASH] = ACTIONS(949),
    [anon_sym_PERCENT] = ACTIONS(951),
    [anon_sym_STAR_STAR] = ACTIONS(951),
    [anon_sym_BANG] = ACTIONS(949),
    [anon_sym_TILDE] = ACTIONS(951),
    [anon_sym_typeof] = ACTIONS(949),
    [anon_sym_void] = ACTIONS(949),
    [anon_sym_delete] = ACTIONS(949),
    [anon_sym_QMARK] = ACTIONS(949),
    [anon_sym_await] = ACTIONS(949),
    [anon_sym_LBRACK] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(949),
    [anon_sym_else] = ACTIONS(949),
    [anon_sym_async] = ACTIONS(949),
    [anon_sym_var] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(949),
    [anon_sym_const] = ACTIONS(949),
    [anon_sym_return] = ACTIONS(949),
    [anon_sym_try] = ACTIONS(949),
    [anon_sym_throw] = ACTIONS(949),
    [anon_sym_for] = ACTIONS(949),
    [anon_sym_while] = ACTIONS(949),
    [anon_sym_break] = ACTIONS(949),
    [anon_sym_continue] = ACTIONS(949),
    [anon_sym_QMARK_DOT] = ACTIONS(951),
    [anon_sym_BQUOTE] = ACTIONS(951),
    [anon_sym_DOLLARr] = ACTIONS(949),
    [anon_sym_PLUS_PLUS] = ACTIONS(951),
    [anon_sym_DASH_DASH] = ACTIONS(951),
    [anon_sym_new] = ACTIONS(949),
  },
  [STATE(327)] = {
    [sym_comment] = STATE(327),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(949),
    [anon_sym_LBRACE] = ACTIONS(951),
    [anon_sym_RBRACE] = ACTIONS(951),
    [anon_sym_STAR] = ACTIONS(949),
    [anon_sym_as] = ACTIONS(949),
    [anon_sym_SEMI] = ACTIONS(951),
    [anon_sym_LPAREN] = ACTIONS(951),
    [anon_sym_DOT] = ACTIONS(951),
    [sym_identifier] = ACTIONS(949),
    [anon_sym_DQUOTE] = ACTIONS(951),
    [anon_sym_SQUOTE] = ACTIONS(951),
    [anon_sym_DOLLAR] = ACTIONS(949),
    [sym_numeric_literal] = ACTIONS(951),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_null] = ACTIONS(949),
    [anon_sym_PIPE_PIPE] = ACTIONS(951),
    [anon_sym_AMP_AMP] = ACTIONS(951),
    [anon_sym_PIPE] = ACTIONS(949),
    [anon_sym_CARET] = ACTIONS(951),
    [anon_sym_AMP] = ACTIONS(949),
    [anon_sym_EQ_EQ] = ACTIONS(949),
    [anon_sym_BANG_EQ] = ACTIONS(949),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(951),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(951),
    [anon_sym_LT] = ACTIONS(949),
    [anon_sym_GT] = ACTIONS(949),
    [anon_sym_LT_EQ] = ACTIONS(951),
    [anon_sym_GT_EQ] = ACTIONS(951),
    [anon_sym_instanceof] = ACTIONS(949),
    [anon_sym_in] = ACTIONS(949),
    [anon_sym_LT_LT] = ACTIONS(951),
    [anon_sym_GT_GT] = ACTIONS(949),
    [anon_sym_GT_GT_GT] = ACTIONS(951),
    [anon_sym_PLUS] = ACTIONS(949),
    [anon_sym_DASH] = ACTIONS(949),
    [anon_sym_PERCENT] = ACTIONS(951),
    [anon_sym_STAR_STAR] = ACTIONS(951),
    [anon_sym_BANG] = ACTIONS(949),
    [anon_sym_TILDE] = ACTIONS(951),
    [anon_sym_typeof] = ACTIONS(949),
    [anon_sym_void] = ACTIONS(949),
    [anon_sym_delete] = ACTIONS(949),
    [anon_sym_QMARK] = ACTIONS(949),
    [anon_sym_await] = ACTIONS(949),
    [anon_sym_LBRACK] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(949),
    [anon_sym_else] = ACTIONS(949),
    [anon_sym_async] = ACTIONS(949),
    [anon_sym_var] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(949),
    [anon_sym_const] = ACTIONS(949),
    [anon_sym_return] = ACTIONS(949),
    [anon_sym_try] = ACTIONS(949),
    [anon_sym_throw] = ACTIONS(949),
    [anon_sym_for] = ACTIONS(949),
    [anon_sym_while] = ACTIONS(949),
    [anon_sym_break] = ACTIONS(949),
    [anon_sym_continue] = ACTIONS(949),
    [anon_sym_QMARK_DOT] = ACTIONS(951),
    [anon_sym_BQUOTE] = ACTIONS(951),
    [anon_sym_DOLLARr] = ACTIONS(949),
    [anon_sym_PLUS_PLUS] = ACTIONS(951),
    [anon_sym_DASH_DASH] = ACTIONS(951),
    [anon_sym_new] = ACTIONS(949),
  },
  [STATE(328)] = {
    [sym_comment] = STATE(328),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(953),
    [anon_sym_LBRACE] = ACTIONS(955),
    [anon_sym_RBRACE] = ACTIONS(955),
    [anon_sym_STAR] = ACTIONS(953),
    [anon_sym_as] = ACTIONS(953),
    [anon_sym_SEMI] = ACTIONS(955),
    [anon_sym_LPAREN] = ACTIONS(955),
    [anon_sym_DOT] = ACTIONS(955),
    [sym_identifier] = ACTIONS(953),
    [anon_sym_DQUOTE] = ACTIONS(955),
    [anon_sym_SQUOTE] = ACTIONS(955),
    [anon_sym_DOLLAR] = ACTIONS(953),
    [sym_numeric_literal] = ACTIONS(955),
    [anon_sym_true] = ACTIONS(953),
    [anon_sym_false] = ACTIONS(953),
    [anon_sym_null] = ACTIONS(953),
    [anon_sym_PIPE_PIPE] = ACTIONS(955),
    [anon_sym_AMP_AMP] = ACTIONS(955),
    [anon_sym_PIPE] = ACTIONS(953),
    [anon_sym_CARET] = ACTIONS(955),
    [anon_sym_AMP] = ACTIONS(953),
    [anon_sym_EQ_EQ] = ACTIONS(953),
    [anon_sym_BANG_EQ] = ACTIONS(953),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(955),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(955),
    [anon_sym_LT] = ACTIONS(953),
    [anon_sym_GT] = ACTIONS(953),
    [anon_sym_LT_EQ] = ACTIONS(955),
    [anon_sym_GT_EQ] = ACTIONS(955),
    [anon_sym_instanceof] = ACTIONS(953),
    [anon_sym_in] = ACTIONS(953),
    [anon_sym_LT_LT] = ACTIONS(955),
    [anon_sym_GT_GT] = ACTIONS(953),
    [anon_sym_GT_GT_GT] = ACTIONS(955),
    [anon_sym_PLUS] = ACTIONS(953),
    [anon_sym_DASH] = ACTIONS(953),
    [anon_sym_PERCENT] = ACTIONS(955),
    [anon_sym_STAR_STAR] = ACTIONS(955),
    [anon_sym_BANG] = ACTIONS(953),
    [anon_sym_TILDE] = ACTIONS(955),
    [anon_sym_typeof] = ACTIONS(953),
    [anon_sym_void] = ACTIONS(953),
    [anon_sym_delete] = ACTIONS(953),
    [anon_sym_QMARK] = ACTIONS(953),
    [anon_sym_await] = ACTIONS(953),
    [anon_sym_LBRACK] = ACTIONS(955),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_else] = ACTIONS(953),
    [anon_sym_async] = ACTIONS(953),
    [anon_sym_var] = ACTIONS(953),
    [anon_sym_let] = ACTIONS(953),
    [anon_sym_const] = ACTIONS(953),
    [anon_sym_return] = ACTIONS(953),
    [anon_sym_try] = ACTIONS(953),
    [anon_sym_throw] = ACTIONS(953),
    [anon_sym_for] = ACTIONS(953),
    [anon_sym_while] = ACTIONS(953),
    [anon_sym_break] = ACTIONS(953),
    [anon_sym_continue] = ACTIONS(953),
    [anon_sym_QMARK_DOT] = ACTIONS(955),
    [anon_sym_BQUOTE] = ACTIONS(955),
    [anon_sym_DOLLARr] = ACTIONS(953),
    [anon_sym_PLUS_PLUS] = ACTIONS(955),
    [anon_sym_DASH_DASH] = ACTIONS(955),
    [anon_sym_new] = ACTIONS(953),
  },
  [STATE(329)] = {
    [sym_comment] = STATE(329),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(719),
    [anon_sym_LBRACE] = ACTIONS(717),
    [anon_sym_RBRACE] = ACTIONS(717),
    [anon_sym_STAR] = ACTIONS(719),
    [anon_sym_as] = ACTIONS(719),
    [anon_sym_SEMI] = ACTIONS(717),
    [anon_sym_LPAREN] = ACTIONS(717),
    [anon_sym_DOT] = ACTIONS(717),
    [sym_identifier] = ACTIONS(719),
    [anon_sym_DQUOTE] = ACTIONS(717),
    [anon_sym_SQUOTE] = ACTIONS(717),
    [anon_sym_DOLLAR] = ACTIONS(719),
    [sym_numeric_literal] = ACTIONS(717),
    [anon_sym_true] = ACTIONS(719),
    [anon_sym_false] = ACTIONS(719),
    [anon_sym_null] = ACTIONS(719),
    [anon_sym_PIPE_PIPE] = ACTIONS(717),
    [anon_sym_AMP_AMP] = ACTIONS(717),
    [anon_sym_PIPE] = ACTIONS(719),
    [anon_sym_CARET] = ACTIONS(717),
    [anon_sym_AMP] = ACTIONS(719),
    [anon_sym_EQ_EQ] = ACTIONS(719),
    [anon_sym_BANG_EQ] = ACTIONS(719),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(717),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(717),
    [anon_sym_LT] = ACTIONS(719),
    [anon_sym_GT] = ACTIONS(719),
    [anon_sym_LT_EQ] = ACTIONS(717),
    [anon_sym_GT_EQ] = ACTIONS(717),
    [anon_sym_instanceof] = ACTIONS(719),
    [anon_sym_in] = ACTIONS(719),
    [anon_sym_LT_LT] = ACTIONS(717),
    [anon_sym_GT_GT] = ACTIONS(719),
    [anon_sym_GT_GT_GT] = ACTIONS(717),
    [anon_sym_PLUS] = ACTIONS(719),
    [anon_sym_DASH] = ACTIONS(719),
    [anon_sym_PERCENT] = ACTIONS(717),
    [anon_sym_STAR_STAR] = ACTIONS(717),
    [anon_sym_BANG] = ACTIONS(719),
    [anon_sym_TILDE] = ACTIONS(717),
    [anon_sym_typeof] = ACTIONS(719),
    [anon_sym_void] = ACTIONS(719),
    [anon_sym_delete] = ACTIONS(719),
    [anon_sym_QMARK] = ACTIONS(719),
    [anon_sym_await] = ACTIONS(719),
    [anon_sym_LBRACK] = ACTIONS(717),
    [anon_sym_if] = ACTIONS(719),
    [anon_sym_else] = ACTIONS(719),
    [anon_sym_async] = ACTIONS(719),
    [anon_sym_var] = ACTIONS(719),
    [anon_sym_let] = ACTIONS(719),
    [anon_sym_const] = ACTIONS(719),
    [anon_sym_return] = ACTIONS(719),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_throw] = ACTIONS(719),
    [anon_sym_for] = ACTIONS(719),
    [anon_sym_while] = ACTIONS(719),
    [anon_sym_break] = ACTIONS(719),
    [anon_sym_continue] = ACTIONS(719),
    [anon_sym_QMARK_DOT] = ACTIONS(717),
    [anon_sym_BQUOTE] = ACTIONS(717),
    [anon_sym_DOLLARr] = ACTIONS(719),
    [anon_sym_PLUS_PLUS] = ACTIONS(717),
    [anon_sym_DASH_DASH] = ACTIONS(717),
    [anon_sym_new] = ACTIONS(719),
  },
  [STATE(330)] = {
    [sym_comment] = STATE(330),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(969),
    [anon_sym_LBRACE] = ACTIONS(971),
    [anon_sym_RBRACE] = ACTIONS(971),
    [anon_sym_STAR] = ACTIONS(969),
    [anon_sym_as] = ACTIONS(969),
    [anon_sym_SEMI] = ACTIONS(971),
    [anon_sym_LPAREN] = ACTIONS(971),
    [anon_sym_DOT] = ACTIONS(971),
    [sym_identifier] = ACTIONS(969),
    [anon_sym_DQUOTE] = ACTIONS(971),
    [anon_sym_SQUOTE] = ACTIONS(971),
    [anon_sym_DOLLAR] = ACTIONS(969),
    [sym_numeric_literal] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(969),
    [anon_sym_false] = ACTIONS(969),
    [anon_sym_null] = ACTIONS(969),
    [anon_sym_PIPE_PIPE] = ACTIONS(971),
    [anon_sym_AMP_AMP] = ACTIONS(971),
    [anon_sym_PIPE] = ACTIONS(969),
    [anon_sym_CARET] = ACTIONS(971),
    [anon_sym_AMP] = ACTIONS(969),
    [anon_sym_EQ_EQ] = ACTIONS(969),
    [anon_sym_BANG_EQ] = ACTIONS(969),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(971),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(971),
    [anon_sym_LT] = ACTIONS(969),
    [anon_sym_GT] = ACTIONS(969),
    [anon_sym_LT_EQ] = ACTIONS(971),
    [anon_sym_GT_EQ] = ACTIONS(971),
    [anon_sym_instanceof] = ACTIONS(969),
    [anon_sym_in] = ACTIONS(969),
    [anon_sym_LT_LT] = ACTIONS(971),
    [anon_sym_GT_GT] = ACTIONS(969),
    [anon_sym_GT_GT_GT] = ACTIONS(971),
    [anon_sym_PLUS] = ACTIONS(969),
    [anon_sym_DASH] = ACTIONS(969),
    [anon_sym_PERCENT] = ACTIONS(971),
    [anon_sym_STAR_STAR] = ACTIONS(971),
    [anon_sym_BANG] = ACTIONS(969),
    [anon_sym_TILDE] = ACTIONS(971),
    [anon_sym_typeof] = ACTIONS(969),
    [anon_sym_void] = ACTIONS(969),
    [anon_sym_delete] = ACTIONS(969),
    [anon_sym_QMARK] = ACTIONS(969),
    [anon_sym_await] = ACTIONS(969),
    [anon_sym_LBRACK] = ACTIONS(971),
    [anon_sym_if] = ACTIONS(969),
    [anon_sym_else] = ACTIONS(969),
    [anon_sym_async] = ACTIONS(969),
    [anon_sym_var] = ACTIONS(969),
    [anon_sym_let] = ACTIONS(969),
    [anon_sym_const] = ACTIONS(969),
    [anon_sym_return] = ACTIONS(969),
    [anon_sym_try] = ACTIONS(969),
    [anon_sym_throw] = ACTIONS(969),
    [anon_sym_for] = ACTIONS(969),
    [anon_sym_while] = ACTIONS(969),
    [anon_sym_break] = ACTIONS(969),
    [anon_sym_continue] = ACTIONS(969),
    [anon_sym_QMARK_DOT] = ACTIONS(971),
    [anon_sym_BQUOTE] = ACTIONS(971),
    [anon_sym_DOLLARr] = ACTIONS(969),
    [anon_sym_PLUS_PLUS] = ACTIONS(971),
    [anon_sym_DASH_DASH] = ACTIONS(971),
    [anon_sym_new] = ACTIONS(969),
  },
  [STATE(331)] = {
    [sym_comment] = STATE(331),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(969),
    [anon_sym_LBRACE] = ACTIONS(971),
    [anon_sym_RBRACE] = ACTIONS(971),
    [anon_sym_STAR] = ACTIONS(969),
    [anon_sym_as] = ACTIONS(969),
    [anon_sym_SEMI] = ACTIONS(971),
    [anon_sym_LPAREN] = ACTIONS(971),
    [anon_sym_DOT] = ACTIONS(971),
    [sym_identifier] = ACTIONS(969),
    [anon_sym_DQUOTE] = ACTIONS(971),
    [anon_sym_SQUOTE] = ACTIONS(971),
    [anon_sym_DOLLAR] = ACTIONS(969),
    [sym_numeric_literal] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(969),
    [anon_sym_false] = ACTIONS(969),
    [anon_sym_null] = ACTIONS(969),
    [anon_sym_PIPE_PIPE] = ACTIONS(971),
    [anon_sym_AMP_AMP] = ACTIONS(971),
    [anon_sym_PIPE] = ACTIONS(969),
    [anon_sym_CARET] = ACTIONS(971),
    [anon_sym_AMP] = ACTIONS(969),
    [anon_sym_EQ_EQ] = ACTIONS(969),
    [anon_sym_BANG_EQ] = ACTIONS(969),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(971),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(971),
    [anon_sym_LT] = ACTIONS(969),
    [anon_sym_GT] = ACTIONS(969),
    [anon_sym_LT_EQ] = ACTIONS(971),
    [anon_sym_GT_EQ] = ACTIONS(971),
    [anon_sym_instanceof] = ACTIONS(969),
    [anon_sym_in] = ACTIONS(969),
    [anon_sym_LT_LT] = ACTIONS(971),
    [anon_sym_GT_GT] = ACTIONS(969),
    [anon_sym_GT_GT_GT] = ACTIONS(971),
    [anon_sym_PLUS] = ACTIONS(969),
    [anon_sym_DASH] = ACTIONS(969),
    [anon_sym_PERCENT] = ACTIONS(971),
    [anon_sym_STAR_STAR] = ACTIONS(971),
    [anon_sym_BANG] = ACTIONS(969),
    [anon_sym_TILDE] = ACTIONS(971),
    [anon_sym_typeof] = ACTIONS(969),
    [anon_sym_void] = ACTIONS(969),
    [anon_sym_delete] = ACTIONS(969),
    [anon_sym_QMARK] = ACTIONS(969),
    [anon_sym_await] = ACTIONS(969),
    [anon_sym_LBRACK] = ACTIONS(971),
    [anon_sym_if] = ACTIONS(969),
    [anon_sym_else] = ACTIONS(969),
    [anon_sym_async] = ACTIONS(969),
    [anon_sym_var] = ACTIONS(969),
    [anon_sym_let] = ACTIONS(969),
    [anon_sym_const] = ACTIONS(969),
    [anon_sym_return] = ACTIONS(969),
    [anon_sym_try] = ACTIONS(969),
    [anon_sym_throw] = ACTIONS(969),
    [anon_sym_for] = ACTIONS(969),
    [anon_sym_while] = ACTIONS(969),
    [anon_sym_break] = ACTIONS(969),
    [anon_sym_continue] = ACTIONS(969),
    [anon_sym_QMARK_DOT] = ACTIONS(971),
    [anon_sym_BQUOTE] = ACTIONS(971),
    [anon_sym_DOLLARr] = ACTIONS(969),
    [anon_sym_PLUS_PLUS] = ACTIONS(971),
    [anon_sym_DASH_DASH] = ACTIONS(971),
    [anon_sym_new] = ACTIONS(969),
  },
  [STATE(332)] = {
    [sym_comment] = STATE(332),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(723),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(721),
    [anon_sym_STAR] = ACTIONS(723),
    [anon_sym_as] = ACTIONS(723),
    [anon_sym_SEMI] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(721),
    [anon_sym_DOT] = ACTIONS(721),
    [sym_identifier] = ACTIONS(723),
    [anon_sym_DQUOTE] = ACTIONS(721),
    [anon_sym_SQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR] = ACTIONS(723),
    [sym_numeric_literal] = ACTIONS(721),
    [anon_sym_true] = ACTIONS(723),
    [anon_sym_false] = ACTIONS(723),
    [anon_sym_null] = ACTIONS(723),
    [anon_sym_PIPE_PIPE] = ACTIONS(721),
    [anon_sym_AMP_AMP] = ACTIONS(721),
    [anon_sym_PIPE] = ACTIONS(723),
    [anon_sym_CARET] = ACTIONS(721),
    [anon_sym_AMP] = ACTIONS(723),
    [anon_sym_EQ_EQ] = ACTIONS(723),
    [anon_sym_BANG_EQ] = ACTIONS(723),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(721),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(721),
    [anon_sym_LT] = ACTIONS(723),
    [anon_sym_GT] = ACTIONS(723),
    [anon_sym_LT_EQ] = ACTIONS(721),
    [anon_sym_GT_EQ] = ACTIONS(721),
    [anon_sym_instanceof] = ACTIONS(723),
    [anon_sym_in] = ACTIONS(723),
    [anon_sym_LT_LT] = ACTIONS(721),
    [anon_sym_GT_GT] = ACTIONS(723),
    [anon_sym_GT_GT_GT] = ACTIONS(721),
    [anon_sym_PLUS] = ACTIONS(723),
    [anon_sym_DASH] = ACTIONS(723),
    [anon_sym_PERCENT] = ACTIONS(721),
    [anon_sym_STAR_STAR] = ACTIONS(721),
    [anon_sym_BANG] = ACTIONS(723),
    [anon_sym_TILDE] = ACTIONS(721),
    [anon_sym_typeof] = ACTIONS(723),
    [anon_sym_void] = ACTIONS(723),
    [anon_sym_delete] = ACTIONS(723),
    [anon_sym_QMARK] = ACTIONS(723),
    [anon_sym_await] = ACTIONS(723),
    [anon_sym_LBRACK] = ACTIONS(721),
    [anon_sym_if] = ACTIONS(723),
    [anon_sym_else] = ACTIONS(723),
    [anon_sym_async] = ACTIONS(723),
    [anon_sym_var] = ACTIONS(723),
    [anon_sym_let] = ACTIONS(723),
    [anon_sym_const] = ACTIONS(723),
    [anon_sym_return] = ACTIONS(723),
    [anon_sym_try] = ACTIONS(723),
    [anon_sym_throw] = ACTIONS(723),
    [anon_sym_for] = ACTIONS(723),
    [anon_sym_while] = ACTIONS(723),
    [anon_sym_break] = ACTIONS(723),
    [anon_sym_continue] = ACTIONS(723),
    [anon_sym_QMARK_DOT] = ACTIONS(721),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLARr] = ACTIONS(723),
    [anon_sym_PLUS_PLUS] = ACTIONS(721),
    [anon_sym_DASH_DASH] = ACTIONS(721),
    [anon_sym_new] = ACTIONS(723),
  },
  [STATE(333)] = {
    [sym_comment] = STATE(333),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(875),
    [anon_sym_LBRACE] = ACTIONS(877),
    [anon_sym_RBRACE] = ACTIONS(877),
    [anon_sym_STAR] = ACTIONS(875),
    [anon_sym_as] = ACTIONS(875),
    [anon_sym_SEMI] = ACTIONS(877),
    [anon_sym_LPAREN] = ACTIONS(877),
    [anon_sym_DOT] = ACTIONS(877),
    [sym_identifier] = ACTIONS(875),
    [anon_sym_DQUOTE] = ACTIONS(877),
    [anon_sym_SQUOTE] = ACTIONS(877),
    [anon_sym_DOLLAR] = ACTIONS(875),
    [sym_numeric_literal] = ACTIONS(877),
    [anon_sym_true] = ACTIONS(875),
    [anon_sym_false] = ACTIONS(875),
    [anon_sym_null] = ACTIONS(875),
    [anon_sym_PIPE_PIPE] = ACTIONS(877),
    [anon_sym_AMP_AMP] = ACTIONS(877),
    [anon_sym_PIPE] = ACTIONS(875),
    [anon_sym_CARET] = ACTIONS(877),
    [anon_sym_AMP] = ACTIONS(875),
    [anon_sym_EQ_EQ] = ACTIONS(875),
    [anon_sym_BANG_EQ] = ACTIONS(875),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(877),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(877),
    [anon_sym_LT] = ACTIONS(875),
    [anon_sym_GT] = ACTIONS(875),
    [anon_sym_LT_EQ] = ACTIONS(877),
    [anon_sym_GT_EQ] = ACTIONS(877),
    [anon_sym_instanceof] = ACTIONS(875),
    [anon_sym_in] = ACTIONS(875),
    [anon_sym_LT_LT] = ACTIONS(877),
    [anon_sym_GT_GT] = ACTIONS(875),
    [anon_sym_GT_GT_GT] = ACTIONS(877),
    [anon_sym_PLUS] = ACTIONS(875),
    [anon_sym_DASH] = ACTIONS(875),
    [anon_sym_PERCENT] = ACTIONS(877),
    [anon_sym_STAR_STAR] = ACTIONS(877),
    [anon_sym_BANG] = ACTIONS(875),
    [anon_sym_TILDE] = ACTIONS(877),
    [anon_sym_typeof] = ACTIONS(875),
    [anon_sym_void] = ACTIONS(875),
    [anon_sym_delete] = ACTIONS(875),
    [anon_sym_QMARK] = ACTIONS(875),
    [anon_sym_await] = ACTIONS(875),
    [anon_sym_LBRACK] = ACTIONS(877),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_else] = ACTIONS(875),
    [anon_sym_async] = ACTIONS(875),
    [anon_sym_var] = ACTIONS(875),
    [anon_sym_let] = ACTIONS(875),
    [anon_sym_const] = ACTIONS(875),
    [anon_sym_return] = ACTIONS(875),
    [anon_sym_try] = ACTIONS(875),
    [anon_sym_throw] = ACTIONS(875),
    [anon_sym_for] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(875),
    [anon_sym_break] = ACTIONS(875),
    [anon_sym_continue] = ACTIONS(875),
    [anon_sym_QMARK_DOT] = ACTIONS(877),
    [anon_sym_BQUOTE] = ACTIONS(877),
    [anon_sym_DOLLARr] = ACTIONS(875),
    [anon_sym_PLUS_PLUS] = ACTIONS(877),
    [anon_sym_DASH_DASH] = ACTIONS(877),
    [anon_sym_new] = ACTIONS(875),
  },
  [STATE(334)] = {
    [sym_comment] = STATE(334),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(871),
    [anon_sym_LBRACE] = ACTIONS(873),
    [anon_sym_RBRACE] = ACTIONS(873),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_as] = ACTIONS(871),
    [anon_sym_SEMI] = ACTIONS(873),
    [anon_sym_LPAREN] = ACTIONS(873),
    [anon_sym_DOT] = ACTIONS(873),
    [sym_identifier] = ACTIONS(871),
    [anon_sym_DQUOTE] = ACTIONS(873),
    [anon_sym_SQUOTE] = ACTIONS(873),
    [anon_sym_DOLLAR] = ACTIONS(871),
    [sym_numeric_literal] = ACTIONS(873),
    [anon_sym_true] = ACTIONS(871),
    [anon_sym_false] = ACTIONS(871),
    [anon_sym_null] = ACTIONS(871),
    [anon_sym_PIPE_PIPE] = ACTIONS(873),
    [anon_sym_AMP_AMP] = ACTIONS(873),
    [anon_sym_PIPE] = ACTIONS(871),
    [anon_sym_CARET] = ACTIONS(873),
    [anon_sym_AMP] = ACTIONS(871),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(873),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(873),
    [anon_sym_LT] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(873),
    [anon_sym_GT_EQ] = ACTIONS(873),
    [anon_sym_instanceof] = ACTIONS(871),
    [anon_sym_in] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(873),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_GT_GT_GT] = ACTIONS(873),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(871),
    [anon_sym_PERCENT] = ACTIONS(873),
    [anon_sym_STAR_STAR] = ACTIONS(873),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_TILDE] = ACTIONS(873),
    [anon_sym_typeof] = ACTIONS(871),
    [anon_sym_void] = ACTIONS(871),
    [anon_sym_delete] = ACTIONS(871),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_await] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(871),
    [anon_sym_else] = ACTIONS(871),
    [anon_sym_async] = ACTIONS(871),
    [anon_sym_var] = ACTIONS(871),
    [anon_sym_let] = ACTIONS(871),
    [anon_sym_const] = ACTIONS(871),
    [anon_sym_return] = ACTIONS(871),
    [anon_sym_try] = ACTIONS(871),
    [anon_sym_throw] = ACTIONS(871),
    [anon_sym_for] = ACTIONS(871),
    [anon_sym_while] = ACTIONS(871),
    [anon_sym_break] = ACTIONS(871),
    [anon_sym_continue] = ACTIONS(871),
    [anon_sym_QMARK_DOT] = ACTIONS(873),
    [anon_sym_BQUOTE] = ACTIONS(873),
    [anon_sym_DOLLARr] = ACTIONS(871),
    [anon_sym_PLUS_PLUS] = ACTIONS(873),
    [anon_sym_DASH_DASH] = ACTIONS(873),
    [anon_sym_new] = ACTIONS(871),
  },
  [STATE(335)] = {
    [sym_comment] = STATE(335),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(887),
    [anon_sym_LBRACE] = ACTIONS(889),
    [anon_sym_RBRACE] = ACTIONS(889),
    [anon_sym_STAR] = ACTIONS(887),
    [anon_sym_as] = ACTIONS(887),
    [anon_sym_SEMI] = ACTIONS(889),
    [anon_sym_LPAREN] = ACTIONS(889),
    [anon_sym_DOT] = ACTIONS(889),
    [sym_identifier] = ACTIONS(887),
    [anon_sym_DQUOTE] = ACTIONS(889),
    [anon_sym_SQUOTE] = ACTIONS(889),
    [anon_sym_DOLLAR] = ACTIONS(887),
    [sym_numeric_literal] = ACTIONS(889),
    [anon_sym_true] = ACTIONS(887),
    [anon_sym_false] = ACTIONS(887),
    [anon_sym_null] = ACTIONS(887),
    [anon_sym_PIPE_PIPE] = ACTIONS(889),
    [anon_sym_AMP_AMP] = ACTIONS(889),
    [anon_sym_PIPE] = ACTIONS(887),
    [anon_sym_CARET] = ACTIONS(889),
    [anon_sym_AMP] = ACTIONS(887),
    [anon_sym_EQ_EQ] = ACTIONS(887),
    [anon_sym_BANG_EQ] = ACTIONS(887),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(889),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(889),
    [anon_sym_LT] = ACTIONS(887),
    [anon_sym_GT] = ACTIONS(887),
    [anon_sym_LT_EQ] = ACTIONS(889),
    [anon_sym_GT_EQ] = ACTIONS(889),
    [anon_sym_instanceof] = ACTIONS(887),
    [anon_sym_in] = ACTIONS(887),
    [anon_sym_LT_LT] = ACTIONS(889),
    [anon_sym_GT_GT] = ACTIONS(887),
    [anon_sym_GT_GT_GT] = ACTIONS(889),
    [anon_sym_PLUS] = ACTIONS(887),
    [anon_sym_DASH] = ACTIONS(887),
    [anon_sym_PERCENT] = ACTIONS(889),
    [anon_sym_STAR_STAR] = ACTIONS(889),
    [anon_sym_BANG] = ACTIONS(887),
    [anon_sym_TILDE] = ACTIONS(889),
    [anon_sym_typeof] = ACTIONS(887),
    [anon_sym_void] = ACTIONS(887),
    [anon_sym_delete] = ACTIONS(887),
    [anon_sym_QMARK] = ACTIONS(887),
    [anon_sym_await] = ACTIONS(887),
    [anon_sym_LBRACK] = ACTIONS(889),
    [anon_sym_if] = ACTIONS(887),
    [anon_sym_else] = ACTIONS(887),
    [anon_sym_async] = ACTIONS(887),
    [anon_sym_var] = ACTIONS(887),
    [anon_sym_let] = ACTIONS(887),
    [anon_sym_const] = ACTIONS(887),
    [anon_sym_return] = ACTIONS(887),
    [anon_sym_try] = ACTIONS(887),
    [anon_sym_throw] = ACTIONS(887),
    [anon_sym_for] = ACTIONS(887),
    [anon_sym_while] = ACTIONS(887),
    [anon_sym_break] = ACTIONS(887),
    [anon_sym_continue] = ACTIONS(887),
    [anon_sym_QMARK_DOT] = ACTIONS(889),
    [anon_sym_BQUOTE] = ACTIONS(889),
    [anon_sym_DOLLARr] = ACTIONS(887),
    [anon_sym_PLUS_PLUS] = ACTIONS(889),
    [anon_sym_DASH_DASH] = ACTIONS(889),
    [anon_sym_new] = ACTIONS(887),
  },
  [STATE(336)] = {
    [sym_comment] = STATE(336),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(843),
    [anon_sym_LBRACE] = ACTIONS(845),
    [anon_sym_RBRACE] = ACTIONS(845),
    [anon_sym_STAR] = ACTIONS(843),
    [anon_sym_as] = ACTIONS(843),
    [anon_sym_SEMI] = ACTIONS(845),
    [anon_sym_LPAREN] = ACTIONS(845),
    [anon_sym_DOT] = ACTIONS(845),
    [sym_identifier] = ACTIONS(843),
    [anon_sym_DQUOTE] = ACTIONS(845),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DOLLAR] = ACTIONS(843),
    [sym_numeric_literal] = ACTIONS(845),
    [anon_sym_true] = ACTIONS(843),
    [anon_sym_false] = ACTIONS(843),
    [anon_sym_null] = ACTIONS(843),
    [anon_sym_PIPE_PIPE] = ACTIONS(845),
    [anon_sym_AMP_AMP] = ACTIONS(845),
    [anon_sym_PIPE] = ACTIONS(843),
    [anon_sym_CARET] = ACTIONS(845),
    [anon_sym_AMP] = ACTIONS(843),
    [anon_sym_EQ_EQ] = ACTIONS(843),
    [anon_sym_BANG_EQ] = ACTIONS(843),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(845),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(845),
    [anon_sym_LT] = ACTIONS(843),
    [anon_sym_GT] = ACTIONS(843),
    [anon_sym_LT_EQ] = ACTIONS(845),
    [anon_sym_GT_EQ] = ACTIONS(845),
    [anon_sym_instanceof] = ACTIONS(843),
    [anon_sym_in] = ACTIONS(843),
    [anon_sym_LT_LT] = ACTIONS(845),
    [anon_sym_GT_GT] = ACTIONS(843),
    [anon_sym_GT_GT_GT] = ACTIONS(845),
    [anon_sym_PLUS] = ACTIONS(843),
    [anon_sym_DASH] = ACTIONS(843),
    [anon_sym_PERCENT] = ACTIONS(845),
    [anon_sym_STAR_STAR] = ACTIONS(845),
    [anon_sym_BANG] = ACTIONS(843),
    [anon_sym_TILDE] = ACTIONS(845),
    [anon_sym_typeof] = ACTIONS(843),
    [anon_sym_void] = ACTIONS(843),
    [anon_sym_delete] = ACTIONS(843),
    [anon_sym_QMARK] = ACTIONS(843),
    [anon_sym_await] = ACTIONS(843),
    [anon_sym_LBRACK] = ACTIONS(845),
    [anon_sym_extends] = ACTIONS(843),
    [anon_sym_if] = ACTIONS(843),
    [anon_sym_async] = ACTIONS(843),
    [anon_sym_var] = ACTIONS(843),
    [anon_sym_let] = ACTIONS(843),
    [anon_sym_const] = ACTIONS(843),
    [anon_sym_return] = ACTIONS(843),
    [anon_sym_try] = ACTIONS(843),
    [anon_sym_throw] = ACTIONS(843),
    [anon_sym_for] = ACTIONS(843),
    [anon_sym_while] = ACTIONS(843),
    [anon_sym_break] = ACTIONS(843),
    [anon_sym_continue] = ACTIONS(843),
    [anon_sym_QMARK_DOT] = ACTIONS(845),
    [anon_sym_BQUOTE] = ACTIONS(845),
    [anon_sym_DOLLARr] = ACTIONS(843),
    [anon_sym_PLUS_PLUS] = ACTIONS(845),
    [anon_sym_DASH_DASH] = ACTIONS(845),
    [anon_sym_new] = ACTIONS(843),
  },
  [STATE(337)] = {
    [sym_comment] = STATE(337),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_COLON] = ACTIONS(1380),
    [anon_sym_DOT] = ACTIONS(37),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(37),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(37),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(37),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(37),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(338)] = {
    [sym_comment] = STATE(338),
    [aux_sym_union_type_repeat1] = STATE(340),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(813),
    [anon_sym_LBRACE] = ACTIONS(815),
    [anon_sym_RBRACE] = ACTIONS(815),
    [anon_sym_STAR] = ACTIONS(813),
    [anon_sym_as] = ACTIONS(813),
    [anon_sym_SEMI] = ACTIONS(815),
    [anon_sym_LPAREN] = ACTIONS(815),
    [anon_sym_DOT] = ACTIONS(815),
    [sym_identifier] = ACTIONS(813),
    [anon_sym_DQUOTE] = ACTIONS(815),
    [anon_sym_SQUOTE] = ACTIONS(815),
    [anon_sym_DOLLAR] = ACTIONS(813),
    [sym_numeric_literal] = ACTIONS(815),
    [anon_sym_true] = ACTIONS(813),
    [anon_sym_false] = ACTIONS(813),
    [anon_sym_null] = ACTIONS(813),
    [anon_sym_PIPE_PIPE] = ACTIONS(815),
    [anon_sym_AMP_AMP] = ACTIONS(815),
    [anon_sym_PIPE] = ACTIONS(813),
    [anon_sym_CARET] = ACTIONS(815),
    [anon_sym_AMP] = ACTIONS(813),
    [anon_sym_EQ_EQ] = ACTIONS(813),
    [anon_sym_BANG_EQ] = ACTIONS(813),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(815),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(815),
    [anon_sym_LT] = ACTIONS(813),
    [anon_sym_GT] = ACTIONS(813),
    [anon_sym_LT_EQ] = ACTIONS(815),
    [anon_sym_GT_EQ] = ACTIONS(815),
    [anon_sym_instanceof] = ACTIONS(813),
    [anon_sym_in] = ACTIONS(813),
    [anon_sym_LT_LT] = ACTIONS(815),
    [anon_sym_GT_GT] = ACTIONS(813),
    [anon_sym_GT_GT_GT] = ACTIONS(815),
    [anon_sym_PLUS] = ACTIONS(813),
    [anon_sym_DASH] = ACTIONS(813),
    [anon_sym_PERCENT] = ACTIONS(815),
    [anon_sym_STAR_STAR] = ACTIONS(815),
    [anon_sym_BANG] = ACTIONS(813),
    [anon_sym_TILDE] = ACTIONS(815),
    [anon_sym_typeof] = ACTIONS(813),
    [anon_sym_void] = ACTIONS(813),
    [anon_sym_delete] = ACTIONS(813),
    [anon_sym_QMARK] = ACTIONS(813),
    [anon_sym_await] = ACTIONS(813),
    [anon_sym_LBRACK] = ACTIONS(815),
    [anon_sym_if] = ACTIONS(813),
    [anon_sym_async] = ACTIONS(813),
    [anon_sym_var] = ACTIONS(813),
    [anon_sym_let] = ACTIONS(813),
    [anon_sym_const] = ACTIONS(813),
    [anon_sym_return] = ACTIONS(813),
    [anon_sym_try] = ACTIONS(813),
    [anon_sym_throw] = ACTIONS(813),
    [anon_sym_for] = ACTIONS(813),
    [anon_sym_while] = ACTIONS(813),
    [anon_sym_break] = ACTIONS(813),
    [anon_sym_continue] = ACTIONS(813),
    [anon_sym_QMARK_DOT] = ACTIONS(815),
    [anon_sym_BQUOTE] = ACTIONS(815),
    [anon_sym_DOLLARr] = ACTIONS(813),
    [anon_sym_PLUS_PLUS] = ACTIONS(815),
    [anon_sym_DASH_DASH] = ACTIONS(815),
    [anon_sym_new] = ACTIONS(813),
  },
  [STATE(339)] = {
    [sym_comment] = STATE(339),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(847),
    [anon_sym_LBRACE] = ACTIONS(849),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_STAR] = ACTIONS(847),
    [anon_sym_as] = ACTIONS(847),
    [anon_sym_SEMI] = ACTIONS(849),
    [anon_sym_LPAREN] = ACTIONS(849),
    [anon_sym_DOT] = ACTIONS(849),
    [sym_identifier] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [anon_sym_SQUOTE] = ACTIONS(849),
    [anon_sym_DOLLAR] = ACTIONS(847),
    [sym_numeric_literal] = ACTIONS(849),
    [anon_sym_true] = ACTIONS(847),
    [anon_sym_false] = ACTIONS(847),
    [anon_sym_null] = ACTIONS(847),
    [anon_sym_PIPE_PIPE] = ACTIONS(849),
    [anon_sym_AMP_AMP] = ACTIONS(849),
    [anon_sym_PIPE] = ACTIONS(847),
    [anon_sym_CARET] = ACTIONS(849),
    [anon_sym_AMP] = ACTIONS(847),
    [anon_sym_EQ_EQ] = ACTIONS(847),
    [anon_sym_BANG_EQ] = ACTIONS(847),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(849),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(849),
    [anon_sym_LT] = ACTIONS(847),
    [anon_sym_GT] = ACTIONS(847),
    [anon_sym_LT_EQ] = ACTIONS(849),
    [anon_sym_GT_EQ] = ACTIONS(849),
    [anon_sym_instanceof] = ACTIONS(847),
    [anon_sym_in] = ACTIONS(847),
    [anon_sym_LT_LT] = ACTIONS(849),
    [anon_sym_GT_GT] = ACTIONS(847),
    [anon_sym_GT_GT_GT] = ACTIONS(849),
    [anon_sym_PLUS] = ACTIONS(847),
    [anon_sym_DASH] = ACTIONS(847),
    [anon_sym_PERCENT] = ACTIONS(849),
    [anon_sym_STAR_STAR] = ACTIONS(849),
    [anon_sym_BANG] = ACTIONS(847),
    [anon_sym_TILDE] = ACTIONS(849),
    [anon_sym_typeof] = ACTIONS(847),
    [anon_sym_void] = ACTIONS(847),
    [anon_sym_delete] = ACTIONS(847),
    [anon_sym_QMARK] = ACTIONS(847),
    [anon_sym_await] = ACTIONS(847),
    [anon_sym_LBRACK] = ACTIONS(849),
    [anon_sym_extends] = ACTIONS(847),
    [anon_sym_if] = ACTIONS(847),
    [anon_sym_async] = ACTIONS(847),
    [anon_sym_var] = ACTIONS(847),
    [anon_sym_let] = ACTIONS(847),
    [anon_sym_const] = ACTIONS(847),
    [anon_sym_return] = ACTIONS(847),
    [anon_sym_try] = ACTIONS(847),
    [anon_sym_throw] = ACTIONS(847),
    [anon_sym_for] = ACTIONS(847),
    [anon_sym_while] = ACTIONS(847),
    [anon_sym_break] = ACTIONS(847),
    [anon_sym_continue] = ACTIONS(847),
    [anon_sym_QMARK_DOT] = ACTIONS(849),
    [anon_sym_BQUOTE] = ACTIONS(849),
    [anon_sym_DOLLARr] = ACTIONS(847),
    [anon_sym_PLUS_PLUS] = ACTIONS(849),
    [anon_sym_DASH_DASH] = ACTIONS(849),
    [anon_sym_new] = ACTIONS(847),
  },
  [STATE(340)] = {
    [sym_comment] = STATE(340),
    [aux_sym_union_type_repeat1] = STATE(340),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(817),
    [anon_sym_LBRACE] = ACTIONS(819),
    [anon_sym_RBRACE] = ACTIONS(819),
    [anon_sym_STAR] = ACTIONS(817),
    [anon_sym_as] = ACTIONS(817),
    [anon_sym_SEMI] = ACTIONS(819),
    [anon_sym_LPAREN] = ACTIONS(819),
    [anon_sym_DOT] = ACTIONS(819),
    [sym_identifier] = ACTIONS(817),
    [anon_sym_DQUOTE] = ACTIONS(819),
    [anon_sym_SQUOTE] = ACTIONS(819),
    [anon_sym_DOLLAR] = ACTIONS(817),
    [sym_numeric_literal] = ACTIONS(819),
    [anon_sym_true] = ACTIONS(817),
    [anon_sym_false] = ACTIONS(817),
    [anon_sym_null] = ACTIONS(817),
    [anon_sym_PIPE_PIPE] = ACTIONS(819),
    [anon_sym_AMP_AMP] = ACTIONS(819),
    [anon_sym_PIPE] = ACTIONS(1382),
    [anon_sym_CARET] = ACTIONS(819),
    [anon_sym_AMP] = ACTIONS(817),
    [anon_sym_EQ_EQ] = ACTIONS(817),
    [anon_sym_BANG_EQ] = ACTIONS(817),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(819),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(819),
    [anon_sym_LT] = ACTIONS(817),
    [anon_sym_GT] = ACTIONS(817),
    [anon_sym_LT_EQ] = ACTIONS(819),
    [anon_sym_GT_EQ] = ACTIONS(819),
    [anon_sym_instanceof] = ACTIONS(817),
    [anon_sym_in] = ACTIONS(817),
    [anon_sym_LT_LT] = ACTIONS(819),
    [anon_sym_GT_GT] = ACTIONS(817),
    [anon_sym_GT_GT_GT] = ACTIONS(819),
    [anon_sym_PLUS] = ACTIONS(817),
    [anon_sym_DASH] = ACTIONS(817),
    [anon_sym_PERCENT] = ACTIONS(819),
    [anon_sym_STAR_STAR] = ACTIONS(819),
    [anon_sym_BANG] = ACTIONS(817),
    [anon_sym_TILDE] = ACTIONS(819),
    [anon_sym_typeof] = ACTIONS(817),
    [anon_sym_void] = ACTIONS(817),
    [anon_sym_delete] = ACTIONS(817),
    [anon_sym_QMARK] = ACTIONS(817),
    [anon_sym_await] = ACTIONS(817),
    [anon_sym_LBRACK] = ACTIONS(819),
    [anon_sym_if] = ACTIONS(817),
    [anon_sym_async] = ACTIONS(817),
    [anon_sym_var] = ACTIONS(817),
    [anon_sym_let] = ACTIONS(817),
    [anon_sym_const] = ACTIONS(817),
    [anon_sym_return] = ACTIONS(817),
    [anon_sym_try] = ACTIONS(817),
    [anon_sym_throw] = ACTIONS(817),
    [anon_sym_for] = ACTIONS(817),
    [anon_sym_while] = ACTIONS(817),
    [anon_sym_break] = ACTIONS(817),
    [anon_sym_continue] = ACTIONS(817),
    [anon_sym_QMARK_DOT] = ACTIONS(819),
    [anon_sym_BQUOTE] = ACTIONS(819),
    [anon_sym_DOLLARr] = ACTIONS(817),
    [anon_sym_PLUS_PLUS] = ACTIONS(819),
    [anon_sym_DASH_DASH] = ACTIONS(819),
    [anon_sym_new] = ACTIONS(817),
  },
  [STATE(341)] = {
    [sym_comment] = STATE(341),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(855),
    [anon_sym_LBRACE] = ACTIONS(857),
    [anon_sym_RBRACE] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_as] = ACTIONS(855),
    [anon_sym_SEMI] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(857),
    [anon_sym_DOT] = ACTIONS(857),
    [sym_identifier] = ACTIONS(855),
    [anon_sym_DQUOTE] = ACTIONS(857),
    [anon_sym_SQUOTE] = ACTIONS(857),
    [anon_sym_DOLLAR] = ACTIONS(855),
    [sym_numeric_literal] = ACTIONS(857),
    [anon_sym_true] = ACTIONS(855),
    [anon_sym_false] = ACTIONS(855),
    [anon_sym_null] = ACTIONS(855),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(855),
    [anon_sym_CARET] = ACTIONS(857),
    [anon_sym_AMP] = ACTIONS(855),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(857),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(857),
    [anon_sym_LT] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(857),
    [anon_sym_instanceof] = ACTIONS(855),
    [anon_sym_in] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_GT_GT_GT] = ACTIONS(857),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(855),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_STAR_STAR] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(855),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_typeof] = ACTIONS(855),
    [anon_sym_void] = ACTIONS(855),
    [anon_sym_delete] = ACTIONS(855),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_await] = ACTIONS(855),
    [anon_sym_LBRACK] = ACTIONS(857),
    [anon_sym_if] = ACTIONS(855),
    [anon_sym_else] = ACTIONS(855),
    [anon_sym_async] = ACTIONS(855),
    [anon_sym_var] = ACTIONS(855),
    [anon_sym_let] = ACTIONS(855),
    [anon_sym_const] = ACTIONS(855),
    [anon_sym_return] = ACTIONS(855),
    [anon_sym_try] = ACTIONS(855),
    [anon_sym_throw] = ACTIONS(855),
    [anon_sym_for] = ACTIONS(855),
    [anon_sym_while] = ACTIONS(855),
    [anon_sym_break] = ACTIONS(855),
    [anon_sym_continue] = ACTIONS(855),
    [anon_sym_QMARK_DOT] = ACTIONS(857),
    [anon_sym_BQUOTE] = ACTIONS(857),
    [anon_sym_DOLLARr] = ACTIONS(855),
    [anon_sym_PLUS_PLUS] = ACTIONS(857),
    [anon_sym_DASH_DASH] = ACTIONS(857),
    [anon_sym_new] = ACTIONS(855),
  },
  [STATE(342)] = {
    [sym_comment] = STATE(342),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(851),
    [anon_sym_LBRACE] = ACTIONS(853),
    [anon_sym_RBRACE] = ACTIONS(853),
    [anon_sym_STAR] = ACTIONS(851),
    [anon_sym_as] = ACTIONS(851),
    [anon_sym_SEMI] = ACTIONS(853),
    [anon_sym_LPAREN] = ACTIONS(853),
    [anon_sym_DOT] = ACTIONS(853),
    [sym_identifier] = ACTIONS(851),
    [anon_sym_DQUOTE] = ACTIONS(853),
    [anon_sym_SQUOTE] = ACTIONS(853),
    [anon_sym_DOLLAR] = ACTIONS(851),
    [sym_numeric_literal] = ACTIONS(853),
    [anon_sym_true] = ACTIONS(851),
    [anon_sym_false] = ACTIONS(851),
    [anon_sym_null] = ACTIONS(851),
    [anon_sym_PIPE_PIPE] = ACTIONS(853),
    [anon_sym_AMP_AMP] = ACTIONS(853),
    [anon_sym_PIPE] = ACTIONS(851),
    [anon_sym_CARET] = ACTIONS(853),
    [anon_sym_AMP] = ACTIONS(851),
    [anon_sym_EQ_EQ] = ACTIONS(851),
    [anon_sym_BANG_EQ] = ACTIONS(851),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(853),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(853),
    [anon_sym_LT] = ACTIONS(851),
    [anon_sym_GT] = ACTIONS(851),
    [anon_sym_LT_EQ] = ACTIONS(853),
    [anon_sym_GT_EQ] = ACTIONS(853),
    [anon_sym_instanceof] = ACTIONS(851),
    [anon_sym_in] = ACTIONS(851),
    [anon_sym_LT_LT] = ACTIONS(853),
    [anon_sym_GT_GT] = ACTIONS(851),
    [anon_sym_GT_GT_GT] = ACTIONS(853),
    [anon_sym_PLUS] = ACTIONS(851),
    [anon_sym_DASH] = ACTIONS(851),
    [anon_sym_PERCENT] = ACTIONS(853),
    [anon_sym_STAR_STAR] = ACTIONS(853),
    [anon_sym_BANG] = ACTIONS(851),
    [anon_sym_TILDE] = ACTIONS(853),
    [anon_sym_typeof] = ACTIONS(851),
    [anon_sym_void] = ACTIONS(851),
    [anon_sym_delete] = ACTIONS(851),
    [anon_sym_QMARK] = ACTIONS(851),
    [anon_sym_await] = ACTIONS(851),
    [anon_sym_LBRACK] = ACTIONS(853),
    [anon_sym_extends] = ACTIONS(851),
    [anon_sym_if] = ACTIONS(851),
    [anon_sym_async] = ACTIONS(851),
    [anon_sym_var] = ACTIONS(851),
    [anon_sym_let] = ACTIONS(851),
    [anon_sym_const] = ACTIONS(851),
    [anon_sym_return] = ACTIONS(851),
    [anon_sym_try] = ACTIONS(851),
    [anon_sym_throw] = ACTIONS(851),
    [anon_sym_for] = ACTIONS(851),
    [anon_sym_while] = ACTIONS(851),
    [anon_sym_break] = ACTIONS(851),
    [anon_sym_continue] = ACTIONS(851),
    [anon_sym_QMARK_DOT] = ACTIONS(853),
    [anon_sym_BQUOTE] = ACTIONS(853),
    [anon_sym_DOLLARr] = ACTIONS(851),
    [anon_sym_PLUS_PLUS] = ACTIONS(853),
    [anon_sym_DASH_DASH] = ACTIONS(853),
    [anon_sym_new] = ACTIONS(851),
  },
  [STATE(343)] = {
    [sym_comment] = STATE(343),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(828),
    [anon_sym_LBRACE] = ACTIONS(830),
    [anon_sym_RBRACE] = ACTIONS(830),
    [anon_sym_STAR] = ACTIONS(828),
    [anon_sym_as] = ACTIONS(828),
    [anon_sym_SEMI] = ACTIONS(830),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_DOT] = ACTIONS(830),
    [sym_identifier] = ACTIONS(828),
    [anon_sym_DQUOTE] = ACTIONS(830),
    [anon_sym_SQUOTE] = ACTIONS(830),
    [anon_sym_DOLLAR] = ACTIONS(828),
    [sym_numeric_literal] = ACTIONS(830),
    [anon_sym_true] = ACTIONS(828),
    [anon_sym_false] = ACTIONS(828),
    [anon_sym_null] = ACTIONS(828),
    [anon_sym_PIPE_PIPE] = ACTIONS(830),
    [anon_sym_AMP_AMP] = ACTIONS(830),
    [anon_sym_PIPE] = ACTIONS(828),
    [anon_sym_CARET] = ACTIONS(830),
    [anon_sym_AMP] = ACTIONS(828),
    [anon_sym_EQ_EQ] = ACTIONS(828),
    [anon_sym_BANG_EQ] = ACTIONS(828),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(830),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(830),
    [anon_sym_LT] = ACTIONS(828),
    [anon_sym_GT] = ACTIONS(828),
    [anon_sym_LT_EQ] = ACTIONS(830),
    [anon_sym_GT_EQ] = ACTIONS(830),
    [anon_sym_instanceof] = ACTIONS(828),
    [anon_sym_in] = ACTIONS(828),
    [anon_sym_LT_LT] = ACTIONS(830),
    [anon_sym_GT_GT] = ACTIONS(828),
    [anon_sym_GT_GT_GT] = ACTIONS(830),
    [anon_sym_PLUS] = ACTIONS(828),
    [anon_sym_DASH] = ACTIONS(828),
    [anon_sym_PERCENT] = ACTIONS(830),
    [anon_sym_STAR_STAR] = ACTIONS(830),
    [anon_sym_BANG] = ACTIONS(828),
    [anon_sym_TILDE] = ACTIONS(830),
    [anon_sym_typeof] = ACTIONS(828),
    [anon_sym_void] = ACTIONS(828),
    [anon_sym_delete] = ACTIONS(828),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_await] = ACTIONS(828),
    [anon_sym_LBRACK] = ACTIONS(830),
    [anon_sym_if] = ACTIONS(828),
    [anon_sym_else] = ACTIONS(828),
    [anon_sym_async] = ACTIONS(828),
    [anon_sym_var] = ACTIONS(828),
    [anon_sym_let] = ACTIONS(828),
    [anon_sym_const] = ACTIONS(828),
    [anon_sym_return] = ACTIONS(828),
    [anon_sym_try] = ACTIONS(828),
    [anon_sym_throw] = ACTIONS(828),
    [anon_sym_for] = ACTIONS(828),
    [anon_sym_while] = ACTIONS(828),
    [anon_sym_break] = ACTIONS(828),
    [anon_sym_continue] = ACTIONS(828),
    [anon_sym_QMARK_DOT] = ACTIONS(830),
    [anon_sym_BQUOTE] = ACTIONS(830),
    [anon_sym_DOLLARr] = ACTIONS(828),
    [anon_sym_PLUS_PLUS] = ACTIONS(830),
    [anon_sym_DASH_DASH] = ACTIONS(830),
    [anon_sym_new] = ACTIONS(828),
  },
  [STATE(344)] = {
    [sym_comment] = STATE(344),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(981),
    [anon_sym_LBRACE] = ACTIONS(983),
    [anon_sym_RBRACE] = ACTIONS(983),
    [anon_sym_STAR] = ACTIONS(981),
    [anon_sym_as] = ACTIONS(981),
    [anon_sym_SEMI] = ACTIONS(983),
    [anon_sym_LPAREN] = ACTIONS(983),
    [anon_sym_DOT] = ACTIONS(983),
    [sym_identifier] = ACTIONS(981),
    [anon_sym_DQUOTE] = ACTIONS(983),
    [anon_sym_SQUOTE] = ACTIONS(983),
    [anon_sym_DOLLAR] = ACTIONS(981),
    [sym_numeric_literal] = ACTIONS(983),
    [anon_sym_true] = ACTIONS(981),
    [anon_sym_false] = ACTIONS(981),
    [anon_sym_null] = ACTIONS(981),
    [anon_sym_PIPE_PIPE] = ACTIONS(983),
    [anon_sym_AMP_AMP] = ACTIONS(983),
    [anon_sym_PIPE] = ACTIONS(981),
    [anon_sym_CARET] = ACTIONS(983),
    [anon_sym_AMP] = ACTIONS(981),
    [anon_sym_EQ_EQ] = ACTIONS(981),
    [anon_sym_BANG_EQ] = ACTIONS(981),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(983),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(983),
    [anon_sym_LT] = ACTIONS(981),
    [anon_sym_GT] = ACTIONS(981),
    [anon_sym_LT_EQ] = ACTIONS(983),
    [anon_sym_GT_EQ] = ACTIONS(983),
    [anon_sym_instanceof] = ACTIONS(981),
    [anon_sym_in] = ACTIONS(981),
    [anon_sym_LT_LT] = ACTIONS(983),
    [anon_sym_GT_GT] = ACTIONS(981),
    [anon_sym_GT_GT_GT] = ACTIONS(983),
    [anon_sym_PLUS] = ACTIONS(981),
    [anon_sym_DASH] = ACTIONS(981),
    [anon_sym_PERCENT] = ACTIONS(983),
    [anon_sym_STAR_STAR] = ACTIONS(983),
    [anon_sym_BANG] = ACTIONS(981),
    [anon_sym_TILDE] = ACTIONS(983),
    [anon_sym_typeof] = ACTIONS(981),
    [anon_sym_void] = ACTIONS(981),
    [anon_sym_delete] = ACTIONS(981),
    [anon_sym_QMARK] = ACTIONS(981),
    [anon_sym_await] = ACTIONS(981),
    [anon_sym_LBRACK] = ACTIONS(983),
    [anon_sym_if] = ACTIONS(981),
    [anon_sym_else] = ACTIONS(981),
    [anon_sym_async] = ACTIONS(981),
    [anon_sym_var] = ACTIONS(981),
    [anon_sym_let] = ACTIONS(981),
    [anon_sym_const] = ACTIONS(981),
    [anon_sym_return] = ACTIONS(981),
    [anon_sym_try] = ACTIONS(981),
    [anon_sym_throw] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_break] = ACTIONS(981),
    [anon_sym_continue] = ACTIONS(981),
    [anon_sym_QMARK_DOT] = ACTIONS(983),
    [anon_sym_BQUOTE] = ACTIONS(983),
    [anon_sym_DOLLARr] = ACTIONS(981),
    [anon_sym_PLUS_PLUS] = ACTIONS(983),
    [anon_sym_DASH_DASH] = ACTIONS(983),
    [anon_sym_new] = ACTIONS(981),
  },
  [STATE(345)] = {
    [sym_comment] = STATE(345),
    [aux_sym_array_type_repeat1] = STATE(348),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(1200),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(346)] = {
    [sym_comment] = STATE(346),
    [sym_type_arguments] = STATE(399),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(1197),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(347)] = {
    [sym_comment] = STATE(347),
    [aux_sym_qualified_type_repeat1] = STATE(352),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(767),
    [anon_sym_LBRACE] = ACTIONS(769),
    [anon_sym_RBRACE] = ACTIONS(769),
    [anon_sym_STAR] = ACTIONS(767),
    [anon_sym_as] = ACTIONS(767),
    [anon_sym_SEMI] = ACTIONS(769),
    [anon_sym_LPAREN] = ACTIONS(769),
    [anon_sym_DOT] = ACTIONS(769),
    [sym_identifier] = ACTIONS(767),
    [anon_sym_DQUOTE] = ACTIONS(769),
    [anon_sym_SQUOTE] = ACTIONS(769),
    [anon_sym_DOLLAR] = ACTIONS(767),
    [sym_numeric_literal] = ACTIONS(769),
    [anon_sym_true] = ACTIONS(767),
    [anon_sym_false] = ACTIONS(767),
    [anon_sym_null] = ACTIONS(767),
    [anon_sym_PIPE_PIPE] = ACTIONS(769),
    [anon_sym_AMP_AMP] = ACTIONS(769),
    [anon_sym_PIPE] = ACTIONS(767),
    [anon_sym_CARET] = ACTIONS(769),
    [anon_sym_AMP] = ACTIONS(767),
    [anon_sym_EQ_EQ] = ACTIONS(767),
    [anon_sym_BANG_EQ] = ACTIONS(767),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(769),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(769),
    [anon_sym_LT] = ACTIONS(767),
    [anon_sym_GT] = ACTIONS(767),
    [anon_sym_LT_EQ] = ACTIONS(769),
    [anon_sym_GT_EQ] = ACTIONS(769),
    [anon_sym_instanceof] = ACTIONS(767),
    [anon_sym_in] = ACTIONS(767),
    [anon_sym_LT_LT] = ACTIONS(769),
    [anon_sym_GT_GT] = ACTIONS(767),
    [anon_sym_GT_GT_GT] = ACTIONS(769),
    [anon_sym_PLUS] = ACTIONS(767),
    [anon_sym_DASH] = ACTIONS(767),
    [anon_sym_PERCENT] = ACTIONS(769),
    [anon_sym_STAR_STAR] = ACTIONS(769),
    [anon_sym_BANG] = ACTIONS(767),
    [anon_sym_TILDE] = ACTIONS(769),
    [anon_sym_typeof] = ACTIONS(767),
    [anon_sym_void] = ACTIONS(767),
    [anon_sym_delete] = ACTIONS(767),
    [anon_sym_QMARK] = ACTIONS(767),
    [anon_sym_await] = ACTIONS(767),
    [anon_sym_LBRACK] = ACTIONS(769),
    [anon_sym_if] = ACTIONS(767),
    [anon_sym_async] = ACTIONS(767),
    [anon_sym_var] = ACTIONS(767),
    [anon_sym_let] = ACTIONS(767),
    [anon_sym_const] = ACTIONS(767),
    [anon_sym_return] = ACTIONS(767),
    [anon_sym_try] = ACTIONS(767),
    [anon_sym_throw] = ACTIONS(767),
    [anon_sym_for] = ACTIONS(767),
    [anon_sym_while] = ACTIONS(767),
    [anon_sym_break] = ACTIONS(767),
    [anon_sym_continue] = ACTIONS(767),
    [anon_sym_QMARK_DOT] = ACTIONS(769),
    [anon_sym_BQUOTE] = ACTIONS(769),
    [anon_sym_DOLLARr] = ACTIONS(767),
    [anon_sym_PLUS_PLUS] = ACTIONS(769),
    [anon_sym_DASH_DASH] = ACTIONS(769),
    [anon_sym_new] = ACTIONS(767),
  },
  [STATE(348)] = {
    [sym_comment] = STATE(348),
    [aux_sym_array_type_repeat1] = STATE(320),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(771),
    [anon_sym_LBRACE] = ACTIONS(773),
    [anon_sym_RBRACE] = ACTIONS(773),
    [anon_sym_STAR] = ACTIONS(771),
    [anon_sym_as] = ACTIONS(771),
    [anon_sym_SEMI] = ACTIONS(773),
    [anon_sym_LPAREN] = ACTIONS(773),
    [anon_sym_DOT] = ACTIONS(773),
    [sym_identifier] = ACTIONS(771),
    [anon_sym_DQUOTE] = ACTIONS(773),
    [anon_sym_SQUOTE] = ACTIONS(773),
    [anon_sym_DOLLAR] = ACTIONS(771),
    [sym_numeric_literal] = ACTIONS(773),
    [anon_sym_true] = ACTIONS(771),
    [anon_sym_false] = ACTIONS(771),
    [anon_sym_null] = ACTIONS(771),
    [anon_sym_PIPE_PIPE] = ACTIONS(773),
    [anon_sym_AMP_AMP] = ACTIONS(773),
    [anon_sym_PIPE] = ACTIONS(771),
    [anon_sym_CARET] = ACTIONS(773),
    [anon_sym_AMP] = ACTIONS(771),
    [anon_sym_EQ_EQ] = ACTIONS(771),
    [anon_sym_BANG_EQ] = ACTIONS(771),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(773),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(773),
    [anon_sym_LT] = ACTIONS(771),
    [anon_sym_GT] = ACTIONS(771),
    [anon_sym_LT_EQ] = ACTIONS(773),
    [anon_sym_GT_EQ] = ACTIONS(773),
    [anon_sym_instanceof] = ACTIONS(771),
    [anon_sym_in] = ACTIONS(771),
    [anon_sym_LT_LT] = ACTIONS(773),
    [anon_sym_GT_GT] = ACTIONS(771),
    [anon_sym_GT_GT_GT] = ACTIONS(773),
    [anon_sym_PLUS] = ACTIONS(771),
    [anon_sym_DASH] = ACTIONS(771),
    [anon_sym_PERCENT] = ACTIONS(773),
    [anon_sym_STAR_STAR] = ACTIONS(773),
    [anon_sym_BANG] = ACTIONS(771),
    [anon_sym_TILDE] = ACTIONS(773),
    [anon_sym_typeof] = ACTIONS(771),
    [anon_sym_void] = ACTIONS(771),
    [anon_sym_delete] = ACTIONS(771),
    [anon_sym_QMARK] = ACTIONS(771),
    [anon_sym_await] = ACTIONS(771),
    [anon_sym_LBRACK] = ACTIONS(1385),
    [anon_sym_if] = ACTIONS(771),
    [anon_sym_async] = ACTIONS(771),
    [anon_sym_var] = ACTIONS(771),
    [anon_sym_let] = ACTIONS(771),
    [anon_sym_const] = ACTIONS(771),
    [anon_sym_return] = ACTIONS(771),
    [anon_sym_try] = ACTIONS(771),
    [anon_sym_throw] = ACTIONS(771),
    [anon_sym_for] = ACTIONS(771),
    [anon_sym_while] = ACTIONS(771),
    [anon_sym_break] = ACTIONS(771),
    [anon_sym_continue] = ACTIONS(771),
    [anon_sym_QMARK_DOT] = ACTIONS(773),
    [anon_sym_BQUOTE] = ACTIONS(773),
    [anon_sym_DOLLARr] = ACTIONS(771),
    [anon_sym_PLUS_PLUS] = ACTIONS(773),
    [anon_sym_DASH_DASH] = ACTIONS(773),
    [anon_sym_new] = ACTIONS(771),
  },
  [STATE(349)] = {
    [sym_comment] = STATE(349),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(907),
    [anon_sym_LBRACE] = ACTIONS(910),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_STAR] = ACTIONS(907),
    [anon_sym_as] = ACTIONS(907),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_LPAREN] = ACTIONS(910),
    [anon_sym_DOT] = ACTIONS(910),
    [sym_identifier] = ACTIONS(907),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [anon_sym_SQUOTE] = ACTIONS(910),
    [anon_sym_DOLLAR] = ACTIONS(907),
    [sym_numeric_literal] = ACTIONS(910),
    [anon_sym_true] = ACTIONS(907),
    [anon_sym_false] = ACTIONS(907),
    [anon_sym_null] = ACTIONS(907),
    [anon_sym_PIPE_PIPE] = ACTIONS(910),
    [anon_sym_AMP_AMP] = ACTIONS(910),
    [anon_sym_PIPE] = ACTIONS(907),
    [anon_sym_CARET] = ACTIONS(910),
    [anon_sym_AMP] = ACTIONS(907),
    [anon_sym_EQ_EQ] = ACTIONS(907),
    [anon_sym_BANG_EQ] = ACTIONS(907),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(910),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(910),
    [anon_sym_LT] = ACTIONS(907),
    [anon_sym_GT] = ACTIONS(907),
    [anon_sym_LT_EQ] = ACTIONS(910),
    [anon_sym_GT_EQ] = ACTIONS(910),
    [anon_sym_instanceof] = ACTIONS(907),
    [anon_sym_in] = ACTIONS(907),
    [anon_sym_LT_LT] = ACTIONS(910),
    [anon_sym_GT_GT] = ACTIONS(907),
    [anon_sym_GT_GT_GT] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(907),
    [anon_sym_PERCENT] = ACTIONS(910),
    [anon_sym_STAR_STAR] = ACTIONS(910),
    [anon_sym_BANG] = ACTIONS(907),
    [anon_sym_TILDE] = ACTIONS(910),
    [anon_sym_typeof] = ACTIONS(907),
    [anon_sym_void] = ACTIONS(907),
    [anon_sym_delete] = ACTIONS(907),
    [anon_sym_QMARK] = ACTIONS(907),
    [anon_sym_await] = ACTIONS(907),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_if] = ACTIONS(907),
    [anon_sym_else] = ACTIONS(907),
    [anon_sym_async] = ACTIONS(907),
    [anon_sym_var] = ACTIONS(907),
    [anon_sym_let] = ACTIONS(907),
    [anon_sym_const] = ACTIONS(907),
    [anon_sym_return] = ACTIONS(907),
    [anon_sym_try] = ACTIONS(907),
    [anon_sym_throw] = ACTIONS(907),
    [anon_sym_for] = ACTIONS(907),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_break] = ACTIONS(907),
    [anon_sym_continue] = ACTIONS(907),
    [anon_sym_QMARK_DOT] = ACTIONS(910),
    [anon_sym_BQUOTE] = ACTIONS(910),
    [anon_sym_DOLLARr] = ACTIONS(907),
    [anon_sym_PLUS_PLUS] = ACTIONS(910),
    [anon_sym_DASH_DASH] = ACTIONS(910),
    [anon_sym_new] = ACTIONS(907),
  },
  [STATE(350)] = {
    [sym_comment] = STATE(350),
    [sym_modifier_chain_expression] = STATE(412),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(867),
    [anon_sym_RBRACE] = ACTIONS(867),
    [anon_sym_STAR] = ACTIONS(865),
    [anon_sym_as] = ACTIONS(865),
    [anon_sym_SEMI] = ACTIONS(867),
    [anon_sym_LPAREN] = ACTIONS(1388),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(865),
    [anon_sym_DQUOTE] = ACTIONS(867),
    [anon_sym_SQUOTE] = ACTIONS(867),
    [anon_sym_DOLLAR] = ACTIONS(865),
    [sym_numeric_literal] = ACTIONS(867),
    [anon_sym_true] = ACTIONS(865),
    [anon_sym_false] = ACTIONS(865),
    [anon_sym_null] = ACTIONS(865),
    [anon_sym_PIPE_PIPE] = ACTIONS(867),
    [anon_sym_AMP_AMP] = ACTIONS(867),
    [anon_sym_PIPE] = ACTIONS(865),
    [anon_sym_CARET] = ACTIONS(867),
    [anon_sym_AMP] = ACTIONS(865),
    [anon_sym_EQ_EQ] = ACTIONS(865),
    [anon_sym_BANG_EQ] = ACTIONS(865),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(867),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(867),
    [anon_sym_LT] = ACTIONS(865),
    [anon_sym_GT] = ACTIONS(865),
    [anon_sym_LT_EQ] = ACTIONS(867),
    [anon_sym_GT_EQ] = ACTIONS(867),
    [anon_sym_instanceof] = ACTIONS(865),
    [anon_sym_in] = ACTIONS(865),
    [anon_sym_LT_LT] = ACTIONS(867),
    [anon_sym_GT_GT] = ACTIONS(865),
    [anon_sym_GT_GT_GT] = ACTIONS(867),
    [anon_sym_PLUS] = ACTIONS(865),
    [anon_sym_DASH] = ACTIONS(865),
    [anon_sym_PERCENT] = ACTIONS(867),
    [anon_sym_STAR_STAR] = ACTIONS(867),
    [anon_sym_BANG] = ACTIONS(865),
    [anon_sym_TILDE] = ACTIONS(867),
    [anon_sym_typeof] = ACTIONS(865),
    [anon_sym_void] = ACTIONS(865),
    [anon_sym_delete] = ACTIONS(865),
    [anon_sym_QMARK] = ACTIONS(865),
    [anon_sym_await] = ACTIONS(865),
    [anon_sym_LBRACK] = ACTIONS(867),
    [anon_sym_if] = ACTIONS(865),
    [anon_sym_async] = ACTIONS(865),
    [anon_sym_var] = ACTIONS(865),
    [anon_sym_let] = ACTIONS(865),
    [anon_sym_const] = ACTIONS(865),
    [anon_sym_return] = ACTIONS(865),
    [anon_sym_try] = ACTIONS(865),
    [anon_sym_throw] = ACTIONS(865),
    [anon_sym_for] = ACTIONS(865),
    [anon_sym_while] = ACTIONS(865),
    [anon_sym_break] = ACTIONS(865),
    [anon_sym_continue] = ACTIONS(865),
    [anon_sym_QMARK_DOT] = ACTIONS(867),
    [anon_sym_BQUOTE] = ACTIONS(867),
    [anon_sym_DOLLARr] = ACTIONS(865),
    [anon_sym_PLUS_PLUS] = ACTIONS(867),
    [anon_sym_DASH_DASH] = ACTIONS(867),
    [anon_sym_new] = ACTIONS(865),
  },
  [STATE(351)] = {
    [sym_comment] = STATE(351),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(883),
    [anon_sym_LBRACE] = ACTIONS(885),
    [anon_sym_RBRACE] = ACTIONS(885),
    [anon_sym_STAR] = ACTIONS(883),
    [anon_sym_as] = ACTIONS(883),
    [anon_sym_SEMI] = ACTIONS(885),
    [anon_sym_LPAREN] = ACTIONS(885),
    [anon_sym_COLON] = ACTIONS(885),
    [anon_sym_DOT] = ACTIONS(885),
    [sym_identifier] = ACTIONS(883),
    [anon_sym_DQUOTE] = ACTIONS(885),
    [anon_sym_SQUOTE] = ACTIONS(885),
    [anon_sym_DOLLAR] = ACTIONS(883),
    [sym_numeric_literal] = ACTIONS(885),
    [anon_sym_true] = ACTIONS(883),
    [anon_sym_false] = ACTIONS(883),
    [anon_sym_null] = ACTIONS(883),
    [anon_sym_PIPE_PIPE] = ACTIONS(885),
    [anon_sym_AMP_AMP] = ACTIONS(885),
    [anon_sym_PIPE] = ACTIONS(883),
    [anon_sym_CARET] = ACTIONS(885),
    [anon_sym_AMP] = ACTIONS(883),
    [anon_sym_EQ_EQ] = ACTIONS(883),
    [anon_sym_BANG_EQ] = ACTIONS(883),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(885),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(885),
    [anon_sym_LT] = ACTIONS(883),
    [anon_sym_GT] = ACTIONS(883),
    [anon_sym_LT_EQ] = ACTIONS(885),
    [anon_sym_GT_EQ] = ACTIONS(885),
    [anon_sym_instanceof] = ACTIONS(883),
    [anon_sym_in] = ACTIONS(883),
    [anon_sym_LT_LT] = ACTIONS(885),
    [anon_sym_GT_GT] = ACTIONS(883),
    [anon_sym_GT_GT_GT] = ACTIONS(885),
    [anon_sym_PLUS] = ACTIONS(883),
    [anon_sym_DASH] = ACTIONS(883),
    [anon_sym_PERCENT] = ACTIONS(885),
    [anon_sym_STAR_STAR] = ACTIONS(885),
    [anon_sym_BANG] = ACTIONS(883),
    [anon_sym_TILDE] = ACTIONS(885),
    [anon_sym_typeof] = ACTIONS(883),
    [anon_sym_void] = ACTIONS(883),
    [anon_sym_delete] = ACTIONS(883),
    [anon_sym_QMARK] = ACTIONS(883),
    [anon_sym_await] = ACTIONS(883),
    [anon_sym_LBRACK] = ACTIONS(885),
    [anon_sym_if] = ACTIONS(883),
    [anon_sym_async] = ACTIONS(883),
    [anon_sym_var] = ACTIONS(883),
    [anon_sym_let] = ACTIONS(883),
    [anon_sym_const] = ACTIONS(883),
    [anon_sym_return] = ACTIONS(883),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_throw] = ACTIONS(883),
    [anon_sym_for] = ACTIONS(883),
    [anon_sym_while] = ACTIONS(883),
    [anon_sym_break] = ACTIONS(883),
    [anon_sym_continue] = ACTIONS(883),
    [anon_sym_QMARK_DOT] = ACTIONS(885),
    [anon_sym_BQUOTE] = ACTIONS(885),
    [anon_sym_DOLLARr] = ACTIONS(883),
    [anon_sym_PLUS_PLUS] = ACTIONS(885),
    [anon_sym_DASH_DASH] = ACTIONS(885),
    [anon_sym_new] = ACTIONS(883),
  },
  [STATE(352)] = {
    [sym_comment] = STATE(352),
    [aux_sym_qualified_type_repeat1] = STATE(352),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(1390),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_var] = ACTIONS(778),
    [anon_sym_let] = ACTIONS(778),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_return] = ACTIONS(778),
    [anon_sym_try] = ACTIONS(778),
    [anon_sym_throw] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_break] = ACTIONS(778),
    [anon_sym_continue] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(353)] = {
    [sym_comment] = STATE(353),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_LBRACE] = ACTIONS(897),
    [anon_sym_RBRACE] = ACTIONS(897),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_as] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(897),
    [anon_sym_LPAREN] = ACTIONS(897),
    [anon_sym_DOT] = ACTIONS(897),
    [sym_identifier] = ACTIONS(895),
    [anon_sym_DQUOTE] = ACTIONS(897),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DOLLAR] = ACTIONS(895),
    [sym_numeric_literal] = ACTIONS(897),
    [anon_sym_true] = ACTIONS(895),
    [anon_sym_false] = ACTIONS(895),
    [anon_sym_null] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(897),
    [anon_sym_AMP_AMP] = ACTIONS(897),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(897),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(895),
    [anon_sym_BANG_EQ] = ACTIONS(895),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(897),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(897),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_LT_EQ] = ACTIONS(897),
    [anon_sym_GT_EQ] = ACTIONS(897),
    [anon_sym_instanceof] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(897),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_GT_GT_GT] = ACTIONS(897),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(897),
    [anon_sym_STAR_STAR] = ACTIONS(897),
    [anon_sym_BANG] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(897),
    [anon_sym_typeof] = ACTIONS(895),
    [anon_sym_void] = ACTIONS(895),
    [anon_sym_delete] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(895),
    [anon_sym_await] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(897),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_else] = ACTIONS(895),
    [anon_sym_async] = ACTIONS(895),
    [anon_sym_var] = ACTIONS(895),
    [anon_sym_let] = ACTIONS(895),
    [anon_sym_const] = ACTIONS(895),
    [anon_sym_return] = ACTIONS(895),
    [anon_sym_try] = ACTIONS(895),
    [anon_sym_throw] = ACTIONS(895),
    [anon_sym_for] = ACTIONS(895),
    [anon_sym_while] = ACTIONS(895),
    [anon_sym_break] = ACTIONS(895),
    [anon_sym_continue] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(897),
    [anon_sym_BQUOTE] = ACTIONS(897),
    [anon_sym_DOLLARr] = ACTIONS(895),
    [anon_sym_PLUS_PLUS] = ACTIONS(897),
    [anon_sym_DASH_DASH] = ACTIONS(897),
    [anon_sym_new] = ACTIONS(895),
  },
  [STATE(354)] = {
    [sym_comment] = STATE(354),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(957),
    [anon_sym_LBRACE] = ACTIONS(910),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_STAR] = ACTIONS(957),
    [anon_sym_as] = ACTIONS(957),
    [anon_sym_SEMI] = ACTIONS(959),
    [anon_sym_LPAREN] = ACTIONS(910),
    [anon_sym_DOT] = ACTIONS(910),
    [sym_identifier] = ACTIONS(907),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [anon_sym_SQUOTE] = ACTIONS(910),
    [anon_sym_DOLLAR] = ACTIONS(907),
    [sym_numeric_literal] = ACTIONS(910),
    [anon_sym_true] = ACTIONS(907),
    [anon_sym_false] = ACTIONS(907),
    [anon_sym_null] = ACTIONS(907),
    [anon_sym_PIPE_PIPE] = ACTIONS(959),
    [anon_sym_AMP_AMP] = ACTIONS(959),
    [anon_sym_PIPE] = ACTIONS(957),
    [anon_sym_CARET] = ACTIONS(959),
    [anon_sym_AMP] = ACTIONS(957),
    [anon_sym_EQ_EQ] = ACTIONS(957),
    [anon_sym_BANG_EQ] = ACTIONS(957),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(959),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(959),
    [anon_sym_LT] = ACTIONS(907),
    [anon_sym_GT] = ACTIONS(957),
    [anon_sym_LT_EQ] = ACTIONS(959),
    [anon_sym_GT_EQ] = ACTIONS(959),
    [anon_sym_instanceof] = ACTIONS(957),
    [anon_sym_in] = ACTIONS(957),
    [anon_sym_LT_LT] = ACTIONS(959),
    [anon_sym_GT_GT] = ACTIONS(957),
    [anon_sym_GT_GT_GT] = ACTIONS(959),
    [anon_sym_PLUS] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(907),
    [anon_sym_PERCENT] = ACTIONS(959),
    [anon_sym_STAR_STAR] = ACTIONS(959),
    [anon_sym_BANG] = ACTIONS(907),
    [anon_sym_TILDE] = ACTIONS(910),
    [anon_sym_typeof] = ACTIONS(907),
    [anon_sym_void] = ACTIONS(907),
    [anon_sym_delete] = ACTIONS(907),
    [anon_sym_QMARK] = ACTIONS(957),
    [anon_sym_await] = ACTIONS(907),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_if] = ACTIONS(907),
    [anon_sym_else] = ACTIONS(907),
    [anon_sym_async] = ACTIONS(907),
    [anon_sym_var] = ACTIONS(907),
    [anon_sym_let] = ACTIONS(907),
    [anon_sym_const] = ACTIONS(907),
    [anon_sym_return] = ACTIONS(907),
    [anon_sym_try] = ACTIONS(907),
    [anon_sym_throw] = ACTIONS(907),
    [anon_sym_for] = ACTIONS(907),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_break] = ACTIONS(907),
    [anon_sym_continue] = ACTIONS(907),
    [anon_sym_QMARK_DOT] = ACTIONS(959),
    [anon_sym_BQUOTE] = ACTIONS(910),
    [anon_sym_DOLLARr] = ACTIONS(907),
    [anon_sym_PLUS_PLUS] = ACTIONS(910),
    [anon_sym_DASH_DASH] = ACTIONS(910),
    [anon_sym_new] = ACTIONS(907),
  },
  [STATE(355)] = {
    [sym_comment] = STATE(355),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(961),
    [anon_sym_LBRACE] = ACTIONS(963),
    [anon_sym_RBRACE] = ACTIONS(963),
    [anon_sym_STAR] = ACTIONS(961),
    [anon_sym_as] = ACTIONS(961),
    [anon_sym_SEMI] = ACTIONS(963),
    [anon_sym_LPAREN] = ACTIONS(963),
    [anon_sym_COLON] = ACTIONS(963),
    [anon_sym_DOT] = ACTIONS(963),
    [sym_identifier] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DOLLAR] = ACTIONS(961),
    [sym_numeric_literal] = ACTIONS(963),
    [anon_sym_true] = ACTIONS(961),
    [anon_sym_false] = ACTIONS(961),
    [anon_sym_null] = ACTIONS(961),
    [anon_sym_PIPE_PIPE] = ACTIONS(963),
    [anon_sym_AMP_AMP] = ACTIONS(963),
    [anon_sym_PIPE] = ACTIONS(961),
    [anon_sym_CARET] = ACTIONS(963),
    [anon_sym_AMP] = ACTIONS(961),
    [anon_sym_EQ_EQ] = ACTIONS(961),
    [anon_sym_BANG_EQ] = ACTIONS(961),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(963),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(963),
    [anon_sym_LT] = ACTIONS(961),
    [anon_sym_GT] = ACTIONS(961),
    [anon_sym_LT_EQ] = ACTIONS(963),
    [anon_sym_GT_EQ] = ACTIONS(963),
    [anon_sym_instanceof] = ACTIONS(961),
    [anon_sym_in] = ACTIONS(961),
    [anon_sym_LT_LT] = ACTIONS(963),
    [anon_sym_GT_GT] = ACTIONS(961),
    [anon_sym_GT_GT_GT] = ACTIONS(963),
    [anon_sym_PLUS] = ACTIONS(961),
    [anon_sym_DASH] = ACTIONS(961),
    [anon_sym_PERCENT] = ACTIONS(963),
    [anon_sym_STAR_STAR] = ACTIONS(963),
    [anon_sym_BANG] = ACTIONS(961),
    [anon_sym_TILDE] = ACTIONS(963),
    [anon_sym_typeof] = ACTIONS(961),
    [anon_sym_void] = ACTIONS(961),
    [anon_sym_delete] = ACTIONS(961),
    [anon_sym_QMARK] = ACTIONS(961),
    [anon_sym_await] = ACTIONS(961),
    [anon_sym_LBRACK] = ACTIONS(963),
    [anon_sym_if] = ACTIONS(961),
    [anon_sym_async] = ACTIONS(961),
    [anon_sym_var] = ACTIONS(961),
    [anon_sym_let] = ACTIONS(961),
    [anon_sym_const] = ACTIONS(961),
    [anon_sym_return] = ACTIONS(961),
    [anon_sym_try] = ACTIONS(961),
    [anon_sym_throw] = ACTIONS(961),
    [anon_sym_for] = ACTIONS(961),
    [anon_sym_while] = ACTIONS(961),
    [anon_sym_break] = ACTIONS(961),
    [anon_sym_continue] = ACTIONS(961),
    [anon_sym_QMARK_DOT] = ACTIONS(963),
    [anon_sym_BQUOTE] = ACTIONS(963),
    [anon_sym_DOLLARr] = ACTIONS(961),
    [anon_sym_PLUS_PLUS] = ACTIONS(963),
    [anon_sym_DASH_DASH] = ACTIONS(963),
    [anon_sym_new] = ACTIONS(961),
  },
  [STATE(356)] = {
    [sym_comment] = STATE(356),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_else] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(357)] = {
    [sym_comment] = STATE(357),
    [sym_argument_list] = STATE(425),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(832),
    [anon_sym_LBRACE] = ACTIONS(834),
    [anon_sym_RBRACE] = ACTIONS(834),
    [anon_sym_STAR] = ACTIONS(832),
    [anon_sym_as] = ACTIONS(832),
    [anon_sym_SEMI] = ACTIONS(834),
    [anon_sym_LPAREN] = ACTIONS(834),
    [anon_sym_DOT] = ACTIONS(834),
    [sym_identifier] = ACTIONS(832),
    [anon_sym_DQUOTE] = ACTIONS(834),
    [anon_sym_SQUOTE] = ACTIONS(834),
    [anon_sym_DOLLAR] = ACTIONS(832),
    [sym_numeric_literal] = ACTIONS(834),
    [anon_sym_true] = ACTIONS(832),
    [anon_sym_false] = ACTIONS(832),
    [anon_sym_null] = ACTIONS(832),
    [anon_sym_PIPE_PIPE] = ACTIONS(834),
    [anon_sym_AMP_AMP] = ACTIONS(834),
    [anon_sym_PIPE] = ACTIONS(832),
    [anon_sym_CARET] = ACTIONS(834),
    [anon_sym_AMP] = ACTIONS(832),
    [anon_sym_EQ_EQ] = ACTIONS(832),
    [anon_sym_BANG_EQ] = ACTIONS(832),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(834),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(834),
    [anon_sym_LT] = ACTIONS(832),
    [anon_sym_GT] = ACTIONS(832),
    [anon_sym_LT_EQ] = ACTIONS(834),
    [anon_sym_GT_EQ] = ACTIONS(834),
    [anon_sym_instanceof] = ACTIONS(832),
    [anon_sym_in] = ACTIONS(832),
    [anon_sym_LT_LT] = ACTIONS(834),
    [anon_sym_GT_GT] = ACTIONS(832),
    [anon_sym_GT_GT_GT] = ACTIONS(834),
    [anon_sym_PLUS] = ACTIONS(832),
    [anon_sym_DASH] = ACTIONS(832),
    [anon_sym_PERCENT] = ACTIONS(834),
    [anon_sym_STAR_STAR] = ACTIONS(834),
    [anon_sym_BANG] = ACTIONS(832),
    [anon_sym_TILDE] = ACTIONS(834),
    [anon_sym_typeof] = ACTIONS(832),
    [anon_sym_void] = ACTIONS(832),
    [anon_sym_delete] = ACTIONS(832),
    [anon_sym_QMARK] = ACTIONS(832),
    [anon_sym_await] = ACTIONS(832),
    [anon_sym_LBRACK] = ACTIONS(834),
    [anon_sym_if] = ACTIONS(832),
    [anon_sym_async] = ACTIONS(832),
    [anon_sym_var] = ACTIONS(832),
    [anon_sym_let] = ACTIONS(832),
    [anon_sym_const] = ACTIONS(832),
    [anon_sym_return] = ACTIONS(832),
    [anon_sym_try] = ACTIONS(832),
    [anon_sym_throw] = ACTIONS(832),
    [anon_sym_for] = ACTIONS(832),
    [anon_sym_while] = ACTIONS(832),
    [anon_sym_break] = ACTIONS(832),
    [anon_sym_continue] = ACTIONS(832),
    [anon_sym_QMARK_DOT] = ACTIONS(834),
    [anon_sym_BQUOTE] = ACTIONS(834),
    [anon_sym_DOLLARr] = ACTIONS(832),
    [anon_sym_PLUS_PLUS] = ACTIONS(834),
    [anon_sym_DASH_DASH] = ACTIONS(834),
    [anon_sym_new] = ACTIONS(832),
  },
  [STATE(358)] = {
    [sym_comment] = STATE(358),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_RBRACE] = ACTIONS(838),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_as] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_LPAREN] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(838),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_DQUOTE] = ACTIONS(838),
    [anon_sym_SQUOTE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(836),
    [sym_numeric_literal] = ACTIONS(838),
    [anon_sym_true] = ACTIONS(836),
    [anon_sym_false] = ACTIONS(836),
    [anon_sym_null] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(838),
    [anon_sym_AMP_AMP] = ACTIONS(838),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(838),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(836),
    [anon_sym_BANG_EQ] = ACTIONS(836),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(838),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(838),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_instanceof] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(838),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_GT_GT_GT] = ACTIONS(838),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(838),
    [anon_sym_STAR_STAR] = ACTIONS(838),
    [anon_sym_BANG] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(836),
    [anon_sym_void] = ACTIONS(836),
    [anon_sym_delete] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(836),
    [anon_sym_await] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_else] = ACTIONS(836),
    [anon_sym_async] = ACTIONS(836),
    [anon_sym_var] = ACTIONS(836),
    [anon_sym_let] = ACTIONS(836),
    [anon_sym_const] = ACTIONS(836),
    [anon_sym_return] = ACTIONS(836),
    [anon_sym_try] = ACTIONS(836),
    [anon_sym_throw] = ACTIONS(836),
    [anon_sym_for] = ACTIONS(836),
    [anon_sym_while] = ACTIONS(836),
    [anon_sym_break] = ACTIONS(836),
    [anon_sym_continue] = ACTIONS(836),
    [anon_sym_QMARK_DOT] = ACTIONS(838),
    [anon_sym_BQUOTE] = ACTIONS(838),
    [anon_sym_DOLLARr] = ACTIONS(836),
    [anon_sym_PLUS_PLUS] = ACTIONS(838),
    [anon_sym_DASH_DASH] = ACTIONS(838),
    [anon_sym_new] = ACTIONS(836),
  },
  [STATE(359)] = {
    [sym_comment] = STATE(359),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(754),
    [anon_sym_LBRACE] = ACTIONS(749),
    [anon_sym_RBRACE] = ACTIONS(749),
    [anon_sym_STAR] = ACTIONS(754),
    [anon_sym_as] = ACTIONS(754),
    [anon_sym_SEMI] = ACTIONS(749),
    [anon_sym_LPAREN] = ACTIONS(749),
    [anon_sym_DOT] = ACTIONS(749),
    [sym_identifier] = ACTIONS(754),
    [anon_sym_DQUOTE] = ACTIONS(749),
    [anon_sym_SQUOTE] = ACTIONS(749),
    [anon_sym_DOLLAR] = ACTIONS(754),
    [sym_numeric_literal] = ACTIONS(749),
    [anon_sym_true] = ACTIONS(754),
    [anon_sym_false] = ACTIONS(754),
    [anon_sym_null] = ACTIONS(754),
    [anon_sym_PIPE_PIPE] = ACTIONS(749),
    [anon_sym_AMP_AMP] = ACTIONS(749),
    [anon_sym_PIPE] = ACTIONS(754),
    [anon_sym_CARET] = ACTIONS(749),
    [anon_sym_AMP] = ACTIONS(754),
    [anon_sym_EQ_EQ] = ACTIONS(754),
    [anon_sym_BANG_EQ] = ACTIONS(754),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(749),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(749),
    [anon_sym_LT] = ACTIONS(754),
    [anon_sym_GT] = ACTIONS(754),
    [anon_sym_LT_EQ] = ACTIONS(749),
    [anon_sym_GT_EQ] = ACTIONS(749),
    [anon_sym_instanceof] = ACTIONS(754),
    [anon_sym_in] = ACTIONS(754),
    [anon_sym_LT_LT] = ACTIONS(749),
    [anon_sym_GT_GT] = ACTIONS(754),
    [anon_sym_GT_GT_GT] = ACTIONS(749),
    [anon_sym_PLUS] = ACTIONS(754),
    [anon_sym_DASH] = ACTIONS(754),
    [anon_sym_PERCENT] = ACTIONS(749),
    [anon_sym_STAR_STAR] = ACTIONS(749),
    [anon_sym_BANG] = ACTIONS(754),
    [anon_sym_TILDE] = ACTIONS(749),
    [anon_sym_typeof] = ACTIONS(754),
    [anon_sym_void] = ACTIONS(754),
    [anon_sym_delete] = ACTIONS(754),
    [anon_sym_QMARK] = ACTIONS(754),
    [anon_sym_await] = ACTIONS(754),
    [anon_sym_LBRACK] = ACTIONS(749),
    [anon_sym_if] = ACTIONS(754),
    [anon_sym_else] = ACTIONS(754),
    [anon_sym_async] = ACTIONS(754),
    [anon_sym_var] = ACTIONS(754),
    [anon_sym_let] = ACTIONS(754),
    [anon_sym_const] = ACTIONS(754),
    [anon_sym_return] = ACTIONS(754),
    [anon_sym_try] = ACTIONS(754),
    [anon_sym_throw] = ACTIONS(754),
    [anon_sym_for] = ACTIONS(754),
    [anon_sym_while] = ACTIONS(754),
    [anon_sym_break] = ACTIONS(754),
    [anon_sym_continue] = ACTIONS(754),
    [anon_sym_QMARK_DOT] = ACTIONS(749),
    [anon_sym_BQUOTE] = ACTIONS(749),
    [anon_sym_DOLLARr] = ACTIONS(754),
    [anon_sym_PLUS_PLUS] = ACTIONS(749),
    [anon_sym_DASH_DASH] = ACTIONS(749),
    [anon_sym_new] = ACTIONS(754),
  },
  [STATE(360)] = {
    [sym_comment] = STATE(360),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(965),
    [anon_sym_LBRACE] = ACTIONS(967),
    [anon_sym_RBRACE] = ACTIONS(967),
    [anon_sym_STAR] = ACTIONS(965),
    [anon_sym_as] = ACTIONS(965),
    [anon_sym_SEMI] = ACTIONS(967),
    [anon_sym_LPAREN] = ACTIONS(967),
    [anon_sym_COLON] = ACTIONS(1393),
    [anon_sym_DOT] = ACTIONS(967),
    [sym_identifier] = ACTIONS(965),
    [anon_sym_DQUOTE] = ACTIONS(967),
    [anon_sym_SQUOTE] = ACTIONS(967),
    [anon_sym_DOLLAR] = ACTIONS(965),
    [sym_numeric_literal] = ACTIONS(967),
    [anon_sym_true] = ACTIONS(965),
    [anon_sym_false] = ACTIONS(965),
    [anon_sym_null] = ACTIONS(965),
    [anon_sym_PIPE_PIPE] = ACTIONS(967),
    [anon_sym_AMP_AMP] = ACTIONS(967),
    [anon_sym_PIPE] = ACTIONS(965),
    [anon_sym_CARET] = ACTIONS(967),
    [anon_sym_AMP] = ACTIONS(965),
    [anon_sym_EQ_EQ] = ACTIONS(965),
    [anon_sym_BANG_EQ] = ACTIONS(965),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(967),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(967),
    [anon_sym_LT] = ACTIONS(965),
    [anon_sym_GT] = ACTIONS(965),
    [anon_sym_LT_EQ] = ACTIONS(967),
    [anon_sym_GT_EQ] = ACTIONS(967),
    [anon_sym_instanceof] = ACTIONS(965),
    [anon_sym_in] = ACTIONS(965),
    [anon_sym_LT_LT] = ACTIONS(967),
    [anon_sym_GT_GT] = ACTIONS(965),
    [anon_sym_GT_GT_GT] = ACTIONS(967),
    [anon_sym_PLUS] = ACTIONS(965),
    [anon_sym_DASH] = ACTIONS(965),
    [anon_sym_PERCENT] = ACTIONS(967),
    [anon_sym_STAR_STAR] = ACTIONS(967),
    [anon_sym_BANG] = ACTIONS(965),
    [anon_sym_TILDE] = ACTIONS(967),
    [anon_sym_typeof] = ACTIONS(965),
    [anon_sym_void] = ACTIONS(965),
    [anon_sym_delete] = ACTIONS(965),
    [anon_sym_QMARK] = ACTIONS(965),
    [anon_sym_await] = ACTIONS(965),
    [anon_sym_LBRACK] = ACTIONS(967),
    [anon_sym_if] = ACTIONS(965),
    [anon_sym_async] = ACTIONS(965),
    [anon_sym_var] = ACTIONS(965),
    [anon_sym_let] = ACTIONS(965),
    [anon_sym_const] = ACTIONS(965),
    [anon_sym_return] = ACTIONS(965),
    [anon_sym_try] = ACTIONS(965),
    [anon_sym_throw] = ACTIONS(965),
    [anon_sym_for] = ACTIONS(965),
    [anon_sym_while] = ACTIONS(965),
    [anon_sym_break] = ACTIONS(965),
    [anon_sym_continue] = ACTIONS(965),
    [anon_sym_QMARK_DOT] = ACTIONS(967),
    [anon_sym_BQUOTE] = ACTIONS(967),
    [anon_sym_DOLLARr] = ACTIONS(965),
    [anon_sym_PLUS_PLUS] = ACTIONS(967),
    [anon_sym_DASH_DASH] = ACTIONS(967),
    [anon_sym_new] = ACTIONS(965),
  },
  [STATE(361)] = {
    [sym_comment] = STATE(361),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(758),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_else] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_var] = ACTIONS(756),
    [anon_sym_let] = ACTIONS(756),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_return] = ACTIONS(756),
    [anon_sym_try] = ACTIONS(756),
    [anon_sym_throw] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_continue] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(362)] = {
    [sym_comment] = STATE(362),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(805),
    [anon_sym_LBRACE] = ACTIONS(807),
    [anon_sym_RBRACE] = ACTIONS(807),
    [anon_sym_STAR] = ACTIONS(805),
    [anon_sym_as] = ACTIONS(805),
    [anon_sym_SEMI] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(807),
    [anon_sym_DOT] = ACTIONS(807),
    [sym_identifier] = ACTIONS(805),
    [anon_sym_DQUOTE] = ACTIONS(807),
    [anon_sym_SQUOTE] = ACTIONS(807),
    [anon_sym_DOLLAR] = ACTIONS(805),
    [sym_numeric_literal] = ACTIONS(807),
    [anon_sym_true] = ACTIONS(805),
    [anon_sym_false] = ACTIONS(805),
    [anon_sym_null] = ACTIONS(805),
    [anon_sym_PIPE_PIPE] = ACTIONS(807),
    [anon_sym_AMP_AMP] = ACTIONS(807),
    [anon_sym_PIPE] = ACTIONS(805),
    [anon_sym_CARET] = ACTIONS(807),
    [anon_sym_AMP] = ACTIONS(805),
    [anon_sym_EQ_EQ] = ACTIONS(805),
    [anon_sym_BANG_EQ] = ACTIONS(805),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(807),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(807),
    [anon_sym_LT] = ACTIONS(805),
    [anon_sym_GT] = ACTIONS(805),
    [anon_sym_LT_EQ] = ACTIONS(807),
    [anon_sym_GT_EQ] = ACTIONS(807),
    [anon_sym_instanceof] = ACTIONS(805),
    [anon_sym_in] = ACTIONS(805),
    [anon_sym_LT_LT] = ACTIONS(807),
    [anon_sym_GT_GT] = ACTIONS(805),
    [anon_sym_GT_GT_GT] = ACTIONS(807),
    [anon_sym_PLUS] = ACTIONS(805),
    [anon_sym_DASH] = ACTIONS(805),
    [anon_sym_PERCENT] = ACTIONS(807),
    [anon_sym_STAR_STAR] = ACTIONS(807),
    [anon_sym_BANG] = ACTIONS(805),
    [anon_sym_TILDE] = ACTIONS(807),
    [anon_sym_typeof] = ACTIONS(805),
    [anon_sym_void] = ACTIONS(805),
    [anon_sym_delete] = ACTIONS(805),
    [anon_sym_QMARK] = ACTIONS(805),
    [anon_sym_await] = ACTIONS(805),
    [anon_sym_LBRACK] = ACTIONS(807),
    [anon_sym_if] = ACTIONS(805),
    [anon_sym_else] = ACTIONS(805),
    [anon_sym_async] = ACTIONS(805),
    [anon_sym_var] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(805),
    [anon_sym_const] = ACTIONS(805),
    [anon_sym_return] = ACTIONS(805),
    [anon_sym_try] = ACTIONS(805),
    [anon_sym_throw] = ACTIONS(805),
    [anon_sym_for] = ACTIONS(805),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_break] = ACTIONS(805),
    [anon_sym_continue] = ACTIONS(805),
    [anon_sym_QMARK_DOT] = ACTIONS(807),
    [anon_sym_BQUOTE] = ACTIONS(807),
    [anon_sym_DOLLARr] = ACTIONS(805),
    [anon_sym_PLUS_PLUS] = ACTIONS(807),
    [anon_sym_DASH_DASH] = ACTIONS(807),
    [anon_sym_new] = ACTIONS(805),
  },
  [STATE(363)] = {
    [sym_comment] = STATE(363),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(809),
    [anon_sym_LBRACE] = ACTIONS(811),
    [anon_sym_RBRACE] = ACTIONS(811),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_as] = ACTIONS(809),
    [anon_sym_SEMI] = ACTIONS(811),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_DOT] = ACTIONS(811),
    [sym_identifier] = ACTIONS(809),
    [anon_sym_DQUOTE] = ACTIONS(811),
    [anon_sym_SQUOTE] = ACTIONS(811),
    [anon_sym_DOLLAR] = ACTIONS(809),
    [sym_numeric_literal] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(809),
    [anon_sym_false] = ACTIONS(809),
    [anon_sym_null] = ACTIONS(809),
    [anon_sym_PIPE_PIPE] = ACTIONS(811),
    [anon_sym_AMP_AMP] = ACTIONS(811),
    [anon_sym_PIPE] = ACTIONS(809),
    [anon_sym_CARET] = ACTIONS(811),
    [anon_sym_AMP] = ACTIONS(809),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(811),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(811),
    [anon_sym_LT] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(811),
    [anon_sym_GT_EQ] = ACTIONS(811),
    [anon_sym_instanceof] = ACTIONS(809),
    [anon_sym_in] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(811),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_GT_GT_GT] = ACTIONS(811),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(809),
    [anon_sym_PERCENT] = ACTIONS(811),
    [anon_sym_STAR_STAR] = ACTIONS(811),
    [anon_sym_BANG] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(811),
    [anon_sym_typeof] = ACTIONS(809),
    [anon_sym_void] = ACTIONS(809),
    [anon_sym_delete] = ACTIONS(809),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_await] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_if] = ACTIONS(809),
    [anon_sym_else] = ACTIONS(809),
    [anon_sym_async] = ACTIONS(809),
    [anon_sym_var] = ACTIONS(809),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_const] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(809),
    [anon_sym_try] = ACTIONS(809),
    [anon_sym_throw] = ACTIONS(809),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_while] = ACTIONS(809),
    [anon_sym_break] = ACTIONS(809),
    [anon_sym_continue] = ACTIONS(809),
    [anon_sym_QMARK_DOT] = ACTIONS(811),
    [anon_sym_BQUOTE] = ACTIONS(811),
    [anon_sym_DOLLARr] = ACTIONS(809),
    [anon_sym_PLUS_PLUS] = ACTIONS(811),
    [anon_sym_DASH_DASH] = ACTIONS(811),
    [anon_sym_new] = ACTIONS(809),
  },
  [STATE(364)] = {
    [sym_comment] = STATE(364),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(843),
    [anon_sym_LBRACE] = ACTIONS(845),
    [anon_sym_RBRACE] = ACTIONS(845),
    [anon_sym_STAR] = ACTIONS(843),
    [anon_sym_as] = ACTIONS(843),
    [anon_sym_SEMI] = ACTIONS(845),
    [anon_sym_LPAREN] = ACTIONS(845),
    [anon_sym_DOT] = ACTIONS(845),
    [sym_identifier] = ACTIONS(843),
    [anon_sym_DQUOTE] = ACTIONS(845),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DOLLAR] = ACTIONS(843),
    [sym_numeric_literal] = ACTIONS(845),
    [anon_sym_true] = ACTIONS(843),
    [anon_sym_false] = ACTIONS(843),
    [anon_sym_null] = ACTIONS(843),
    [anon_sym_PIPE_PIPE] = ACTIONS(845),
    [anon_sym_AMP_AMP] = ACTIONS(845),
    [anon_sym_PIPE] = ACTIONS(843),
    [anon_sym_CARET] = ACTIONS(845),
    [anon_sym_AMP] = ACTIONS(843),
    [anon_sym_EQ_EQ] = ACTIONS(843),
    [anon_sym_BANG_EQ] = ACTIONS(843),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(845),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(845),
    [anon_sym_LT] = ACTIONS(843),
    [anon_sym_GT] = ACTIONS(843),
    [anon_sym_LT_EQ] = ACTIONS(845),
    [anon_sym_GT_EQ] = ACTIONS(845),
    [anon_sym_instanceof] = ACTIONS(843),
    [anon_sym_in] = ACTIONS(843),
    [anon_sym_LT_LT] = ACTIONS(845),
    [anon_sym_GT_GT] = ACTIONS(843),
    [anon_sym_GT_GT_GT] = ACTIONS(845),
    [anon_sym_PLUS] = ACTIONS(843),
    [anon_sym_DASH] = ACTIONS(843),
    [anon_sym_PERCENT] = ACTIONS(845),
    [anon_sym_STAR_STAR] = ACTIONS(845),
    [anon_sym_BANG] = ACTIONS(843),
    [anon_sym_TILDE] = ACTIONS(845),
    [anon_sym_typeof] = ACTIONS(843),
    [anon_sym_void] = ACTIONS(843),
    [anon_sym_delete] = ACTIONS(843),
    [anon_sym_QMARK] = ACTIONS(843),
    [anon_sym_await] = ACTIONS(843),
    [anon_sym_LBRACK] = ACTIONS(845),
    [anon_sym_if] = ACTIONS(843),
    [anon_sym_else] = ACTIONS(843),
    [anon_sym_async] = ACTIONS(843),
    [anon_sym_var] = ACTIONS(843),
    [anon_sym_let] = ACTIONS(843),
    [anon_sym_const] = ACTIONS(843),
    [anon_sym_return] = ACTIONS(843),
    [anon_sym_try] = ACTIONS(843),
    [anon_sym_throw] = ACTIONS(843),
    [anon_sym_for] = ACTIONS(843),
    [anon_sym_while] = ACTIONS(843),
    [anon_sym_break] = ACTIONS(843),
    [anon_sym_continue] = ACTIONS(843),
    [anon_sym_QMARK_DOT] = ACTIONS(845),
    [anon_sym_BQUOTE] = ACTIONS(845),
    [anon_sym_DOLLARr] = ACTIONS(843),
    [anon_sym_PLUS_PLUS] = ACTIONS(845),
    [anon_sym_DASH_DASH] = ACTIONS(845),
    [anon_sym_new] = ACTIONS(843),
  },
  [STATE(365)] = {
    [sym_comment] = STATE(365),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(847),
    [anon_sym_LBRACE] = ACTIONS(849),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_STAR] = ACTIONS(847),
    [anon_sym_as] = ACTIONS(847),
    [anon_sym_SEMI] = ACTIONS(849),
    [anon_sym_LPAREN] = ACTIONS(849),
    [anon_sym_DOT] = ACTIONS(849),
    [sym_identifier] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [anon_sym_SQUOTE] = ACTIONS(849),
    [anon_sym_DOLLAR] = ACTIONS(847),
    [sym_numeric_literal] = ACTIONS(849),
    [anon_sym_true] = ACTIONS(847),
    [anon_sym_false] = ACTIONS(847),
    [anon_sym_null] = ACTIONS(847),
    [anon_sym_PIPE_PIPE] = ACTIONS(849),
    [anon_sym_AMP_AMP] = ACTIONS(849),
    [anon_sym_PIPE] = ACTIONS(847),
    [anon_sym_CARET] = ACTIONS(849),
    [anon_sym_AMP] = ACTIONS(847),
    [anon_sym_EQ_EQ] = ACTIONS(847),
    [anon_sym_BANG_EQ] = ACTIONS(847),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(849),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(849),
    [anon_sym_LT] = ACTIONS(847),
    [anon_sym_GT] = ACTIONS(847),
    [anon_sym_LT_EQ] = ACTIONS(849),
    [anon_sym_GT_EQ] = ACTIONS(849),
    [anon_sym_instanceof] = ACTIONS(847),
    [anon_sym_in] = ACTIONS(847),
    [anon_sym_LT_LT] = ACTIONS(849),
    [anon_sym_GT_GT] = ACTIONS(847),
    [anon_sym_GT_GT_GT] = ACTIONS(849),
    [anon_sym_PLUS] = ACTIONS(847),
    [anon_sym_DASH] = ACTIONS(847),
    [anon_sym_PERCENT] = ACTIONS(849),
    [anon_sym_STAR_STAR] = ACTIONS(849),
    [anon_sym_BANG] = ACTIONS(847),
    [anon_sym_TILDE] = ACTIONS(849),
    [anon_sym_typeof] = ACTIONS(847),
    [anon_sym_void] = ACTIONS(847),
    [anon_sym_delete] = ACTIONS(847),
    [anon_sym_QMARK] = ACTIONS(847),
    [anon_sym_await] = ACTIONS(847),
    [anon_sym_LBRACK] = ACTIONS(849),
    [anon_sym_if] = ACTIONS(847),
    [anon_sym_else] = ACTIONS(847),
    [anon_sym_async] = ACTIONS(847),
    [anon_sym_var] = ACTIONS(847),
    [anon_sym_let] = ACTIONS(847),
    [anon_sym_const] = ACTIONS(847),
    [anon_sym_return] = ACTIONS(847),
    [anon_sym_try] = ACTIONS(847),
    [anon_sym_throw] = ACTIONS(847),
    [anon_sym_for] = ACTIONS(847),
    [anon_sym_while] = ACTIONS(847),
    [anon_sym_break] = ACTIONS(847),
    [anon_sym_continue] = ACTIONS(847),
    [anon_sym_QMARK_DOT] = ACTIONS(849),
    [anon_sym_BQUOTE] = ACTIONS(849),
    [anon_sym_DOLLARr] = ACTIONS(847),
    [anon_sym_PLUS_PLUS] = ACTIONS(849),
    [anon_sym_DASH_DASH] = ACTIONS(849),
    [anon_sym_new] = ACTIONS(847),
  },
  [STATE(366)] = {
    [sym_comment] = STATE(366),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(851),
    [anon_sym_LBRACE] = ACTIONS(853),
    [anon_sym_RBRACE] = ACTIONS(853),
    [anon_sym_STAR] = ACTIONS(851),
    [anon_sym_as] = ACTIONS(851),
    [anon_sym_SEMI] = ACTIONS(853),
    [anon_sym_LPAREN] = ACTIONS(853),
    [anon_sym_DOT] = ACTIONS(853),
    [sym_identifier] = ACTIONS(851),
    [anon_sym_DQUOTE] = ACTIONS(853),
    [anon_sym_SQUOTE] = ACTIONS(853),
    [anon_sym_DOLLAR] = ACTIONS(851),
    [sym_numeric_literal] = ACTIONS(853),
    [anon_sym_true] = ACTIONS(851),
    [anon_sym_false] = ACTIONS(851),
    [anon_sym_null] = ACTIONS(851),
    [anon_sym_PIPE_PIPE] = ACTIONS(853),
    [anon_sym_AMP_AMP] = ACTIONS(853),
    [anon_sym_PIPE] = ACTIONS(851),
    [anon_sym_CARET] = ACTIONS(853),
    [anon_sym_AMP] = ACTIONS(851),
    [anon_sym_EQ_EQ] = ACTIONS(851),
    [anon_sym_BANG_EQ] = ACTIONS(851),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(853),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(853),
    [anon_sym_LT] = ACTIONS(851),
    [anon_sym_GT] = ACTIONS(851),
    [anon_sym_LT_EQ] = ACTIONS(853),
    [anon_sym_GT_EQ] = ACTIONS(853),
    [anon_sym_instanceof] = ACTIONS(851),
    [anon_sym_in] = ACTIONS(851),
    [anon_sym_LT_LT] = ACTIONS(853),
    [anon_sym_GT_GT] = ACTIONS(851),
    [anon_sym_GT_GT_GT] = ACTIONS(853),
    [anon_sym_PLUS] = ACTIONS(851),
    [anon_sym_DASH] = ACTIONS(851),
    [anon_sym_PERCENT] = ACTIONS(853),
    [anon_sym_STAR_STAR] = ACTIONS(853),
    [anon_sym_BANG] = ACTIONS(851),
    [anon_sym_TILDE] = ACTIONS(853),
    [anon_sym_typeof] = ACTIONS(851),
    [anon_sym_void] = ACTIONS(851),
    [anon_sym_delete] = ACTIONS(851),
    [anon_sym_QMARK] = ACTIONS(851),
    [anon_sym_await] = ACTIONS(851),
    [anon_sym_LBRACK] = ACTIONS(853),
    [anon_sym_if] = ACTIONS(851),
    [anon_sym_else] = ACTIONS(851),
    [anon_sym_async] = ACTIONS(851),
    [anon_sym_var] = ACTIONS(851),
    [anon_sym_let] = ACTIONS(851),
    [anon_sym_const] = ACTIONS(851),
    [anon_sym_return] = ACTIONS(851),
    [anon_sym_try] = ACTIONS(851),
    [anon_sym_throw] = ACTIONS(851),
    [anon_sym_for] = ACTIONS(851),
    [anon_sym_while] = ACTIONS(851),
    [anon_sym_break] = ACTIONS(851),
    [anon_sym_continue] = ACTIONS(851),
    [anon_sym_QMARK_DOT] = ACTIONS(853),
    [anon_sym_BQUOTE] = ACTIONS(853),
    [anon_sym_DOLLARr] = ACTIONS(851),
    [anon_sym_PLUS_PLUS] = ACTIONS(853),
    [anon_sym_DASH_DASH] = ACTIONS(853),
    [anon_sym_new] = ACTIONS(851),
  },
  [STATE(367)] = {
    [sym_comment] = STATE(367),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_RBRACE] = ACTIONS(838),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_as] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_LPAREN] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(838),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_DQUOTE] = ACTIONS(838),
    [anon_sym_SQUOTE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(836),
    [sym_numeric_literal] = ACTIONS(838),
    [anon_sym_true] = ACTIONS(836),
    [anon_sym_false] = ACTIONS(836),
    [anon_sym_null] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(838),
    [anon_sym_AMP_AMP] = ACTIONS(838),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(838),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(836),
    [anon_sym_BANG_EQ] = ACTIONS(836),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(838),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(838),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_instanceof] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(838),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_GT_GT_GT] = ACTIONS(838),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(838),
    [anon_sym_STAR_STAR] = ACTIONS(838),
    [anon_sym_BANG] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(836),
    [anon_sym_void] = ACTIONS(836),
    [anon_sym_delete] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(836),
    [anon_sym_await] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [anon_sym_extends] = ACTIONS(836),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_async] = ACTIONS(836),
    [anon_sym_var] = ACTIONS(836),
    [anon_sym_let] = ACTIONS(836),
    [anon_sym_const] = ACTIONS(836),
    [anon_sym_return] = ACTIONS(836),
    [anon_sym_try] = ACTIONS(836),
    [anon_sym_throw] = ACTIONS(836),
    [anon_sym_for] = ACTIONS(836),
    [anon_sym_while] = ACTIONS(836),
    [anon_sym_break] = ACTIONS(836),
    [anon_sym_continue] = ACTIONS(836),
    [anon_sym_QMARK_DOT] = ACTIONS(838),
    [anon_sym_BQUOTE] = ACTIONS(838),
    [anon_sym_DOLLARr] = ACTIONS(836),
    [anon_sym_PLUS_PLUS] = ACTIONS(838),
    [anon_sym_DASH_DASH] = ACTIONS(838),
    [anon_sym_new] = ACTIONS(836),
  },
  [STATE(368)] = {
    [sym_comment] = STATE(368),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(754),
    [anon_sym_LBRACE] = ACTIONS(749),
    [anon_sym_RBRACE] = ACTIONS(749),
    [anon_sym_STAR] = ACTIONS(754),
    [anon_sym_as] = ACTIONS(754),
    [anon_sym_SEMI] = ACTIONS(749),
    [anon_sym_LPAREN] = ACTIONS(749),
    [anon_sym_DOT] = ACTIONS(749),
    [sym_identifier] = ACTIONS(754),
    [anon_sym_DQUOTE] = ACTIONS(749),
    [anon_sym_SQUOTE] = ACTIONS(749),
    [anon_sym_DOLLAR] = ACTIONS(754),
    [sym_numeric_literal] = ACTIONS(749),
    [anon_sym_true] = ACTIONS(754),
    [anon_sym_false] = ACTIONS(754),
    [anon_sym_null] = ACTIONS(754),
    [anon_sym_PIPE_PIPE] = ACTIONS(749),
    [anon_sym_AMP_AMP] = ACTIONS(749),
    [anon_sym_PIPE] = ACTIONS(754),
    [anon_sym_CARET] = ACTIONS(749),
    [anon_sym_AMP] = ACTIONS(754),
    [anon_sym_EQ_EQ] = ACTIONS(754),
    [anon_sym_BANG_EQ] = ACTIONS(754),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(749),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(749),
    [anon_sym_LT] = ACTIONS(754),
    [anon_sym_GT] = ACTIONS(754),
    [anon_sym_LT_EQ] = ACTIONS(749),
    [anon_sym_GT_EQ] = ACTIONS(749),
    [anon_sym_instanceof] = ACTIONS(754),
    [anon_sym_in] = ACTIONS(754),
    [anon_sym_LT_LT] = ACTIONS(749),
    [anon_sym_GT_GT] = ACTIONS(754),
    [anon_sym_GT_GT_GT] = ACTIONS(749),
    [anon_sym_PLUS] = ACTIONS(754),
    [anon_sym_DASH] = ACTIONS(754),
    [anon_sym_PERCENT] = ACTIONS(749),
    [anon_sym_STAR_STAR] = ACTIONS(749),
    [anon_sym_BANG] = ACTIONS(754),
    [anon_sym_TILDE] = ACTIONS(749),
    [anon_sym_typeof] = ACTIONS(754),
    [anon_sym_void] = ACTIONS(754),
    [anon_sym_delete] = ACTIONS(754),
    [anon_sym_QMARK] = ACTIONS(754),
    [anon_sym_await] = ACTIONS(754),
    [anon_sym_LBRACK] = ACTIONS(749),
    [anon_sym_extends] = ACTIONS(754),
    [anon_sym_if] = ACTIONS(754),
    [anon_sym_async] = ACTIONS(754),
    [anon_sym_var] = ACTIONS(754),
    [anon_sym_let] = ACTIONS(754),
    [anon_sym_const] = ACTIONS(754),
    [anon_sym_return] = ACTIONS(754),
    [anon_sym_try] = ACTIONS(754),
    [anon_sym_throw] = ACTIONS(754),
    [anon_sym_for] = ACTIONS(754),
    [anon_sym_while] = ACTIONS(754),
    [anon_sym_break] = ACTIONS(754),
    [anon_sym_continue] = ACTIONS(754),
    [anon_sym_QMARK_DOT] = ACTIONS(749),
    [anon_sym_BQUOTE] = ACTIONS(749),
    [anon_sym_DOLLARr] = ACTIONS(754),
    [anon_sym_PLUS_PLUS] = ACTIONS(749),
    [anon_sym_DASH_DASH] = ACTIONS(749),
    [anon_sym_new] = ACTIONS(754),
  },
  [STATE(369)] = {
    [sym_comment] = STATE(369),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(780),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_else] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_var] = ACTIONS(778),
    [anon_sym_let] = ACTIONS(778),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_return] = ACTIONS(778),
    [anon_sym_try] = ACTIONS(778),
    [anon_sym_throw] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_break] = ACTIONS(778),
    [anon_sym_continue] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(370)] = {
    [sym_comment] = STATE(370),
    [sym_modifier_chain_expression] = STATE(445),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(824),
    [anon_sym_LBRACE] = ACTIONS(826),
    [anon_sym_RBRACE] = ACTIONS(826),
    [anon_sym_STAR] = ACTIONS(824),
    [anon_sym_as] = ACTIONS(824),
    [anon_sym_SEMI] = ACTIONS(826),
    [anon_sym_LPAREN] = ACTIONS(826),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(824),
    [anon_sym_DQUOTE] = ACTIONS(826),
    [anon_sym_SQUOTE] = ACTIONS(826),
    [anon_sym_DOLLAR] = ACTIONS(824),
    [sym_numeric_literal] = ACTIONS(826),
    [anon_sym_true] = ACTIONS(824),
    [anon_sym_false] = ACTIONS(824),
    [anon_sym_null] = ACTIONS(824),
    [anon_sym_PIPE_PIPE] = ACTIONS(826),
    [anon_sym_AMP_AMP] = ACTIONS(826),
    [anon_sym_PIPE] = ACTIONS(824),
    [anon_sym_CARET] = ACTIONS(826),
    [anon_sym_AMP] = ACTIONS(824),
    [anon_sym_EQ_EQ] = ACTIONS(824),
    [anon_sym_BANG_EQ] = ACTIONS(824),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(826),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(826),
    [anon_sym_LT] = ACTIONS(824),
    [anon_sym_GT] = ACTIONS(824),
    [anon_sym_LT_EQ] = ACTIONS(826),
    [anon_sym_GT_EQ] = ACTIONS(826),
    [anon_sym_instanceof] = ACTIONS(824),
    [anon_sym_in] = ACTIONS(824),
    [anon_sym_LT_LT] = ACTIONS(826),
    [anon_sym_GT_GT] = ACTIONS(824),
    [anon_sym_GT_GT_GT] = ACTIONS(826),
    [anon_sym_PLUS] = ACTIONS(824),
    [anon_sym_DASH] = ACTIONS(824),
    [anon_sym_PERCENT] = ACTIONS(826),
    [anon_sym_STAR_STAR] = ACTIONS(826),
    [anon_sym_BANG] = ACTIONS(824),
    [anon_sym_TILDE] = ACTIONS(826),
    [anon_sym_typeof] = ACTIONS(824),
    [anon_sym_void] = ACTIONS(824),
    [anon_sym_delete] = ACTIONS(824),
    [anon_sym_QMARK] = ACTIONS(824),
    [anon_sym_await] = ACTIONS(824),
    [anon_sym_LBRACK] = ACTIONS(826),
    [anon_sym_if] = ACTIONS(824),
    [anon_sym_async] = ACTIONS(824),
    [anon_sym_var] = ACTIONS(824),
    [anon_sym_let] = ACTIONS(824),
    [anon_sym_const] = ACTIONS(824),
    [anon_sym_return] = ACTIONS(824),
    [anon_sym_try] = ACTIONS(824),
    [anon_sym_throw] = ACTIONS(824),
    [anon_sym_for] = ACTIONS(824),
    [anon_sym_while] = ACTIONS(824),
    [anon_sym_break] = ACTIONS(824),
    [anon_sym_continue] = ACTIONS(824),
    [anon_sym_QMARK_DOT] = ACTIONS(826),
    [anon_sym_BQUOTE] = ACTIONS(826),
    [anon_sym_DOLLARr] = ACTIONS(824),
    [anon_sym_PLUS_PLUS] = ACTIONS(826),
    [anon_sym_DASH_DASH] = ACTIONS(826),
    [anon_sym_new] = ACTIONS(824),
  },
  [STATE(371)] = {
    [sym_comment] = STATE(371),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(973),
    [anon_sym_LBRACE] = ACTIONS(975),
    [anon_sym_RBRACE] = ACTIONS(975),
    [anon_sym_STAR] = ACTIONS(973),
    [anon_sym_as] = ACTIONS(973),
    [anon_sym_SEMI] = ACTIONS(975),
    [anon_sym_LPAREN] = ACTIONS(975),
    [anon_sym_DOT] = ACTIONS(975),
    [sym_identifier] = ACTIONS(973),
    [anon_sym_DQUOTE] = ACTIONS(975),
    [anon_sym_SQUOTE] = ACTIONS(975),
    [anon_sym_DOLLAR] = ACTIONS(973),
    [sym_numeric_literal] = ACTIONS(975),
    [anon_sym_true] = ACTIONS(973),
    [anon_sym_false] = ACTIONS(973),
    [anon_sym_null] = ACTIONS(973),
    [anon_sym_PIPE_PIPE] = ACTIONS(975),
    [anon_sym_AMP_AMP] = ACTIONS(975),
    [anon_sym_PIPE] = ACTIONS(973),
    [anon_sym_CARET] = ACTIONS(975),
    [anon_sym_AMP] = ACTIONS(973),
    [anon_sym_EQ_EQ] = ACTIONS(973),
    [anon_sym_BANG_EQ] = ACTIONS(973),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(975),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(975),
    [anon_sym_LT] = ACTIONS(973),
    [anon_sym_GT] = ACTIONS(973),
    [anon_sym_LT_EQ] = ACTIONS(975),
    [anon_sym_GT_EQ] = ACTIONS(975),
    [anon_sym_instanceof] = ACTIONS(973),
    [anon_sym_in] = ACTIONS(973),
    [anon_sym_LT_LT] = ACTIONS(975),
    [anon_sym_GT_GT] = ACTIONS(973),
    [anon_sym_GT_GT_GT] = ACTIONS(975),
    [anon_sym_PLUS] = ACTIONS(973),
    [anon_sym_DASH] = ACTIONS(973),
    [anon_sym_PERCENT] = ACTIONS(975),
    [anon_sym_STAR_STAR] = ACTIONS(975),
    [anon_sym_BANG] = ACTIONS(973),
    [anon_sym_TILDE] = ACTIONS(975),
    [anon_sym_typeof] = ACTIONS(973),
    [anon_sym_void] = ACTIONS(973),
    [anon_sym_delete] = ACTIONS(973),
    [anon_sym_QMARK] = ACTIONS(973),
    [anon_sym_await] = ACTIONS(973),
    [anon_sym_LBRACK] = ACTIONS(975),
    [anon_sym_if] = ACTIONS(973),
    [anon_sym_else] = ACTIONS(973),
    [anon_sym_async] = ACTIONS(973),
    [anon_sym_var] = ACTIONS(973),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_const] = ACTIONS(973),
    [anon_sym_return] = ACTIONS(973),
    [anon_sym_try] = ACTIONS(973),
    [anon_sym_throw] = ACTIONS(973),
    [anon_sym_for] = ACTIONS(973),
    [anon_sym_while] = ACTIONS(973),
    [anon_sym_break] = ACTIONS(973),
    [anon_sym_continue] = ACTIONS(973),
    [anon_sym_QMARK_DOT] = ACTIONS(975),
    [anon_sym_BQUOTE] = ACTIONS(975),
    [anon_sym_DOLLARr] = ACTIONS(973),
    [anon_sym_PLUS_PLUS] = ACTIONS(975),
    [anon_sym_DASH_DASH] = ACTIONS(975),
    [anon_sym_new] = ACTIONS(973),
  },
  [STATE(372)] = {
    [sym_comment] = STATE(372),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_DOT] = ACTIONS(37),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(37),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(37),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(37),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(37),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_else] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(373)] = {
    [sym_comment] = STATE(373),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(731),
    [anon_sym_LBRACE] = ACTIONS(733),
    [anon_sym_RBRACE] = ACTIONS(733),
    [anon_sym_STAR] = ACTIONS(731),
    [anon_sym_as] = ACTIONS(731),
    [anon_sym_SEMI] = ACTIONS(733),
    [anon_sym_LPAREN] = ACTIONS(733),
    [anon_sym_DOT] = ACTIONS(733),
    [sym_identifier] = ACTIONS(731),
    [anon_sym_DQUOTE] = ACTIONS(733),
    [anon_sym_SQUOTE] = ACTIONS(733),
    [anon_sym_DOLLAR] = ACTIONS(731),
    [sym_numeric_literal] = ACTIONS(733),
    [anon_sym_true] = ACTIONS(731),
    [anon_sym_false] = ACTIONS(731),
    [anon_sym_null] = ACTIONS(731),
    [anon_sym_PIPE_PIPE] = ACTIONS(733),
    [anon_sym_AMP_AMP] = ACTIONS(733),
    [anon_sym_PIPE] = ACTIONS(731),
    [anon_sym_CARET] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_EQ_EQ] = ACTIONS(731),
    [anon_sym_BANG_EQ] = ACTIONS(731),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(733),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(733),
    [anon_sym_LT] = ACTIONS(731),
    [anon_sym_GT] = ACTIONS(731),
    [anon_sym_LT_EQ] = ACTIONS(733),
    [anon_sym_GT_EQ] = ACTIONS(733),
    [anon_sym_instanceof] = ACTIONS(731),
    [anon_sym_in] = ACTIONS(731),
    [anon_sym_LT_LT] = ACTIONS(733),
    [anon_sym_GT_GT] = ACTIONS(731),
    [anon_sym_GT_GT_GT] = ACTIONS(733),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(731),
    [anon_sym_PERCENT] = ACTIONS(733),
    [anon_sym_STAR_STAR] = ACTIONS(733),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_TILDE] = ACTIONS(733),
    [anon_sym_typeof] = ACTIONS(731),
    [anon_sym_void] = ACTIONS(731),
    [anon_sym_delete] = ACTIONS(731),
    [anon_sym_QMARK] = ACTIONS(731),
    [anon_sym_await] = ACTIONS(731),
    [anon_sym_LBRACK] = ACTIONS(733),
    [anon_sym_if] = ACTIONS(731),
    [anon_sym_else] = ACTIONS(731),
    [anon_sym_async] = ACTIONS(731),
    [anon_sym_var] = ACTIONS(731),
    [anon_sym_let] = ACTIONS(731),
    [anon_sym_const] = ACTIONS(731),
    [anon_sym_return] = ACTIONS(731),
    [anon_sym_try] = ACTIONS(731),
    [anon_sym_throw] = ACTIONS(731),
    [anon_sym_for] = ACTIONS(731),
    [anon_sym_while] = ACTIONS(731),
    [anon_sym_break] = ACTIONS(731),
    [anon_sym_continue] = ACTIONS(731),
    [anon_sym_QMARK_DOT] = ACTIONS(733),
    [anon_sym_BQUOTE] = ACTIONS(733),
    [anon_sym_DOLLARr] = ACTIONS(731),
    [anon_sym_PLUS_PLUS] = ACTIONS(733),
    [anon_sym_DASH_DASH] = ACTIONS(733),
    [anon_sym_new] = ACTIONS(731),
  },
  [STATE(374)] = {
    [sym_comment] = STATE(374),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(738),
    [anon_sym_LBRACE] = ACTIONS(740),
    [anon_sym_RBRACE] = ACTIONS(740),
    [anon_sym_STAR] = ACTIONS(738),
    [anon_sym_as] = ACTIONS(738),
    [anon_sym_SEMI] = ACTIONS(740),
    [anon_sym_LPAREN] = ACTIONS(740),
    [anon_sym_DOT] = ACTIONS(740),
    [sym_identifier] = ACTIONS(738),
    [anon_sym_DQUOTE] = ACTIONS(740),
    [anon_sym_SQUOTE] = ACTIONS(740),
    [anon_sym_DOLLAR] = ACTIONS(738),
    [sym_numeric_literal] = ACTIONS(740),
    [anon_sym_true] = ACTIONS(738),
    [anon_sym_false] = ACTIONS(738),
    [anon_sym_null] = ACTIONS(738),
    [anon_sym_PIPE_PIPE] = ACTIONS(740),
    [anon_sym_AMP_AMP] = ACTIONS(740),
    [anon_sym_PIPE] = ACTIONS(738),
    [anon_sym_CARET] = ACTIONS(740),
    [anon_sym_AMP] = ACTIONS(738),
    [anon_sym_EQ_EQ] = ACTIONS(738),
    [anon_sym_BANG_EQ] = ACTIONS(738),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(740),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(738),
    [anon_sym_GT] = ACTIONS(738),
    [anon_sym_LT_EQ] = ACTIONS(740),
    [anon_sym_GT_EQ] = ACTIONS(740),
    [anon_sym_instanceof] = ACTIONS(738),
    [anon_sym_in] = ACTIONS(738),
    [anon_sym_LT_LT] = ACTIONS(740),
    [anon_sym_GT_GT] = ACTIONS(738),
    [anon_sym_GT_GT_GT] = ACTIONS(740),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_PERCENT] = ACTIONS(740),
    [anon_sym_STAR_STAR] = ACTIONS(740),
    [anon_sym_BANG] = ACTIONS(738),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_typeof] = ACTIONS(738),
    [anon_sym_void] = ACTIONS(738),
    [anon_sym_delete] = ACTIONS(738),
    [anon_sym_QMARK] = ACTIONS(738),
    [anon_sym_await] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_if] = ACTIONS(738),
    [anon_sym_else] = ACTIONS(738),
    [anon_sym_async] = ACTIONS(738),
    [anon_sym_var] = ACTIONS(738),
    [anon_sym_let] = ACTIONS(738),
    [anon_sym_const] = ACTIONS(738),
    [anon_sym_return] = ACTIONS(738),
    [anon_sym_try] = ACTIONS(738),
    [anon_sym_throw] = ACTIONS(738),
    [anon_sym_for] = ACTIONS(738),
    [anon_sym_while] = ACTIONS(738),
    [anon_sym_break] = ACTIONS(738),
    [anon_sym_continue] = ACTIONS(738),
    [anon_sym_QMARK_DOT] = ACTIONS(740),
    [anon_sym_BQUOTE] = ACTIONS(740),
    [anon_sym_DOLLARr] = ACTIONS(738),
    [anon_sym_PLUS_PLUS] = ACTIONS(740),
    [anon_sym_DASH_DASH] = ACTIONS(740),
    [anon_sym_new] = ACTIONS(738),
  },
  [STATE(375)] = {
    [sym_comment] = STATE(375),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(957),
    [anon_sym_LBRACE] = ACTIONS(959),
    [anon_sym_RBRACE] = ACTIONS(959),
    [anon_sym_STAR] = ACTIONS(957),
    [anon_sym_as] = ACTIONS(957),
    [anon_sym_SEMI] = ACTIONS(959),
    [anon_sym_LPAREN] = ACTIONS(959),
    [anon_sym_DOT] = ACTIONS(959),
    [sym_identifier] = ACTIONS(957),
    [anon_sym_DQUOTE] = ACTIONS(959),
    [anon_sym_SQUOTE] = ACTIONS(959),
    [anon_sym_DOLLAR] = ACTIONS(957),
    [sym_numeric_literal] = ACTIONS(959),
    [anon_sym_true] = ACTIONS(957),
    [anon_sym_false] = ACTIONS(957),
    [anon_sym_null] = ACTIONS(957),
    [anon_sym_PIPE_PIPE] = ACTIONS(959),
    [anon_sym_AMP_AMP] = ACTIONS(959),
    [anon_sym_PIPE] = ACTIONS(957),
    [anon_sym_CARET] = ACTIONS(959),
    [anon_sym_AMP] = ACTIONS(957),
    [anon_sym_EQ_EQ] = ACTIONS(957),
    [anon_sym_BANG_EQ] = ACTIONS(957),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(959),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(959),
    [anon_sym_LT] = ACTIONS(957),
    [anon_sym_GT] = ACTIONS(957),
    [anon_sym_LT_EQ] = ACTIONS(959),
    [anon_sym_GT_EQ] = ACTIONS(959),
    [anon_sym_instanceof] = ACTIONS(957),
    [anon_sym_in] = ACTIONS(957),
    [anon_sym_LT_LT] = ACTIONS(959),
    [anon_sym_GT_GT] = ACTIONS(957),
    [anon_sym_GT_GT_GT] = ACTIONS(959),
    [anon_sym_PLUS] = ACTIONS(957),
    [anon_sym_DASH] = ACTIONS(957),
    [anon_sym_PERCENT] = ACTIONS(959),
    [anon_sym_STAR_STAR] = ACTIONS(959),
    [anon_sym_BANG] = ACTIONS(957),
    [anon_sym_TILDE] = ACTIONS(959),
    [anon_sym_typeof] = ACTIONS(957),
    [anon_sym_void] = ACTIONS(957),
    [anon_sym_delete] = ACTIONS(957),
    [anon_sym_QMARK] = ACTIONS(957),
    [anon_sym_await] = ACTIONS(957),
    [anon_sym_LBRACK] = ACTIONS(959),
    [anon_sym_if] = ACTIONS(957),
    [anon_sym_else] = ACTIONS(957),
    [anon_sym_async] = ACTIONS(957),
    [anon_sym_var] = ACTIONS(957),
    [anon_sym_let] = ACTIONS(957),
    [anon_sym_const] = ACTIONS(957),
    [anon_sym_return] = ACTIONS(957),
    [anon_sym_try] = ACTIONS(957),
    [anon_sym_throw] = ACTIONS(957),
    [anon_sym_for] = ACTIONS(957),
    [anon_sym_while] = ACTIONS(957),
    [anon_sym_break] = ACTIONS(957),
    [anon_sym_continue] = ACTIONS(957),
    [anon_sym_QMARK_DOT] = ACTIONS(959),
    [anon_sym_BQUOTE] = ACTIONS(959),
    [anon_sym_DOLLARr] = ACTIONS(957),
    [anon_sym_PLUS_PLUS] = ACTIONS(959),
    [anon_sym_DASH_DASH] = ACTIONS(959),
    [anon_sym_new] = ACTIONS(957),
  },
  [STATE(376)] = {
    [sym_comment] = STATE(376),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(883),
    [anon_sym_LBRACE] = ACTIONS(885),
    [anon_sym_RBRACE] = ACTIONS(885),
    [anon_sym_STAR] = ACTIONS(883),
    [anon_sym_as] = ACTIONS(883),
    [anon_sym_SEMI] = ACTIONS(885),
    [anon_sym_LPAREN] = ACTIONS(885),
    [anon_sym_DOT] = ACTIONS(885),
    [sym_identifier] = ACTIONS(883),
    [anon_sym_DQUOTE] = ACTIONS(885),
    [anon_sym_SQUOTE] = ACTIONS(885),
    [anon_sym_DOLLAR] = ACTIONS(883),
    [sym_numeric_literal] = ACTIONS(885),
    [anon_sym_true] = ACTIONS(883),
    [anon_sym_false] = ACTIONS(883),
    [anon_sym_null] = ACTIONS(883),
    [anon_sym_PIPE_PIPE] = ACTIONS(885),
    [anon_sym_AMP_AMP] = ACTIONS(885),
    [anon_sym_PIPE] = ACTIONS(883),
    [anon_sym_CARET] = ACTIONS(885),
    [anon_sym_AMP] = ACTIONS(883),
    [anon_sym_EQ_EQ] = ACTIONS(883),
    [anon_sym_BANG_EQ] = ACTIONS(883),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(885),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(885),
    [anon_sym_LT] = ACTIONS(883),
    [anon_sym_GT] = ACTIONS(883),
    [anon_sym_LT_EQ] = ACTIONS(885),
    [anon_sym_GT_EQ] = ACTIONS(885),
    [anon_sym_instanceof] = ACTIONS(883),
    [anon_sym_in] = ACTIONS(883),
    [anon_sym_LT_LT] = ACTIONS(885),
    [anon_sym_GT_GT] = ACTIONS(883),
    [anon_sym_GT_GT_GT] = ACTIONS(885),
    [anon_sym_PLUS] = ACTIONS(883),
    [anon_sym_DASH] = ACTIONS(883),
    [anon_sym_PERCENT] = ACTIONS(885),
    [anon_sym_STAR_STAR] = ACTIONS(885),
    [anon_sym_BANG] = ACTIONS(883),
    [anon_sym_TILDE] = ACTIONS(885),
    [anon_sym_typeof] = ACTIONS(883),
    [anon_sym_void] = ACTIONS(883),
    [anon_sym_delete] = ACTIONS(883),
    [anon_sym_QMARK] = ACTIONS(883),
    [anon_sym_await] = ACTIONS(883),
    [anon_sym_LBRACK] = ACTIONS(885),
    [anon_sym_if] = ACTIONS(883),
    [anon_sym_else] = ACTIONS(883),
    [anon_sym_async] = ACTIONS(883),
    [anon_sym_var] = ACTIONS(883),
    [anon_sym_let] = ACTIONS(883),
    [anon_sym_const] = ACTIONS(883),
    [anon_sym_return] = ACTIONS(883),
    [anon_sym_try] = ACTIONS(883),
    [anon_sym_throw] = ACTIONS(883),
    [anon_sym_for] = ACTIONS(883),
    [anon_sym_while] = ACTIONS(883),
    [anon_sym_break] = ACTIONS(883),
    [anon_sym_continue] = ACTIONS(883),
    [anon_sym_QMARK_DOT] = ACTIONS(885),
    [anon_sym_BQUOTE] = ACTIONS(885),
    [anon_sym_DOLLARr] = ACTIONS(883),
    [anon_sym_PLUS_PLUS] = ACTIONS(885),
    [anon_sym_DASH_DASH] = ACTIONS(885),
    [anon_sym_new] = ACTIONS(883),
  },
  [STATE(377)] = {
    [sym_comment] = STATE(377),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(745),
    [anon_sym_LBRACE] = ACTIONS(747),
    [anon_sym_RBRACE] = ACTIONS(747),
    [anon_sym_STAR] = ACTIONS(745),
    [anon_sym_as] = ACTIONS(745),
    [anon_sym_SEMI] = ACTIONS(747),
    [anon_sym_LPAREN] = ACTIONS(747),
    [anon_sym_DOT] = ACTIONS(747),
    [sym_identifier] = ACTIONS(745),
    [anon_sym_DQUOTE] = ACTIONS(747),
    [anon_sym_SQUOTE] = ACTIONS(747),
    [anon_sym_DOLLAR] = ACTIONS(745),
    [sym_numeric_literal] = ACTIONS(747),
    [anon_sym_true] = ACTIONS(745),
    [anon_sym_false] = ACTIONS(745),
    [anon_sym_null] = ACTIONS(745),
    [anon_sym_PIPE_PIPE] = ACTIONS(747),
    [anon_sym_AMP_AMP] = ACTIONS(747),
    [anon_sym_PIPE] = ACTIONS(745),
    [anon_sym_CARET] = ACTIONS(747),
    [anon_sym_AMP] = ACTIONS(745),
    [anon_sym_EQ_EQ] = ACTIONS(745),
    [anon_sym_BANG_EQ] = ACTIONS(745),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(747),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(747),
    [anon_sym_LT] = ACTIONS(745),
    [anon_sym_GT] = ACTIONS(745),
    [anon_sym_LT_EQ] = ACTIONS(747),
    [anon_sym_GT_EQ] = ACTIONS(747),
    [anon_sym_instanceof] = ACTIONS(745),
    [anon_sym_in] = ACTIONS(745),
    [anon_sym_LT_LT] = ACTIONS(747),
    [anon_sym_GT_GT] = ACTIONS(745),
    [anon_sym_GT_GT_GT] = ACTIONS(747),
    [anon_sym_PLUS] = ACTIONS(745),
    [anon_sym_DASH] = ACTIONS(745),
    [anon_sym_PERCENT] = ACTIONS(747),
    [anon_sym_STAR_STAR] = ACTIONS(747),
    [anon_sym_BANG] = ACTIONS(745),
    [anon_sym_TILDE] = ACTIONS(747),
    [anon_sym_typeof] = ACTIONS(745),
    [anon_sym_void] = ACTIONS(745),
    [anon_sym_delete] = ACTIONS(745),
    [anon_sym_QMARK] = ACTIONS(745),
    [anon_sym_await] = ACTIONS(745),
    [anon_sym_LBRACK] = ACTIONS(747),
    [anon_sym_if] = ACTIONS(745),
    [anon_sym_else] = ACTIONS(745),
    [anon_sym_async] = ACTIONS(745),
    [anon_sym_var] = ACTIONS(745),
    [anon_sym_let] = ACTIONS(745),
    [anon_sym_const] = ACTIONS(745),
    [anon_sym_return] = ACTIONS(745),
    [anon_sym_try] = ACTIONS(745),
    [anon_sym_throw] = ACTIONS(745),
    [anon_sym_for] = ACTIONS(745),
    [anon_sym_while] = ACTIONS(745),
    [anon_sym_break] = ACTIONS(745),
    [anon_sym_continue] = ACTIONS(745),
    [anon_sym_QMARK_DOT] = ACTIONS(747),
    [anon_sym_BQUOTE] = ACTIONS(747),
    [anon_sym_DOLLARr] = ACTIONS(745),
    [anon_sym_PLUS_PLUS] = ACTIONS(747),
    [anon_sym_DASH_DASH] = ACTIONS(747),
    [anon_sym_new] = ACTIONS(745),
  },
  [STATE(378)] = {
    [sym_comment] = STATE(378),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(977),
    [anon_sym_LBRACE] = ACTIONS(979),
    [anon_sym_RBRACE] = ACTIONS(979),
    [anon_sym_STAR] = ACTIONS(977),
    [anon_sym_as] = ACTIONS(977),
    [anon_sym_SEMI] = ACTIONS(979),
    [anon_sym_LPAREN] = ACTIONS(979),
    [anon_sym_DOT] = ACTIONS(979),
    [sym_identifier] = ACTIONS(977),
    [anon_sym_DQUOTE] = ACTIONS(979),
    [anon_sym_SQUOTE] = ACTIONS(979),
    [anon_sym_DOLLAR] = ACTIONS(977),
    [sym_numeric_literal] = ACTIONS(979),
    [anon_sym_true] = ACTIONS(977),
    [anon_sym_false] = ACTIONS(977),
    [anon_sym_null] = ACTIONS(977),
    [anon_sym_PIPE_PIPE] = ACTIONS(979),
    [anon_sym_AMP_AMP] = ACTIONS(979),
    [anon_sym_PIPE] = ACTIONS(977),
    [anon_sym_CARET] = ACTIONS(979),
    [anon_sym_AMP] = ACTIONS(977),
    [anon_sym_EQ_EQ] = ACTIONS(977),
    [anon_sym_BANG_EQ] = ACTIONS(977),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(979),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(979),
    [anon_sym_LT] = ACTIONS(977),
    [anon_sym_GT] = ACTIONS(977),
    [anon_sym_LT_EQ] = ACTIONS(979),
    [anon_sym_GT_EQ] = ACTIONS(979),
    [anon_sym_instanceof] = ACTIONS(977),
    [anon_sym_in] = ACTIONS(977),
    [anon_sym_LT_LT] = ACTIONS(979),
    [anon_sym_GT_GT] = ACTIONS(977),
    [anon_sym_GT_GT_GT] = ACTIONS(979),
    [anon_sym_PLUS] = ACTIONS(977),
    [anon_sym_DASH] = ACTIONS(977),
    [anon_sym_PERCENT] = ACTIONS(979),
    [anon_sym_STAR_STAR] = ACTIONS(979),
    [anon_sym_BANG] = ACTIONS(977),
    [anon_sym_TILDE] = ACTIONS(979),
    [anon_sym_typeof] = ACTIONS(977),
    [anon_sym_void] = ACTIONS(977),
    [anon_sym_delete] = ACTIONS(977),
    [anon_sym_QMARK] = ACTIONS(977),
    [anon_sym_await] = ACTIONS(977),
    [anon_sym_LBRACK] = ACTIONS(979),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_else] = ACTIONS(977),
    [anon_sym_async] = ACTIONS(977),
    [anon_sym_var] = ACTIONS(977),
    [anon_sym_let] = ACTIONS(977),
    [anon_sym_const] = ACTIONS(977),
    [anon_sym_return] = ACTIONS(977),
    [anon_sym_try] = ACTIONS(977),
    [anon_sym_throw] = ACTIONS(977),
    [anon_sym_for] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(977),
    [anon_sym_break] = ACTIONS(977),
    [anon_sym_continue] = ACTIONS(977),
    [anon_sym_QMARK_DOT] = ACTIONS(979),
    [anon_sym_BQUOTE] = ACTIONS(979),
    [anon_sym_DOLLARr] = ACTIONS(977),
    [anon_sym_PLUS_PLUS] = ACTIONS(979),
    [anon_sym_DASH_DASH] = ACTIONS(979),
    [anon_sym_new] = ACTIONS(977),
  },
  [STATE(379)] = {
    [sym_comment] = STATE(379),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(789),
    [anon_sym_LBRACE] = ACTIONS(791),
    [anon_sym_RBRACE] = ACTIONS(791),
    [anon_sym_STAR] = ACTIONS(789),
    [anon_sym_as] = ACTIONS(789),
    [anon_sym_SEMI] = ACTIONS(791),
    [anon_sym_LPAREN] = ACTIONS(791),
    [anon_sym_DOT] = ACTIONS(791),
    [sym_identifier] = ACTIONS(789),
    [anon_sym_DQUOTE] = ACTIONS(791),
    [anon_sym_SQUOTE] = ACTIONS(791),
    [anon_sym_DOLLAR] = ACTIONS(789),
    [sym_numeric_literal] = ACTIONS(791),
    [anon_sym_true] = ACTIONS(789),
    [anon_sym_false] = ACTIONS(789),
    [anon_sym_null] = ACTIONS(789),
    [anon_sym_PIPE_PIPE] = ACTIONS(791),
    [anon_sym_AMP_AMP] = ACTIONS(791),
    [anon_sym_PIPE] = ACTIONS(789),
    [anon_sym_CARET] = ACTIONS(791),
    [anon_sym_AMP] = ACTIONS(789),
    [anon_sym_EQ_EQ] = ACTIONS(789),
    [anon_sym_BANG_EQ] = ACTIONS(789),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(791),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(791),
    [anon_sym_LT] = ACTIONS(789),
    [anon_sym_GT] = ACTIONS(789),
    [anon_sym_LT_EQ] = ACTIONS(791),
    [anon_sym_GT_EQ] = ACTIONS(791),
    [anon_sym_instanceof] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(789),
    [anon_sym_LT_LT] = ACTIONS(791),
    [anon_sym_GT_GT] = ACTIONS(789),
    [anon_sym_GT_GT_GT] = ACTIONS(791),
    [anon_sym_PLUS] = ACTIONS(789),
    [anon_sym_DASH] = ACTIONS(789),
    [anon_sym_PERCENT] = ACTIONS(791),
    [anon_sym_STAR_STAR] = ACTIONS(791),
    [anon_sym_BANG] = ACTIONS(789),
    [anon_sym_TILDE] = ACTIONS(791),
    [anon_sym_typeof] = ACTIONS(789),
    [anon_sym_void] = ACTIONS(789),
    [anon_sym_delete] = ACTIONS(789),
    [anon_sym_QMARK] = ACTIONS(789),
    [anon_sym_await] = ACTIONS(789),
    [anon_sym_LBRACK] = ACTIONS(791),
    [anon_sym_if] = ACTIONS(789),
    [anon_sym_else] = ACTIONS(789),
    [anon_sym_async] = ACTIONS(789),
    [anon_sym_var] = ACTIONS(789),
    [anon_sym_let] = ACTIONS(789),
    [anon_sym_const] = ACTIONS(789),
    [anon_sym_return] = ACTIONS(789),
    [anon_sym_try] = ACTIONS(789),
    [anon_sym_throw] = ACTIONS(789),
    [anon_sym_for] = ACTIONS(789),
    [anon_sym_while] = ACTIONS(789),
    [anon_sym_break] = ACTIONS(789),
    [anon_sym_continue] = ACTIONS(789),
    [anon_sym_QMARK_DOT] = ACTIONS(791),
    [anon_sym_BQUOTE] = ACTIONS(791),
    [anon_sym_DOLLARr] = ACTIONS(789),
    [anon_sym_PLUS_PLUS] = ACTIONS(791),
    [anon_sym_DASH_DASH] = ACTIONS(791),
    [anon_sym_new] = ACTIONS(789),
  },
  [STATE(380)] = {
    [sym_comment] = STATE(380),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(985),
    [anon_sym_LBRACE] = ACTIONS(987),
    [anon_sym_RBRACE] = ACTIONS(987),
    [anon_sym_STAR] = ACTIONS(985),
    [anon_sym_as] = ACTIONS(985),
    [anon_sym_SEMI] = ACTIONS(987),
    [anon_sym_LPAREN] = ACTIONS(987),
    [anon_sym_DOT] = ACTIONS(987),
    [sym_identifier] = ACTIONS(985),
    [anon_sym_DQUOTE] = ACTIONS(987),
    [anon_sym_SQUOTE] = ACTIONS(987),
    [anon_sym_DOLLAR] = ACTIONS(985),
    [sym_numeric_literal] = ACTIONS(987),
    [anon_sym_true] = ACTIONS(985),
    [anon_sym_false] = ACTIONS(985),
    [anon_sym_null] = ACTIONS(985),
    [anon_sym_PIPE_PIPE] = ACTIONS(987),
    [anon_sym_AMP_AMP] = ACTIONS(987),
    [anon_sym_PIPE] = ACTIONS(985),
    [anon_sym_CARET] = ACTIONS(987),
    [anon_sym_AMP] = ACTIONS(985),
    [anon_sym_EQ_EQ] = ACTIONS(985),
    [anon_sym_BANG_EQ] = ACTIONS(985),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(987),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(987),
    [anon_sym_LT] = ACTIONS(985),
    [anon_sym_GT] = ACTIONS(985),
    [anon_sym_LT_EQ] = ACTIONS(987),
    [anon_sym_GT_EQ] = ACTIONS(987),
    [anon_sym_instanceof] = ACTIONS(985),
    [anon_sym_in] = ACTIONS(985),
    [anon_sym_LT_LT] = ACTIONS(987),
    [anon_sym_GT_GT] = ACTIONS(985),
    [anon_sym_GT_GT_GT] = ACTIONS(987),
    [anon_sym_PLUS] = ACTIONS(985),
    [anon_sym_DASH] = ACTIONS(985),
    [anon_sym_PERCENT] = ACTIONS(987),
    [anon_sym_STAR_STAR] = ACTIONS(987),
    [anon_sym_BANG] = ACTIONS(985),
    [anon_sym_TILDE] = ACTIONS(987),
    [anon_sym_typeof] = ACTIONS(985),
    [anon_sym_void] = ACTIONS(985),
    [anon_sym_delete] = ACTIONS(985),
    [anon_sym_QMARK] = ACTIONS(985),
    [anon_sym_await] = ACTIONS(985),
    [anon_sym_LBRACK] = ACTIONS(987),
    [anon_sym_if] = ACTIONS(985),
    [anon_sym_else] = ACTIONS(985),
    [anon_sym_async] = ACTIONS(985),
    [anon_sym_var] = ACTIONS(985),
    [anon_sym_let] = ACTIONS(985),
    [anon_sym_const] = ACTIONS(985),
    [anon_sym_return] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(985),
    [anon_sym_throw] = ACTIONS(985),
    [anon_sym_for] = ACTIONS(985),
    [anon_sym_while] = ACTIONS(985),
    [anon_sym_break] = ACTIONS(985),
    [anon_sym_continue] = ACTIONS(985),
    [anon_sym_QMARK_DOT] = ACTIONS(987),
    [anon_sym_BQUOTE] = ACTIONS(987),
    [anon_sym_DOLLARr] = ACTIONS(985),
    [anon_sym_PLUS_PLUS] = ACTIONS(987),
    [anon_sym_DASH_DASH] = ACTIONS(987),
    [anon_sym_new] = ACTIONS(985),
  },
  [STATE(381)] = {
    [sym_comment] = STATE(381),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(758),
    [anon_sym_extends] = ACTIONS(756),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_var] = ACTIONS(756),
    [anon_sym_let] = ACTIONS(756),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_return] = ACTIONS(756),
    [anon_sym_try] = ACTIONS(756),
    [anon_sym_throw] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_continue] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(382)] = {
    [sym_comment] = STATE(382),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(805),
    [anon_sym_LBRACE] = ACTIONS(807),
    [anon_sym_RBRACE] = ACTIONS(807),
    [anon_sym_STAR] = ACTIONS(805),
    [anon_sym_as] = ACTIONS(805),
    [anon_sym_SEMI] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(807),
    [anon_sym_DOT] = ACTIONS(807),
    [sym_identifier] = ACTIONS(805),
    [anon_sym_DQUOTE] = ACTIONS(807),
    [anon_sym_SQUOTE] = ACTIONS(807),
    [anon_sym_DOLLAR] = ACTIONS(805),
    [sym_numeric_literal] = ACTIONS(807),
    [anon_sym_true] = ACTIONS(805),
    [anon_sym_false] = ACTIONS(805),
    [anon_sym_null] = ACTIONS(805),
    [anon_sym_PIPE_PIPE] = ACTIONS(807),
    [anon_sym_AMP_AMP] = ACTIONS(807),
    [anon_sym_PIPE] = ACTIONS(805),
    [anon_sym_CARET] = ACTIONS(807),
    [anon_sym_AMP] = ACTIONS(805),
    [anon_sym_EQ_EQ] = ACTIONS(805),
    [anon_sym_BANG_EQ] = ACTIONS(805),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(807),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(807),
    [anon_sym_LT] = ACTIONS(805),
    [anon_sym_GT] = ACTIONS(805),
    [anon_sym_LT_EQ] = ACTIONS(807),
    [anon_sym_GT_EQ] = ACTIONS(807),
    [anon_sym_instanceof] = ACTIONS(805),
    [anon_sym_in] = ACTIONS(805),
    [anon_sym_LT_LT] = ACTIONS(807),
    [anon_sym_GT_GT] = ACTIONS(805),
    [anon_sym_GT_GT_GT] = ACTIONS(807),
    [anon_sym_PLUS] = ACTIONS(805),
    [anon_sym_DASH] = ACTIONS(805),
    [anon_sym_PERCENT] = ACTIONS(807),
    [anon_sym_STAR_STAR] = ACTIONS(807),
    [anon_sym_BANG] = ACTIONS(805),
    [anon_sym_TILDE] = ACTIONS(807),
    [anon_sym_typeof] = ACTIONS(805),
    [anon_sym_void] = ACTIONS(805),
    [anon_sym_delete] = ACTIONS(805),
    [anon_sym_QMARK] = ACTIONS(805),
    [anon_sym_await] = ACTIONS(805),
    [anon_sym_LBRACK] = ACTIONS(807),
    [anon_sym_extends] = ACTIONS(805),
    [anon_sym_if] = ACTIONS(805),
    [anon_sym_async] = ACTIONS(805),
    [anon_sym_var] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(805),
    [anon_sym_const] = ACTIONS(805),
    [anon_sym_return] = ACTIONS(805),
    [anon_sym_try] = ACTIONS(805),
    [anon_sym_throw] = ACTIONS(805),
    [anon_sym_for] = ACTIONS(805),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_break] = ACTIONS(805),
    [anon_sym_continue] = ACTIONS(805),
    [anon_sym_QMARK_DOT] = ACTIONS(807),
    [anon_sym_BQUOTE] = ACTIONS(807),
    [anon_sym_DOLLARr] = ACTIONS(805),
    [anon_sym_PLUS_PLUS] = ACTIONS(807),
    [anon_sym_DASH_DASH] = ACTIONS(807),
    [anon_sym_new] = ACTIONS(805),
  },
  [STATE(383)] = {
    [sym_comment] = STATE(383),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(797),
    [anon_sym_LBRACE] = ACTIONS(799),
    [anon_sym_RBRACE] = ACTIONS(799),
    [anon_sym_STAR] = ACTIONS(797),
    [anon_sym_as] = ACTIONS(797),
    [anon_sym_SEMI] = ACTIONS(799),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_DOT] = ACTIONS(799),
    [sym_identifier] = ACTIONS(797),
    [anon_sym_DQUOTE] = ACTIONS(799),
    [anon_sym_SQUOTE] = ACTIONS(799),
    [anon_sym_DOLLAR] = ACTIONS(797),
    [sym_numeric_literal] = ACTIONS(799),
    [anon_sym_true] = ACTIONS(797),
    [anon_sym_false] = ACTIONS(797),
    [anon_sym_null] = ACTIONS(797),
    [anon_sym_PIPE_PIPE] = ACTIONS(799),
    [anon_sym_AMP_AMP] = ACTIONS(799),
    [anon_sym_PIPE] = ACTIONS(797),
    [anon_sym_CARET] = ACTIONS(799),
    [anon_sym_AMP] = ACTIONS(797),
    [anon_sym_EQ_EQ] = ACTIONS(797),
    [anon_sym_BANG_EQ] = ACTIONS(797),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(799),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(799),
    [anon_sym_LT] = ACTIONS(797),
    [anon_sym_GT] = ACTIONS(797),
    [anon_sym_LT_EQ] = ACTIONS(799),
    [anon_sym_GT_EQ] = ACTIONS(799),
    [anon_sym_instanceof] = ACTIONS(797),
    [anon_sym_in] = ACTIONS(797),
    [anon_sym_LT_LT] = ACTIONS(799),
    [anon_sym_GT_GT] = ACTIONS(797),
    [anon_sym_GT_GT_GT] = ACTIONS(799),
    [anon_sym_PLUS] = ACTIONS(797),
    [anon_sym_DASH] = ACTIONS(797),
    [anon_sym_PERCENT] = ACTIONS(799),
    [anon_sym_STAR_STAR] = ACTIONS(799),
    [anon_sym_BANG] = ACTIONS(797),
    [anon_sym_TILDE] = ACTIONS(799),
    [anon_sym_typeof] = ACTIONS(797),
    [anon_sym_void] = ACTIONS(797),
    [anon_sym_delete] = ACTIONS(797),
    [anon_sym_QMARK] = ACTIONS(797),
    [anon_sym_await] = ACTIONS(797),
    [anon_sym_LBRACK] = ACTIONS(799),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_else] = ACTIONS(797),
    [anon_sym_async] = ACTIONS(797),
    [anon_sym_var] = ACTIONS(797),
    [anon_sym_let] = ACTIONS(797),
    [anon_sym_const] = ACTIONS(797),
    [anon_sym_return] = ACTIONS(797),
    [anon_sym_try] = ACTIONS(797),
    [anon_sym_throw] = ACTIONS(797),
    [anon_sym_for] = ACTIONS(797),
    [anon_sym_while] = ACTIONS(797),
    [anon_sym_break] = ACTIONS(797),
    [anon_sym_continue] = ACTIONS(797),
    [anon_sym_QMARK_DOT] = ACTIONS(799),
    [anon_sym_BQUOTE] = ACTIONS(799),
    [anon_sym_DOLLARr] = ACTIONS(797),
    [anon_sym_PLUS_PLUS] = ACTIONS(799),
    [anon_sym_DASH_DASH] = ACTIONS(799),
    [anon_sym_new] = ACTIONS(797),
  },
  [STATE(384)] = {
    [sym_comment] = STATE(384),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(943),
    [anon_sym_RBRACE] = ACTIONS(943),
    [anon_sym_STAR] = ACTIONS(941),
    [anon_sym_as] = ACTIONS(941),
    [anon_sym_SEMI] = ACTIONS(943),
    [anon_sym_LPAREN] = ACTIONS(943),
    [anon_sym_DOT] = ACTIONS(943),
    [sym_identifier] = ACTIONS(941),
    [anon_sym_DQUOTE] = ACTIONS(943),
    [anon_sym_SQUOTE] = ACTIONS(943),
    [anon_sym_DOLLAR] = ACTIONS(941),
    [sym_numeric_literal] = ACTIONS(943),
    [anon_sym_true] = ACTIONS(941),
    [anon_sym_false] = ACTIONS(941),
    [anon_sym_null] = ACTIONS(941),
    [anon_sym_PIPE_PIPE] = ACTIONS(943),
    [anon_sym_AMP_AMP] = ACTIONS(943),
    [anon_sym_PIPE] = ACTIONS(941),
    [anon_sym_CARET] = ACTIONS(943),
    [anon_sym_AMP] = ACTIONS(941),
    [anon_sym_EQ_EQ] = ACTIONS(941),
    [anon_sym_BANG_EQ] = ACTIONS(941),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(943),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(943),
    [anon_sym_LT] = ACTIONS(941),
    [anon_sym_GT] = ACTIONS(941),
    [anon_sym_LT_EQ] = ACTIONS(943),
    [anon_sym_GT_EQ] = ACTIONS(943),
    [anon_sym_instanceof] = ACTIONS(941),
    [anon_sym_in] = ACTIONS(941),
    [anon_sym_LT_LT] = ACTIONS(943),
    [anon_sym_GT_GT] = ACTIONS(941),
    [anon_sym_GT_GT_GT] = ACTIONS(943),
    [anon_sym_PLUS] = ACTIONS(941),
    [anon_sym_DASH] = ACTIONS(941),
    [anon_sym_PERCENT] = ACTIONS(943),
    [anon_sym_STAR_STAR] = ACTIONS(943),
    [anon_sym_BANG] = ACTIONS(941),
    [anon_sym_TILDE] = ACTIONS(943),
    [anon_sym_typeof] = ACTIONS(941),
    [anon_sym_void] = ACTIONS(941),
    [anon_sym_delete] = ACTIONS(941),
    [anon_sym_QMARK] = ACTIONS(941),
    [anon_sym_await] = ACTIONS(941),
    [anon_sym_LBRACK] = ACTIONS(943),
    [anon_sym_if] = ACTIONS(941),
    [anon_sym_else] = ACTIONS(941),
    [anon_sym_async] = ACTIONS(941),
    [anon_sym_var] = ACTIONS(941),
    [anon_sym_let] = ACTIONS(941),
    [anon_sym_const] = ACTIONS(941),
    [anon_sym_return] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_throw] = ACTIONS(941),
    [anon_sym_for] = ACTIONS(941),
    [anon_sym_while] = ACTIONS(941),
    [anon_sym_break] = ACTIONS(941),
    [anon_sym_continue] = ACTIONS(941),
    [anon_sym_QMARK_DOT] = ACTIONS(943),
    [anon_sym_BQUOTE] = ACTIONS(943),
    [anon_sym_DOLLARr] = ACTIONS(941),
    [anon_sym_PLUS_PLUS] = ACTIONS(943),
    [anon_sym_DASH_DASH] = ACTIONS(943),
    [anon_sym_new] = ACTIONS(941),
  },
  [STATE(385)] = {
    [sym_comment] = STATE(385),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(879),
    [anon_sym_LBRACE] = ACTIONS(881),
    [anon_sym_RBRACE] = ACTIONS(881),
    [anon_sym_STAR] = ACTIONS(879),
    [anon_sym_as] = ACTIONS(879),
    [anon_sym_SEMI] = ACTIONS(881),
    [anon_sym_LPAREN] = ACTIONS(881),
    [anon_sym_DOT] = ACTIONS(881),
    [sym_identifier] = ACTIONS(879),
    [anon_sym_DQUOTE] = ACTIONS(881),
    [anon_sym_SQUOTE] = ACTIONS(881),
    [anon_sym_DOLLAR] = ACTIONS(879),
    [sym_numeric_literal] = ACTIONS(881),
    [anon_sym_true] = ACTIONS(879),
    [anon_sym_false] = ACTIONS(879),
    [anon_sym_null] = ACTIONS(879),
    [anon_sym_PIPE_PIPE] = ACTIONS(881),
    [anon_sym_AMP_AMP] = ACTIONS(881),
    [anon_sym_PIPE] = ACTIONS(879),
    [anon_sym_CARET] = ACTIONS(881),
    [anon_sym_AMP] = ACTIONS(879),
    [anon_sym_EQ_EQ] = ACTIONS(879),
    [anon_sym_BANG_EQ] = ACTIONS(879),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(881),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(881),
    [anon_sym_LT] = ACTIONS(879),
    [anon_sym_GT] = ACTIONS(879),
    [anon_sym_LT_EQ] = ACTIONS(881),
    [anon_sym_GT_EQ] = ACTIONS(881),
    [anon_sym_instanceof] = ACTIONS(879),
    [anon_sym_in] = ACTIONS(879),
    [anon_sym_LT_LT] = ACTIONS(881),
    [anon_sym_GT_GT] = ACTIONS(879),
    [anon_sym_GT_GT_GT] = ACTIONS(881),
    [anon_sym_PLUS] = ACTIONS(879),
    [anon_sym_DASH] = ACTIONS(879),
    [anon_sym_PERCENT] = ACTIONS(881),
    [anon_sym_STAR_STAR] = ACTIONS(881),
    [anon_sym_BANG] = ACTIONS(879),
    [anon_sym_TILDE] = ACTIONS(881),
    [anon_sym_typeof] = ACTIONS(879),
    [anon_sym_void] = ACTIONS(879),
    [anon_sym_delete] = ACTIONS(879),
    [anon_sym_QMARK] = ACTIONS(879),
    [anon_sym_await] = ACTIONS(879),
    [anon_sym_LBRACK] = ACTIONS(881),
    [anon_sym_if] = ACTIONS(879),
    [anon_sym_else] = ACTIONS(879),
    [anon_sym_async] = ACTIONS(879),
    [anon_sym_var] = ACTIONS(879),
    [anon_sym_let] = ACTIONS(879),
    [anon_sym_const] = ACTIONS(879),
    [anon_sym_return] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(879),
    [anon_sym_throw] = ACTIONS(879),
    [anon_sym_for] = ACTIONS(879),
    [anon_sym_while] = ACTIONS(879),
    [anon_sym_break] = ACTIONS(879),
    [anon_sym_continue] = ACTIONS(879),
    [anon_sym_QMARK_DOT] = ACTIONS(881),
    [anon_sym_BQUOTE] = ACTIONS(881),
    [anon_sym_DOLLARr] = ACTIONS(879),
    [anon_sym_PLUS_PLUS] = ACTIONS(881),
    [anon_sym_DASH_DASH] = ACTIONS(881),
    [anon_sym_new] = ACTIONS(879),
  },
  [STATE(386)] = {
    [sym_comment] = STATE(386),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(700),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_RBRACE] = ACTIONS(698),
    [anon_sym_STAR] = ACTIONS(700),
    [anon_sym_as] = ACTIONS(700),
    [anon_sym_SEMI] = ACTIONS(698),
    [anon_sym_LPAREN] = ACTIONS(698),
    [anon_sym_DOT] = ACTIONS(698),
    [sym_identifier] = ACTIONS(700),
    [anon_sym_DQUOTE] = ACTIONS(698),
    [anon_sym_SQUOTE] = ACTIONS(698),
    [anon_sym_DOLLAR] = ACTIONS(700),
    [sym_numeric_literal] = ACTIONS(698),
    [anon_sym_true] = ACTIONS(700),
    [anon_sym_false] = ACTIONS(700),
    [anon_sym_null] = ACTIONS(700),
    [anon_sym_PIPE_PIPE] = ACTIONS(698),
    [anon_sym_AMP_AMP] = ACTIONS(698),
    [anon_sym_PIPE] = ACTIONS(700),
    [anon_sym_CARET] = ACTIONS(698),
    [anon_sym_AMP] = ACTIONS(700),
    [anon_sym_EQ_EQ] = ACTIONS(700),
    [anon_sym_BANG_EQ] = ACTIONS(700),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(698),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(698),
    [anon_sym_LT] = ACTIONS(700),
    [anon_sym_GT] = ACTIONS(700),
    [anon_sym_LT_EQ] = ACTIONS(698),
    [anon_sym_GT_EQ] = ACTIONS(698),
    [anon_sym_instanceof] = ACTIONS(700),
    [anon_sym_in] = ACTIONS(700),
    [anon_sym_LT_LT] = ACTIONS(698),
    [anon_sym_GT_GT] = ACTIONS(700),
    [anon_sym_GT_GT_GT] = ACTIONS(698),
    [anon_sym_PLUS] = ACTIONS(700),
    [anon_sym_DASH] = ACTIONS(700),
    [anon_sym_PERCENT] = ACTIONS(698),
    [anon_sym_STAR_STAR] = ACTIONS(698),
    [anon_sym_BANG] = ACTIONS(700),
    [anon_sym_TILDE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(700),
    [anon_sym_void] = ACTIONS(700),
    [anon_sym_delete] = ACTIONS(700),
    [anon_sym_QMARK] = ACTIONS(700),
    [anon_sym_await] = ACTIONS(700),
    [anon_sym_LBRACK] = ACTIONS(698),
    [anon_sym_if] = ACTIONS(700),
    [anon_sym_else] = ACTIONS(700),
    [anon_sym_async] = ACTIONS(700),
    [anon_sym_var] = ACTIONS(700),
    [anon_sym_let] = ACTIONS(700),
    [anon_sym_const] = ACTIONS(700),
    [anon_sym_return] = ACTIONS(700),
    [anon_sym_try] = ACTIONS(700),
    [anon_sym_throw] = ACTIONS(700),
    [anon_sym_for] = ACTIONS(700),
    [anon_sym_while] = ACTIONS(700),
    [anon_sym_break] = ACTIONS(700),
    [anon_sym_continue] = ACTIONS(700),
    [anon_sym_QMARK_DOT] = ACTIONS(698),
    [anon_sym_BQUOTE] = ACTIONS(698),
    [anon_sym_DOLLARr] = ACTIONS(700),
    [anon_sym_PLUS_PLUS] = ACTIONS(698),
    [anon_sym_DASH_DASH] = ACTIONS(698),
    [anon_sym_new] = ACTIONS(700),
  },
  [STATE(387)] = {
    [sym_comment] = STATE(387),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(961),
    [anon_sym_LBRACE] = ACTIONS(963),
    [anon_sym_RBRACE] = ACTIONS(963),
    [anon_sym_STAR] = ACTIONS(961),
    [anon_sym_as] = ACTIONS(961),
    [anon_sym_SEMI] = ACTIONS(963),
    [anon_sym_LPAREN] = ACTIONS(963),
    [anon_sym_DOT] = ACTIONS(963),
    [sym_identifier] = ACTIONS(961),
    [anon_sym_DQUOTE] = ACTIONS(963),
    [anon_sym_SQUOTE] = ACTIONS(963),
    [anon_sym_DOLLAR] = ACTIONS(961),
    [sym_numeric_literal] = ACTIONS(963),
    [anon_sym_true] = ACTIONS(961),
    [anon_sym_false] = ACTIONS(961),
    [anon_sym_null] = ACTIONS(961),
    [anon_sym_PIPE_PIPE] = ACTIONS(963),
    [anon_sym_AMP_AMP] = ACTIONS(963),
    [anon_sym_PIPE] = ACTIONS(961),
    [anon_sym_CARET] = ACTIONS(963),
    [anon_sym_AMP] = ACTIONS(961),
    [anon_sym_EQ_EQ] = ACTIONS(961),
    [anon_sym_BANG_EQ] = ACTIONS(961),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(963),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(963),
    [anon_sym_LT] = ACTIONS(961),
    [anon_sym_GT] = ACTIONS(961),
    [anon_sym_LT_EQ] = ACTIONS(963),
    [anon_sym_GT_EQ] = ACTIONS(963),
    [anon_sym_instanceof] = ACTIONS(961),
    [anon_sym_in] = ACTIONS(961),
    [anon_sym_LT_LT] = ACTIONS(963),
    [anon_sym_GT_GT] = ACTIONS(961),
    [anon_sym_GT_GT_GT] = ACTIONS(963),
    [anon_sym_PLUS] = ACTIONS(961),
    [anon_sym_DASH] = ACTIONS(961),
    [anon_sym_PERCENT] = ACTIONS(963),
    [anon_sym_STAR_STAR] = ACTIONS(963),
    [anon_sym_BANG] = ACTIONS(961),
    [anon_sym_TILDE] = ACTIONS(963),
    [anon_sym_typeof] = ACTIONS(961),
    [anon_sym_void] = ACTIONS(961),
    [anon_sym_delete] = ACTIONS(961),
    [anon_sym_QMARK] = ACTIONS(961),
    [anon_sym_await] = ACTIONS(961),
    [anon_sym_LBRACK] = ACTIONS(963),
    [anon_sym_if] = ACTIONS(961),
    [anon_sym_else] = ACTIONS(961),
    [anon_sym_async] = ACTIONS(961),
    [anon_sym_var] = ACTIONS(961),
    [anon_sym_let] = ACTIONS(961),
    [anon_sym_const] = ACTIONS(961),
    [anon_sym_return] = ACTIONS(961),
    [anon_sym_try] = ACTIONS(961),
    [anon_sym_throw] = ACTIONS(961),
    [anon_sym_for] = ACTIONS(961),
    [anon_sym_while] = ACTIONS(961),
    [anon_sym_break] = ACTIONS(961),
    [anon_sym_continue] = ACTIONS(961),
    [anon_sym_QMARK_DOT] = ACTIONS(963),
    [anon_sym_BQUOTE] = ACTIONS(963),
    [anon_sym_DOLLARr] = ACTIONS(961),
    [anon_sym_PLUS_PLUS] = ACTIONS(963),
    [anon_sym_DASH_DASH] = ACTIONS(963),
    [anon_sym_new] = ACTIONS(961),
  },
  [STATE(388)] = {
    [sym_comment] = STATE(388),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(965),
    [anon_sym_LBRACE] = ACTIONS(967),
    [anon_sym_RBRACE] = ACTIONS(967),
    [anon_sym_STAR] = ACTIONS(965),
    [anon_sym_as] = ACTIONS(965),
    [anon_sym_SEMI] = ACTIONS(967),
    [anon_sym_LPAREN] = ACTIONS(967),
    [anon_sym_DOT] = ACTIONS(967),
    [sym_identifier] = ACTIONS(965),
    [anon_sym_DQUOTE] = ACTIONS(967),
    [anon_sym_SQUOTE] = ACTIONS(967),
    [anon_sym_DOLLAR] = ACTIONS(965),
    [sym_numeric_literal] = ACTIONS(967),
    [anon_sym_true] = ACTIONS(965),
    [anon_sym_false] = ACTIONS(965),
    [anon_sym_null] = ACTIONS(965),
    [anon_sym_PIPE_PIPE] = ACTIONS(967),
    [anon_sym_AMP_AMP] = ACTIONS(967),
    [anon_sym_PIPE] = ACTIONS(965),
    [anon_sym_CARET] = ACTIONS(967),
    [anon_sym_AMP] = ACTIONS(965),
    [anon_sym_EQ_EQ] = ACTIONS(965),
    [anon_sym_BANG_EQ] = ACTIONS(965),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(967),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(967),
    [anon_sym_LT] = ACTIONS(965),
    [anon_sym_GT] = ACTIONS(965),
    [anon_sym_LT_EQ] = ACTIONS(967),
    [anon_sym_GT_EQ] = ACTIONS(967),
    [anon_sym_instanceof] = ACTIONS(965),
    [anon_sym_in] = ACTIONS(965),
    [anon_sym_LT_LT] = ACTIONS(967),
    [anon_sym_GT_GT] = ACTIONS(965),
    [anon_sym_GT_GT_GT] = ACTIONS(967),
    [anon_sym_PLUS] = ACTIONS(965),
    [anon_sym_DASH] = ACTIONS(965),
    [anon_sym_PERCENT] = ACTIONS(967),
    [anon_sym_STAR_STAR] = ACTIONS(967),
    [anon_sym_BANG] = ACTIONS(965),
    [anon_sym_TILDE] = ACTIONS(967),
    [anon_sym_typeof] = ACTIONS(965),
    [anon_sym_void] = ACTIONS(965),
    [anon_sym_delete] = ACTIONS(965),
    [anon_sym_QMARK] = ACTIONS(965),
    [anon_sym_await] = ACTIONS(965),
    [anon_sym_LBRACK] = ACTIONS(967),
    [anon_sym_if] = ACTIONS(965),
    [anon_sym_else] = ACTIONS(965),
    [anon_sym_async] = ACTIONS(965),
    [anon_sym_var] = ACTIONS(965),
    [anon_sym_let] = ACTIONS(965),
    [anon_sym_const] = ACTIONS(965),
    [anon_sym_return] = ACTIONS(965),
    [anon_sym_try] = ACTIONS(965),
    [anon_sym_throw] = ACTIONS(965),
    [anon_sym_for] = ACTIONS(965),
    [anon_sym_while] = ACTIONS(965),
    [anon_sym_break] = ACTIONS(965),
    [anon_sym_continue] = ACTIONS(965),
    [anon_sym_QMARK_DOT] = ACTIONS(967),
    [anon_sym_BQUOTE] = ACTIONS(967),
    [anon_sym_DOLLARr] = ACTIONS(965),
    [anon_sym_PLUS_PLUS] = ACTIONS(967),
    [anon_sym_DASH_DASH] = ACTIONS(967),
    [anon_sym_new] = ACTIONS(965),
  },
  [STATE(389)] = {
    [sym_comment] = STATE(389),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(937),
    [anon_sym_LBRACE] = ACTIONS(939),
    [anon_sym_RBRACE] = ACTIONS(939),
    [anon_sym_STAR] = ACTIONS(937),
    [anon_sym_as] = ACTIONS(937),
    [anon_sym_SEMI] = ACTIONS(939),
    [anon_sym_LPAREN] = ACTIONS(939),
    [anon_sym_DOT] = ACTIONS(939),
    [sym_identifier] = ACTIONS(937),
    [anon_sym_DQUOTE] = ACTIONS(939),
    [anon_sym_SQUOTE] = ACTIONS(939),
    [anon_sym_DOLLAR] = ACTIONS(937),
    [sym_numeric_literal] = ACTIONS(939),
    [anon_sym_true] = ACTIONS(937),
    [anon_sym_false] = ACTIONS(937),
    [anon_sym_null] = ACTIONS(937),
    [anon_sym_PIPE_PIPE] = ACTIONS(939),
    [anon_sym_AMP_AMP] = ACTIONS(939),
    [anon_sym_PIPE] = ACTIONS(937),
    [anon_sym_CARET] = ACTIONS(939),
    [anon_sym_AMP] = ACTIONS(937),
    [anon_sym_EQ_EQ] = ACTIONS(937),
    [anon_sym_BANG_EQ] = ACTIONS(937),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(939),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(939),
    [anon_sym_LT] = ACTIONS(937),
    [anon_sym_GT] = ACTIONS(937),
    [anon_sym_LT_EQ] = ACTIONS(939),
    [anon_sym_GT_EQ] = ACTIONS(939),
    [anon_sym_instanceof] = ACTIONS(937),
    [anon_sym_in] = ACTIONS(937),
    [anon_sym_LT_LT] = ACTIONS(939),
    [anon_sym_GT_GT] = ACTIONS(937),
    [anon_sym_GT_GT_GT] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(937),
    [anon_sym_DASH] = ACTIONS(937),
    [anon_sym_PERCENT] = ACTIONS(939),
    [anon_sym_STAR_STAR] = ACTIONS(939),
    [anon_sym_BANG] = ACTIONS(937),
    [anon_sym_TILDE] = ACTIONS(939),
    [anon_sym_typeof] = ACTIONS(937),
    [anon_sym_void] = ACTIONS(937),
    [anon_sym_delete] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(937),
    [anon_sym_await] = ACTIONS(937),
    [anon_sym_LBRACK] = ACTIONS(939),
    [anon_sym_if] = ACTIONS(937),
    [anon_sym_else] = ACTIONS(937),
    [anon_sym_async] = ACTIONS(937),
    [anon_sym_var] = ACTIONS(937),
    [anon_sym_let] = ACTIONS(937),
    [anon_sym_const] = ACTIONS(937),
    [anon_sym_return] = ACTIONS(937),
    [anon_sym_try] = ACTIONS(937),
    [anon_sym_throw] = ACTIONS(937),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_while] = ACTIONS(937),
    [anon_sym_break] = ACTIONS(937),
    [anon_sym_continue] = ACTIONS(937),
    [anon_sym_QMARK_DOT] = ACTIONS(939),
    [anon_sym_BQUOTE] = ACTIONS(939),
    [anon_sym_DOLLARr] = ACTIONS(937),
    [anon_sym_PLUS_PLUS] = ACTIONS(939),
    [anon_sym_DASH_DASH] = ACTIONS(939),
    [anon_sym_new] = ACTIONS(937),
  },
  [STATE(390)] = {
    [sym_comment] = STATE(390),
    [sym_modifier_chain_expression] = STATE(423),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(855),
    [anon_sym_LBRACE] = ACTIONS(857),
    [anon_sym_RBRACE] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_as] = ACTIONS(855),
    [anon_sym_SEMI] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(857),
    [anon_sym_DOT] = ACTIONS(428),
    [sym_identifier] = ACTIONS(855),
    [anon_sym_DQUOTE] = ACTIONS(857),
    [anon_sym_SQUOTE] = ACTIONS(857),
    [anon_sym_DOLLAR] = ACTIONS(855),
    [sym_numeric_literal] = ACTIONS(857),
    [anon_sym_true] = ACTIONS(855),
    [anon_sym_false] = ACTIONS(855),
    [anon_sym_null] = ACTIONS(855),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(855),
    [anon_sym_CARET] = ACTIONS(857),
    [anon_sym_AMP] = ACTIONS(855),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(857),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(857),
    [anon_sym_LT] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(857),
    [anon_sym_instanceof] = ACTIONS(855),
    [anon_sym_in] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_GT_GT_GT] = ACTIONS(857),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(855),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_STAR_STAR] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(855),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_typeof] = ACTIONS(855),
    [anon_sym_void] = ACTIONS(855),
    [anon_sym_delete] = ACTIONS(855),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_await] = ACTIONS(855),
    [anon_sym_LBRACK] = ACTIONS(857),
    [anon_sym_if] = ACTIONS(855),
    [anon_sym_async] = ACTIONS(855),
    [anon_sym_var] = ACTIONS(855),
    [anon_sym_let] = ACTIONS(855),
    [anon_sym_const] = ACTIONS(855),
    [anon_sym_return] = ACTIONS(855),
    [anon_sym_try] = ACTIONS(855),
    [anon_sym_throw] = ACTIONS(855),
    [anon_sym_for] = ACTIONS(855),
    [anon_sym_while] = ACTIONS(855),
    [anon_sym_break] = ACTIONS(855),
    [anon_sym_continue] = ACTIONS(855),
    [anon_sym_QMARK_DOT] = ACTIONS(857),
    [anon_sym_BQUOTE] = ACTIONS(857),
    [anon_sym_DOLLARr] = ACTIONS(855),
    [anon_sym_PLUS_PLUS] = ACTIONS(857),
    [anon_sym_DASH_DASH] = ACTIONS(857),
    [anon_sym_new] = ACTIONS(855),
  },
  [STATE(391)] = {
    [sym_comment] = STATE(391),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(891),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(891),
    [anon_sym_as] = ACTIONS(891),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(893),
    [sym_identifier] = ACTIONS(891),
    [anon_sym_DQUOTE] = ACTIONS(893),
    [anon_sym_SQUOTE] = ACTIONS(893),
    [anon_sym_DOLLAR] = ACTIONS(891),
    [sym_numeric_literal] = ACTIONS(893),
    [anon_sym_true] = ACTIONS(891),
    [anon_sym_false] = ACTIONS(891),
    [anon_sym_null] = ACTIONS(891),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_PIPE] = ACTIONS(891),
    [anon_sym_CARET] = ACTIONS(893),
    [anon_sym_AMP] = ACTIONS(891),
    [anon_sym_EQ_EQ] = ACTIONS(891),
    [anon_sym_BANG_EQ] = ACTIONS(891),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(891),
    [anon_sym_GT] = ACTIONS(891),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_instanceof] = ACTIONS(891),
    [anon_sym_in] = ACTIONS(891),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(891),
    [anon_sym_GT_GT_GT] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(891),
    [anon_sym_DASH] = ACTIONS(891),
    [anon_sym_PERCENT] = ACTIONS(893),
    [anon_sym_STAR_STAR] = ACTIONS(893),
    [anon_sym_BANG] = ACTIONS(891),
    [anon_sym_TILDE] = ACTIONS(893),
    [anon_sym_typeof] = ACTIONS(891),
    [anon_sym_void] = ACTIONS(891),
    [anon_sym_delete] = ACTIONS(891),
    [anon_sym_QMARK] = ACTIONS(891),
    [anon_sym_await] = ACTIONS(891),
    [anon_sym_LBRACK] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(891),
    [anon_sym_else] = ACTIONS(891),
    [anon_sym_async] = ACTIONS(891),
    [anon_sym_var] = ACTIONS(891),
    [anon_sym_let] = ACTIONS(891),
    [anon_sym_const] = ACTIONS(891),
    [anon_sym_return] = ACTIONS(891),
    [anon_sym_try] = ACTIONS(891),
    [anon_sym_throw] = ACTIONS(891),
    [anon_sym_for] = ACTIONS(891),
    [anon_sym_while] = ACTIONS(891),
    [anon_sym_break] = ACTIONS(891),
    [anon_sym_continue] = ACTIONS(891),
    [anon_sym_QMARK_DOT] = ACTIONS(893),
    [anon_sym_BQUOTE] = ACTIONS(893),
    [anon_sym_DOLLARr] = ACTIONS(891),
    [anon_sym_PLUS_PLUS] = ACTIONS(893),
    [anon_sym_DASH_DASH] = ACTIONS(893),
    [anon_sym_new] = ACTIONS(891),
  },
  [STATE(392)] = {
    [sym_comment] = STATE(392),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_extends] = ACTIONS(61),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(393)] = {
    [sym_comment] = STATE(393),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(719),
    [anon_sym_LBRACE] = ACTIONS(717),
    [anon_sym_RBRACE] = ACTIONS(717),
    [anon_sym_STAR] = ACTIONS(719),
    [anon_sym_as] = ACTIONS(719),
    [anon_sym_SEMI] = ACTIONS(717),
    [anon_sym_LPAREN] = ACTIONS(717),
    [anon_sym_DOT] = ACTIONS(717),
    [sym_identifier] = ACTIONS(719),
    [anon_sym_DQUOTE] = ACTIONS(717),
    [anon_sym_SQUOTE] = ACTIONS(717),
    [anon_sym_DOLLAR] = ACTIONS(719),
    [sym_numeric_literal] = ACTIONS(717),
    [anon_sym_true] = ACTIONS(719),
    [anon_sym_false] = ACTIONS(719),
    [anon_sym_null] = ACTIONS(719),
    [anon_sym_PIPE_PIPE] = ACTIONS(717),
    [anon_sym_AMP_AMP] = ACTIONS(717),
    [anon_sym_PIPE] = ACTIONS(719),
    [anon_sym_CARET] = ACTIONS(717),
    [anon_sym_AMP] = ACTIONS(719),
    [anon_sym_EQ_EQ] = ACTIONS(719),
    [anon_sym_BANG_EQ] = ACTIONS(719),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(717),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(717),
    [anon_sym_LT] = ACTIONS(719),
    [anon_sym_GT] = ACTIONS(719),
    [anon_sym_LT_EQ] = ACTIONS(717),
    [anon_sym_GT_EQ] = ACTIONS(717),
    [anon_sym_instanceof] = ACTIONS(719),
    [anon_sym_in] = ACTIONS(719),
    [anon_sym_LT_LT] = ACTIONS(717),
    [anon_sym_GT_GT] = ACTIONS(719),
    [anon_sym_GT_GT_GT] = ACTIONS(717),
    [anon_sym_PLUS] = ACTIONS(719),
    [anon_sym_DASH] = ACTIONS(719),
    [anon_sym_PERCENT] = ACTIONS(717),
    [anon_sym_STAR_STAR] = ACTIONS(717),
    [anon_sym_BANG] = ACTIONS(719),
    [anon_sym_TILDE] = ACTIONS(717),
    [anon_sym_typeof] = ACTIONS(719),
    [anon_sym_void] = ACTIONS(719),
    [anon_sym_delete] = ACTIONS(719),
    [anon_sym_QMARK] = ACTIONS(719),
    [anon_sym_await] = ACTIONS(719),
    [anon_sym_LBRACK] = ACTIONS(717),
    [anon_sym_if] = ACTIONS(719),
    [anon_sym_async] = ACTIONS(719),
    [anon_sym_var] = ACTIONS(719),
    [anon_sym_let] = ACTIONS(719),
    [anon_sym_const] = ACTIONS(719),
    [anon_sym_return] = ACTIONS(719),
    [anon_sym_try] = ACTIONS(719),
    [anon_sym_throw] = ACTIONS(719),
    [anon_sym_for] = ACTIONS(719),
    [anon_sym_while] = ACTIONS(719),
    [anon_sym_break] = ACTIONS(719),
    [anon_sym_continue] = ACTIONS(719),
    [anon_sym_QMARK_DOT] = ACTIONS(717),
    [anon_sym_BQUOTE] = ACTIONS(717),
    [anon_sym_DOLLARr] = ACTIONS(719),
    [anon_sym_PLUS_PLUS] = ACTIONS(717),
    [anon_sym_DASH_DASH] = ACTIONS(717),
    [anon_sym_new] = ACTIONS(719),
  },
  [STATE(394)] = {
    [sym_comment] = STATE(394),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(945),
    [anon_sym_LBRACE] = ACTIONS(947),
    [anon_sym_RBRACE] = ACTIONS(947),
    [anon_sym_STAR] = ACTIONS(945),
    [anon_sym_as] = ACTIONS(945),
    [anon_sym_SEMI] = ACTIONS(947),
    [anon_sym_LPAREN] = ACTIONS(947),
    [anon_sym_DOT] = ACTIONS(947),
    [sym_identifier] = ACTIONS(945),
    [anon_sym_DQUOTE] = ACTIONS(947),
    [anon_sym_SQUOTE] = ACTIONS(947),
    [anon_sym_DOLLAR] = ACTIONS(945),
    [sym_numeric_literal] = ACTIONS(947),
    [anon_sym_true] = ACTIONS(945),
    [anon_sym_false] = ACTIONS(945),
    [anon_sym_null] = ACTIONS(945),
    [anon_sym_PIPE_PIPE] = ACTIONS(947),
    [anon_sym_AMP_AMP] = ACTIONS(947),
    [anon_sym_PIPE] = ACTIONS(945),
    [anon_sym_CARET] = ACTIONS(947),
    [anon_sym_AMP] = ACTIONS(945),
    [anon_sym_EQ_EQ] = ACTIONS(945),
    [anon_sym_BANG_EQ] = ACTIONS(945),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(947),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(947),
    [anon_sym_LT] = ACTIONS(945),
    [anon_sym_GT] = ACTIONS(945),
    [anon_sym_LT_EQ] = ACTIONS(947),
    [anon_sym_GT_EQ] = ACTIONS(947),
    [anon_sym_instanceof] = ACTIONS(945),
    [anon_sym_in] = ACTIONS(945),
    [anon_sym_LT_LT] = ACTIONS(947),
    [anon_sym_GT_GT] = ACTIONS(945),
    [anon_sym_GT_GT_GT] = ACTIONS(947),
    [anon_sym_PLUS] = ACTIONS(945),
    [anon_sym_DASH] = ACTIONS(945),
    [anon_sym_PERCENT] = ACTIONS(947),
    [anon_sym_STAR_STAR] = ACTIONS(947),
    [anon_sym_BANG] = ACTIONS(945),
    [anon_sym_TILDE] = ACTIONS(947),
    [anon_sym_typeof] = ACTIONS(945),
    [anon_sym_void] = ACTIONS(945),
    [anon_sym_delete] = ACTIONS(945),
    [anon_sym_QMARK] = ACTIONS(945),
    [anon_sym_await] = ACTIONS(945),
    [anon_sym_LBRACK] = ACTIONS(947),
    [anon_sym_if] = ACTIONS(945),
    [anon_sym_async] = ACTIONS(945),
    [anon_sym_var] = ACTIONS(945),
    [anon_sym_let] = ACTIONS(945),
    [anon_sym_const] = ACTIONS(945),
    [anon_sym_return] = ACTIONS(945),
    [anon_sym_try] = ACTIONS(945),
    [anon_sym_throw] = ACTIONS(945),
    [anon_sym_for] = ACTIONS(945),
    [anon_sym_while] = ACTIONS(945),
    [anon_sym_break] = ACTIONS(945),
    [anon_sym_continue] = ACTIONS(945),
    [anon_sym_QMARK_DOT] = ACTIONS(947),
    [anon_sym_BQUOTE] = ACTIONS(947),
    [anon_sym_DOLLARr] = ACTIONS(945),
    [anon_sym_PLUS_PLUS] = ACTIONS(947),
    [anon_sym_DASH_DASH] = ACTIONS(947),
    [anon_sym_new] = ACTIONS(945),
  },
  [STATE(395)] = {
    [sym_comment] = STATE(395),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(953),
    [anon_sym_LBRACE] = ACTIONS(955),
    [anon_sym_RBRACE] = ACTIONS(955),
    [anon_sym_STAR] = ACTIONS(953),
    [anon_sym_as] = ACTIONS(953),
    [anon_sym_SEMI] = ACTIONS(955),
    [anon_sym_LPAREN] = ACTIONS(955),
    [anon_sym_DOT] = ACTIONS(955),
    [sym_identifier] = ACTIONS(953),
    [anon_sym_DQUOTE] = ACTIONS(955),
    [anon_sym_SQUOTE] = ACTIONS(955),
    [anon_sym_DOLLAR] = ACTIONS(953),
    [sym_numeric_literal] = ACTIONS(955),
    [anon_sym_true] = ACTIONS(953),
    [anon_sym_false] = ACTIONS(953),
    [anon_sym_null] = ACTIONS(953),
    [anon_sym_PIPE_PIPE] = ACTIONS(955),
    [anon_sym_AMP_AMP] = ACTIONS(955),
    [anon_sym_PIPE] = ACTIONS(953),
    [anon_sym_CARET] = ACTIONS(955),
    [anon_sym_AMP] = ACTIONS(953),
    [anon_sym_EQ_EQ] = ACTIONS(953),
    [anon_sym_BANG_EQ] = ACTIONS(953),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(955),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(955),
    [anon_sym_LT] = ACTIONS(953),
    [anon_sym_GT] = ACTIONS(953),
    [anon_sym_LT_EQ] = ACTIONS(955),
    [anon_sym_GT_EQ] = ACTIONS(955),
    [anon_sym_instanceof] = ACTIONS(953),
    [anon_sym_in] = ACTIONS(953),
    [anon_sym_LT_LT] = ACTIONS(955),
    [anon_sym_GT_GT] = ACTIONS(953),
    [anon_sym_GT_GT_GT] = ACTIONS(955),
    [anon_sym_PLUS] = ACTIONS(953),
    [anon_sym_DASH] = ACTIONS(953),
    [anon_sym_PERCENT] = ACTIONS(955),
    [anon_sym_STAR_STAR] = ACTIONS(955),
    [anon_sym_BANG] = ACTIONS(953),
    [anon_sym_TILDE] = ACTIONS(955),
    [anon_sym_typeof] = ACTIONS(953),
    [anon_sym_void] = ACTIONS(953),
    [anon_sym_delete] = ACTIONS(953),
    [anon_sym_QMARK] = ACTIONS(953),
    [anon_sym_await] = ACTIONS(953),
    [anon_sym_LBRACK] = ACTIONS(955),
    [anon_sym_if] = ACTIONS(953),
    [anon_sym_async] = ACTIONS(953),
    [anon_sym_var] = ACTIONS(953),
    [anon_sym_let] = ACTIONS(953),
    [anon_sym_const] = ACTIONS(953),
    [anon_sym_return] = ACTIONS(953),
    [anon_sym_try] = ACTIONS(953),
    [anon_sym_throw] = ACTIONS(953),
    [anon_sym_for] = ACTIONS(953),
    [anon_sym_while] = ACTIONS(953),
    [anon_sym_break] = ACTIONS(953),
    [anon_sym_continue] = ACTIONS(953),
    [anon_sym_QMARK_DOT] = ACTIONS(955),
    [anon_sym_BQUOTE] = ACTIONS(955),
    [anon_sym_DOLLARr] = ACTIONS(953),
    [anon_sym_PLUS_PLUS] = ACTIONS(955),
    [anon_sym_DASH_DASH] = ACTIONS(955),
    [anon_sym_new] = ACTIONS(953),
  },
  [STATE(396)] = {
    [sym_comment] = STATE(396),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_LBRACE] = ACTIONS(37),
    [anon_sym_RBRACE] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_DOT] = ACTIONS(37),
    [sym_identifier] = ACTIONS(35),
    [anon_sym_DQUOTE] = ACTIONS(37),
    [anon_sym_SQUOTE] = ACTIONS(37),
    [anon_sym_DOLLAR] = ACTIONS(35),
    [sym_numeric_literal] = ACTIONS(37),
    [anon_sym_true] = ACTIONS(35),
    [anon_sym_false] = ACTIONS(35),
    [anon_sym_null] = ACTIONS(35),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(37),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(35),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(37),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(37),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(37),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_BANG] = ACTIONS(35),
    [anon_sym_TILDE] = ACTIONS(37),
    [anon_sym_typeof] = ACTIONS(35),
    [anon_sym_void] = ACTIONS(35),
    [anon_sym_delete] = ACTIONS(35),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_await] = ACTIONS(35),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_async] = ACTIONS(35),
    [anon_sym_var] = ACTIONS(35),
    [anon_sym_let] = ACTIONS(35),
    [anon_sym_const] = ACTIONS(35),
    [anon_sym_return] = ACTIONS(35),
    [anon_sym_try] = ACTIONS(35),
    [anon_sym_throw] = ACTIONS(35),
    [anon_sym_for] = ACTIONS(35),
    [anon_sym_while] = ACTIONS(35),
    [anon_sym_break] = ACTIONS(35),
    [anon_sym_continue] = ACTIONS(35),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_BQUOTE] = ACTIONS(37),
    [anon_sym_DOLLARr] = ACTIONS(35),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
    [anon_sym_new] = ACTIONS(35),
  },
  [STATE(397)] = {
    [sym_comment] = STATE(397),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(731),
    [anon_sym_LBRACE] = ACTIONS(733),
    [anon_sym_RBRACE] = ACTIONS(733),
    [anon_sym_STAR] = ACTIONS(731),
    [anon_sym_as] = ACTIONS(731),
    [anon_sym_SEMI] = ACTIONS(733),
    [anon_sym_LPAREN] = ACTIONS(733),
    [anon_sym_DOT] = ACTIONS(733),
    [sym_identifier] = ACTIONS(731),
    [anon_sym_DQUOTE] = ACTIONS(733),
    [anon_sym_SQUOTE] = ACTIONS(733),
    [anon_sym_DOLLAR] = ACTIONS(731),
    [sym_numeric_literal] = ACTIONS(733),
    [anon_sym_true] = ACTIONS(731),
    [anon_sym_false] = ACTIONS(731),
    [anon_sym_null] = ACTIONS(731),
    [anon_sym_PIPE_PIPE] = ACTIONS(733),
    [anon_sym_AMP_AMP] = ACTIONS(733),
    [anon_sym_PIPE] = ACTIONS(731),
    [anon_sym_CARET] = ACTIONS(733),
    [anon_sym_AMP] = ACTIONS(731),
    [anon_sym_EQ_EQ] = ACTIONS(731),
    [anon_sym_BANG_EQ] = ACTIONS(731),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(733),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(733),
    [anon_sym_LT] = ACTIONS(731),
    [anon_sym_GT] = ACTIONS(731),
    [anon_sym_LT_EQ] = ACTIONS(733),
    [anon_sym_GT_EQ] = ACTIONS(733),
    [anon_sym_instanceof] = ACTIONS(731),
    [anon_sym_in] = ACTIONS(731),
    [anon_sym_LT_LT] = ACTIONS(733),
    [anon_sym_GT_GT] = ACTIONS(731),
    [anon_sym_GT_GT_GT] = ACTIONS(733),
    [anon_sym_PLUS] = ACTIONS(731),
    [anon_sym_DASH] = ACTIONS(731),
    [anon_sym_PERCENT] = ACTIONS(733),
    [anon_sym_STAR_STAR] = ACTIONS(733),
    [anon_sym_BANG] = ACTIONS(731),
    [anon_sym_TILDE] = ACTIONS(733),
    [anon_sym_typeof] = ACTIONS(731),
    [anon_sym_void] = ACTIONS(731),
    [anon_sym_delete] = ACTIONS(731),
    [anon_sym_QMARK] = ACTIONS(731),
    [anon_sym_await] = ACTIONS(731),
    [anon_sym_LBRACK] = ACTIONS(733),
    [anon_sym_if] = ACTIONS(731),
    [anon_sym_async] = ACTIONS(731),
    [anon_sym_var] = ACTIONS(731),
    [anon_sym_let] = ACTIONS(731),
    [anon_sym_const] = ACTIONS(731),
    [anon_sym_return] = ACTIONS(731),
    [anon_sym_try] = ACTIONS(731),
    [anon_sym_throw] = ACTIONS(731),
    [anon_sym_for] = ACTIONS(731),
    [anon_sym_while] = ACTIONS(731),
    [anon_sym_break] = ACTIONS(731),
    [anon_sym_continue] = ACTIONS(731),
    [anon_sym_QMARK_DOT] = ACTIONS(733),
    [anon_sym_BQUOTE] = ACTIONS(733),
    [anon_sym_DOLLARr] = ACTIONS(731),
    [anon_sym_PLUS_PLUS] = ACTIONS(733),
    [anon_sym_DASH_DASH] = ACTIONS(733),
    [anon_sym_new] = ACTIONS(731),
  },
  [STATE(398)] = {
    [sym_comment] = STATE(398),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(738),
    [anon_sym_LBRACE] = ACTIONS(740),
    [anon_sym_RBRACE] = ACTIONS(740),
    [anon_sym_STAR] = ACTIONS(738),
    [anon_sym_as] = ACTIONS(738),
    [anon_sym_SEMI] = ACTIONS(740),
    [anon_sym_LPAREN] = ACTIONS(740),
    [anon_sym_DOT] = ACTIONS(740),
    [sym_identifier] = ACTIONS(738),
    [anon_sym_DQUOTE] = ACTIONS(740),
    [anon_sym_SQUOTE] = ACTIONS(740),
    [anon_sym_DOLLAR] = ACTIONS(738),
    [sym_numeric_literal] = ACTIONS(740),
    [anon_sym_true] = ACTIONS(738),
    [anon_sym_false] = ACTIONS(738),
    [anon_sym_null] = ACTIONS(738),
    [anon_sym_PIPE_PIPE] = ACTIONS(740),
    [anon_sym_AMP_AMP] = ACTIONS(740),
    [anon_sym_PIPE] = ACTIONS(738),
    [anon_sym_CARET] = ACTIONS(740),
    [anon_sym_AMP] = ACTIONS(738),
    [anon_sym_EQ_EQ] = ACTIONS(738),
    [anon_sym_BANG_EQ] = ACTIONS(738),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(740),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(740),
    [anon_sym_LT] = ACTIONS(738),
    [anon_sym_GT] = ACTIONS(738),
    [anon_sym_LT_EQ] = ACTIONS(740),
    [anon_sym_GT_EQ] = ACTIONS(740),
    [anon_sym_instanceof] = ACTIONS(738),
    [anon_sym_in] = ACTIONS(738),
    [anon_sym_LT_LT] = ACTIONS(740),
    [anon_sym_GT_GT] = ACTIONS(738),
    [anon_sym_GT_GT_GT] = ACTIONS(740),
    [anon_sym_PLUS] = ACTIONS(738),
    [anon_sym_DASH] = ACTIONS(738),
    [anon_sym_PERCENT] = ACTIONS(740),
    [anon_sym_STAR_STAR] = ACTIONS(740),
    [anon_sym_BANG] = ACTIONS(738),
    [anon_sym_TILDE] = ACTIONS(740),
    [anon_sym_typeof] = ACTIONS(738),
    [anon_sym_void] = ACTIONS(738),
    [anon_sym_delete] = ACTIONS(738),
    [anon_sym_QMARK] = ACTIONS(738),
    [anon_sym_await] = ACTIONS(738),
    [anon_sym_LBRACK] = ACTIONS(740),
    [anon_sym_if] = ACTIONS(738),
    [anon_sym_async] = ACTIONS(738),
    [anon_sym_var] = ACTIONS(738),
    [anon_sym_let] = ACTIONS(738),
    [anon_sym_const] = ACTIONS(738),
    [anon_sym_return] = ACTIONS(738),
    [anon_sym_try] = ACTIONS(738),
    [anon_sym_throw] = ACTIONS(738),
    [anon_sym_for] = ACTIONS(738),
    [anon_sym_while] = ACTIONS(738),
    [anon_sym_break] = ACTIONS(738),
    [anon_sym_continue] = ACTIONS(738),
    [anon_sym_QMARK_DOT] = ACTIONS(740),
    [anon_sym_BQUOTE] = ACTIONS(740),
    [anon_sym_DOLLARr] = ACTIONS(738),
    [anon_sym_PLUS_PLUS] = ACTIONS(740),
    [anon_sym_DASH_DASH] = ACTIONS(740),
    [anon_sym_new] = ACTIONS(738),
  },
  [STATE(399)] = {
    [sym_comment] = STATE(399),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(836),
    [anon_sym_LBRACE] = ACTIONS(838),
    [anon_sym_RBRACE] = ACTIONS(838),
    [anon_sym_STAR] = ACTIONS(836),
    [anon_sym_as] = ACTIONS(836),
    [anon_sym_SEMI] = ACTIONS(838),
    [anon_sym_LPAREN] = ACTIONS(838),
    [anon_sym_DOT] = ACTIONS(838),
    [sym_identifier] = ACTIONS(836),
    [anon_sym_DQUOTE] = ACTIONS(838),
    [anon_sym_SQUOTE] = ACTIONS(838),
    [anon_sym_DOLLAR] = ACTIONS(836),
    [sym_numeric_literal] = ACTIONS(838),
    [anon_sym_true] = ACTIONS(836),
    [anon_sym_false] = ACTIONS(836),
    [anon_sym_null] = ACTIONS(836),
    [anon_sym_PIPE_PIPE] = ACTIONS(838),
    [anon_sym_AMP_AMP] = ACTIONS(838),
    [anon_sym_PIPE] = ACTIONS(836),
    [anon_sym_CARET] = ACTIONS(838),
    [anon_sym_AMP] = ACTIONS(836),
    [anon_sym_EQ_EQ] = ACTIONS(836),
    [anon_sym_BANG_EQ] = ACTIONS(836),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(838),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(838),
    [anon_sym_LT] = ACTIONS(836),
    [anon_sym_GT] = ACTIONS(836),
    [anon_sym_LT_EQ] = ACTIONS(838),
    [anon_sym_GT_EQ] = ACTIONS(838),
    [anon_sym_instanceof] = ACTIONS(836),
    [anon_sym_in] = ACTIONS(836),
    [anon_sym_LT_LT] = ACTIONS(838),
    [anon_sym_GT_GT] = ACTIONS(836),
    [anon_sym_GT_GT_GT] = ACTIONS(838),
    [anon_sym_PLUS] = ACTIONS(836),
    [anon_sym_DASH] = ACTIONS(836),
    [anon_sym_PERCENT] = ACTIONS(838),
    [anon_sym_STAR_STAR] = ACTIONS(838),
    [anon_sym_BANG] = ACTIONS(836),
    [anon_sym_TILDE] = ACTIONS(838),
    [anon_sym_typeof] = ACTIONS(836),
    [anon_sym_void] = ACTIONS(836),
    [anon_sym_delete] = ACTIONS(836),
    [anon_sym_QMARK] = ACTIONS(836),
    [anon_sym_await] = ACTIONS(836),
    [anon_sym_LBRACK] = ACTIONS(838),
    [anon_sym_if] = ACTIONS(836),
    [anon_sym_async] = ACTIONS(836),
    [anon_sym_var] = ACTIONS(836),
    [anon_sym_let] = ACTIONS(836),
    [anon_sym_const] = ACTIONS(836),
    [anon_sym_return] = ACTIONS(836),
    [anon_sym_try] = ACTIONS(836),
    [anon_sym_throw] = ACTIONS(836),
    [anon_sym_for] = ACTIONS(836),
    [anon_sym_while] = ACTIONS(836),
    [anon_sym_break] = ACTIONS(836),
    [anon_sym_continue] = ACTIONS(836),
    [anon_sym_QMARK_DOT] = ACTIONS(838),
    [anon_sym_BQUOTE] = ACTIONS(838),
    [anon_sym_DOLLARr] = ACTIONS(836),
    [anon_sym_PLUS_PLUS] = ACTIONS(838),
    [anon_sym_DASH_DASH] = ACTIONS(838),
    [anon_sym_new] = ACTIONS(836),
  },
  [STATE(400)] = {
    [sym_comment] = STATE(400),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(957),
    [anon_sym_LBRACE] = ACTIONS(959),
    [anon_sym_RBRACE] = ACTIONS(959),
    [anon_sym_STAR] = ACTIONS(957),
    [anon_sym_as] = ACTIONS(957),
    [anon_sym_SEMI] = ACTIONS(959),
    [anon_sym_LPAREN] = ACTIONS(959),
    [anon_sym_DOT] = ACTIONS(959),
    [sym_identifier] = ACTIONS(957),
    [anon_sym_DQUOTE] = ACTIONS(959),
    [anon_sym_SQUOTE] = ACTIONS(959),
    [anon_sym_DOLLAR] = ACTIONS(957),
    [sym_numeric_literal] = ACTIONS(959),
    [anon_sym_true] = ACTIONS(957),
    [anon_sym_false] = ACTIONS(957),
    [anon_sym_null] = ACTIONS(957),
    [anon_sym_PIPE_PIPE] = ACTIONS(959),
    [anon_sym_AMP_AMP] = ACTIONS(959),
    [anon_sym_PIPE] = ACTIONS(957),
    [anon_sym_CARET] = ACTIONS(959),
    [anon_sym_AMP] = ACTIONS(957),
    [anon_sym_EQ_EQ] = ACTIONS(957),
    [anon_sym_BANG_EQ] = ACTIONS(957),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(959),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(959),
    [anon_sym_LT] = ACTIONS(957),
    [anon_sym_GT] = ACTIONS(957),
    [anon_sym_LT_EQ] = ACTIONS(959),
    [anon_sym_GT_EQ] = ACTIONS(959),
    [anon_sym_instanceof] = ACTIONS(957),
    [anon_sym_in] = ACTIONS(957),
    [anon_sym_LT_LT] = ACTIONS(959),
    [anon_sym_GT_GT] = ACTIONS(957),
    [anon_sym_GT_GT_GT] = ACTIONS(959),
    [anon_sym_PLUS] = ACTIONS(957),
    [anon_sym_DASH] = ACTIONS(957),
    [anon_sym_PERCENT] = ACTIONS(959),
    [anon_sym_STAR_STAR] = ACTIONS(959),
    [anon_sym_BANG] = ACTIONS(957),
    [anon_sym_TILDE] = ACTIONS(959),
    [anon_sym_typeof] = ACTIONS(957),
    [anon_sym_void] = ACTIONS(957),
    [anon_sym_delete] = ACTIONS(957),
    [anon_sym_QMARK] = ACTIONS(957),
    [anon_sym_await] = ACTIONS(957),
    [anon_sym_LBRACK] = ACTIONS(959),
    [anon_sym_if] = ACTIONS(957),
    [anon_sym_async] = ACTIONS(957),
    [anon_sym_var] = ACTIONS(957),
    [anon_sym_let] = ACTIONS(957),
    [anon_sym_const] = ACTIONS(957),
    [anon_sym_return] = ACTIONS(957),
    [anon_sym_try] = ACTIONS(957),
    [anon_sym_throw] = ACTIONS(957),
    [anon_sym_for] = ACTIONS(957),
    [anon_sym_while] = ACTIONS(957),
    [anon_sym_break] = ACTIONS(957),
    [anon_sym_continue] = ACTIONS(957),
    [anon_sym_QMARK_DOT] = ACTIONS(959),
    [anon_sym_BQUOTE] = ACTIONS(959),
    [anon_sym_DOLLARr] = ACTIONS(957),
    [anon_sym_PLUS_PLUS] = ACTIONS(959),
    [anon_sym_DASH_DASH] = ACTIONS(959),
    [anon_sym_new] = ACTIONS(957),
  },
  [STATE(401)] = {
    [sym_comment] = STATE(401),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(969),
    [anon_sym_LBRACE] = ACTIONS(971),
    [anon_sym_RBRACE] = ACTIONS(971),
    [anon_sym_STAR] = ACTIONS(969),
    [anon_sym_as] = ACTIONS(969),
    [anon_sym_SEMI] = ACTIONS(971),
    [anon_sym_LPAREN] = ACTIONS(971),
    [anon_sym_DOT] = ACTIONS(971),
    [sym_identifier] = ACTIONS(969),
    [anon_sym_DQUOTE] = ACTIONS(971),
    [anon_sym_SQUOTE] = ACTIONS(971),
    [anon_sym_DOLLAR] = ACTIONS(969),
    [sym_numeric_literal] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(969),
    [anon_sym_false] = ACTIONS(969),
    [anon_sym_null] = ACTIONS(969),
    [anon_sym_PIPE_PIPE] = ACTIONS(971),
    [anon_sym_AMP_AMP] = ACTIONS(971),
    [anon_sym_PIPE] = ACTIONS(969),
    [anon_sym_CARET] = ACTIONS(971),
    [anon_sym_AMP] = ACTIONS(969),
    [anon_sym_EQ_EQ] = ACTIONS(969),
    [anon_sym_BANG_EQ] = ACTIONS(969),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(971),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(971),
    [anon_sym_LT] = ACTIONS(969),
    [anon_sym_GT] = ACTIONS(969),
    [anon_sym_LT_EQ] = ACTIONS(971),
    [anon_sym_GT_EQ] = ACTIONS(971),
    [anon_sym_instanceof] = ACTIONS(969),
    [anon_sym_in] = ACTIONS(969),
    [anon_sym_LT_LT] = ACTIONS(971),
    [anon_sym_GT_GT] = ACTIONS(969),
    [anon_sym_GT_GT_GT] = ACTIONS(971),
    [anon_sym_PLUS] = ACTIONS(969),
    [anon_sym_DASH] = ACTIONS(969),
    [anon_sym_PERCENT] = ACTIONS(971),
    [anon_sym_STAR_STAR] = ACTIONS(971),
    [anon_sym_BANG] = ACTIONS(969),
    [anon_sym_TILDE] = ACTIONS(971),
    [anon_sym_typeof] = ACTIONS(969),
    [anon_sym_void] = ACTIONS(969),
    [anon_sym_delete] = ACTIONS(969),
    [anon_sym_QMARK] = ACTIONS(969),
    [anon_sym_await] = ACTIONS(969),
    [anon_sym_LBRACK] = ACTIONS(971),
    [anon_sym_if] = ACTIONS(969),
    [anon_sym_async] = ACTIONS(969),
    [anon_sym_var] = ACTIONS(969),
    [anon_sym_let] = ACTIONS(969),
    [anon_sym_const] = ACTIONS(969),
    [anon_sym_return] = ACTIONS(969),
    [anon_sym_try] = ACTIONS(969),
    [anon_sym_throw] = ACTIONS(969),
    [anon_sym_for] = ACTIONS(969),
    [anon_sym_while] = ACTIONS(969),
    [anon_sym_break] = ACTIONS(969),
    [anon_sym_continue] = ACTIONS(969),
    [anon_sym_QMARK_DOT] = ACTIONS(971),
    [anon_sym_BQUOTE] = ACTIONS(971),
    [anon_sym_DOLLARr] = ACTIONS(969),
    [anon_sym_PLUS_PLUS] = ACTIONS(971),
    [anon_sym_DASH_DASH] = ACTIONS(971),
    [anon_sym_new] = ACTIONS(969),
  },
  [STATE(402)] = {
    [sym_comment] = STATE(402),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(969),
    [anon_sym_LBRACE] = ACTIONS(971),
    [anon_sym_RBRACE] = ACTIONS(971),
    [anon_sym_STAR] = ACTIONS(969),
    [anon_sym_as] = ACTIONS(969),
    [anon_sym_SEMI] = ACTIONS(971),
    [anon_sym_LPAREN] = ACTIONS(971),
    [anon_sym_DOT] = ACTIONS(971),
    [sym_identifier] = ACTIONS(969),
    [anon_sym_DQUOTE] = ACTIONS(971),
    [anon_sym_SQUOTE] = ACTIONS(971),
    [anon_sym_DOLLAR] = ACTIONS(969),
    [sym_numeric_literal] = ACTIONS(971),
    [anon_sym_true] = ACTIONS(969),
    [anon_sym_false] = ACTIONS(969),
    [anon_sym_null] = ACTIONS(969),
    [anon_sym_PIPE_PIPE] = ACTIONS(971),
    [anon_sym_AMP_AMP] = ACTIONS(971),
    [anon_sym_PIPE] = ACTIONS(969),
    [anon_sym_CARET] = ACTIONS(971),
    [anon_sym_AMP] = ACTIONS(969),
    [anon_sym_EQ_EQ] = ACTIONS(969),
    [anon_sym_BANG_EQ] = ACTIONS(969),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(971),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(971),
    [anon_sym_LT] = ACTIONS(969),
    [anon_sym_GT] = ACTIONS(969),
    [anon_sym_LT_EQ] = ACTIONS(971),
    [anon_sym_GT_EQ] = ACTIONS(971),
    [anon_sym_instanceof] = ACTIONS(969),
    [anon_sym_in] = ACTIONS(969),
    [anon_sym_LT_LT] = ACTIONS(971),
    [anon_sym_GT_GT] = ACTIONS(969),
    [anon_sym_GT_GT_GT] = ACTIONS(971),
    [anon_sym_PLUS] = ACTIONS(969),
    [anon_sym_DASH] = ACTIONS(969),
    [anon_sym_PERCENT] = ACTIONS(971),
    [anon_sym_STAR_STAR] = ACTIONS(971),
    [anon_sym_BANG] = ACTIONS(969),
    [anon_sym_TILDE] = ACTIONS(971),
    [anon_sym_typeof] = ACTIONS(969),
    [anon_sym_void] = ACTIONS(969),
    [anon_sym_delete] = ACTIONS(969),
    [anon_sym_QMARK] = ACTIONS(969),
    [anon_sym_await] = ACTIONS(969),
    [anon_sym_LBRACK] = ACTIONS(971),
    [anon_sym_if] = ACTIONS(969),
    [anon_sym_async] = ACTIONS(969),
    [anon_sym_var] = ACTIONS(969),
    [anon_sym_let] = ACTIONS(969),
    [anon_sym_const] = ACTIONS(969),
    [anon_sym_return] = ACTIONS(969),
    [anon_sym_try] = ACTIONS(969),
    [anon_sym_throw] = ACTIONS(969),
    [anon_sym_for] = ACTIONS(969),
    [anon_sym_while] = ACTIONS(969),
    [anon_sym_break] = ACTIONS(969),
    [anon_sym_continue] = ACTIONS(969),
    [anon_sym_QMARK_DOT] = ACTIONS(971),
    [anon_sym_BQUOTE] = ACTIONS(971),
    [anon_sym_DOLLARr] = ACTIONS(969),
    [anon_sym_PLUS_PLUS] = ACTIONS(971),
    [anon_sym_DASH_DASH] = ACTIONS(971),
    [anon_sym_new] = ACTIONS(969),
  },
  [STATE(403)] = {
    [sym_comment] = STATE(403),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(778),
    [anon_sym_LBRACE] = ACTIONS(780),
    [anon_sym_RBRACE] = ACTIONS(780),
    [anon_sym_STAR] = ACTIONS(778),
    [anon_sym_as] = ACTIONS(778),
    [anon_sym_SEMI] = ACTIONS(780),
    [anon_sym_LPAREN] = ACTIONS(780),
    [anon_sym_DOT] = ACTIONS(780),
    [sym_identifier] = ACTIONS(778),
    [anon_sym_DQUOTE] = ACTIONS(780),
    [anon_sym_SQUOTE] = ACTIONS(780),
    [anon_sym_DOLLAR] = ACTIONS(778),
    [sym_numeric_literal] = ACTIONS(780),
    [anon_sym_true] = ACTIONS(778),
    [anon_sym_false] = ACTIONS(778),
    [anon_sym_null] = ACTIONS(778),
    [anon_sym_PIPE_PIPE] = ACTIONS(780),
    [anon_sym_AMP_AMP] = ACTIONS(780),
    [anon_sym_PIPE] = ACTIONS(778),
    [anon_sym_CARET] = ACTIONS(780),
    [anon_sym_AMP] = ACTIONS(778),
    [anon_sym_EQ_EQ] = ACTIONS(778),
    [anon_sym_BANG_EQ] = ACTIONS(778),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(780),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(780),
    [anon_sym_LT] = ACTIONS(778),
    [anon_sym_GT] = ACTIONS(778),
    [anon_sym_LT_EQ] = ACTIONS(780),
    [anon_sym_GT_EQ] = ACTIONS(780),
    [anon_sym_instanceof] = ACTIONS(778),
    [anon_sym_in] = ACTIONS(778),
    [anon_sym_LT_LT] = ACTIONS(780),
    [anon_sym_GT_GT] = ACTIONS(778),
    [anon_sym_GT_GT_GT] = ACTIONS(780),
    [anon_sym_PLUS] = ACTIONS(778),
    [anon_sym_DASH] = ACTIONS(778),
    [anon_sym_PERCENT] = ACTIONS(780),
    [anon_sym_STAR_STAR] = ACTIONS(780),
    [anon_sym_BANG] = ACTIONS(778),
    [anon_sym_TILDE] = ACTIONS(780),
    [anon_sym_typeof] = ACTIONS(778),
    [anon_sym_void] = ACTIONS(778),
    [anon_sym_delete] = ACTIONS(778),
    [anon_sym_QMARK] = ACTIONS(778),
    [anon_sym_await] = ACTIONS(778),
    [anon_sym_LBRACK] = ACTIONS(780),
    [anon_sym_if] = ACTIONS(778),
    [anon_sym_async] = ACTIONS(778),
    [anon_sym_var] = ACTIONS(778),
    [anon_sym_let] = ACTIONS(778),
    [anon_sym_const] = ACTIONS(778),
    [anon_sym_return] = ACTIONS(778),
    [anon_sym_try] = ACTIONS(778),
    [anon_sym_throw] = ACTIONS(778),
    [anon_sym_for] = ACTIONS(778),
    [anon_sym_while] = ACTIONS(778),
    [anon_sym_break] = ACTIONS(778),
    [anon_sym_continue] = ACTIONS(778),
    [anon_sym_QMARK_DOT] = ACTIONS(780),
    [anon_sym_BQUOTE] = ACTIONS(780),
    [anon_sym_DOLLARr] = ACTIONS(778),
    [anon_sym_PLUS_PLUS] = ACTIONS(780),
    [anon_sym_DASH_DASH] = ACTIONS(780),
    [anon_sym_new] = ACTIONS(778),
  },
  [STATE(404)] = {
    [sym_comment] = STATE(404),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(754),
    [anon_sym_LBRACE] = ACTIONS(749),
    [anon_sym_RBRACE] = ACTIONS(749),
    [anon_sym_STAR] = ACTIONS(754),
    [anon_sym_as] = ACTIONS(754),
    [anon_sym_SEMI] = ACTIONS(749),
    [anon_sym_LPAREN] = ACTIONS(749),
    [anon_sym_DOT] = ACTIONS(749),
    [sym_identifier] = ACTIONS(754),
    [anon_sym_DQUOTE] = ACTIONS(749),
    [anon_sym_SQUOTE] = ACTIONS(749),
    [anon_sym_DOLLAR] = ACTIONS(754),
    [sym_numeric_literal] = ACTIONS(749),
    [anon_sym_true] = ACTIONS(754),
    [anon_sym_false] = ACTIONS(754),
    [anon_sym_null] = ACTIONS(754),
    [anon_sym_PIPE_PIPE] = ACTIONS(749),
    [anon_sym_AMP_AMP] = ACTIONS(749),
    [anon_sym_PIPE] = ACTIONS(754),
    [anon_sym_CARET] = ACTIONS(749),
    [anon_sym_AMP] = ACTIONS(754),
    [anon_sym_EQ_EQ] = ACTIONS(754),
    [anon_sym_BANG_EQ] = ACTIONS(754),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(749),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(749),
    [anon_sym_LT] = ACTIONS(754),
    [anon_sym_GT] = ACTIONS(754),
    [anon_sym_LT_EQ] = ACTIONS(749),
    [anon_sym_GT_EQ] = ACTIONS(749),
    [anon_sym_instanceof] = ACTIONS(754),
    [anon_sym_in] = ACTIONS(754),
    [anon_sym_LT_LT] = ACTIONS(749),
    [anon_sym_GT_GT] = ACTIONS(754),
    [anon_sym_GT_GT_GT] = ACTIONS(749),
    [anon_sym_PLUS] = ACTIONS(754),
    [anon_sym_DASH] = ACTIONS(754),
    [anon_sym_PERCENT] = ACTIONS(749),
    [anon_sym_STAR_STAR] = ACTIONS(749),
    [anon_sym_BANG] = ACTIONS(754),
    [anon_sym_TILDE] = ACTIONS(749),
    [anon_sym_typeof] = ACTIONS(754),
    [anon_sym_void] = ACTIONS(754),
    [anon_sym_delete] = ACTIONS(754),
    [anon_sym_QMARK] = ACTIONS(754),
    [anon_sym_await] = ACTIONS(754),
    [anon_sym_LBRACK] = ACTIONS(749),
    [anon_sym_if] = ACTIONS(754),
    [anon_sym_async] = ACTIONS(754),
    [anon_sym_var] = ACTIONS(754),
    [anon_sym_let] = ACTIONS(754),
    [anon_sym_const] = ACTIONS(754),
    [anon_sym_return] = ACTIONS(754),
    [anon_sym_try] = ACTIONS(754),
    [anon_sym_throw] = ACTIONS(754),
    [anon_sym_for] = ACTIONS(754),
    [anon_sym_while] = ACTIONS(754),
    [anon_sym_break] = ACTIONS(754),
    [anon_sym_continue] = ACTIONS(754),
    [anon_sym_QMARK_DOT] = ACTIONS(749),
    [anon_sym_BQUOTE] = ACTIONS(749),
    [anon_sym_DOLLARr] = ACTIONS(754),
    [anon_sym_PLUS_PLUS] = ACTIONS(749),
    [anon_sym_DASH_DASH] = ACTIONS(749),
    [anon_sym_new] = ACTIONS(754),
  },
  [STATE(405)] = {
    [sym_comment] = STATE(405),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(745),
    [anon_sym_LBRACE] = ACTIONS(747),
    [anon_sym_RBRACE] = ACTIONS(747),
    [anon_sym_STAR] = ACTIONS(745),
    [anon_sym_as] = ACTIONS(745),
    [anon_sym_SEMI] = ACTIONS(747),
    [anon_sym_LPAREN] = ACTIONS(747),
    [anon_sym_DOT] = ACTIONS(747),
    [sym_identifier] = ACTIONS(745),
    [anon_sym_DQUOTE] = ACTIONS(747),
    [anon_sym_SQUOTE] = ACTIONS(747),
    [anon_sym_DOLLAR] = ACTIONS(745),
    [sym_numeric_literal] = ACTIONS(747),
    [anon_sym_true] = ACTIONS(745),
    [anon_sym_false] = ACTIONS(745),
    [anon_sym_null] = ACTIONS(745),
    [anon_sym_PIPE_PIPE] = ACTIONS(747),
    [anon_sym_AMP_AMP] = ACTIONS(747),
    [anon_sym_PIPE] = ACTIONS(745),
    [anon_sym_CARET] = ACTIONS(747),
    [anon_sym_AMP] = ACTIONS(745),
    [anon_sym_EQ_EQ] = ACTIONS(745),
    [anon_sym_BANG_EQ] = ACTIONS(745),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(747),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(747),
    [anon_sym_LT] = ACTIONS(745),
    [anon_sym_GT] = ACTIONS(745),
    [anon_sym_LT_EQ] = ACTIONS(747),
    [anon_sym_GT_EQ] = ACTIONS(747),
    [anon_sym_instanceof] = ACTIONS(745),
    [anon_sym_in] = ACTIONS(745),
    [anon_sym_LT_LT] = ACTIONS(747),
    [anon_sym_GT_GT] = ACTIONS(745),
    [anon_sym_GT_GT_GT] = ACTIONS(747),
    [anon_sym_PLUS] = ACTIONS(745),
    [anon_sym_DASH] = ACTIONS(745),
    [anon_sym_PERCENT] = ACTIONS(747),
    [anon_sym_STAR_STAR] = ACTIONS(747),
    [anon_sym_BANG] = ACTIONS(745),
    [anon_sym_TILDE] = ACTIONS(747),
    [anon_sym_typeof] = ACTIONS(745),
    [anon_sym_void] = ACTIONS(745),
    [anon_sym_delete] = ACTIONS(745),
    [anon_sym_QMARK] = ACTIONS(745),
    [anon_sym_await] = ACTIONS(745),
    [anon_sym_LBRACK] = ACTIONS(747),
    [anon_sym_if] = ACTIONS(745),
    [anon_sym_async] = ACTIONS(745),
    [anon_sym_var] = ACTIONS(745),
    [anon_sym_let] = ACTIONS(745),
    [anon_sym_const] = ACTIONS(745),
    [anon_sym_return] = ACTIONS(745),
    [anon_sym_try] = ACTIONS(745),
    [anon_sym_throw] = ACTIONS(745),
    [anon_sym_for] = ACTIONS(745),
    [anon_sym_while] = ACTIONS(745),
    [anon_sym_break] = ACTIONS(745),
    [anon_sym_continue] = ACTIONS(745),
    [anon_sym_QMARK_DOT] = ACTIONS(747),
    [anon_sym_BQUOTE] = ACTIONS(747),
    [anon_sym_DOLLARr] = ACTIONS(745),
    [anon_sym_PLUS_PLUS] = ACTIONS(747),
    [anon_sym_DASH_DASH] = ACTIONS(747),
    [anon_sym_new] = ACTIONS(745),
  },
  [STATE(406)] = {
    [sym_comment] = STATE(406),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(977),
    [anon_sym_LBRACE] = ACTIONS(979),
    [anon_sym_RBRACE] = ACTIONS(979),
    [anon_sym_STAR] = ACTIONS(977),
    [anon_sym_as] = ACTIONS(977),
    [anon_sym_SEMI] = ACTIONS(979),
    [anon_sym_LPAREN] = ACTIONS(979),
    [anon_sym_DOT] = ACTIONS(979),
    [sym_identifier] = ACTIONS(977),
    [anon_sym_DQUOTE] = ACTIONS(979),
    [anon_sym_SQUOTE] = ACTIONS(979),
    [anon_sym_DOLLAR] = ACTIONS(977),
    [sym_numeric_literal] = ACTIONS(979),
    [anon_sym_true] = ACTIONS(977),
    [anon_sym_false] = ACTIONS(977),
    [anon_sym_null] = ACTIONS(977),
    [anon_sym_PIPE_PIPE] = ACTIONS(979),
    [anon_sym_AMP_AMP] = ACTIONS(979),
    [anon_sym_PIPE] = ACTIONS(977),
    [anon_sym_CARET] = ACTIONS(979),
    [anon_sym_AMP] = ACTIONS(977),
    [anon_sym_EQ_EQ] = ACTIONS(977),
    [anon_sym_BANG_EQ] = ACTIONS(977),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(979),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(979),
    [anon_sym_LT] = ACTIONS(977),
    [anon_sym_GT] = ACTIONS(977),
    [anon_sym_LT_EQ] = ACTIONS(979),
    [anon_sym_GT_EQ] = ACTIONS(979),
    [anon_sym_instanceof] = ACTIONS(977),
    [anon_sym_in] = ACTIONS(977),
    [anon_sym_LT_LT] = ACTIONS(979),
    [anon_sym_GT_GT] = ACTIONS(977),
    [anon_sym_GT_GT_GT] = ACTIONS(979),
    [anon_sym_PLUS] = ACTIONS(977),
    [anon_sym_DASH] = ACTIONS(977),
    [anon_sym_PERCENT] = ACTIONS(979),
    [anon_sym_STAR_STAR] = ACTIONS(979),
    [anon_sym_BANG] = ACTIONS(977),
    [anon_sym_TILDE] = ACTIONS(979),
    [anon_sym_typeof] = ACTIONS(977),
    [anon_sym_void] = ACTIONS(977),
    [anon_sym_delete] = ACTIONS(977),
    [anon_sym_QMARK] = ACTIONS(977),
    [anon_sym_await] = ACTIONS(977),
    [anon_sym_LBRACK] = ACTIONS(979),
    [anon_sym_if] = ACTIONS(977),
    [anon_sym_async] = ACTIONS(977),
    [anon_sym_var] = ACTIONS(977),
    [anon_sym_let] = ACTIONS(977),
    [anon_sym_const] = ACTIONS(977),
    [anon_sym_return] = ACTIONS(977),
    [anon_sym_try] = ACTIONS(977),
    [anon_sym_throw] = ACTIONS(977),
    [anon_sym_for] = ACTIONS(977),
    [anon_sym_while] = ACTIONS(977),
    [anon_sym_break] = ACTIONS(977),
    [anon_sym_continue] = ACTIONS(977),
    [anon_sym_QMARK_DOT] = ACTIONS(979),
    [anon_sym_BQUOTE] = ACTIONS(979),
    [anon_sym_DOLLARr] = ACTIONS(977),
    [anon_sym_PLUS_PLUS] = ACTIONS(979),
    [anon_sym_DASH_DASH] = ACTIONS(979),
    [anon_sym_new] = ACTIONS(977),
  },
  [STATE(407)] = {
    [sym_comment] = STATE(407),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(789),
    [anon_sym_LBRACE] = ACTIONS(791),
    [anon_sym_RBRACE] = ACTIONS(791),
    [anon_sym_STAR] = ACTIONS(789),
    [anon_sym_as] = ACTIONS(789),
    [anon_sym_SEMI] = ACTIONS(791),
    [anon_sym_LPAREN] = ACTIONS(791),
    [anon_sym_DOT] = ACTIONS(791),
    [sym_identifier] = ACTIONS(789),
    [anon_sym_DQUOTE] = ACTIONS(791),
    [anon_sym_SQUOTE] = ACTIONS(791),
    [anon_sym_DOLLAR] = ACTIONS(789),
    [sym_numeric_literal] = ACTIONS(791),
    [anon_sym_true] = ACTIONS(789),
    [anon_sym_false] = ACTIONS(789),
    [anon_sym_null] = ACTIONS(789),
    [anon_sym_PIPE_PIPE] = ACTIONS(791),
    [anon_sym_AMP_AMP] = ACTIONS(791),
    [anon_sym_PIPE] = ACTIONS(789),
    [anon_sym_CARET] = ACTIONS(791),
    [anon_sym_AMP] = ACTIONS(789),
    [anon_sym_EQ_EQ] = ACTIONS(789),
    [anon_sym_BANG_EQ] = ACTIONS(789),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(791),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(791),
    [anon_sym_LT] = ACTIONS(789),
    [anon_sym_GT] = ACTIONS(789),
    [anon_sym_LT_EQ] = ACTIONS(791),
    [anon_sym_GT_EQ] = ACTIONS(791),
    [anon_sym_instanceof] = ACTIONS(789),
    [anon_sym_in] = ACTIONS(789),
    [anon_sym_LT_LT] = ACTIONS(791),
    [anon_sym_GT_GT] = ACTIONS(789),
    [anon_sym_GT_GT_GT] = ACTIONS(791),
    [anon_sym_PLUS] = ACTIONS(789),
    [anon_sym_DASH] = ACTIONS(789),
    [anon_sym_PERCENT] = ACTIONS(791),
    [anon_sym_STAR_STAR] = ACTIONS(791),
    [anon_sym_BANG] = ACTIONS(789),
    [anon_sym_TILDE] = ACTIONS(791),
    [anon_sym_typeof] = ACTIONS(789),
    [anon_sym_void] = ACTIONS(789),
    [anon_sym_delete] = ACTIONS(789),
    [anon_sym_QMARK] = ACTIONS(789),
    [anon_sym_await] = ACTIONS(789),
    [anon_sym_LBRACK] = ACTIONS(791),
    [anon_sym_if] = ACTIONS(789),
    [anon_sym_async] = ACTIONS(789),
    [anon_sym_var] = ACTIONS(789),
    [anon_sym_let] = ACTIONS(789),
    [anon_sym_const] = ACTIONS(789),
    [anon_sym_return] = ACTIONS(789),
    [anon_sym_try] = ACTIONS(789),
    [anon_sym_throw] = ACTIONS(789),
    [anon_sym_for] = ACTIONS(789),
    [anon_sym_while] = ACTIONS(789),
    [anon_sym_break] = ACTIONS(789),
    [anon_sym_continue] = ACTIONS(789),
    [anon_sym_QMARK_DOT] = ACTIONS(791),
    [anon_sym_BQUOTE] = ACTIONS(791),
    [anon_sym_DOLLARr] = ACTIONS(789),
    [anon_sym_PLUS_PLUS] = ACTIONS(791),
    [anon_sym_DASH_DASH] = ACTIONS(791),
    [anon_sym_new] = ACTIONS(789),
  },
  [STATE(408)] = {
    [sym_comment] = STATE(408),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(985),
    [anon_sym_LBRACE] = ACTIONS(987),
    [anon_sym_RBRACE] = ACTIONS(987),
    [anon_sym_STAR] = ACTIONS(985),
    [anon_sym_as] = ACTIONS(985),
    [anon_sym_SEMI] = ACTIONS(987),
    [anon_sym_LPAREN] = ACTIONS(987),
    [anon_sym_DOT] = ACTIONS(987),
    [sym_identifier] = ACTIONS(985),
    [anon_sym_DQUOTE] = ACTIONS(987),
    [anon_sym_SQUOTE] = ACTIONS(987),
    [anon_sym_DOLLAR] = ACTIONS(985),
    [sym_numeric_literal] = ACTIONS(987),
    [anon_sym_true] = ACTIONS(985),
    [anon_sym_false] = ACTIONS(985),
    [anon_sym_null] = ACTIONS(985),
    [anon_sym_PIPE_PIPE] = ACTIONS(987),
    [anon_sym_AMP_AMP] = ACTIONS(987),
    [anon_sym_PIPE] = ACTIONS(985),
    [anon_sym_CARET] = ACTIONS(987),
    [anon_sym_AMP] = ACTIONS(985),
    [anon_sym_EQ_EQ] = ACTIONS(985),
    [anon_sym_BANG_EQ] = ACTIONS(985),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(987),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(987),
    [anon_sym_LT] = ACTIONS(985),
    [anon_sym_GT] = ACTIONS(985),
    [anon_sym_LT_EQ] = ACTIONS(987),
    [anon_sym_GT_EQ] = ACTIONS(987),
    [anon_sym_instanceof] = ACTIONS(985),
    [anon_sym_in] = ACTIONS(985),
    [anon_sym_LT_LT] = ACTIONS(987),
    [anon_sym_GT_GT] = ACTIONS(985),
    [anon_sym_GT_GT_GT] = ACTIONS(987),
    [anon_sym_PLUS] = ACTIONS(985),
    [anon_sym_DASH] = ACTIONS(985),
    [anon_sym_PERCENT] = ACTIONS(987),
    [anon_sym_STAR_STAR] = ACTIONS(987),
    [anon_sym_BANG] = ACTIONS(985),
    [anon_sym_TILDE] = ACTIONS(987),
    [anon_sym_typeof] = ACTIONS(985),
    [anon_sym_void] = ACTIONS(985),
    [anon_sym_delete] = ACTIONS(985),
    [anon_sym_QMARK] = ACTIONS(985),
    [anon_sym_await] = ACTIONS(985),
    [anon_sym_LBRACK] = ACTIONS(987),
    [anon_sym_if] = ACTIONS(985),
    [anon_sym_async] = ACTIONS(985),
    [anon_sym_var] = ACTIONS(985),
    [anon_sym_let] = ACTIONS(985),
    [anon_sym_const] = ACTIONS(985),
    [anon_sym_return] = ACTIONS(985),
    [anon_sym_try] = ACTIONS(985),
    [anon_sym_throw] = ACTIONS(985),
    [anon_sym_for] = ACTIONS(985),
    [anon_sym_while] = ACTIONS(985),
    [anon_sym_break] = ACTIONS(985),
    [anon_sym_continue] = ACTIONS(985),
    [anon_sym_QMARK_DOT] = ACTIONS(987),
    [anon_sym_BQUOTE] = ACTIONS(987),
    [anon_sym_DOLLARr] = ACTIONS(985),
    [anon_sym_PLUS_PLUS] = ACTIONS(987),
    [anon_sym_DASH_DASH] = ACTIONS(987),
    [anon_sym_new] = ACTIONS(985),
  },
  [STATE(409)] = {
    [sym_comment] = STATE(409),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(797),
    [anon_sym_LBRACE] = ACTIONS(799),
    [anon_sym_RBRACE] = ACTIONS(799),
    [anon_sym_STAR] = ACTIONS(797),
    [anon_sym_as] = ACTIONS(797),
    [anon_sym_SEMI] = ACTIONS(799),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_DOT] = ACTIONS(799),
    [sym_identifier] = ACTIONS(797),
    [anon_sym_DQUOTE] = ACTIONS(799),
    [anon_sym_SQUOTE] = ACTIONS(799),
    [anon_sym_DOLLAR] = ACTIONS(797),
    [sym_numeric_literal] = ACTIONS(799),
    [anon_sym_true] = ACTIONS(797),
    [anon_sym_false] = ACTIONS(797),
    [anon_sym_null] = ACTIONS(797),
    [anon_sym_PIPE_PIPE] = ACTIONS(799),
    [anon_sym_AMP_AMP] = ACTIONS(799),
    [anon_sym_PIPE] = ACTIONS(797),
    [anon_sym_CARET] = ACTIONS(799),
    [anon_sym_AMP] = ACTIONS(797),
    [anon_sym_EQ_EQ] = ACTIONS(797),
    [anon_sym_BANG_EQ] = ACTIONS(797),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(799),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(799),
    [anon_sym_LT] = ACTIONS(797),
    [anon_sym_GT] = ACTIONS(797),
    [anon_sym_LT_EQ] = ACTIONS(799),
    [anon_sym_GT_EQ] = ACTIONS(799),
    [anon_sym_instanceof] = ACTIONS(797),
    [anon_sym_in] = ACTIONS(797),
    [anon_sym_LT_LT] = ACTIONS(799),
    [anon_sym_GT_GT] = ACTIONS(797),
    [anon_sym_GT_GT_GT] = ACTIONS(799),
    [anon_sym_PLUS] = ACTIONS(797),
    [anon_sym_DASH] = ACTIONS(797),
    [anon_sym_PERCENT] = ACTIONS(799),
    [anon_sym_STAR_STAR] = ACTIONS(799),
    [anon_sym_BANG] = ACTIONS(797),
    [anon_sym_TILDE] = ACTIONS(799),
    [anon_sym_typeof] = ACTIONS(797),
    [anon_sym_void] = ACTIONS(797),
    [anon_sym_delete] = ACTIONS(797),
    [anon_sym_QMARK] = ACTIONS(797),
    [anon_sym_await] = ACTIONS(797),
    [anon_sym_LBRACK] = ACTIONS(799),
    [anon_sym_if] = ACTIONS(797),
    [anon_sym_async] = ACTIONS(797),
    [anon_sym_var] = ACTIONS(797),
    [anon_sym_let] = ACTIONS(797),
    [anon_sym_const] = ACTIONS(797),
    [anon_sym_return] = ACTIONS(797),
    [anon_sym_try] = ACTIONS(797),
    [anon_sym_throw] = ACTIONS(797),
    [anon_sym_for] = ACTIONS(797),
    [anon_sym_while] = ACTIONS(797),
    [anon_sym_break] = ACTIONS(797),
    [anon_sym_continue] = ACTIONS(797),
    [anon_sym_QMARK_DOT] = ACTIONS(799),
    [anon_sym_BQUOTE] = ACTIONS(799),
    [anon_sym_DOLLARr] = ACTIONS(797),
    [anon_sym_PLUS_PLUS] = ACTIONS(799),
    [anon_sym_DASH_DASH] = ACTIONS(799),
    [anon_sym_new] = ACTIONS(797),
  },
  [STATE(410)] = {
    [sym_comment] = STATE(410),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(941),
    [anon_sym_LBRACE] = ACTIONS(943),
    [anon_sym_RBRACE] = ACTIONS(943),
    [anon_sym_STAR] = ACTIONS(941),
    [anon_sym_as] = ACTIONS(941),
    [anon_sym_SEMI] = ACTIONS(943),
    [anon_sym_LPAREN] = ACTIONS(943),
    [anon_sym_DOT] = ACTIONS(943),
    [sym_identifier] = ACTIONS(941),
    [anon_sym_DQUOTE] = ACTIONS(943),
    [anon_sym_SQUOTE] = ACTIONS(943),
    [anon_sym_DOLLAR] = ACTIONS(941),
    [sym_numeric_literal] = ACTIONS(943),
    [anon_sym_true] = ACTIONS(941),
    [anon_sym_false] = ACTIONS(941),
    [anon_sym_null] = ACTIONS(941),
    [anon_sym_PIPE_PIPE] = ACTIONS(943),
    [anon_sym_AMP_AMP] = ACTIONS(943),
    [anon_sym_PIPE] = ACTIONS(941),
    [anon_sym_CARET] = ACTIONS(943),
    [anon_sym_AMP] = ACTIONS(941),
    [anon_sym_EQ_EQ] = ACTIONS(941),
    [anon_sym_BANG_EQ] = ACTIONS(941),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(943),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(943),
    [anon_sym_LT] = ACTIONS(941),
    [anon_sym_GT] = ACTIONS(941),
    [anon_sym_LT_EQ] = ACTIONS(943),
    [anon_sym_GT_EQ] = ACTIONS(943),
    [anon_sym_instanceof] = ACTIONS(941),
    [anon_sym_in] = ACTIONS(941),
    [anon_sym_LT_LT] = ACTIONS(943),
    [anon_sym_GT_GT] = ACTIONS(941),
    [anon_sym_GT_GT_GT] = ACTIONS(943),
    [anon_sym_PLUS] = ACTIONS(941),
    [anon_sym_DASH] = ACTIONS(941),
    [anon_sym_PERCENT] = ACTIONS(943),
    [anon_sym_STAR_STAR] = ACTIONS(943),
    [anon_sym_BANG] = ACTIONS(941),
    [anon_sym_TILDE] = ACTIONS(943),
    [anon_sym_typeof] = ACTIONS(941),
    [anon_sym_void] = ACTIONS(941),
    [anon_sym_delete] = ACTIONS(941),
    [anon_sym_QMARK] = ACTIONS(941),
    [anon_sym_await] = ACTIONS(941),
    [anon_sym_LBRACK] = ACTIONS(943),
    [anon_sym_if] = ACTIONS(941),
    [anon_sym_async] = ACTIONS(941),
    [anon_sym_var] = ACTIONS(941),
    [anon_sym_let] = ACTIONS(941),
    [anon_sym_const] = ACTIONS(941),
    [anon_sym_return] = ACTIONS(941),
    [anon_sym_try] = ACTIONS(941),
    [anon_sym_throw] = ACTIONS(941),
    [anon_sym_for] = ACTIONS(941),
    [anon_sym_while] = ACTIONS(941),
    [anon_sym_break] = ACTIONS(941),
    [anon_sym_continue] = ACTIONS(941),
    [anon_sym_QMARK_DOT] = ACTIONS(943),
    [anon_sym_BQUOTE] = ACTIONS(943),
    [anon_sym_DOLLARr] = ACTIONS(941),
    [anon_sym_PLUS_PLUS] = ACTIONS(943),
    [anon_sym_DASH_DASH] = ACTIONS(943),
    [anon_sym_new] = ACTIONS(941),
  },
  [STATE(411)] = {
    [sym_comment] = STATE(411),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(879),
    [anon_sym_LBRACE] = ACTIONS(881),
    [anon_sym_RBRACE] = ACTIONS(881),
    [anon_sym_STAR] = ACTIONS(879),
    [anon_sym_as] = ACTIONS(879),
    [anon_sym_SEMI] = ACTIONS(881),
    [anon_sym_LPAREN] = ACTIONS(881),
    [anon_sym_DOT] = ACTIONS(881),
    [sym_identifier] = ACTIONS(879),
    [anon_sym_DQUOTE] = ACTIONS(881),
    [anon_sym_SQUOTE] = ACTIONS(881),
    [anon_sym_DOLLAR] = ACTIONS(879),
    [sym_numeric_literal] = ACTIONS(881),
    [anon_sym_true] = ACTIONS(879),
    [anon_sym_false] = ACTIONS(879),
    [anon_sym_null] = ACTIONS(879),
    [anon_sym_PIPE_PIPE] = ACTIONS(881),
    [anon_sym_AMP_AMP] = ACTIONS(881),
    [anon_sym_PIPE] = ACTIONS(879),
    [anon_sym_CARET] = ACTIONS(881),
    [anon_sym_AMP] = ACTIONS(879),
    [anon_sym_EQ_EQ] = ACTIONS(879),
    [anon_sym_BANG_EQ] = ACTIONS(879),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(881),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(881),
    [anon_sym_LT] = ACTIONS(879),
    [anon_sym_GT] = ACTIONS(879),
    [anon_sym_LT_EQ] = ACTIONS(881),
    [anon_sym_GT_EQ] = ACTIONS(881),
    [anon_sym_instanceof] = ACTIONS(879),
    [anon_sym_in] = ACTIONS(879),
    [anon_sym_LT_LT] = ACTIONS(881),
    [anon_sym_GT_GT] = ACTIONS(879),
    [anon_sym_GT_GT_GT] = ACTIONS(881),
    [anon_sym_PLUS] = ACTIONS(879),
    [anon_sym_DASH] = ACTIONS(879),
    [anon_sym_PERCENT] = ACTIONS(881),
    [anon_sym_STAR_STAR] = ACTIONS(881),
    [anon_sym_BANG] = ACTIONS(879),
    [anon_sym_TILDE] = ACTIONS(881),
    [anon_sym_typeof] = ACTIONS(879),
    [anon_sym_void] = ACTIONS(879),
    [anon_sym_delete] = ACTIONS(879),
    [anon_sym_QMARK] = ACTIONS(879),
    [anon_sym_await] = ACTIONS(879),
    [anon_sym_LBRACK] = ACTIONS(881),
    [anon_sym_if] = ACTIONS(879),
    [anon_sym_async] = ACTIONS(879),
    [anon_sym_var] = ACTIONS(879),
    [anon_sym_let] = ACTIONS(879),
    [anon_sym_const] = ACTIONS(879),
    [anon_sym_return] = ACTIONS(879),
    [anon_sym_try] = ACTIONS(879),
    [anon_sym_throw] = ACTIONS(879),
    [anon_sym_for] = ACTIONS(879),
    [anon_sym_while] = ACTIONS(879),
    [anon_sym_break] = ACTIONS(879),
    [anon_sym_continue] = ACTIONS(879),
    [anon_sym_QMARK_DOT] = ACTIONS(881),
    [anon_sym_BQUOTE] = ACTIONS(881),
    [anon_sym_DOLLARr] = ACTIONS(879),
    [anon_sym_PLUS_PLUS] = ACTIONS(881),
    [anon_sym_DASH_DASH] = ACTIONS(881),
    [anon_sym_new] = ACTIONS(879),
  },
  [STATE(412)] = {
    [sym_comment] = STATE(412),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(887),
    [anon_sym_LBRACE] = ACTIONS(889),
    [anon_sym_RBRACE] = ACTIONS(889),
    [anon_sym_STAR] = ACTIONS(887),
    [anon_sym_as] = ACTIONS(887),
    [anon_sym_SEMI] = ACTIONS(889),
    [anon_sym_LPAREN] = ACTIONS(889),
    [anon_sym_DOT] = ACTIONS(889),
    [sym_identifier] = ACTIONS(887),
    [anon_sym_DQUOTE] = ACTIONS(889),
    [anon_sym_SQUOTE] = ACTIONS(889),
    [anon_sym_DOLLAR] = ACTIONS(887),
    [sym_numeric_literal] = ACTIONS(889),
    [anon_sym_true] = ACTIONS(887),
    [anon_sym_false] = ACTIONS(887),
    [anon_sym_null] = ACTIONS(887),
    [anon_sym_PIPE_PIPE] = ACTIONS(889),
    [anon_sym_AMP_AMP] = ACTIONS(889),
    [anon_sym_PIPE] = ACTIONS(887),
    [anon_sym_CARET] = ACTIONS(889),
    [anon_sym_AMP] = ACTIONS(887),
    [anon_sym_EQ_EQ] = ACTIONS(887),
    [anon_sym_BANG_EQ] = ACTIONS(887),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(889),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(889),
    [anon_sym_LT] = ACTIONS(887),
    [anon_sym_GT] = ACTIONS(887),
    [anon_sym_LT_EQ] = ACTIONS(889),
    [anon_sym_GT_EQ] = ACTIONS(889),
    [anon_sym_instanceof] = ACTIONS(887),
    [anon_sym_in] = ACTIONS(887),
    [anon_sym_LT_LT] = ACTIONS(889),
    [anon_sym_GT_GT] = ACTIONS(887),
    [anon_sym_GT_GT_GT] = ACTIONS(889),
    [anon_sym_PLUS] = ACTIONS(887),
    [anon_sym_DASH] = ACTIONS(887),
    [anon_sym_PERCENT] = ACTIONS(889),
    [anon_sym_STAR_STAR] = ACTIONS(889),
    [anon_sym_BANG] = ACTIONS(887),
    [anon_sym_TILDE] = ACTIONS(889),
    [anon_sym_typeof] = ACTIONS(887),
    [anon_sym_void] = ACTIONS(887),
    [anon_sym_delete] = ACTIONS(887),
    [anon_sym_QMARK] = ACTIONS(887),
    [anon_sym_await] = ACTIONS(887),
    [anon_sym_LBRACK] = ACTIONS(889),
    [anon_sym_if] = ACTIONS(887),
    [anon_sym_async] = ACTIONS(887),
    [anon_sym_var] = ACTIONS(887),
    [anon_sym_let] = ACTIONS(887),
    [anon_sym_const] = ACTIONS(887),
    [anon_sym_return] = ACTIONS(887),
    [anon_sym_try] = ACTIONS(887),
    [anon_sym_throw] = ACTIONS(887),
    [anon_sym_for] = ACTIONS(887),
    [anon_sym_while] = ACTIONS(887),
    [anon_sym_break] = ACTIONS(887),
    [anon_sym_continue] = ACTIONS(887),
    [anon_sym_QMARK_DOT] = ACTIONS(889),
    [anon_sym_BQUOTE] = ACTIONS(889),
    [anon_sym_DOLLARr] = ACTIONS(887),
    [anon_sym_PLUS_PLUS] = ACTIONS(889),
    [anon_sym_DASH_DASH] = ACTIONS(889),
    [anon_sym_new] = ACTIONS(887),
  },
  [STATE(413)] = {
    [sym_comment] = STATE(413),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(700),
    [anon_sym_LBRACE] = ACTIONS(698),
    [anon_sym_RBRACE] = ACTIONS(698),
    [anon_sym_STAR] = ACTIONS(700),
    [anon_sym_as] = ACTIONS(700),
    [anon_sym_SEMI] = ACTIONS(698),
    [anon_sym_LPAREN] = ACTIONS(698),
    [anon_sym_DOT] = ACTIONS(698),
    [sym_identifier] = ACTIONS(700),
    [anon_sym_DQUOTE] = ACTIONS(698),
    [anon_sym_SQUOTE] = ACTIONS(698),
    [anon_sym_DOLLAR] = ACTIONS(700),
    [sym_numeric_literal] = ACTIONS(698),
    [anon_sym_true] = ACTIONS(700),
    [anon_sym_false] = ACTIONS(700),
    [anon_sym_null] = ACTIONS(700),
    [anon_sym_PIPE_PIPE] = ACTIONS(698),
    [anon_sym_AMP_AMP] = ACTIONS(698),
    [anon_sym_PIPE] = ACTIONS(700),
    [anon_sym_CARET] = ACTIONS(698),
    [anon_sym_AMP] = ACTIONS(700),
    [anon_sym_EQ_EQ] = ACTIONS(700),
    [anon_sym_BANG_EQ] = ACTIONS(700),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(698),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(698),
    [anon_sym_LT] = ACTIONS(700),
    [anon_sym_GT] = ACTIONS(700),
    [anon_sym_LT_EQ] = ACTIONS(698),
    [anon_sym_GT_EQ] = ACTIONS(698),
    [anon_sym_instanceof] = ACTIONS(700),
    [anon_sym_in] = ACTIONS(700),
    [anon_sym_LT_LT] = ACTIONS(698),
    [anon_sym_GT_GT] = ACTIONS(700),
    [anon_sym_GT_GT_GT] = ACTIONS(698),
    [anon_sym_PLUS] = ACTIONS(700),
    [anon_sym_DASH] = ACTIONS(700),
    [anon_sym_PERCENT] = ACTIONS(698),
    [anon_sym_STAR_STAR] = ACTIONS(698),
    [anon_sym_BANG] = ACTIONS(700),
    [anon_sym_TILDE] = ACTIONS(698),
    [anon_sym_typeof] = ACTIONS(700),
    [anon_sym_void] = ACTIONS(700),
    [anon_sym_delete] = ACTIONS(700),
    [anon_sym_QMARK] = ACTIONS(700),
    [anon_sym_await] = ACTIONS(700),
    [anon_sym_LBRACK] = ACTIONS(698),
    [anon_sym_if] = ACTIONS(700),
    [anon_sym_async] = ACTIONS(700),
    [anon_sym_var] = ACTIONS(700),
    [anon_sym_let] = ACTIONS(700),
    [anon_sym_const] = ACTIONS(700),
    [anon_sym_return] = ACTIONS(700),
    [anon_sym_try] = ACTIONS(700),
    [anon_sym_throw] = ACTIONS(700),
    [anon_sym_for] = ACTIONS(700),
    [anon_sym_while] = ACTIONS(700),
    [anon_sym_break] = ACTIONS(700),
    [anon_sym_continue] = ACTIONS(700),
    [anon_sym_QMARK_DOT] = ACTIONS(698),
    [anon_sym_BQUOTE] = ACTIONS(698),
    [anon_sym_DOLLARr] = ACTIONS(700),
    [anon_sym_PLUS_PLUS] = ACTIONS(698),
    [anon_sym_DASH_DASH] = ACTIONS(698),
    [anon_sym_new] = ACTIONS(700),
  },
  [STATE(414)] = {
    [sym_comment] = STATE(414),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(851),
    [anon_sym_LBRACE] = ACTIONS(853),
    [anon_sym_RBRACE] = ACTIONS(853),
    [anon_sym_STAR] = ACTIONS(851),
    [anon_sym_as] = ACTIONS(851),
    [anon_sym_SEMI] = ACTIONS(853),
    [anon_sym_LPAREN] = ACTIONS(853),
    [anon_sym_DOT] = ACTIONS(853),
    [sym_identifier] = ACTIONS(851),
    [anon_sym_DQUOTE] = ACTIONS(853),
    [anon_sym_SQUOTE] = ACTIONS(853),
    [anon_sym_DOLLAR] = ACTIONS(851),
    [sym_numeric_literal] = ACTIONS(853),
    [anon_sym_true] = ACTIONS(851),
    [anon_sym_false] = ACTIONS(851),
    [anon_sym_null] = ACTIONS(851),
    [anon_sym_PIPE_PIPE] = ACTIONS(853),
    [anon_sym_AMP_AMP] = ACTIONS(853),
    [anon_sym_PIPE] = ACTIONS(851),
    [anon_sym_CARET] = ACTIONS(853),
    [anon_sym_AMP] = ACTIONS(851),
    [anon_sym_EQ_EQ] = ACTIONS(851),
    [anon_sym_BANG_EQ] = ACTIONS(851),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(853),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(853),
    [anon_sym_LT] = ACTIONS(851),
    [anon_sym_GT] = ACTIONS(851),
    [anon_sym_LT_EQ] = ACTIONS(853),
    [anon_sym_GT_EQ] = ACTIONS(853),
    [anon_sym_instanceof] = ACTIONS(851),
    [anon_sym_in] = ACTIONS(851),
    [anon_sym_LT_LT] = ACTIONS(853),
    [anon_sym_GT_GT] = ACTIONS(851),
    [anon_sym_GT_GT_GT] = ACTIONS(853),
    [anon_sym_PLUS] = ACTIONS(851),
    [anon_sym_DASH] = ACTIONS(851),
    [anon_sym_PERCENT] = ACTIONS(853),
    [anon_sym_STAR_STAR] = ACTIONS(853),
    [anon_sym_BANG] = ACTIONS(851),
    [anon_sym_TILDE] = ACTIONS(853),
    [anon_sym_typeof] = ACTIONS(851),
    [anon_sym_void] = ACTIONS(851),
    [anon_sym_delete] = ACTIONS(851),
    [anon_sym_QMARK] = ACTIONS(851),
    [anon_sym_await] = ACTIONS(851),
    [anon_sym_LBRACK] = ACTIONS(853),
    [anon_sym_if] = ACTIONS(851),
    [anon_sym_async] = ACTIONS(851),
    [anon_sym_var] = ACTIONS(851),
    [anon_sym_let] = ACTIONS(851),
    [anon_sym_const] = ACTIONS(851),
    [anon_sym_return] = ACTIONS(851),
    [anon_sym_try] = ACTIONS(851),
    [anon_sym_throw] = ACTIONS(851),
    [anon_sym_for] = ACTIONS(851),
    [anon_sym_while] = ACTIONS(851),
    [anon_sym_break] = ACTIONS(851),
    [anon_sym_continue] = ACTIONS(851),
    [anon_sym_QMARK_DOT] = ACTIONS(853),
    [anon_sym_BQUOTE] = ACTIONS(853),
    [anon_sym_DOLLARr] = ACTIONS(851),
    [anon_sym_PLUS_PLUS] = ACTIONS(853),
    [anon_sym_DASH_DASH] = ACTIONS(853),
    [anon_sym_new] = ACTIONS(851),
  },
  [STATE(415)] = {
    [sym_comment] = STATE(415),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(965),
    [anon_sym_LBRACE] = ACTIONS(967),
    [anon_sym_RBRACE] = ACTIONS(967),
    [anon_sym_STAR] = ACTIONS(965),
    [anon_sym_as] = ACTIONS(965),
    [anon_sym_SEMI] = ACTIONS(967),
    [anon_sym_LPAREN] = ACTIONS(967),
    [anon_sym_DOT] = ACTIONS(967),
    [sym_identifier] = ACTIONS(965),
    [anon_sym_DQUOTE] = ACTIONS(967),
    [anon_sym_SQUOTE] = ACTIONS(967),
    [anon_sym_DOLLAR] = ACTIONS(965),
    [sym_numeric_literal] = ACTIONS(967),
    [anon_sym_true] = ACTIONS(965),
    [anon_sym_false] = ACTIONS(965),
    [anon_sym_null] = ACTIONS(965),
    [anon_sym_PIPE_PIPE] = ACTIONS(967),
    [anon_sym_AMP_AMP] = ACTIONS(967),
    [anon_sym_PIPE] = ACTIONS(965),
    [anon_sym_CARET] = ACTIONS(967),
    [anon_sym_AMP] = ACTIONS(965),
    [anon_sym_EQ_EQ] = ACTIONS(965),
    [anon_sym_BANG_EQ] = ACTIONS(965),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(967),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(967),
    [anon_sym_LT] = ACTIONS(965),
    [anon_sym_GT] = ACTIONS(965),
    [anon_sym_LT_EQ] = ACTIONS(967),
    [anon_sym_GT_EQ] = ACTIONS(967),
    [anon_sym_instanceof] = ACTIONS(965),
    [anon_sym_in] = ACTIONS(965),
    [anon_sym_LT_LT] = ACTIONS(967),
    [anon_sym_GT_GT] = ACTIONS(965),
    [anon_sym_GT_GT_GT] = ACTIONS(967),
    [anon_sym_PLUS] = ACTIONS(965),
    [anon_sym_DASH] = ACTIONS(965),
    [anon_sym_PERCENT] = ACTIONS(967),
    [anon_sym_STAR_STAR] = ACTIONS(967),
    [anon_sym_BANG] = ACTIONS(965),
    [anon_sym_TILDE] = ACTIONS(967),
    [anon_sym_typeof] = ACTIONS(965),
    [anon_sym_void] = ACTIONS(965),
    [anon_sym_delete] = ACTIONS(965),
    [anon_sym_QMARK] = ACTIONS(965),
    [anon_sym_await] = ACTIONS(965),
    [anon_sym_LBRACK] = ACTIONS(967),
    [anon_sym_if] = ACTIONS(965),
    [anon_sym_async] = ACTIONS(965),
    [anon_sym_var] = ACTIONS(965),
    [anon_sym_let] = ACTIONS(965),
    [anon_sym_const] = ACTIONS(965),
    [anon_sym_return] = ACTIONS(965),
    [anon_sym_try] = ACTIONS(965),
    [anon_sym_throw] = ACTIONS(965),
    [anon_sym_for] = ACTIONS(965),
    [anon_sym_while] = ACTIONS(965),
    [anon_sym_break] = ACTIONS(965),
    [anon_sym_continue] = ACTIONS(965),
    [anon_sym_QMARK_DOT] = ACTIONS(967),
    [anon_sym_BQUOTE] = ACTIONS(967),
    [anon_sym_DOLLARr] = ACTIONS(965),
    [anon_sym_PLUS_PLUS] = ACTIONS(967),
    [anon_sym_DASH_DASH] = ACTIONS(967),
    [anon_sym_new] = ACTIONS(965),
  },
  [STATE(416)] = {
    [sym_comment] = STATE(416),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(937),
    [anon_sym_LBRACE] = ACTIONS(939),
    [anon_sym_RBRACE] = ACTIONS(939),
    [anon_sym_STAR] = ACTIONS(937),
    [anon_sym_as] = ACTIONS(937),
    [anon_sym_SEMI] = ACTIONS(939),
    [anon_sym_LPAREN] = ACTIONS(939),
    [anon_sym_DOT] = ACTIONS(939),
    [sym_identifier] = ACTIONS(937),
    [anon_sym_DQUOTE] = ACTIONS(939),
    [anon_sym_SQUOTE] = ACTIONS(939),
    [anon_sym_DOLLAR] = ACTIONS(937),
    [sym_numeric_literal] = ACTIONS(939),
    [anon_sym_true] = ACTIONS(937),
    [anon_sym_false] = ACTIONS(937),
    [anon_sym_null] = ACTIONS(937),
    [anon_sym_PIPE_PIPE] = ACTIONS(939),
    [anon_sym_AMP_AMP] = ACTIONS(939),
    [anon_sym_PIPE] = ACTIONS(937),
    [anon_sym_CARET] = ACTIONS(939),
    [anon_sym_AMP] = ACTIONS(937),
    [anon_sym_EQ_EQ] = ACTIONS(937),
    [anon_sym_BANG_EQ] = ACTIONS(937),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(939),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(939),
    [anon_sym_LT] = ACTIONS(937),
    [anon_sym_GT] = ACTIONS(937),
    [anon_sym_LT_EQ] = ACTIONS(939),
    [anon_sym_GT_EQ] = ACTIONS(939),
    [anon_sym_instanceof] = ACTIONS(937),
    [anon_sym_in] = ACTIONS(937),
    [anon_sym_LT_LT] = ACTIONS(939),
    [anon_sym_GT_GT] = ACTIONS(937),
    [anon_sym_GT_GT_GT] = ACTIONS(939),
    [anon_sym_PLUS] = ACTIONS(937),
    [anon_sym_DASH] = ACTIONS(937),
    [anon_sym_PERCENT] = ACTIONS(939),
    [anon_sym_STAR_STAR] = ACTIONS(939),
    [anon_sym_BANG] = ACTIONS(937),
    [anon_sym_TILDE] = ACTIONS(939),
    [anon_sym_typeof] = ACTIONS(937),
    [anon_sym_void] = ACTIONS(937),
    [anon_sym_delete] = ACTIONS(937),
    [anon_sym_QMARK] = ACTIONS(937),
    [anon_sym_await] = ACTIONS(937),
    [anon_sym_LBRACK] = ACTIONS(939),
    [anon_sym_if] = ACTIONS(937),
    [anon_sym_async] = ACTIONS(937),
    [anon_sym_var] = ACTIONS(937),
    [anon_sym_let] = ACTIONS(937),
    [anon_sym_const] = ACTIONS(937),
    [anon_sym_return] = ACTIONS(937),
    [anon_sym_try] = ACTIONS(937),
    [anon_sym_throw] = ACTIONS(937),
    [anon_sym_for] = ACTIONS(937),
    [anon_sym_while] = ACTIONS(937),
    [anon_sym_break] = ACTIONS(937),
    [anon_sym_continue] = ACTIONS(937),
    [anon_sym_QMARK_DOT] = ACTIONS(939),
    [anon_sym_BQUOTE] = ACTIONS(939),
    [anon_sym_DOLLARr] = ACTIONS(937),
    [anon_sym_PLUS_PLUS] = ACTIONS(939),
    [anon_sym_DASH_DASH] = ACTIONS(939),
    [anon_sym_new] = ACTIONS(937),
  },
  [STATE(417)] = {
    [sym_comment] = STATE(417),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(809),
    [anon_sym_LBRACE] = ACTIONS(811),
    [anon_sym_RBRACE] = ACTIONS(811),
    [anon_sym_STAR] = ACTIONS(809),
    [anon_sym_as] = ACTIONS(809),
    [anon_sym_SEMI] = ACTIONS(811),
    [anon_sym_LPAREN] = ACTIONS(811),
    [anon_sym_DOT] = ACTIONS(811),
    [sym_identifier] = ACTIONS(809),
    [anon_sym_DQUOTE] = ACTIONS(811),
    [anon_sym_SQUOTE] = ACTIONS(811),
    [anon_sym_DOLLAR] = ACTIONS(809),
    [sym_numeric_literal] = ACTIONS(811),
    [anon_sym_true] = ACTIONS(809),
    [anon_sym_false] = ACTIONS(809),
    [anon_sym_null] = ACTIONS(809),
    [anon_sym_PIPE_PIPE] = ACTIONS(811),
    [anon_sym_AMP_AMP] = ACTIONS(811),
    [anon_sym_PIPE] = ACTIONS(809),
    [anon_sym_CARET] = ACTIONS(811),
    [anon_sym_AMP] = ACTIONS(809),
    [anon_sym_EQ_EQ] = ACTIONS(809),
    [anon_sym_BANG_EQ] = ACTIONS(809),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(811),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(811),
    [anon_sym_LT] = ACTIONS(809),
    [anon_sym_GT] = ACTIONS(809),
    [anon_sym_LT_EQ] = ACTIONS(811),
    [anon_sym_GT_EQ] = ACTIONS(811),
    [anon_sym_instanceof] = ACTIONS(809),
    [anon_sym_in] = ACTIONS(809),
    [anon_sym_LT_LT] = ACTIONS(811),
    [anon_sym_GT_GT] = ACTIONS(809),
    [anon_sym_GT_GT_GT] = ACTIONS(811),
    [anon_sym_PLUS] = ACTIONS(809),
    [anon_sym_DASH] = ACTIONS(809),
    [anon_sym_PERCENT] = ACTIONS(811),
    [anon_sym_STAR_STAR] = ACTIONS(811),
    [anon_sym_BANG] = ACTIONS(809),
    [anon_sym_TILDE] = ACTIONS(811),
    [anon_sym_typeof] = ACTIONS(809),
    [anon_sym_void] = ACTIONS(809),
    [anon_sym_delete] = ACTIONS(809),
    [anon_sym_QMARK] = ACTIONS(809),
    [anon_sym_await] = ACTIONS(809),
    [anon_sym_LBRACK] = ACTIONS(811),
    [anon_sym_if] = ACTIONS(809),
    [anon_sym_async] = ACTIONS(809),
    [anon_sym_var] = ACTIONS(809),
    [anon_sym_let] = ACTIONS(809),
    [anon_sym_const] = ACTIONS(809),
    [anon_sym_return] = ACTIONS(809),
    [anon_sym_try] = ACTIONS(809),
    [anon_sym_throw] = ACTIONS(809),
    [anon_sym_for] = ACTIONS(809),
    [anon_sym_while] = ACTIONS(809),
    [anon_sym_break] = ACTIONS(809),
    [anon_sym_continue] = ACTIONS(809),
    [anon_sym_QMARK_DOT] = ACTIONS(811),
    [anon_sym_BQUOTE] = ACTIONS(811),
    [anon_sym_DOLLARr] = ACTIONS(809),
    [anon_sym_PLUS_PLUS] = ACTIONS(811),
    [anon_sym_DASH_DASH] = ACTIONS(811),
    [anon_sym_new] = ACTIONS(809),
  },
  [STATE(418)] = {
    [sym_comment] = STATE(418),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(891),
    [anon_sym_LBRACE] = ACTIONS(893),
    [anon_sym_RBRACE] = ACTIONS(893),
    [anon_sym_STAR] = ACTIONS(891),
    [anon_sym_as] = ACTIONS(891),
    [anon_sym_SEMI] = ACTIONS(893),
    [anon_sym_LPAREN] = ACTIONS(893),
    [anon_sym_DOT] = ACTIONS(893),
    [sym_identifier] = ACTIONS(891),
    [anon_sym_DQUOTE] = ACTIONS(893),
    [anon_sym_SQUOTE] = ACTIONS(893),
    [anon_sym_DOLLAR] = ACTIONS(891),
    [sym_numeric_literal] = ACTIONS(893),
    [anon_sym_true] = ACTIONS(891),
    [anon_sym_false] = ACTIONS(891),
    [anon_sym_null] = ACTIONS(891),
    [anon_sym_PIPE_PIPE] = ACTIONS(893),
    [anon_sym_AMP_AMP] = ACTIONS(893),
    [anon_sym_PIPE] = ACTIONS(891),
    [anon_sym_CARET] = ACTIONS(893),
    [anon_sym_AMP] = ACTIONS(891),
    [anon_sym_EQ_EQ] = ACTIONS(891),
    [anon_sym_BANG_EQ] = ACTIONS(891),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(893),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(893),
    [anon_sym_LT] = ACTIONS(891),
    [anon_sym_GT] = ACTIONS(891),
    [anon_sym_LT_EQ] = ACTIONS(893),
    [anon_sym_GT_EQ] = ACTIONS(893),
    [anon_sym_instanceof] = ACTIONS(891),
    [anon_sym_in] = ACTIONS(891),
    [anon_sym_LT_LT] = ACTIONS(893),
    [anon_sym_GT_GT] = ACTIONS(891),
    [anon_sym_GT_GT_GT] = ACTIONS(893),
    [anon_sym_PLUS] = ACTIONS(891),
    [anon_sym_DASH] = ACTIONS(891),
    [anon_sym_PERCENT] = ACTIONS(893),
    [anon_sym_STAR_STAR] = ACTIONS(893),
    [anon_sym_BANG] = ACTIONS(891),
    [anon_sym_TILDE] = ACTIONS(893),
    [anon_sym_typeof] = ACTIONS(891),
    [anon_sym_void] = ACTIONS(891),
    [anon_sym_delete] = ACTIONS(891),
    [anon_sym_QMARK] = ACTIONS(891),
    [anon_sym_await] = ACTIONS(891),
    [anon_sym_LBRACK] = ACTIONS(893),
    [anon_sym_if] = ACTIONS(891),
    [anon_sym_async] = ACTIONS(891),
    [anon_sym_var] = ACTIONS(891),
    [anon_sym_let] = ACTIONS(891),
    [anon_sym_const] = ACTIONS(891),
    [anon_sym_return] = ACTIONS(891),
    [anon_sym_try] = ACTIONS(891),
    [anon_sym_throw] = ACTIONS(891),
    [anon_sym_for] = ACTIONS(891),
    [anon_sym_while] = ACTIONS(891),
    [anon_sym_break] = ACTIONS(891),
    [anon_sym_continue] = ACTIONS(891),
    [anon_sym_QMARK_DOT] = ACTIONS(893),
    [anon_sym_BQUOTE] = ACTIONS(893),
    [anon_sym_DOLLARr] = ACTIONS(891),
    [anon_sym_PLUS_PLUS] = ACTIONS(893),
    [anon_sym_DASH_DASH] = ACTIONS(893),
    [anon_sym_new] = ACTIONS(891),
  },
  [STATE(419)] = {
    [sym_comment] = STATE(419),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(895),
    [anon_sym_LBRACE] = ACTIONS(897),
    [anon_sym_RBRACE] = ACTIONS(897),
    [anon_sym_STAR] = ACTIONS(895),
    [anon_sym_as] = ACTIONS(895),
    [anon_sym_SEMI] = ACTIONS(897),
    [anon_sym_LPAREN] = ACTIONS(897),
    [anon_sym_DOT] = ACTIONS(897),
    [sym_identifier] = ACTIONS(895),
    [anon_sym_DQUOTE] = ACTIONS(897),
    [anon_sym_SQUOTE] = ACTIONS(897),
    [anon_sym_DOLLAR] = ACTIONS(895),
    [sym_numeric_literal] = ACTIONS(897),
    [anon_sym_true] = ACTIONS(895),
    [anon_sym_false] = ACTIONS(895),
    [anon_sym_null] = ACTIONS(895),
    [anon_sym_PIPE_PIPE] = ACTIONS(897),
    [anon_sym_AMP_AMP] = ACTIONS(897),
    [anon_sym_PIPE] = ACTIONS(895),
    [anon_sym_CARET] = ACTIONS(897),
    [anon_sym_AMP] = ACTIONS(895),
    [anon_sym_EQ_EQ] = ACTIONS(895),
    [anon_sym_BANG_EQ] = ACTIONS(895),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(897),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(897),
    [anon_sym_LT] = ACTIONS(895),
    [anon_sym_GT] = ACTIONS(895),
    [anon_sym_LT_EQ] = ACTIONS(897),
    [anon_sym_GT_EQ] = ACTIONS(897),
    [anon_sym_instanceof] = ACTIONS(895),
    [anon_sym_in] = ACTIONS(895),
    [anon_sym_LT_LT] = ACTIONS(897),
    [anon_sym_GT_GT] = ACTIONS(895),
    [anon_sym_GT_GT_GT] = ACTIONS(897),
    [anon_sym_PLUS] = ACTIONS(895),
    [anon_sym_DASH] = ACTIONS(895),
    [anon_sym_PERCENT] = ACTIONS(897),
    [anon_sym_STAR_STAR] = ACTIONS(897),
    [anon_sym_BANG] = ACTIONS(895),
    [anon_sym_TILDE] = ACTIONS(897),
    [anon_sym_typeof] = ACTIONS(895),
    [anon_sym_void] = ACTIONS(895),
    [anon_sym_delete] = ACTIONS(895),
    [anon_sym_QMARK] = ACTIONS(895),
    [anon_sym_await] = ACTIONS(895),
    [anon_sym_LBRACK] = ACTIONS(897),
    [anon_sym_if] = ACTIONS(895),
    [anon_sym_async] = ACTIONS(895),
    [anon_sym_var] = ACTIONS(895),
    [anon_sym_let] = ACTIONS(895),
    [anon_sym_const] = ACTIONS(895),
    [anon_sym_return] = ACTIONS(895),
    [anon_sym_try] = ACTIONS(895),
    [anon_sym_throw] = ACTIONS(895),
    [anon_sym_for] = ACTIONS(895),
    [anon_sym_while] = ACTIONS(895),
    [anon_sym_break] = ACTIONS(895),
    [anon_sym_continue] = ACTIONS(895),
    [anon_sym_QMARK_DOT] = ACTIONS(897),
    [anon_sym_BQUOTE] = ACTIONS(897),
    [anon_sym_DOLLARr] = ACTIONS(895),
    [anon_sym_PLUS_PLUS] = ACTIONS(897),
    [anon_sym_DASH_DASH] = ACTIONS(897),
    [anon_sym_new] = ACTIONS(895),
  },
  [STATE(420)] = {
    [sym_comment] = STATE(420),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(957),
    [anon_sym_LBRACE] = ACTIONS(910),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_STAR] = ACTIONS(957),
    [anon_sym_as] = ACTIONS(957),
    [anon_sym_SEMI] = ACTIONS(959),
    [anon_sym_LPAREN] = ACTIONS(910),
    [anon_sym_DOT] = ACTIONS(910),
    [sym_identifier] = ACTIONS(907),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [anon_sym_SQUOTE] = ACTIONS(910),
    [anon_sym_DOLLAR] = ACTIONS(907),
    [sym_numeric_literal] = ACTIONS(910),
    [anon_sym_true] = ACTIONS(907),
    [anon_sym_false] = ACTIONS(907),
    [anon_sym_null] = ACTIONS(907),
    [anon_sym_PIPE_PIPE] = ACTIONS(959),
    [anon_sym_AMP_AMP] = ACTIONS(959),
    [anon_sym_PIPE] = ACTIONS(957),
    [anon_sym_CARET] = ACTIONS(959),
    [anon_sym_AMP] = ACTIONS(957),
    [anon_sym_EQ_EQ] = ACTIONS(957),
    [anon_sym_BANG_EQ] = ACTIONS(957),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(959),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(959),
    [anon_sym_LT] = ACTIONS(907),
    [anon_sym_GT] = ACTIONS(957),
    [anon_sym_LT_EQ] = ACTIONS(959),
    [anon_sym_GT_EQ] = ACTIONS(959),
    [anon_sym_instanceof] = ACTIONS(957),
    [anon_sym_in] = ACTIONS(957),
    [anon_sym_LT_LT] = ACTIONS(959),
    [anon_sym_GT_GT] = ACTIONS(957),
    [anon_sym_GT_GT_GT] = ACTIONS(959),
    [anon_sym_PLUS] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(907),
    [anon_sym_PERCENT] = ACTIONS(959),
    [anon_sym_STAR_STAR] = ACTIONS(959),
    [anon_sym_BANG] = ACTIONS(907),
    [anon_sym_TILDE] = ACTIONS(910),
    [anon_sym_typeof] = ACTIONS(907),
    [anon_sym_void] = ACTIONS(907),
    [anon_sym_delete] = ACTIONS(907),
    [anon_sym_QMARK] = ACTIONS(957),
    [anon_sym_await] = ACTIONS(907),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_if] = ACTIONS(907),
    [anon_sym_async] = ACTIONS(907),
    [anon_sym_var] = ACTIONS(907),
    [anon_sym_let] = ACTIONS(907),
    [anon_sym_const] = ACTIONS(907),
    [anon_sym_return] = ACTIONS(907),
    [anon_sym_try] = ACTIONS(907),
    [anon_sym_throw] = ACTIONS(907),
    [anon_sym_for] = ACTIONS(907),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_break] = ACTIONS(907),
    [anon_sym_continue] = ACTIONS(907),
    [anon_sym_QMARK_DOT] = ACTIONS(959),
    [anon_sym_BQUOTE] = ACTIONS(910),
    [anon_sym_DOLLARr] = ACTIONS(907),
    [anon_sym_PLUS_PLUS] = ACTIONS(910),
    [anon_sym_DASH_DASH] = ACTIONS(910),
    [anon_sym_new] = ACTIONS(907),
  },
  [STATE(421)] = {
    [sym_comment] = STATE(421),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(981),
    [anon_sym_LBRACE] = ACTIONS(983),
    [anon_sym_RBRACE] = ACTIONS(983),
    [anon_sym_STAR] = ACTIONS(981),
    [anon_sym_as] = ACTIONS(981),
    [anon_sym_SEMI] = ACTIONS(983),
    [anon_sym_LPAREN] = ACTIONS(983),
    [anon_sym_DOT] = ACTIONS(983),
    [sym_identifier] = ACTIONS(981),
    [anon_sym_DQUOTE] = ACTIONS(983),
    [anon_sym_SQUOTE] = ACTIONS(983),
    [anon_sym_DOLLAR] = ACTIONS(981),
    [sym_numeric_literal] = ACTIONS(983),
    [anon_sym_true] = ACTIONS(981),
    [anon_sym_false] = ACTIONS(981),
    [anon_sym_null] = ACTIONS(981),
    [anon_sym_PIPE_PIPE] = ACTIONS(983),
    [anon_sym_AMP_AMP] = ACTIONS(983),
    [anon_sym_PIPE] = ACTIONS(981),
    [anon_sym_CARET] = ACTIONS(983),
    [anon_sym_AMP] = ACTIONS(981),
    [anon_sym_EQ_EQ] = ACTIONS(981),
    [anon_sym_BANG_EQ] = ACTIONS(981),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(983),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(983),
    [anon_sym_LT] = ACTIONS(981),
    [anon_sym_GT] = ACTIONS(981),
    [anon_sym_LT_EQ] = ACTIONS(983),
    [anon_sym_GT_EQ] = ACTIONS(983),
    [anon_sym_instanceof] = ACTIONS(981),
    [anon_sym_in] = ACTIONS(981),
    [anon_sym_LT_LT] = ACTIONS(983),
    [anon_sym_GT_GT] = ACTIONS(981),
    [anon_sym_GT_GT_GT] = ACTIONS(983),
    [anon_sym_PLUS] = ACTIONS(981),
    [anon_sym_DASH] = ACTIONS(981),
    [anon_sym_PERCENT] = ACTIONS(983),
    [anon_sym_STAR_STAR] = ACTIONS(983),
    [anon_sym_BANG] = ACTIONS(981),
    [anon_sym_TILDE] = ACTIONS(983),
    [anon_sym_typeof] = ACTIONS(981),
    [anon_sym_void] = ACTIONS(981),
    [anon_sym_delete] = ACTIONS(981),
    [anon_sym_QMARK] = ACTIONS(981),
    [anon_sym_await] = ACTIONS(981),
    [anon_sym_LBRACK] = ACTIONS(983),
    [anon_sym_if] = ACTIONS(981),
    [anon_sym_async] = ACTIONS(981),
    [anon_sym_var] = ACTIONS(981),
    [anon_sym_let] = ACTIONS(981),
    [anon_sym_const] = ACTIONS(981),
    [anon_sym_return] = ACTIONS(981),
    [anon_sym_try] = ACTIONS(981),
    [anon_sym_throw] = ACTIONS(981),
    [anon_sym_for] = ACTIONS(981),
    [anon_sym_while] = ACTIONS(981),
    [anon_sym_break] = ACTIONS(981),
    [anon_sym_continue] = ACTIONS(981),
    [anon_sym_QMARK_DOT] = ACTIONS(983),
    [anon_sym_BQUOTE] = ACTIONS(983),
    [anon_sym_DOLLARr] = ACTIONS(981),
    [anon_sym_PLUS_PLUS] = ACTIONS(983),
    [anon_sym_DASH_DASH] = ACTIONS(983),
    [anon_sym_new] = ACTIONS(981),
  },
  [STATE(422)] = {
    [sym_comment] = STATE(422),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(805),
    [anon_sym_LBRACE] = ACTIONS(807),
    [anon_sym_RBRACE] = ACTIONS(807),
    [anon_sym_STAR] = ACTIONS(805),
    [anon_sym_as] = ACTIONS(805),
    [anon_sym_SEMI] = ACTIONS(807),
    [anon_sym_LPAREN] = ACTIONS(807),
    [anon_sym_DOT] = ACTIONS(807),
    [sym_identifier] = ACTIONS(805),
    [anon_sym_DQUOTE] = ACTIONS(807),
    [anon_sym_SQUOTE] = ACTIONS(807),
    [anon_sym_DOLLAR] = ACTIONS(805),
    [sym_numeric_literal] = ACTIONS(807),
    [anon_sym_true] = ACTIONS(805),
    [anon_sym_false] = ACTIONS(805),
    [anon_sym_null] = ACTIONS(805),
    [anon_sym_PIPE_PIPE] = ACTIONS(807),
    [anon_sym_AMP_AMP] = ACTIONS(807),
    [anon_sym_PIPE] = ACTIONS(805),
    [anon_sym_CARET] = ACTIONS(807),
    [anon_sym_AMP] = ACTIONS(805),
    [anon_sym_EQ_EQ] = ACTIONS(805),
    [anon_sym_BANG_EQ] = ACTIONS(805),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(807),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(807),
    [anon_sym_LT] = ACTIONS(805),
    [anon_sym_GT] = ACTIONS(805),
    [anon_sym_LT_EQ] = ACTIONS(807),
    [anon_sym_GT_EQ] = ACTIONS(807),
    [anon_sym_instanceof] = ACTIONS(805),
    [anon_sym_in] = ACTIONS(805),
    [anon_sym_LT_LT] = ACTIONS(807),
    [anon_sym_GT_GT] = ACTIONS(805),
    [anon_sym_GT_GT_GT] = ACTIONS(807),
    [anon_sym_PLUS] = ACTIONS(805),
    [anon_sym_DASH] = ACTIONS(805),
    [anon_sym_PERCENT] = ACTIONS(807),
    [anon_sym_STAR_STAR] = ACTIONS(807),
    [anon_sym_BANG] = ACTIONS(805),
    [anon_sym_TILDE] = ACTIONS(807),
    [anon_sym_typeof] = ACTIONS(805),
    [anon_sym_void] = ACTIONS(805),
    [anon_sym_delete] = ACTIONS(805),
    [anon_sym_QMARK] = ACTIONS(805),
    [anon_sym_await] = ACTIONS(805),
    [anon_sym_LBRACK] = ACTIONS(807),
    [anon_sym_if] = ACTIONS(805),
    [anon_sym_async] = ACTIONS(805),
    [anon_sym_var] = ACTIONS(805),
    [anon_sym_let] = ACTIONS(805),
    [anon_sym_const] = ACTIONS(805),
    [anon_sym_return] = ACTIONS(805),
    [anon_sym_try] = ACTIONS(805),
    [anon_sym_throw] = ACTIONS(805),
    [anon_sym_for] = ACTIONS(805),
    [anon_sym_while] = ACTIONS(805),
    [anon_sym_break] = ACTIONS(805),
    [anon_sym_continue] = ACTIONS(805),
    [anon_sym_QMARK_DOT] = ACTIONS(807),
    [anon_sym_BQUOTE] = ACTIONS(807),
    [anon_sym_DOLLARr] = ACTIONS(805),
    [anon_sym_PLUS_PLUS] = ACTIONS(807),
    [anon_sym_DASH_DASH] = ACTIONS(807),
    [anon_sym_new] = ACTIONS(805),
  },
  [STATE(423)] = {
    [sym_comment] = STATE(423),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(828),
    [anon_sym_LBRACE] = ACTIONS(830),
    [anon_sym_RBRACE] = ACTIONS(830),
    [anon_sym_STAR] = ACTIONS(828),
    [anon_sym_as] = ACTIONS(828),
    [anon_sym_SEMI] = ACTIONS(830),
    [anon_sym_LPAREN] = ACTIONS(830),
    [anon_sym_DOT] = ACTIONS(830),
    [sym_identifier] = ACTIONS(828),
    [anon_sym_DQUOTE] = ACTIONS(830),
    [anon_sym_SQUOTE] = ACTIONS(830),
    [anon_sym_DOLLAR] = ACTIONS(828),
    [sym_numeric_literal] = ACTIONS(830),
    [anon_sym_true] = ACTIONS(828),
    [anon_sym_false] = ACTIONS(828),
    [anon_sym_null] = ACTIONS(828),
    [anon_sym_PIPE_PIPE] = ACTIONS(830),
    [anon_sym_AMP_AMP] = ACTIONS(830),
    [anon_sym_PIPE] = ACTIONS(828),
    [anon_sym_CARET] = ACTIONS(830),
    [anon_sym_AMP] = ACTIONS(828),
    [anon_sym_EQ_EQ] = ACTIONS(828),
    [anon_sym_BANG_EQ] = ACTIONS(828),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(830),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(830),
    [anon_sym_LT] = ACTIONS(828),
    [anon_sym_GT] = ACTIONS(828),
    [anon_sym_LT_EQ] = ACTIONS(830),
    [anon_sym_GT_EQ] = ACTIONS(830),
    [anon_sym_instanceof] = ACTIONS(828),
    [anon_sym_in] = ACTIONS(828),
    [anon_sym_LT_LT] = ACTIONS(830),
    [anon_sym_GT_GT] = ACTIONS(828),
    [anon_sym_GT_GT_GT] = ACTIONS(830),
    [anon_sym_PLUS] = ACTIONS(828),
    [anon_sym_DASH] = ACTIONS(828),
    [anon_sym_PERCENT] = ACTIONS(830),
    [anon_sym_STAR_STAR] = ACTIONS(830),
    [anon_sym_BANG] = ACTIONS(828),
    [anon_sym_TILDE] = ACTIONS(830),
    [anon_sym_typeof] = ACTIONS(828),
    [anon_sym_void] = ACTIONS(828),
    [anon_sym_delete] = ACTIONS(828),
    [anon_sym_QMARK] = ACTIONS(828),
    [anon_sym_await] = ACTIONS(828),
    [anon_sym_LBRACK] = ACTIONS(830),
    [anon_sym_if] = ACTIONS(828),
    [anon_sym_async] = ACTIONS(828),
    [anon_sym_var] = ACTIONS(828),
    [anon_sym_let] = ACTIONS(828),
    [anon_sym_const] = ACTIONS(828),
    [anon_sym_return] = ACTIONS(828),
    [anon_sym_try] = ACTIONS(828),
    [anon_sym_throw] = ACTIONS(828),
    [anon_sym_for] = ACTIONS(828),
    [anon_sym_while] = ACTIONS(828),
    [anon_sym_break] = ACTIONS(828),
    [anon_sym_continue] = ACTIONS(828),
    [anon_sym_QMARK_DOT] = ACTIONS(830),
    [anon_sym_BQUOTE] = ACTIONS(830),
    [anon_sym_DOLLARr] = ACTIONS(828),
    [anon_sym_PLUS_PLUS] = ACTIONS(830),
    [anon_sym_DASH_DASH] = ACTIONS(830),
    [anon_sym_new] = ACTIONS(828),
  },
  [STATE(424)] = {
    [sym_comment] = STATE(424),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(843),
    [anon_sym_LBRACE] = ACTIONS(845),
    [anon_sym_RBRACE] = ACTIONS(845),
    [anon_sym_STAR] = ACTIONS(843),
    [anon_sym_as] = ACTIONS(843),
    [anon_sym_SEMI] = ACTIONS(845),
    [anon_sym_LPAREN] = ACTIONS(845),
    [anon_sym_DOT] = ACTIONS(845),
    [sym_identifier] = ACTIONS(843),
    [anon_sym_DQUOTE] = ACTIONS(845),
    [anon_sym_SQUOTE] = ACTIONS(845),
    [anon_sym_DOLLAR] = ACTIONS(843),
    [sym_numeric_literal] = ACTIONS(845),
    [anon_sym_true] = ACTIONS(843),
    [anon_sym_false] = ACTIONS(843),
    [anon_sym_null] = ACTIONS(843),
    [anon_sym_PIPE_PIPE] = ACTIONS(845),
    [anon_sym_AMP_AMP] = ACTIONS(845),
    [anon_sym_PIPE] = ACTIONS(843),
    [anon_sym_CARET] = ACTIONS(845),
    [anon_sym_AMP] = ACTIONS(843),
    [anon_sym_EQ_EQ] = ACTIONS(843),
    [anon_sym_BANG_EQ] = ACTIONS(843),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(845),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(845),
    [anon_sym_LT] = ACTIONS(843),
    [anon_sym_GT] = ACTIONS(843),
    [anon_sym_LT_EQ] = ACTIONS(845),
    [anon_sym_GT_EQ] = ACTIONS(845),
    [anon_sym_instanceof] = ACTIONS(843),
    [anon_sym_in] = ACTIONS(843),
    [anon_sym_LT_LT] = ACTIONS(845),
    [anon_sym_GT_GT] = ACTIONS(843),
    [anon_sym_GT_GT_GT] = ACTIONS(845),
    [anon_sym_PLUS] = ACTIONS(843),
    [anon_sym_DASH] = ACTIONS(843),
    [anon_sym_PERCENT] = ACTIONS(845),
    [anon_sym_STAR_STAR] = ACTIONS(845),
    [anon_sym_BANG] = ACTIONS(843),
    [anon_sym_TILDE] = ACTIONS(845),
    [anon_sym_typeof] = ACTIONS(843),
    [anon_sym_void] = ACTIONS(843),
    [anon_sym_delete] = ACTIONS(843),
    [anon_sym_QMARK] = ACTIONS(843),
    [anon_sym_await] = ACTIONS(843),
    [anon_sym_LBRACK] = ACTIONS(845),
    [anon_sym_if] = ACTIONS(843),
    [anon_sym_async] = ACTIONS(843),
    [anon_sym_var] = ACTIONS(843),
    [anon_sym_let] = ACTIONS(843),
    [anon_sym_const] = ACTIONS(843),
    [anon_sym_return] = ACTIONS(843),
    [anon_sym_try] = ACTIONS(843),
    [anon_sym_throw] = ACTIONS(843),
    [anon_sym_for] = ACTIONS(843),
    [anon_sym_while] = ACTIONS(843),
    [anon_sym_break] = ACTIONS(843),
    [anon_sym_continue] = ACTIONS(843),
    [anon_sym_QMARK_DOT] = ACTIONS(845),
    [anon_sym_BQUOTE] = ACTIONS(845),
    [anon_sym_DOLLARr] = ACTIONS(843),
    [anon_sym_PLUS_PLUS] = ACTIONS(845),
    [anon_sym_DASH_DASH] = ACTIONS(845),
    [anon_sym_new] = ACTIONS(843),
  },
  [STATE(425)] = {
    [sym_comment] = STATE(425),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(899),
    [anon_sym_LBRACE] = ACTIONS(901),
    [anon_sym_RBRACE] = ACTIONS(901),
    [anon_sym_STAR] = ACTIONS(899),
    [anon_sym_as] = ACTIONS(899),
    [anon_sym_SEMI] = ACTIONS(901),
    [anon_sym_LPAREN] = ACTIONS(901),
    [anon_sym_DOT] = ACTIONS(901),
    [sym_identifier] = ACTIONS(899),
    [anon_sym_DQUOTE] = ACTIONS(901),
    [anon_sym_SQUOTE] = ACTIONS(901),
    [anon_sym_DOLLAR] = ACTIONS(899),
    [sym_numeric_literal] = ACTIONS(901),
    [anon_sym_true] = ACTIONS(899),
    [anon_sym_false] = ACTIONS(899),
    [anon_sym_null] = ACTIONS(899),
    [anon_sym_PIPE_PIPE] = ACTIONS(901),
    [anon_sym_AMP_AMP] = ACTIONS(901),
    [anon_sym_PIPE] = ACTIONS(899),
    [anon_sym_CARET] = ACTIONS(901),
    [anon_sym_AMP] = ACTIONS(899),
    [anon_sym_EQ_EQ] = ACTIONS(899),
    [anon_sym_BANG_EQ] = ACTIONS(899),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(901),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(901),
    [anon_sym_LT] = ACTIONS(899),
    [anon_sym_GT] = ACTIONS(899),
    [anon_sym_LT_EQ] = ACTIONS(901),
    [anon_sym_GT_EQ] = ACTIONS(901),
    [anon_sym_instanceof] = ACTIONS(899),
    [anon_sym_in] = ACTIONS(899),
    [anon_sym_LT_LT] = ACTIONS(901),
    [anon_sym_GT_GT] = ACTIONS(899),
    [anon_sym_GT_GT_GT] = ACTIONS(901),
    [anon_sym_PLUS] = ACTIONS(899),
    [anon_sym_DASH] = ACTIONS(899),
    [anon_sym_PERCENT] = ACTIONS(901),
    [anon_sym_STAR_STAR] = ACTIONS(901),
    [anon_sym_BANG] = ACTIONS(899),
    [anon_sym_TILDE] = ACTIONS(901),
    [anon_sym_typeof] = ACTIONS(899),
    [anon_sym_void] = ACTIONS(899),
    [anon_sym_delete] = ACTIONS(899),
    [anon_sym_QMARK] = ACTIONS(899),
    [anon_sym_await] = ACTIONS(899),
    [anon_sym_LBRACK] = ACTIONS(901),
    [anon_sym_if] = ACTIONS(899),
    [anon_sym_async] = ACTIONS(899),
    [anon_sym_var] = ACTIONS(899),
    [anon_sym_let] = ACTIONS(899),
    [anon_sym_const] = ACTIONS(899),
    [anon_sym_return] = ACTIONS(899),
    [anon_sym_try] = ACTIONS(899),
    [anon_sym_throw] = ACTIONS(899),
    [anon_sym_for] = ACTIONS(899),
    [anon_sym_while] = ACTIONS(899),
    [anon_sym_break] = ACTIONS(899),
    [anon_sym_continue] = ACTIONS(899),
    [anon_sym_QMARK_DOT] = ACTIONS(901),
    [anon_sym_BQUOTE] = ACTIONS(901),
    [anon_sym_DOLLARr] = ACTIONS(899),
    [anon_sym_PLUS_PLUS] = ACTIONS(901),
    [anon_sym_DASH_DASH] = ACTIONS(901),
    [anon_sym_new] = ACTIONS(899),
  },
  [STATE(426)] = {
    [sym_comment] = STATE(426),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(903),
    [anon_sym_LBRACE] = ACTIONS(905),
    [anon_sym_RBRACE] = ACTIONS(905),
    [anon_sym_STAR] = ACTIONS(903),
    [anon_sym_as] = ACTIONS(903),
    [anon_sym_SEMI] = ACTIONS(905),
    [anon_sym_LPAREN] = ACTIONS(905),
    [anon_sym_DOT] = ACTIONS(905),
    [sym_identifier] = ACTIONS(903),
    [anon_sym_DQUOTE] = ACTIONS(905),
    [anon_sym_SQUOTE] = ACTIONS(905),
    [anon_sym_DOLLAR] = ACTIONS(903),
    [sym_numeric_literal] = ACTIONS(905),
    [anon_sym_true] = ACTIONS(903),
    [anon_sym_false] = ACTIONS(903),
    [anon_sym_null] = ACTIONS(903),
    [anon_sym_PIPE_PIPE] = ACTIONS(905),
    [anon_sym_AMP_AMP] = ACTIONS(905),
    [anon_sym_PIPE] = ACTIONS(903),
    [anon_sym_CARET] = ACTIONS(905),
    [anon_sym_AMP] = ACTIONS(903),
    [anon_sym_EQ_EQ] = ACTIONS(903),
    [anon_sym_BANG_EQ] = ACTIONS(903),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(905),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(905),
    [anon_sym_LT] = ACTIONS(903),
    [anon_sym_GT] = ACTIONS(903),
    [anon_sym_LT_EQ] = ACTIONS(905),
    [anon_sym_GT_EQ] = ACTIONS(905),
    [anon_sym_instanceof] = ACTIONS(903),
    [anon_sym_in] = ACTIONS(903),
    [anon_sym_LT_LT] = ACTIONS(905),
    [anon_sym_GT_GT] = ACTIONS(903),
    [anon_sym_GT_GT_GT] = ACTIONS(905),
    [anon_sym_PLUS] = ACTIONS(903),
    [anon_sym_DASH] = ACTIONS(903),
    [anon_sym_PERCENT] = ACTIONS(905),
    [anon_sym_STAR_STAR] = ACTIONS(905),
    [anon_sym_BANG] = ACTIONS(903),
    [anon_sym_TILDE] = ACTIONS(905),
    [anon_sym_typeof] = ACTIONS(903),
    [anon_sym_void] = ACTIONS(903),
    [anon_sym_delete] = ACTIONS(903),
    [anon_sym_QMARK] = ACTIONS(903),
    [anon_sym_await] = ACTIONS(903),
    [anon_sym_LBRACK] = ACTIONS(905),
    [anon_sym_if] = ACTIONS(903),
    [anon_sym_async] = ACTIONS(903),
    [anon_sym_var] = ACTIONS(903),
    [anon_sym_let] = ACTIONS(903),
    [anon_sym_const] = ACTIONS(903),
    [anon_sym_return] = ACTIONS(903),
    [anon_sym_try] = ACTIONS(903),
    [anon_sym_throw] = ACTIONS(903),
    [anon_sym_for] = ACTIONS(903),
    [anon_sym_while] = ACTIONS(903),
    [anon_sym_break] = ACTIONS(903),
    [anon_sym_continue] = ACTIONS(903),
    [anon_sym_QMARK_DOT] = ACTIONS(905),
    [anon_sym_BQUOTE] = ACTIONS(905),
    [anon_sym_DOLLARr] = ACTIONS(903),
    [anon_sym_PLUS_PLUS] = ACTIONS(905),
    [anon_sym_DASH_DASH] = ACTIONS(905),
    [anon_sym_new] = ACTIONS(903),
  },
  [STATE(427)] = {
    [sym_comment] = STATE(427),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(907),
    [anon_sym_LBRACE] = ACTIONS(910),
    [anon_sym_RBRACE] = ACTIONS(910),
    [anon_sym_STAR] = ACTIONS(907),
    [anon_sym_as] = ACTIONS(907),
    [anon_sym_SEMI] = ACTIONS(910),
    [anon_sym_LPAREN] = ACTIONS(910),
    [anon_sym_DOT] = ACTIONS(910),
    [sym_identifier] = ACTIONS(907),
    [anon_sym_DQUOTE] = ACTIONS(910),
    [anon_sym_SQUOTE] = ACTIONS(910),
    [anon_sym_DOLLAR] = ACTIONS(907),
    [sym_numeric_literal] = ACTIONS(910),
    [anon_sym_true] = ACTIONS(907),
    [anon_sym_false] = ACTIONS(907),
    [anon_sym_null] = ACTIONS(907),
    [anon_sym_PIPE_PIPE] = ACTIONS(910),
    [anon_sym_AMP_AMP] = ACTIONS(910),
    [anon_sym_PIPE] = ACTIONS(907),
    [anon_sym_CARET] = ACTIONS(910),
    [anon_sym_AMP] = ACTIONS(907),
    [anon_sym_EQ_EQ] = ACTIONS(907),
    [anon_sym_BANG_EQ] = ACTIONS(907),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(910),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(910),
    [anon_sym_LT] = ACTIONS(907),
    [anon_sym_GT] = ACTIONS(907),
    [anon_sym_LT_EQ] = ACTIONS(910),
    [anon_sym_GT_EQ] = ACTIONS(910),
    [anon_sym_instanceof] = ACTIONS(907),
    [anon_sym_in] = ACTIONS(907),
    [anon_sym_LT_LT] = ACTIONS(910),
    [anon_sym_GT_GT] = ACTIONS(907),
    [anon_sym_GT_GT_GT] = ACTIONS(910),
    [anon_sym_PLUS] = ACTIONS(907),
    [anon_sym_DASH] = ACTIONS(907),
    [anon_sym_PERCENT] = ACTIONS(910),
    [anon_sym_STAR_STAR] = ACTIONS(910),
    [anon_sym_BANG] = ACTIONS(907),
    [anon_sym_TILDE] = ACTIONS(910),
    [anon_sym_typeof] = ACTIONS(907),
    [anon_sym_void] = ACTIONS(907),
    [anon_sym_delete] = ACTIONS(907),
    [anon_sym_QMARK] = ACTIONS(907),
    [anon_sym_await] = ACTIONS(907),
    [anon_sym_LBRACK] = ACTIONS(910),
    [anon_sym_if] = ACTIONS(907),
    [anon_sym_async] = ACTIONS(907),
    [anon_sym_var] = ACTIONS(907),
    [anon_sym_let] = ACTIONS(907),
    [anon_sym_const] = ACTIONS(907),
    [anon_sym_return] = ACTIONS(907),
    [anon_sym_try] = ACTIONS(907),
    [anon_sym_throw] = ACTIONS(907),
    [anon_sym_for] = ACTIONS(907),
    [anon_sym_while] = ACTIONS(907),
    [anon_sym_break] = ACTIONS(907),
    [anon_sym_continue] = ACTIONS(907),
    [anon_sym_QMARK_DOT] = ACTIONS(910),
    [anon_sym_BQUOTE] = ACTIONS(910),
    [anon_sym_DOLLARr] = ACTIONS(907),
    [anon_sym_PLUS_PLUS] = ACTIONS(910),
    [anon_sym_DASH_DASH] = ACTIONS(910),
    [anon_sym_new] = ACTIONS(907),
  },
  [STATE(428)] = {
    [sym_comment] = STATE(428),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(723),
    [anon_sym_LBRACE] = ACTIONS(721),
    [anon_sym_RBRACE] = ACTIONS(721),
    [anon_sym_STAR] = ACTIONS(723),
    [anon_sym_as] = ACTIONS(723),
    [anon_sym_SEMI] = ACTIONS(721),
    [anon_sym_LPAREN] = ACTIONS(721),
    [anon_sym_DOT] = ACTIONS(721),
    [sym_identifier] = ACTIONS(723),
    [anon_sym_DQUOTE] = ACTIONS(721),
    [anon_sym_SQUOTE] = ACTIONS(721),
    [anon_sym_DOLLAR] = ACTIONS(723),
    [sym_numeric_literal] = ACTIONS(721),
    [anon_sym_true] = ACTIONS(723),
    [anon_sym_false] = ACTIONS(723),
    [anon_sym_null] = ACTIONS(723),
    [anon_sym_PIPE_PIPE] = ACTIONS(721),
    [anon_sym_AMP_AMP] = ACTIONS(721),
    [anon_sym_PIPE] = ACTIONS(723),
    [anon_sym_CARET] = ACTIONS(721),
    [anon_sym_AMP] = ACTIONS(723),
    [anon_sym_EQ_EQ] = ACTIONS(723),
    [anon_sym_BANG_EQ] = ACTIONS(723),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(721),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(721),
    [anon_sym_LT] = ACTIONS(723),
    [anon_sym_GT] = ACTIONS(723),
    [anon_sym_LT_EQ] = ACTIONS(721),
    [anon_sym_GT_EQ] = ACTIONS(721),
    [anon_sym_instanceof] = ACTIONS(723),
    [anon_sym_in] = ACTIONS(723),
    [anon_sym_LT_LT] = ACTIONS(721),
    [anon_sym_GT_GT] = ACTIONS(723),
    [anon_sym_GT_GT_GT] = ACTIONS(721),
    [anon_sym_PLUS] = ACTIONS(723),
    [anon_sym_DASH] = ACTIONS(723),
    [anon_sym_PERCENT] = ACTIONS(721),
    [anon_sym_STAR_STAR] = ACTIONS(721),
    [anon_sym_BANG] = ACTIONS(723),
    [anon_sym_TILDE] = ACTIONS(721),
    [anon_sym_typeof] = ACTIONS(723),
    [anon_sym_void] = ACTIONS(723),
    [anon_sym_delete] = ACTIONS(723),
    [anon_sym_QMARK] = ACTIONS(723),
    [anon_sym_await] = ACTIONS(723),
    [anon_sym_LBRACK] = ACTIONS(721),
    [anon_sym_if] = ACTIONS(723),
    [anon_sym_async] = ACTIONS(723),
    [anon_sym_var] = ACTIONS(723),
    [anon_sym_let] = ACTIONS(723),
    [anon_sym_const] = ACTIONS(723),
    [anon_sym_return] = ACTIONS(723),
    [anon_sym_try] = ACTIONS(723),
    [anon_sym_throw] = ACTIONS(723),
    [anon_sym_for] = ACTIONS(723),
    [anon_sym_while] = ACTIONS(723),
    [anon_sym_break] = ACTIONS(723),
    [anon_sym_continue] = ACTIONS(723),
    [anon_sym_QMARK_DOT] = ACTIONS(721),
    [anon_sym_BQUOTE] = ACTIONS(721),
    [anon_sym_DOLLARr] = ACTIONS(723),
    [anon_sym_PLUS_PLUS] = ACTIONS(721),
    [anon_sym_DASH_DASH] = ACTIONS(721),
    [anon_sym_new] = ACTIONS(723),
  },
  [STATE(429)] = {
    [sym_comment] = STATE(429),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(913),
    [anon_sym_LBRACE] = ACTIONS(915),
    [anon_sym_RBRACE] = ACTIONS(915),
    [anon_sym_STAR] = ACTIONS(913),
    [anon_sym_as] = ACTIONS(913),
    [anon_sym_SEMI] = ACTIONS(915),
    [anon_sym_LPAREN] = ACTIONS(915),
    [anon_sym_DOT] = ACTIONS(915),
    [sym_identifier] = ACTIONS(913),
    [anon_sym_DQUOTE] = ACTIONS(915),
    [anon_sym_SQUOTE] = ACTIONS(915),
    [anon_sym_DOLLAR] = ACTIONS(913),
    [sym_numeric_literal] = ACTIONS(915),
    [anon_sym_true] = ACTIONS(913),
    [anon_sym_false] = ACTIONS(913),
    [anon_sym_null] = ACTIONS(913),
    [anon_sym_PIPE_PIPE] = ACTIONS(915),
    [anon_sym_AMP_AMP] = ACTIONS(915),
    [anon_sym_PIPE] = ACTIONS(913),
    [anon_sym_CARET] = ACTIONS(915),
    [anon_sym_AMP] = ACTIONS(913),
    [anon_sym_EQ_EQ] = ACTIONS(913),
    [anon_sym_BANG_EQ] = ACTIONS(913),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(915),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(915),
    [anon_sym_LT] = ACTIONS(913),
    [anon_sym_GT] = ACTIONS(913),
    [anon_sym_LT_EQ] = ACTIONS(915),
    [anon_sym_GT_EQ] = ACTIONS(915),
    [anon_sym_instanceof] = ACTIONS(913),
    [anon_sym_in] = ACTIONS(913),
    [anon_sym_LT_LT] = ACTIONS(915),
    [anon_sym_GT_GT] = ACTIONS(913),
    [anon_sym_GT_GT_GT] = ACTIONS(915),
    [anon_sym_PLUS] = ACTIONS(913),
    [anon_sym_DASH] = ACTIONS(913),
    [anon_sym_PERCENT] = ACTIONS(915),
    [anon_sym_STAR_STAR] = ACTIONS(915),
    [anon_sym_BANG] = ACTIONS(913),
    [anon_sym_TILDE] = ACTIONS(915),
    [anon_sym_typeof] = ACTIONS(913),
    [anon_sym_void] = ACTIONS(913),
    [anon_sym_delete] = ACTIONS(913),
    [anon_sym_QMARK] = ACTIONS(913),
    [anon_sym_await] = ACTIONS(913),
    [anon_sym_LBRACK] = ACTIONS(915),
    [anon_sym_if] = ACTIONS(913),
    [anon_sym_async] = ACTIONS(913),
    [anon_sym_var] = ACTIONS(913),
    [anon_sym_let] = ACTIONS(913),
    [anon_sym_const] = ACTIONS(913),
    [anon_sym_return] = ACTIONS(913),
    [anon_sym_try] = ACTIONS(913),
    [anon_sym_throw] = ACTIONS(913),
    [anon_sym_for] = ACTIONS(913),
    [anon_sym_while] = ACTIONS(913),
    [anon_sym_break] = ACTIONS(913),
    [anon_sym_continue] = ACTIONS(913),
    [anon_sym_QMARK_DOT] = ACTIONS(915),
    [anon_sym_BQUOTE] = ACTIONS(915),
    [anon_sym_DOLLARr] = ACTIONS(913),
    [anon_sym_PLUS_PLUS] = ACTIONS(915),
    [anon_sym_DASH_DASH] = ACTIONS(915),
    [anon_sym_new] = ACTIONS(913),
  },
  [STATE(430)] = {
    [sym_comment] = STATE(430),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(847),
    [anon_sym_LBRACE] = ACTIONS(849),
    [anon_sym_RBRACE] = ACTIONS(849),
    [anon_sym_STAR] = ACTIONS(847),
    [anon_sym_as] = ACTIONS(847),
    [anon_sym_SEMI] = ACTIONS(849),
    [anon_sym_LPAREN] = ACTIONS(849),
    [anon_sym_DOT] = ACTIONS(849),
    [sym_identifier] = ACTIONS(847),
    [anon_sym_DQUOTE] = ACTIONS(849),
    [anon_sym_SQUOTE] = ACTIONS(849),
    [anon_sym_DOLLAR] = ACTIONS(847),
    [sym_numeric_literal] = ACTIONS(849),
    [anon_sym_true] = ACTIONS(847),
    [anon_sym_false] = ACTIONS(847),
    [anon_sym_null] = ACTIONS(847),
    [anon_sym_PIPE_PIPE] = ACTIONS(849),
    [anon_sym_AMP_AMP] = ACTIONS(849),
    [anon_sym_PIPE] = ACTIONS(847),
    [anon_sym_CARET] = ACTIONS(849),
    [anon_sym_AMP] = ACTIONS(847),
    [anon_sym_EQ_EQ] = ACTIONS(847),
    [anon_sym_BANG_EQ] = ACTIONS(847),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(849),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(849),
    [anon_sym_LT] = ACTIONS(847),
    [anon_sym_GT] = ACTIONS(847),
    [anon_sym_LT_EQ] = ACTIONS(849),
    [anon_sym_GT_EQ] = ACTIONS(849),
    [anon_sym_instanceof] = ACTIONS(847),
    [anon_sym_in] = ACTIONS(847),
    [anon_sym_LT_LT] = ACTIONS(849),
    [anon_sym_GT_GT] = ACTIONS(847),
    [anon_sym_GT_GT_GT] = ACTIONS(849),
    [anon_sym_PLUS] = ACTIONS(847),
    [anon_sym_DASH] = ACTIONS(847),
    [anon_sym_PERCENT] = ACTIONS(849),
    [anon_sym_STAR_STAR] = ACTIONS(849),
    [anon_sym_BANG] = ACTIONS(847),
    [anon_sym_TILDE] = ACTIONS(849),
    [anon_sym_typeof] = ACTIONS(847),
    [anon_sym_void] = ACTIONS(847),
    [anon_sym_delete] = ACTIONS(847),
    [anon_sym_QMARK] = ACTIONS(847),
    [anon_sym_await] = ACTIONS(847),
    [anon_sym_LBRACK] = ACTIONS(849),
    [anon_sym_if] = ACTIONS(847),
    [anon_sym_async] = ACTIONS(847),
    [anon_sym_var] = ACTIONS(847),
    [anon_sym_let] = ACTIONS(847),
    [anon_sym_const] = ACTIONS(847),
    [anon_sym_return] = ACTIONS(847),
    [anon_sym_try] = ACTIONS(847),
    [anon_sym_throw] = ACTIONS(847),
    [anon_sym_for] = ACTIONS(847),
    [anon_sym_while] = ACTIONS(847),
    [anon_sym_break] = ACTIONS(847),
    [anon_sym_continue] = ACTIONS(847),
    [anon_sym_QMARK_DOT] = ACTIONS(849),
    [anon_sym_BQUOTE] = ACTIONS(849),
    [anon_sym_DOLLARr] = ACTIONS(847),
    [anon_sym_PLUS_PLUS] = ACTIONS(849),
    [anon_sym_DASH_DASH] = ACTIONS(849),
    [anon_sym_new] = ACTIONS(847),
  },
  [STATE(431)] = {
    [sym_comment] = STATE(431),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(875),
    [anon_sym_LBRACE] = ACTIONS(877),
    [anon_sym_RBRACE] = ACTIONS(877),
    [anon_sym_STAR] = ACTIONS(875),
    [anon_sym_as] = ACTIONS(875),
    [anon_sym_SEMI] = ACTIONS(877),
    [anon_sym_LPAREN] = ACTIONS(877),
    [anon_sym_DOT] = ACTIONS(877),
    [sym_identifier] = ACTIONS(875),
    [anon_sym_DQUOTE] = ACTIONS(877),
    [anon_sym_SQUOTE] = ACTIONS(877),
    [anon_sym_DOLLAR] = ACTIONS(875),
    [sym_numeric_literal] = ACTIONS(877),
    [anon_sym_true] = ACTIONS(875),
    [anon_sym_false] = ACTIONS(875),
    [anon_sym_null] = ACTIONS(875),
    [anon_sym_PIPE_PIPE] = ACTIONS(877),
    [anon_sym_AMP_AMP] = ACTIONS(877),
    [anon_sym_PIPE] = ACTIONS(875),
    [anon_sym_CARET] = ACTIONS(877),
    [anon_sym_AMP] = ACTIONS(875),
    [anon_sym_EQ_EQ] = ACTIONS(875),
    [anon_sym_BANG_EQ] = ACTIONS(875),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(877),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(877),
    [anon_sym_LT] = ACTIONS(875),
    [anon_sym_GT] = ACTIONS(875),
    [anon_sym_LT_EQ] = ACTIONS(877),
    [anon_sym_GT_EQ] = ACTIONS(877),
    [anon_sym_instanceof] = ACTIONS(875),
    [anon_sym_in] = ACTIONS(875),
    [anon_sym_LT_LT] = ACTIONS(877),
    [anon_sym_GT_GT] = ACTIONS(875),
    [anon_sym_GT_GT_GT] = ACTIONS(877),
    [anon_sym_PLUS] = ACTIONS(875),
    [anon_sym_DASH] = ACTIONS(875),
    [anon_sym_PERCENT] = ACTIONS(877),
    [anon_sym_STAR_STAR] = ACTIONS(877),
    [anon_sym_BANG] = ACTIONS(875),
    [anon_sym_TILDE] = ACTIONS(877),
    [anon_sym_typeof] = ACTIONS(875),
    [anon_sym_void] = ACTIONS(875),
    [anon_sym_delete] = ACTIONS(875),
    [anon_sym_QMARK] = ACTIONS(875),
    [anon_sym_await] = ACTIONS(875),
    [anon_sym_LBRACK] = ACTIONS(877),
    [anon_sym_if] = ACTIONS(875),
    [anon_sym_async] = ACTIONS(875),
    [anon_sym_var] = ACTIONS(875),
    [anon_sym_let] = ACTIONS(875),
    [anon_sym_const] = ACTIONS(875),
    [anon_sym_return] = ACTIONS(875),
    [anon_sym_try] = ACTIONS(875),
    [anon_sym_throw] = ACTIONS(875),
    [anon_sym_for] = ACTIONS(875),
    [anon_sym_while] = ACTIONS(875),
    [anon_sym_break] = ACTIONS(875),
    [anon_sym_continue] = ACTIONS(875),
    [anon_sym_QMARK_DOT] = ACTIONS(877),
    [anon_sym_BQUOTE] = ACTIONS(877),
    [anon_sym_DOLLARr] = ACTIONS(875),
    [anon_sym_PLUS_PLUS] = ACTIONS(877),
    [anon_sym_DASH_DASH] = ACTIONS(877),
    [anon_sym_new] = ACTIONS(875),
  },
  [STATE(432)] = {
    [sym_comment] = STATE(432),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(711),
    [anon_sym_LBRACE] = ACTIONS(709),
    [anon_sym_RBRACE] = ACTIONS(709),
    [anon_sym_STAR] = ACTIONS(711),
    [anon_sym_as] = ACTIONS(711),
    [anon_sym_SEMI] = ACTIONS(709),
    [anon_sym_LPAREN] = ACTIONS(709),
    [anon_sym_DOT] = ACTIONS(709),
    [sym_identifier] = ACTIONS(711),
    [anon_sym_DQUOTE] = ACTIONS(709),
    [anon_sym_SQUOTE] = ACTIONS(709),
    [anon_sym_DOLLAR] = ACTIONS(711),
    [sym_numeric_literal] = ACTIONS(709),
    [anon_sym_true] = ACTIONS(711),
    [anon_sym_false] = ACTIONS(711),
    [anon_sym_null] = ACTIONS(711),
    [anon_sym_PIPE_PIPE] = ACTIONS(709),
    [anon_sym_AMP_AMP] = ACTIONS(709),
    [anon_sym_PIPE] = ACTIONS(711),
    [anon_sym_CARET] = ACTIONS(709),
    [anon_sym_AMP] = ACTIONS(711),
    [anon_sym_EQ_EQ] = ACTIONS(711),
    [anon_sym_BANG_EQ] = ACTIONS(711),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(709),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(709),
    [anon_sym_LT] = ACTIONS(711),
    [anon_sym_GT] = ACTIONS(711),
    [anon_sym_LT_EQ] = ACTIONS(709),
    [anon_sym_GT_EQ] = ACTIONS(709),
    [anon_sym_instanceof] = ACTIONS(711),
    [anon_sym_in] = ACTIONS(711),
    [anon_sym_LT_LT] = ACTIONS(709),
    [anon_sym_GT_GT] = ACTIONS(711),
    [anon_sym_GT_GT_GT] = ACTIONS(709),
    [anon_sym_PLUS] = ACTIONS(711),
    [anon_sym_DASH] = ACTIONS(711),
    [anon_sym_PERCENT] = ACTIONS(709),
    [anon_sym_STAR_STAR] = ACTIONS(709),
    [anon_sym_BANG] = ACTIONS(711),
    [anon_sym_TILDE] = ACTIONS(709),
    [anon_sym_typeof] = ACTIONS(711),
    [anon_sym_void] = ACTIONS(711),
    [anon_sym_delete] = ACTIONS(711),
    [anon_sym_QMARK] = ACTIONS(711),
    [anon_sym_await] = ACTIONS(711),
    [anon_sym_LBRACK] = ACTIONS(709),
    [anon_sym_if] = ACTIONS(711),
    [anon_sym_async] = ACTIONS(711),
    [anon_sym_var] = ACTIONS(711),
    [anon_sym_let] = ACTIONS(711),
    [anon_sym_const] = ACTIONS(711),
    [anon_sym_return] = ACTIONS(711),
    [anon_sym_try] = ACTIONS(711),
    [anon_sym_throw] = ACTIONS(711),
    [anon_sym_for] = ACTIONS(711),
    [anon_sym_while] = ACTIONS(711),
    [anon_sym_break] = ACTIONS(711),
    [anon_sym_continue] = ACTIONS(711),
    [anon_sym_QMARK_DOT] = ACTIONS(709),
    [anon_sym_BQUOTE] = ACTIONS(709),
    [anon_sym_DOLLARr] = ACTIONS(711),
    [anon_sym_PLUS_PLUS] = ACTIONS(709),
    [anon_sym_DASH_DASH] = ACTIONS(709),
    [anon_sym_new] = ACTIONS(711),
  },
  [STATE(433)] = {
    [sym_comment] = STATE(433),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(917),
    [anon_sym_LBRACE] = ACTIONS(919),
    [anon_sym_RBRACE] = ACTIONS(919),
    [anon_sym_STAR] = ACTIONS(917),
    [anon_sym_as] = ACTIONS(917),
    [anon_sym_SEMI] = ACTIONS(919),
    [anon_sym_LPAREN] = ACTIONS(919),
    [anon_sym_DOT] = ACTIONS(919),
    [sym_identifier] = ACTIONS(917),
    [anon_sym_DQUOTE] = ACTIONS(919),
    [anon_sym_SQUOTE] = ACTIONS(919),
    [anon_sym_DOLLAR] = ACTIONS(917),
    [sym_numeric_literal] = ACTIONS(919),
    [anon_sym_true] = ACTIONS(917),
    [anon_sym_false] = ACTIONS(917),
    [anon_sym_null] = ACTIONS(917),
    [anon_sym_PIPE_PIPE] = ACTIONS(919),
    [anon_sym_AMP_AMP] = ACTIONS(919),
    [anon_sym_PIPE] = ACTIONS(917),
    [anon_sym_CARET] = ACTIONS(919),
    [anon_sym_AMP] = ACTIONS(917),
    [anon_sym_EQ_EQ] = ACTIONS(917),
    [anon_sym_BANG_EQ] = ACTIONS(917),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(919),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(919),
    [anon_sym_LT] = ACTIONS(917),
    [anon_sym_GT] = ACTIONS(917),
    [anon_sym_LT_EQ] = ACTIONS(919),
    [anon_sym_GT_EQ] = ACTIONS(919),
    [anon_sym_instanceof] = ACTIONS(917),
    [anon_sym_in] = ACTIONS(917),
    [anon_sym_LT_LT] = ACTIONS(919),
    [anon_sym_GT_GT] = ACTIONS(917),
    [anon_sym_GT_GT_GT] = ACTIONS(919),
    [anon_sym_PLUS] = ACTIONS(917),
    [anon_sym_DASH] = ACTIONS(917),
    [anon_sym_PERCENT] = ACTIONS(919),
    [anon_sym_STAR_STAR] = ACTIONS(919),
    [anon_sym_BANG] = ACTIONS(917),
    [anon_sym_TILDE] = ACTIONS(919),
    [anon_sym_typeof] = ACTIONS(917),
    [anon_sym_void] = ACTIONS(917),
    [anon_sym_delete] = ACTIONS(917),
    [anon_sym_QMARK] = ACTIONS(917),
    [anon_sym_await] = ACTIONS(917),
    [anon_sym_LBRACK] = ACTIONS(919),
    [anon_sym_if] = ACTIONS(917),
    [anon_sym_async] = ACTIONS(917),
    [anon_sym_var] = ACTIONS(917),
    [anon_sym_let] = ACTIONS(917),
    [anon_sym_const] = ACTIONS(917),
    [anon_sym_return] = ACTIONS(917),
    [anon_sym_try] = ACTIONS(917),
    [anon_sym_throw] = ACTIONS(917),
    [anon_sym_for] = ACTIONS(917),
    [anon_sym_while] = ACTIONS(917),
    [anon_sym_break] = ACTIONS(917),
    [anon_sym_continue] = ACTIONS(917),
    [anon_sym_QMARK_DOT] = ACTIONS(919),
    [anon_sym_BQUOTE] = ACTIONS(919),
    [anon_sym_DOLLARr] = ACTIONS(917),
    [anon_sym_PLUS_PLUS] = ACTIONS(919),
    [anon_sym_DASH_DASH] = ACTIONS(919),
    [anon_sym_new] = ACTIONS(917),
  },
  [STATE(434)] = {
    [sym_comment] = STATE(434),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(921),
    [anon_sym_LBRACE] = ACTIONS(923),
    [anon_sym_RBRACE] = ACTIONS(923),
    [anon_sym_STAR] = ACTIONS(921),
    [anon_sym_as] = ACTIONS(921),
    [anon_sym_SEMI] = ACTIONS(923),
    [anon_sym_LPAREN] = ACTIONS(923),
    [anon_sym_DOT] = ACTIONS(923),
    [sym_identifier] = ACTIONS(921),
    [anon_sym_DQUOTE] = ACTIONS(923),
    [anon_sym_SQUOTE] = ACTIONS(923),
    [anon_sym_DOLLAR] = ACTIONS(921),
    [sym_numeric_literal] = ACTIONS(923),
    [anon_sym_true] = ACTIONS(921),
    [anon_sym_false] = ACTIONS(921),
    [anon_sym_null] = ACTIONS(921),
    [anon_sym_PIPE_PIPE] = ACTIONS(923),
    [anon_sym_AMP_AMP] = ACTIONS(923),
    [anon_sym_PIPE] = ACTIONS(921),
    [anon_sym_CARET] = ACTIONS(923),
    [anon_sym_AMP] = ACTIONS(921),
    [anon_sym_EQ_EQ] = ACTIONS(921),
    [anon_sym_BANG_EQ] = ACTIONS(921),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(923),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(923),
    [anon_sym_LT] = ACTIONS(921),
    [anon_sym_GT] = ACTIONS(921),
    [anon_sym_LT_EQ] = ACTIONS(923),
    [anon_sym_GT_EQ] = ACTIONS(923),
    [anon_sym_instanceof] = ACTIONS(921),
    [anon_sym_in] = ACTIONS(921),
    [anon_sym_LT_LT] = ACTIONS(923),
    [anon_sym_GT_GT] = ACTIONS(921),
    [anon_sym_GT_GT_GT] = ACTIONS(923),
    [anon_sym_PLUS] = ACTIONS(921),
    [anon_sym_DASH] = ACTIONS(921),
    [anon_sym_PERCENT] = ACTIONS(923),
    [anon_sym_STAR_STAR] = ACTIONS(923),
    [anon_sym_BANG] = ACTIONS(921),
    [anon_sym_TILDE] = ACTIONS(923),
    [anon_sym_typeof] = ACTIONS(921),
    [anon_sym_void] = ACTIONS(921),
    [anon_sym_delete] = ACTIONS(921),
    [anon_sym_QMARK] = ACTIONS(921),
    [anon_sym_await] = ACTIONS(921),
    [anon_sym_LBRACK] = ACTIONS(923),
    [anon_sym_if] = ACTIONS(921),
    [anon_sym_async] = ACTIONS(921),
    [anon_sym_var] = ACTIONS(921),
    [anon_sym_let] = ACTIONS(921),
    [anon_sym_const] = ACTIONS(921),
    [anon_sym_return] = ACTIONS(921),
    [anon_sym_try] = ACTIONS(921),
    [anon_sym_throw] = ACTIONS(921),
    [anon_sym_for] = ACTIONS(921),
    [anon_sym_while] = ACTIONS(921),
    [anon_sym_break] = ACTIONS(921),
    [anon_sym_continue] = ACTIONS(921),
    [anon_sym_QMARK_DOT] = ACTIONS(923),
    [anon_sym_BQUOTE] = ACTIONS(923),
    [anon_sym_DOLLARr] = ACTIONS(921),
    [anon_sym_PLUS_PLUS] = ACTIONS(923),
    [anon_sym_DASH_DASH] = ACTIONS(923),
    [anon_sym_new] = ACTIONS(921),
  },
  [STATE(435)] = {
    [sym_comment] = STATE(435),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(925),
    [anon_sym_LBRACE] = ACTIONS(927),
    [anon_sym_RBRACE] = ACTIONS(927),
    [anon_sym_STAR] = ACTIONS(925),
    [anon_sym_as] = ACTIONS(925),
    [anon_sym_SEMI] = ACTIONS(927),
    [anon_sym_LPAREN] = ACTIONS(927),
    [anon_sym_DOT] = ACTIONS(927),
    [sym_identifier] = ACTIONS(925),
    [anon_sym_DQUOTE] = ACTIONS(927),
    [anon_sym_SQUOTE] = ACTIONS(927),
    [anon_sym_DOLLAR] = ACTIONS(925),
    [sym_numeric_literal] = ACTIONS(927),
    [anon_sym_true] = ACTIONS(925),
    [anon_sym_false] = ACTIONS(925),
    [anon_sym_null] = ACTIONS(925),
    [anon_sym_PIPE_PIPE] = ACTIONS(927),
    [anon_sym_AMP_AMP] = ACTIONS(927),
    [anon_sym_PIPE] = ACTIONS(925),
    [anon_sym_CARET] = ACTIONS(927),
    [anon_sym_AMP] = ACTIONS(925),
    [anon_sym_EQ_EQ] = ACTIONS(925),
    [anon_sym_BANG_EQ] = ACTIONS(925),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(927),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(927),
    [anon_sym_LT] = ACTIONS(925),
    [anon_sym_GT] = ACTIONS(925),
    [anon_sym_LT_EQ] = ACTIONS(927),
    [anon_sym_GT_EQ] = ACTIONS(927),
    [anon_sym_instanceof] = ACTIONS(925),
    [anon_sym_in] = ACTIONS(925),
    [anon_sym_LT_LT] = ACTIONS(927),
    [anon_sym_GT_GT] = ACTIONS(925),
    [anon_sym_GT_GT_GT] = ACTIONS(927),
    [anon_sym_PLUS] = ACTIONS(925),
    [anon_sym_DASH] = ACTIONS(925),
    [anon_sym_PERCENT] = ACTIONS(927),
    [anon_sym_STAR_STAR] = ACTIONS(927),
    [anon_sym_BANG] = ACTIONS(925),
    [anon_sym_TILDE] = ACTIONS(927),
    [anon_sym_typeof] = ACTIONS(925),
    [anon_sym_void] = ACTIONS(925),
    [anon_sym_delete] = ACTIONS(925),
    [anon_sym_QMARK] = ACTIONS(925),
    [anon_sym_await] = ACTIONS(925),
    [anon_sym_LBRACK] = ACTIONS(927),
    [anon_sym_if] = ACTIONS(925),
    [anon_sym_async] = ACTIONS(925),
    [anon_sym_var] = ACTIONS(925),
    [anon_sym_let] = ACTIONS(925),
    [anon_sym_const] = ACTIONS(925),
    [anon_sym_return] = ACTIONS(925),
    [anon_sym_try] = ACTIONS(925),
    [anon_sym_throw] = ACTIONS(925),
    [anon_sym_for] = ACTIONS(925),
    [anon_sym_while] = ACTIONS(925),
    [anon_sym_break] = ACTIONS(925),
    [anon_sym_continue] = ACTIONS(925),
    [anon_sym_QMARK_DOT] = ACTIONS(927),
    [anon_sym_BQUOTE] = ACTIONS(927),
    [anon_sym_DOLLARr] = ACTIONS(925),
    [anon_sym_PLUS_PLUS] = ACTIONS(927),
    [anon_sym_DASH_DASH] = ACTIONS(927),
    [anon_sym_new] = ACTIONS(925),
  },
  [STATE(436)] = {
    [sym_comment] = STATE(436),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(929),
    [anon_sym_LBRACE] = ACTIONS(931),
    [anon_sym_RBRACE] = ACTIONS(931),
    [anon_sym_STAR] = ACTIONS(929),
    [anon_sym_as] = ACTIONS(929),
    [anon_sym_SEMI] = ACTIONS(931),
    [anon_sym_LPAREN] = ACTIONS(931),
    [anon_sym_DOT] = ACTIONS(931),
    [sym_identifier] = ACTIONS(929),
    [anon_sym_DQUOTE] = ACTIONS(931),
    [anon_sym_SQUOTE] = ACTIONS(931),
    [anon_sym_DOLLAR] = ACTIONS(929),
    [sym_numeric_literal] = ACTIONS(931),
    [anon_sym_true] = ACTIONS(929),
    [anon_sym_false] = ACTIONS(929),
    [anon_sym_null] = ACTIONS(929),
    [anon_sym_PIPE_PIPE] = ACTIONS(931),
    [anon_sym_AMP_AMP] = ACTIONS(931),
    [anon_sym_PIPE] = ACTIONS(929),
    [anon_sym_CARET] = ACTIONS(931),
    [anon_sym_AMP] = ACTIONS(929),
    [anon_sym_EQ_EQ] = ACTIONS(929),
    [anon_sym_BANG_EQ] = ACTIONS(929),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(931),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(931),
    [anon_sym_LT] = ACTIONS(929),
    [anon_sym_GT] = ACTIONS(929),
    [anon_sym_LT_EQ] = ACTIONS(931),
    [anon_sym_GT_EQ] = ACTIONS(931),
    [anon_sym_instanceof] = ACTIONS(929),
    [anon_sym_in] = ACTIONS(929),
    [anon_sym_LT_LT] = ACTIONS(931),
    [anon_sym_GT_GT] = ACTIONS(929),
    [anon_sym_GT_GT_GT] = ACTIONS(931),
    [anon_sym_PLUS] = ACTIONS(929),
    [anon_sym_DASH] = ACTIONS(929),
    [anon_sym_PERCENT] = ACTIONS(931),
    [anon_sym_STAR_STAR] = ACTIONS(931),
    [anon_sym_BANG] = ACTIONS(929),
    [anon_sym_TILDE] = ACTIONS(931),
    [anon_sym_typeof] = ACTIONS(929),
    [anon_sym_void] = ACTIONS(929),
    [anon_sym_delete] = ACTIONS(929),
    [anon_sym_QMARK] = ACTIONS(929),
    [anon_sym_await] = ACTIONS(929),
    [anon_sym_LBRACK] = ACTIONS(931),
    [anon_sym_if] = ACTIONS(929),
    [anon_sym_async] = ACTIONS(929),
    [anon_sym_var] = ACTIONS(929),
    [anon_sym_let] = ACTIONS(929),
    [anon_sym_const] = ACTIONS(929),
    [anon_sym_return] = ACTIONS(929),
    [anon_sym_try] = ACTIONS(929),
    [anon_sym_throw] = ACTIONS(929),
    [anon_sym_for] = ACTIONS(929),
    [anon_sym_while] = ACTIONS(929),
    [anon_sym_break] = ACTIONS(929),
    [anon_sym_continue] = ACTIONS(929),
    [anon_sym_QMARK_DOT] = ACTIONS(931),
    [anon_sym_BQUOTE] = ACTIONS(931),
    [anon_sym_DOLLARr] = ACTIONS(929),
    [anon_sym_PLUS_PLUS] = ACTIONS(931),
    [anon_sym_DASH_DASH] = ACTIONS(931),
    [anon_sym_new] = ACTIONS(929),
  },
  [STATE(437)] = {
    [sym_comment] = STATE(437),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(949),
    [anon_sym_LBRACE] = ACTIONS(951),
    [anon_sym_RBRACE] = ACTIONS(951),
    [anon_sym_STAR] = ACTIONS(949),
    [anon_sym_as] = ACTIONS(949),
    [anon_sym_SEMI] = ACTIONS(951),
    [anon_sym_LPAREN] = ACTIONS(951),
    [anon_sym_DOT] = ACTIONS(951),
    [sym_identifier] = ACTIONS(949),
    [anon_sym_DQUOTE] = ACTIONS(951),
    [anon_sym_SQUOTE] = ACTIONS(951),
    [anon_sym_DOLLAR] = ACTIONS(949),
    [sym_numeric_literal] = ACTIONS(951),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_null] = ACTIONS(949),
    [anon_sym_PIPE_PIPE] = ACTIONS(951),
    [anon_sym_AMP_AMP] = ACTIONS(951),
    [anon_sym_PIPE] = ACTIONS(949),
    [anon_sym_CARET] = ACTIONS(951),
    [anon_sym_AMP] = ACTIONS(949),
    [anon_sym_EQ_EQ] = ACTIONS(949),
    [anon_sym_BANG_EQ] = ACTIONS(949),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(951),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(951),
    [anon_sym_LT] = ACTIONS(949),
    [anon_sym_GT] = ACTIONS(949),
    [anon_sym_LT_EQ] = ACTIONS(951),
    [anon_sym_GT_EQ] = ACTIONS(951),
    [anon_sym_instanceof] = ACTIONS(949),
    [anon_sym_in] = ACTIONS(949),
    [anon_sym_LT_LT] = ACTIONS(951),
    [anon_sym_GT_GT] = ACTIONS(949),
    [anon_sym_GT_GT_GT] = ACTIONS(951),
    [anon_sym_PLUS] = ACTIONS(949),
    [anon_sym_DASH] = ACTIONS(949),
    [anon_sym_PERCENT] = ACTIONS(951),
    [anon_sym_STAR_STAR] = ACTIONS(951),
    [anon_sym_BANG] = ACTIONS(949),
    [anon_sym_TILDE] = ACTIONS(951),
    [anon_sym_typeof] = ACTIONS(949),
    [anon_sym_void] = ACTIONS(949),
    [anon_sym_delete] = ACTIONS(949),
    [anon_sym_QMARK] = ACTIONS(949),
    [anon_sym_await] = ACTIONS(949),
    [anon_sym_LBRACK] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(949),
    [anon_sym_async] = ACTIONS(949),
    [anon_sym_var] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(949),
    [anon_sym_const] = ACTIONS(949),
    [anon_sym_return] = ACTIONS(949),
    [anon_sym_try] = ACTIONS(949),
    [anon_sym_throw] = ACTIONS(949),
    [anon_sym_for] = ACTIONS(949),
    [anon_sym_while] = ACTIONS(949),
    [anon_sym_break] = ACTIONS(949),
    [anon_sym_continue] = ACTIONS(949),
    [anon_sym_QMARK_DOT] = ACTIONS(951),
    [anon_sym_BQUOTE] = ACTIONS(951),
    [anon_sym_DOLLARr] = ACTIONS(949),
    [anon_sym_PLUS_PLUS] = ACTIONS(951),
    [anon_sym_DASH_DASH] = ACTIONS(951),
    [anon_sym_new] = ACTIONS(949),
  },
  [STATE(438)] = {
    [sym_comment] = STATE(438),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(61),
    [anon_sym_LBRACE] = ACTIONS(39),
    [anon_sym_RBRACE] = ACTIONS(39),
    [anon_sym_STAR] = ACTIONS(61),
    [anon_sym_as] = ACTIONS(61),
    [anon_sym_SEMI] = ACTIONS(39),
    [anon_sym_LPAREN] = ACTIONS(39),
    [anon_sym_DOT] = ACTIONS(39),
    [sym_identifier] = ACTIONS(61),
    [anon_sym_DQUOTE] = ACTIONS(39),
    [anon_sym_SQUOTE] = ACTIONS(39),
    [anon_sym_DOLLAR] = ACTIONS(61),
    [sym_numeric_literal] = ACTIONS(39),
    [anon_sym_true] = ACTIONS(61),
    [anon_sym_false] = ACTIONS(61),
    [anon_sym_null] = ACTIONS(61),
    [anon_sym_PIPE_PIPE] = ACTIONS(39),
    [anon_sym_AMP_AMP] = ACTIONS(39),
    [anon_sym_PIPE] = ACTIONS(61),
    [anon_sym_CARET] = ACTIONS(39),
    [anon_sym_AMP] = ACTIONS(61),
    [anon_sym_EQ_EQ] = ACTIONS(61),
    [anon_sym_BANG_EQ] = ACTIONS(61),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(39),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(39),
    [anon_sym_LT] = ACTIONS(61),
    [anon_sym_GT] = ACTIONS(61),
    [anon_sym_LT_EQ] = ACTIONS(39),
    [anon_sym_GT_EQ] = ACTIONS(39),
    [anon_sym_instanceof] = ACTIONS(61),
    [anon_sym_in] = ACTIONS(61),
    [anon_sym_LT_LT] = ACTIONS(39),
    [anon_sym_GT_GT] = ACTIONS(61),
    [anon_sym_GT_GT_GT] = ACTIONS(39),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_PERCENT] = ACTIONS(39),
    [anon_sym_STAR_STAR] = ACTIONS(39),
    [anon_sym_BANG] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(39),
    [anon_sym_typeof] = ACTIONS(61),
    [anon_sym_void] = ACTIONS(61),
    [anon_sym_delete] = ACTIONS(61),
    [anon_sym_QMARK] = ACTIONS(61),
    [anon_sym_await] = ACTIONS(61),
    [anon_sym_LBRACK] = ACTIONS(39),
    [anon_sym_if] = ACTIONS(61),
    [anon_sym_async] = ACTIONS(61),
    [anon_sym_var] = ACTIONS(61),
    [anon_sym_let] = ACTIONS(61),
    [anon_sym_const] = ACTIONS(61),
    [anon_sym_return] = ACTIONS(61),
    [anon_sym_try] = ACTIONS(61),
    [anon_sym_throw] = ACTIONS(61),
    [anon_sym_for] = ACTIONS(61),
    [anon_sym_while] = ACTIONS(61),
    [anon_sym_break] = ACTIONS(61),
    [anon_sym_continue] = ACTIONS(61),
    [anon_sym_QMARK_DOT] = ACTIONS(39),
    [anon_sym_BQUOTE] = ACTIONS(39),
    [anon_sym_DOLLARr] = ACTIONS(61),
    [anon_sym_PLUS_PLUS] = ACTIONS(39),
    [anon_sym_DASH_DASH] = ACTIONS(39),
    [anon_sym_new] = ACTIONS(61),
  },
  [STATE(439)] = {
    [sym_comment] = STATE(439),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(817),
    [anon_sym_LBRACE] = ACTIONS(819),
    [anon_sym_RBRACE] = ACTIONS(819),
    [anon_sym_STAR] = ACTIONS(817),
    [anon_sym_as] = ACTIONS(817),
    [anon_sym_SEMI] = ACTIONS(819),
    [anon_sym_LPAREN] = ACTIONS(819),
    [anon_sym_DOT] = ACTIONS(819),
    [sym_identifier] = ACTIONS(817),
    [anon_sym_DQUOTE] = ACTIONS(819),
    [anon_sym_SQUOTE] = ACTIONS(819),
    [anon_sym_DOLLAR] = ACTIONS(817),
    [sym_numeric_literal] = ACTIONS(819),
    [anon_sym_true] = ACTIONS(817),
    [anon_sym_false] = ACTIONS(817),
    [anon_sym_null] = ACTIONS(817),
    [anon_sym_PIPE_PIPE] = ACTIONS(819),
    [anon_sym_AMP_AMP] = ACTIONS(819),
    [anon_sym_PIPE] = ACTIONS(817),
    [anon_sym_CARET] = ACTIONS(819),
    [anon_sym_AMP] = ACTIONS(817),
    [anon_sym_EQ_EQ] = ACTIONS(817),
    [anon_sym_BANG_EQ] = ACTIONS(817),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(819),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(819),
    [anon_sym_LT] = ACTIONS(817),
    [anon_sym_GT] = ACTIONS(817),
    [anon_sym_LT_EQ] = ACTIONS(819),
    [anon_sym_GT_EQ] = ACTIONS(819),
    [anon_sym_instanceof] = ACTIONS(817),
    [anon_sym_in] = ACTIONS(817),
    [anon_sym_LT_LT] = ACTIONS(819),
    [anon_sym_GT_GT] = ACTIONS(817),
    [anon_sym_GT_GT_GT] = ACTIONS(819),
    [anon_sym_PLUS] = ACTIONS(817),
    [anon_sym_DASH] = ACTIONS(817),
    [anon_sym_PERCENT] = ACTIONS(819),
    [anon_sym_STAR_STAR] = ACTIONS(819),
    [anon_sym_BANG] = ACTIONS(817),
    [anon_sym_TILDE] = ACTIONS(819),
    [anon_sym_typeof] = ACTIONS(817),
    [anon_sym_void] = ACTIONS(817),
    [anon_sym_delete] = ACTIONS(817),
    [anon_sym_QMARK] = ACTIONS(817),
    [anon_sym_await] = ACTIONS(817),
    [anon_sym_LBRACK] = ACTIONS(819),
    [anon_sym_if] = ACTIONS(817),
    [anon_sym_async] = ACTIONS(817),
    [anon_sym_var] = ACTIONS(817),
    [anon_sym_let] = ACTIONS(817),
    [anon_sym_const] = ACTIONS(817),
    [anon_sym_return] = ACTIONS(817),
    [anon_sym_try] = ACTIONS(817),
    [anon_sym_throw] = ACTIONS(817),
    [anon_sym_for] = ACTIONS(817),
    [anon_sym_while] = ACTIONS(817),
    [anon_sym_break] = ACTIONS(817),
    [anon_sym_continue] = ACTIONS(817),
    [anon_sym_QMARK_DOT] = ACTIONS(819),
    [anon_sym_BQUOTE] = ACTIONS(819),
    [anon_sym_DOLLARr] = ACTIONS(817),
    [anon_sym_PLUS_PLUS] = ACTIONS(819),
    [anon_sym_DASH_DASH] = ACTIONS(819),
    [anon_sym_new] = ACTIONS(817),
  },
  [STATE(440)] = {
    [sym_comment] = STATE(440),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(933),
    [anon_sym_LBRACE] = ACTIONS(935),
    [anon_sym_RBRACE] = ACTIONS(935),
    [anon_sym_STAR] = ACTIONS(933),
    [anon_sym_as] = ACTIONS(933),
    [anon_sym_SEMI] = ACTIONS(935),
    [anon_sym_LPAREN] = ACTIONS(935),
    [anon_sym_DOT] = ACTIONS(935),
    [sym_identifier] = ACTIONS(933),
    [anon_sym_DQUOTE] = ACTIONS(935),
    [anon_sym_SQUOTE] = ACTIONS(935),
    [anon_sym_DOLLAR] = ACTIONS(933),
    [sym_numeric_literal] = ACTIONS(935),
    [anon_sym_true] = ACTIONS(933),
    [anon_sym_false] = ACTIONS(933),
    [anon_sym_null] = ACTIONS(933),
    [anon_sym_PIPE_PIPE] = ACTIONS(935),
    [anon_sym_AMP_AMP] = ACTIONS(935),
    [anon_sym_PIPE] = ACTIONS(933),
    [anon_sym_CARET] = ACTIONS(935),
    [anon_sym_AMP] = ACTIONS(933),
    [anon_sym_EQ_EQ] = ACTIONS(933),
    [anon_sym_BANG_EQ] = ACTIONS(933),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(935),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(935),
    [anon_sym_LT] = ACTIONS(933),
    [anon_sym_GT] = ACTIONS(933),
    [anon_sym_LT_EQ] = ACTIONS(935),
    [anon_sym_GT_EQ] = ACTIONS(935),
    [anon_sym_instanceof] = ACTIONS(933),
    [anon_sym_in] = ACTIONS(933),
    [anon_sym_LT_LT] = ACTIONS(935),
    [anon_sym_GT_GT] = ACTIONS(933),
    [anon_sym_GT_GT_GT] = ACTIONS(935),
    [anon_sym_PLUS] = ACTIONS(933),
    [anon_sym_DASH] = ACTIONS(933),
    [anon_sym_PERCENT] = ACTIONS(935),
    [anon_sym_STAR_STAR] = ACTIONS(935),
    [anon_sym_BANG] = ACTIONS(933),
    [anon_sym_TILDE] = ACTIONS(935),
    [anon_sym_typeof] = ACTIONS(933),
    [anon_sym_void] = ACTIONS(933),
    [anon_sym_delete] = ACTIONS(933),
    [anon_sym_QMARK] = ACTIONS(933),
    [anon_sym_await] = ACTIONS(933),
    [anon_sym_LBRACK] = ACTIONS(935),
    [anon_sym_if] = ACTIONS(933),
    [anon_sym_async] = ACTIONS(933),
    [anon_sym_var] = ACTIONS(933),
    [anon_sym_let] = ACTIONS(933),
    [anon_sym_const] = ACTIONS(933),
    [anon_sym_return] = ACTIONS(933),
    [anon_sym_try] = ACTIONS(933),
    [anon_sym_throw] = ACTIONS(933),
    [anon_sym_for] = ACTIONS(933),
    [anon_sym_while] = ACTIONS(933),
    [anon_sym_break] = ACTIONS(933),
    [anon_sym_continue] = ACTIONS(933),
    [anon_sym_QMARK_DOT] = ACTIONS(935),
    [anon_sym_BQUOTE] = ACTIONS(935),
    [anon_sym_DOLLARr] = ACTIONS(933),
    [anon_sym_PLUS_PLUS] = ACTIONS(935),
    [anon_sym_DASH_DASH] = ACTIONS(935),
    [anon_sym_new] = ACTIONS(933),
  },
  [STATE(441)] = {
    [sym_comment] = STATE(441),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(989),
    [anon_sym_LBRACE] = ACTIONS(991),
    [anon_sym_RBRACE] = ACTIONS(991),
    [anon_sym_STAR] = ACTIONS(989),
    [anon_sym_as] = ACTIONS(989),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LPAREN] = ACTIONS(991),
    [anon_sym_DOT] = ACTIONS(991),
    [sym_identifier] = ACTIONS(989),
    [anon_sym_DQUOTE] = ACTIONS(991),
    [anon_sym_SQUOTE] = ACTIONS(991),
    [anon_sym_DOLLAR] = ACTIONS(989),
    [sym_numeric_literal] = ACTIONS(991),
    [anon_sym_true] = ACTIONS(989),
    [anon_sym_false] = ACTIONS(989),
    [anon_sym_null] = ACTIONS(989),
    [anon_sym_PIPE_PIPE] = ACTIONS(991),
    [anon_sym_AMP_AMP] = ACTIONS(991),
    [anon_sym_PIPE] = ACTIONS(989),
    [anon_sym_CARET] = ACTIONS(991),
    [anon_sym_AMP] = ACTIONS(989),
    [anon_sym_EQ_EQ] = ACTIONS(989),
    [anon_sym_BANG_EQ] = ACTIONS(989),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(991),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(991),
    [anon_sym_LT] = ACTIONS(989),
    [anon_sym_GT] = ACTIONS(989),
    [anon_sym_LT_EQ] = ACTIONS(991),
    [anon_sym_GT_EQ] = ACTIONS(991),
    [anon_sym_instanceof] = ACTIONS(989),
    [anon_sym_in] = ACTIONS(989),
    [anon_sym_LT_LT] = ACTIONS(991),
    [anon_sym_GT_GT] = ACTIONS(989),
    [anon_sym_GT_GT_GT] = ACTIONS(991),
    [anon_sym_PLUS] = ACTIONS(989),
    [anon_sym_DASH] = ACTIONS(989),
    [anon_sym_PERCENT] = ACTIONS(991),
    [anon_sym_STAR_STAR] = ACTIONS(991),
    [anon_sym_BANG] = ACTIONS(989),
    [anon_sym_TILDE] = ACTIONS(991),
    [anon_sym_typeof] = ACTIONS(989),
    [anon_sym_void] = ACTIONS(989),
    [anon_sym_delete] = ACTIONS(989),
    [anon_sym_QMARK] = ACTIONS(989),
    [anon_sym_await] = ACTIONS(989),
    [anon_sym_LBRACK] = ACTIONS(991),
    [anon_sym_if] = ACTIONS(989),
    [anon_sym_async] = ACTIONS(989),
    [anon_sym_var] = ACTIONS(989),
    [anon_sym_let] = ACTIONS(989),
    [anon_sym_const] = ACTIONS(989),
    [anon_sym_return] = ACTIONS(989),
    [anon_sym_try] = ACTIONS(989),
    [anon_sym_throw] = ACTIONS(989),
    [anon_sym_for] = ACTIONS(989),
    [anon_sym_while] = ACTIONS(989),
    [anon_sym_break] = ACTIONS(989),
    [anon_sym_continue] = ACTIONS(989),
    [anon_sym_QMARK_DOT] = ACTIONS(991),
    [anon_sym_BQUOTE] = ACTIONS(991),
    [anon_sym_DOLLARr] = ACTIONS(989),
    [anon_sym_PLUS_PLUS] = ACTIONS(991),
    [anon_sym_DASH_DASH] = ACTIONS(991),
    [anon_sym_new] = ACTIONS(989),
  },
  [STATE(442)] = {
    [sym_comment] = STATE(442),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(973),
    [anon_sym_LBRACE] = ACTIONS(975),
    [anon_sym_RBRACE] = ACTIONS(975),
    [anon_sym_STAR] = ACTIONS(973),
    [anon_sym_as] = ACTIONS(973),
    [anon_sym_SEMI] = ACTIONS(975),
    [anon_sym_LPAREN] = ACTIONS(975),
    [anon_sym_DOT] = ACTIONS(975),
    [sym_identifier] = ACTIONS(973),
    [anon_sym_DQUOTE] = ACTIONS(975),
    [anon_sym_SQUOTE] = ACTIONS(975),
    [anon_sym_DOLLAR] = ACTIONS(973),
    [sym_numeric_literal] = ACTIONS(975),
    [anon_sym_true] = ACTIONS(973),
    [anon_sym_false] = ACTIONS(973),
    [anon_sym_null] = ACTIONS(973),
    [anon_sym_PIPE_PIPE] = ACTIONS(975),
    [anon_sym_AMP_AMP] = ACTIONS(975),
    [anon_sym_PIPE] = ACTIONS(973),
    [anon_sym_CARET] = ACTIONS(975),
    [anon_sym_AMP] = ACTIONS(973),
    [anon_sym_EQ_EQ] = ACTIONS(973),
    [anon_sym_BANG_EQ] = ACTIONS(973),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(975),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(975),
    [anon_sym_LT] = ACTIONS(973),
    [anon_sym_GT] = ACTIONS(973),
    [anon_sym_LT_EQ] = ACTIONS(975),
    [anon_sym_GT_EQ] = ACTIONS(975),
    [anon_sym_instanceof] = ACTIONS(973),
    [anon_sym_in] = ACTIONS(973),
    [anon_sym_LT_LT] = ACTIONS(975),
    [anon_sym_GT_GT] = ACTIONS(973),
    [anon_sym_GT_GT_GT] = ACTIONS(975),
    [anon_sym_PLUS] = ACTIONS(973),
    [anon_sym_DASH] = ACTIONS(973),
    [anon_sym_PERCENT] = ACTIONS(975),
    [anon_sym_STAR_STAR] = ACTIONS(975),
    [anon_sym_BANG] = ACTIONS(973),
    [anon_sym_TILDE] = ACTIONS(975),
    [anon_sym_typeof] = ACTIONS(973),
    [anon_sym_void] = ACTIONS(973),
    [anon_sym_delete] = ACTIONS(973),
    [anon_sym_QMARK] = ACTIONS(973),
    [anon_sym_await] = ACTIONS(973),
    [anon_sym_LBRACK] = ACTIONS(975),
    [anon_sym_if] = ACTIONS(973),
    [anon_sym_async] = ACTIONS(973),
    [anon_sym_var] = ACTIONS(973),
    [anon_sym_let] = ACTIONS(973),
    [anon_sym_const] = ACTIONS(973),
    [anon_sym_return] = ACTIONS(973),
    [anon_sym_try] = ACTIONS(973),
    [anon_sym_throw] = ACTIONS(973),
    [anon_sym_for] = ACTIONS(973),
    [anon_sym_while] = ACTIONS(973),
    [anon_sym_break] = ACTIONS(973),
    [anon_sym_continue] = ACTIONS(973),
    [anon_sym_QMARK_DOT] = ACTIONS(975),
    [anon_sym_BQUOTE] = ACTIONS(975),
    [anon_sym_DOLLARr] = ACTIONS(973),
    [anon_sym_PLUS_PLUS] = ACTIONS(975),
    [anon_sym_DASH_DASH] = ACTIONS(975),
    [anon_sym_new] = ACTIONS(973),
  },
  [STATE(443)] = {
    [sym_comment] = STATE(443),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(756),
    [anon_sym_LBRACE] = ACTIONS(758),
    [anon_sym_RBRACE] = ACTIONS(758),
    [anon_sym_STAR] = ACTIONS(756),
    [anon_sym_as] = ACTIONS(756),
    [anon_sym_SEMI] = ACTIONS(758),
    [anon_sym_LPAREN] = ACTIONS(758),
    [anon_sym_DOT] = ACTIONS(758),
    [sym_identifier] = ACTIONS(756),
    [anon_sym_DQUOTE] = ACTIONS(758),
    [anon_sym_SQUOTE] = ACTIONS(758),
    [anon_sym_DOLLAR] = ACTIONS(756),
    [sym_numeric_literal] = ACTIONS(758),
    [anon_sym_true] = ACTIONS(756),
    [anon_sym_false] = ACTIONS(756),
    [anon_sym_null] = ACTIONS(756),
    [anon_sym_PIPE_PIPE] = ACTIONS(758),
    [anon_sym_AMP_AMP] = ACTIONS(758),
    [anon_sym_PIPE] = ACTIONS(756),
    [anon_sym_CARET] = ACTIONS(758),
    [anon_sym_AMP] = ACTIONS(756),
    [anon_sym_EQ_EQ] = ACTIONS(756),
    [anon_sym_BANG_EQ] = ACTIONS(756),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(758),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(758),
    [anon_sym_LT] = ACTIONS(756),
    [anon_sym_GT] = ACTIONS(756),
    [anon_sym_LT_EQ] = ACTIONS(758),
    [anon_sym_GT_EQ] = ACTIONS(758),
    [anon_sym_instanceof] = ACTIONS(756),
    [anon_sym_in] = ACTIONS(756),
    [anon_sym_LT_LT] = ACTIONS(758),
    [anon_sym_GT_GT] = ACTIONS(756),
    [anon_sym_GT_GT_GT] = ACTIONS(758),
    [anon_sym_PLUS] = ACTIONS(756),
    [anon_sym_DASH] = ACTIONS(756),
    [anon_sym_PERCENT] = ACTIONS(758),
    [anon_sym_STAR_STAR] = ACTIONS(758),
    [anon_sym_BANG] = ACTIONS(756),
    [anon_sym_TILDE] = ACTIONS(758),
    [anon_sym_typeof] = ACTIONS(756),
    [anon_sym_void] = ACTIONS(756),
    [anon_sym_delete] = ACTIONS(756),
    [anon_sym_QMARK] = ACTIONS(756),
    [anon_sym_await] = ACTIONS(756),
    [anon_sym_LBRACK] = ACTIONS(758),
    [anon_sym_if] = ACTIONS(756),
    [anon_sym_async] = ACTIONS(756),
    [anon_sym_var] = ACTIONS(756),
    [anon_sym_let] = ACTIONS(756),
    [anon_sym_const] = ACTIONS(756),
    [anon_sym_return] = ACTIONS(756),
    [anon_sym_try] = ACTIONS(756),
    [anon_sym_throw] = ACTIONS(756),
    [anon_sym_for] = ACTIONS(756),
    [anon_sym_while] = ACTIONS(756),
    [anon_sym_break] = ACTIONS(756),
    [anon_sym_continue] = ACTIONS(756),
    [anon_sym_QMARK_DOT] = ACTIONS(758),
    [anon_sym_BQUOTE] = ACTIONS(758),
    [anon_sym_DOLLARr] = ACTIONS(756),
    [anon_sym_PLUS_PLUS] = ACTIONS(758),
    [anon_sym_DASH_DASH] = ACTIONS(758),
    [anon_sym_new] = ACTIONS(756),
  },
  [STATE(444)] = {
    [sym_comment] = STATE(444),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(871),
    [anon_sym_LBRACE] = ACTIONS(873),
    [anon_sym_RBRACE] = ACTIONS(873),
    [anon_sym_STAR] = ACTIONS(871),
    [anon_sym_as] = ACTIONS(871),
    [anon_sym_SEMI] = ACTIONS(873),
    [anon_sym_LPAREN] = ACTIONS(873),
    [anon_sym_DOT] = ACTIONS(873),
    [sym_identifier] = ACTIONS(871),
    [anon_sym_DQUOTE] = ACTIONS(873),
    [anon_sym_SQUOTE] = ACTIONS(873),
    [anon_sym_DOLLAR] = ACTIONS(871),
    [sym_numeric_literal] = ACTIONS(873),
    [anon_sym_true] = ACTIONS(871),
    [anon_sym_false] = ACTIONS(871),
    [anon_sym_null] = ACTIONS(871),
    [anon_sym_PIPE_PIPE] = ACTIONS(873),
    [anon_sym_AMP_AMP] = ACTIONS(873),
    [anon_sym_PIPE] = ACTIONS(871),
    [anon_sym_CARET] = ACTIONS(873),
    [anon_sym_AMP] = ACTIONS(871),
    [anon_sym_EQ_EQ] = ACTIONS(871),
    [anon_sym_BANG_EQ] = ACTIONS(871),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(873),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(873),
    [anon_sym_LT] = ACTIONS(871),
    [anon_sym_GT] = ACTIONS(871),
    [anon_sym_LT_EQ] = ACTIONS(873),
    [anon_sym_GT_EQ] = ACTIONS(873),
    [anon_sym_instanceof] = ACTIONS(871),
    [anon_sym_in] = ACTIONS(871),
    [anon_sym_LT_LT] = ACTIONS(873),
    [anon_sym_GT_GT] = ACTIONS(871),
    [anon_sym_GT_GT_GT] = ACTIONS(873),
    [anon_sym_PLUS] = ACTIONS(871),
    [anon_sym_DASH] = ACTIONS(871),
    [anon_sym_PERCENT] = ACTIONS(873),
    [anon_sym_STAR_STAR] = ACTIONS(873),
    [anon_sym_BANG] = ACTIONS(871),
    [anon_sym_TILDE] = ACTIONS(873),
    [anon_sym_typeof] = ACTIONS(871),
    [anon_sym_void] = ACTIONS(871),
    [anon_sym_delete] = ACTIONS(871),
    [anon_sym_QMARK] = ACTIONS(871),
    [anon_sym_await] = ACTIONS(871),
    [anon_sym_LBRACK] = ACTIONS(873),
    [anon_sym_if] = ACTIONS(871),
    [anon_sym_async] = ACTIONS(871),
    [anon_sym_var] = ACTIONS(871),
    [anon_sym_let] = ACTIONS(871),
    [anon_sym_const] = ACTIONS(871),
    [anon_sym_return] = ACTIONS(871),
    [anon_sym_try] = ACTIONS(871),
    [anon_sym_throw] = ACTIONS(871),
    [anon_sym_for] = ACTIONS(871),
    [anon_sym_while] = ACTIONS(871),
    [anon_sym_break] = ACTIONS(871),
    [anon_sym_continue] = ACTIONS(871),
    [anon_sym_QMARK_DOT] = ACTIONS(873),
    [anon_sym_BQUOTE] = ACTIONS(873),
    [anon_sym_DOLLARr] = ACTIONS(871),
    [anon_sym_PLUS_PLUS] = ACTIONS(873),
    [anon_sym_DASH_DASH] = ACTIONS(873),
    [anon_sym_new] = ACTIONS(871),
  },
  [STATE(445)] = {
    [sym_comment] = STATE(445),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(855),
    [anon_sym_LBRACE] = ACTIONS(857),
    [anon_sym_RBRACE] = ACTIONS(857),
    [anon_sym_STAR] = ACTIONS(855),
    [anon_sym_as] = ACTIONS(855),
    [anon_sym_SEMI] = ACTIONS(857),
    [anon_sym_LPAREN] = ACTIONS(857),
    [anon_sym_DOT] = ACTIONS(857),
    [sym_identifier] = ACTIONS(855),
    [anon_sym_DQUOTE] = ACTIONS(857),
    [anon_sym_SQUOTE] = ACTIONS(857),
    [anon_sym_DOLLAR] = ACTIONS(855),
    [sym_numeric_literal] = ACTIONS(857),
    [anon_sym_true] = ACTIONS(855),
    [anon_sym_false] = ACTIONS(855),
    [anon_sym_null] = ACTIONS(855),
    [anon_sym_PIPE_PIPE] = ACTIONS(857),
    [anon_sym_AMP_AMP] = ACTIONS(857),
    [anon_sym_PIPE] = ACTIONS(855),
    [anon_sym_CARET] = ACTIONS(857),
    [anon_sym_AMP] = ACTIONS(855),
    [anon_sym_EQ_EQ] = ACTIONS(855),
    [anon_sym_BANG_EQ] = ACTIONS(855),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(857),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(857),
    [anon_sym_LT] = ACTIONS(855),
    [anon_sym_GT] = ACTIONS(855),
    [anon_sym_LT_EQ] = ACTIONS(857),
    [anon_sym_GT_EQ] = ACTIONS(857),
    [anon_sym_instanceof] = ACTIONS(855),
    [anon_sym_in] = ACTIONS(855),
    [anon_sym_LT_LT] = ACTIONS(857),
    [anon_sym_GT_GT] = ACTIONS(855),
    [anon_sym_GT_GT_GT] = ACTIONS(857),
    [anon_sym_PLUS] = ACTIONS(855),
    [anon_sym_DASH] = ACTIONS(855),
    [anon_sym_PERCENT] = ACTIONS(857),
    [anon_sym_STAR_STAR] = ACTIONS(857),
    [anon_sym_BANG] = ACTIONS(855),
    [anon_sym_TILDE] = ACTIONS(857),
    [anon_sym_typeof] = ACTIONS(855),
    [anon_sym_void] = ACTIONS(855),
    [anon_sym_delete] = ACTIONS(855),
    [anon_sym_QMARK] = ACTIONS(855),
    [anon_sym_await] = ACTIONS(855),
    [anon_sym_LBRACK] = ACTIONS(857),
    [anon_sym_if] = ACTIONS(855),
    [anon_sym_async] = ACTIONS(855),
    [anon_sym_var] = ACTIONS(855),
    [anon_sym_let] = ACTIONS(855),
    [anon_sym_const] = ACTIONS(855),
    [anon_sym_return] = ACTIONS(855),
    [anon_sym_try] = ACTIONS(855),
    [anon_sym_throw] = ACTIONS(855),
    [anon_sym_for] = ACTIONS(855),
    [anon_sym_while] = ACTIONS(855),
    [anon_sym_break] = ACTIONS(855),
    [anon_sym_continue] = ACTIONS(855),
    [anon_sym_QMARK_DOT] = ACTIONS(857),
    [anon_sym_BQUOTE] = ACTIONS(857),
    [anon_sym_DOLLARr] = ACTIONS(855),
    [anon_sym_PLUS_PLUS] = ACTIONS(857),
    [anon_sym_DASH_DASH] = ACTIONS(857),
    [anon_sym_new] = ACTIONS(855),
  },
  [STATE(446)] = {
    [sym_comment] = STATE(446),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(715),
    [anon_sym_LBRACE] = ACTIONS(713),
    [anon_sym_RBRACE] = ACTIONS(713),
    [anon_sym_STAR] = ACTIONS(715),
    [anon_sym_as] = ACTIONS(715),
    [anon_sym_SEMI] = ACTIONS(713),
    [anon_sym_LPAREN] = ACTIONS(713),
    [anon_sym_DOT] = ACTIONS(713),
    [sym_identifier] = ACTIONS(715),
    [anon_sym_DQUOTE] = ACTIONS(713),
    [anon_sym_SQUOTE] = ACTIONS(713),
    [anon_sym_DOLLAR] = ACTIONS(715),
    [sym_numeric_literal] = ACTIONS(713),
    [anon_sym_true] = ACTIONS(715),
    [anon_sym_false] = ACTIONS(715),
    [anon_sym_null] = ACTIONS(715),
    [anon_sym_PIPE_PIPE] = ACTIONS(713),
    [anon_sym_AMP_AMP] = ACTIONS(713),
    [anon_sym_PIPE] = ACTIONS(715),
    [anon_sym_CARET] = ACTIONS(713),
    [anon_sym_AMP] = ACTIONS(715),
    [anon_sym_EQ_EQ] = ACTIONS(715),
    [anon_sym_BANG_EQ] = ACTIONS(715),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(713),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(713),
    [anon_sym_LT] = ACTIONS(715),
    [anon_sym_GT] = ACTIONS(715),
    [anon_sym_LT_EQ] = ACTIONS(713),
    [anon_sym_GT_EQ] = ACTIONS(713),
    [anon_sym_instanceof] = ACTIONS(715),
    [anon_sym_in] = ACTIONS(715),
    [anon_sym_LT_LT] = ACTIONS(713),
    [anon_sym_GT_GT] = ACTIONS(715),
    [anon_sym_GT_GT_GT] = ACTIONS(713),
    [anon_sym_PLUS] = ACTIONS(715),
    [anon_sym_DASH] = ACTIONS(715),
    [anon_sym_PERCENT] = ACTIONS(713),
    [anon_sym_STAR_STAR] = ACTIONS(713),
    [anon_sym_BANG] = ACTIONS(715),
    [anon_sym_TILDE] = ACTIONS(713),
    [anon_sym_typeof] = ACTIONS(715),
    [anon_sym_void] = ACTIONS(715),
    [anon_sym_delete] = ACTIONS(715),
    [anon_sym_QMARK] = ACTIONS(715),
    [anon_sym_await] = ACTIONS(715),
    [anon_sym_LBRACK] = ACTIONS(713),
    [anon_sym_if] = ACTIONS(715),
    [anon_sym_async] = ACTIONS(715),
    [anon_sym_var] = ACTIONS(715),
    [anon_sym_let] = ACTIONS(715),
    [anon_sym_const] = ACTIONS(715),
    [anon_sym_return] = ACTIONS(715),
    [anon_sym_try] = ACTIONS(715),
    [anon_sym_throw] = ACTIONS(715),
    [anon_sym_for] = ACTIONS(715),
    [anon_sym_while] = ACTIONS(715),
    [anon_sym_break] = ACTIONS(715),
    [anon_sym_continue] = ACTIONS(715),
    [anon_sym_QMARK_DOT] = ACTIONS(713),
    [anon_sym_BQUOTE] = ACTIONS(713),
    [anon_sym_DOLLARr] = ACTIONS(715),
    [anon_sym_PLUS_PLUS] = ACTIONS(713),
    [anon_sym_DASH_DASH] = ACTIONS(713),
    [anon_sym_new] = ACTIONS(715),
  },
  [STATE(447)] = {
    [sym_comment] = STATE(447),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(949),
    [anon_sym_LBRACE] = ACTIONS(951),
    [anon_sym_RBRACE] = ACTIONS(951),
    [anon_sym_STAR] = ACTIONS(949),
    [anon_sym_as] = ACTIONS(949),
    [anon_sym_SEMI] = ACTIONS(951),
    [anon_sym_LPAREN] = ACTIONS(951),
    [anon_sym_DOT] = ACTIONS(951),
    [sym_identifier] = ACTIONS(949),
    [anon_sym_DQUOTE] = ACTIONS(951),
    [anon_sym_SQUOTE] = ACTIONS(951),
    [anon_sym_DOLLAR] = ACTIONS(949),
    [sym_numeric_literal] = ACTIONS(951),
    [anon_sym_true] = ACTIONS(949),
    [anon_sym_false] = ACTIONS(949),
    [anon_sym_null] = ACTIONS(949),
    [anon_sym_PIPE_PIPE] = ACTIONS(951),
    [anon_sym_AMP_AMP] = ACTIONS(951),
    [anon_sym_PIPE] = ACTIONS(949),
    [anon_sym_CARET] = ACTIONS(951),
    [anon_sym_AMP] = ACTIONS(949),
    [anon_sym_EQ_EQ] = ACTIONS(949),
    [anon_sym_BANG_EQ] = ACTIONS(949),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(951),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(951),
    [anon_sym_LT] = ACTIONS(949),
    [anon_sym_GT] = ACTIONS(949),
    [anon_sym_LT_EQ] = ACTIONS(951),
    [anon_sym_GT_EQ] = ACTIONS(951),
    [anon_sym_instanceof] = ACTIONS(949),
    [anon_sym_in] = ACTIONS(949),
    [anon_sym_LT_LT] = ACTIONS(951),
    [anon_sym_GT_GT] = ACTIONS(949),
    [anon_sym_GT_GT_GT] = ACTIONS(951),
    [anon_sym_PLUS] = ACTIONS(949),
    [anon_sym_DASH] = ACTIONS(949),
    [anon_sym_PERCENT] = ACTIONS(951),
    [anon_sym_STAR_STAR] = ACTIONS(951),
    [anon_sym_BANG] = ACTIONS(949),
    [anon_sym_TILDE] = ACTIONS(951),
    [anon_sym_typeof] = ACTIONS(949),
    [anon_sym_void] = ACTIONS(949),
    [anon_sym_delete] = ACTIONS(949),
    [anon_sym_QMARK] = ACTIONS(949),
    [anon_sym_await] = ACTIONS(949),
    [anon_sym_LBRACK] = ACTIONS(951),
    [anon_sym_if] = ACTIONS(949),
    [anon_sym_async] = ACTIONS(949),
    [anon_sym_var] = ACTIONS(949),
    [anon_sym_let] = ACTIONS(949),
    [anon_sym_const] = ACTIONS(949),
    [anon_sym_return] = ACTIONS(949),
    [anon_sym_try] = ACTIONS(949),
    [anon_sym_throw] = ACTIONS(949),
    [anon_sym_for] = ACTIONS(949),
    [anon_sym_while] = ACTIONS(949),
    [anon_sym_break] = ACTIONS(949),
    [anon_sym_continue] = ACTIONS(949),
    [anon_sym_QMARK_DOT] = ACTIONS(951),
    [anon_sym_BQUOTE] = ACTIONS(951),
    [anon_sym_DOLLARr] = ACTIONS(949),
    [anon_sym_PLUS_PLUS] = ACTIONS(951),
    [anon_sym_DASH_DASH] = ACTIONS(951),
    [anon_sym_new] = ACTIONS(949),
  },
  [STATE(448)] = {
    [sym_comment] = STATE(448),
    [sym_decorator] = STATE(1500),
    [sym_component_declaration] = STATE(1300),
    [sym_modifier_chain_expression] = STATE(787),
    [sym_string_literal] = STATE(787),
    [sym_expression] = STATE(764),
    [sym_state_binding_expression] = STATE(787),
    [sym_boolean_literal] = STATE(787),
    [sym_null_literal] = STATE(787),
    [sym_binary_expression] = STATE(787),
    [sym_unary_expression] = STATE(787),
    [sym_assignment_expression] = STATE(787),
    [sym_conditional_expression] = STATE(787),
    [sym_await_expression] = STATE(787),
    [sym_as_expression] = STATE(787),
    [sym_type_parameters] = STATE(1851),
    [sym_parameter_list] = STATE(1975),
    [sym_arrow_function] = STATE(787),
    [sym_call_expression] = STATE(787),
    [sym_member_expression] = STATE(451),
    [sym_subscript_expression] = STATE(787),
    [sym_parenthesized_expression] = STATE(787),
    [sym_class_declaration] = STATE(1300),
    [sym_function_declaration] = STATE(1300),
    [sym_array_literal] = STATE(787),
    [sym_object_literal] = STATE(787),
    [sym_template_literal] = STATE(787),
    [sym_resource_expression] = STATE(787),
    [sym_update_expression] = STATE(787),
    [sym_new_expression] = STATE(787),
    [aux_sym_component_declaration_repeat1] = STATE(1459),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_LBRACE] = ACTIONS(1288),
    [anon_sym_export] = ACTIONS(1395),
    [anon_sym_AT] = ACTIONS(13),
    [anon_sym_LPAREN] = ACTIONS(1227),
    [anon_sym_struct] = ACTIONS(1397),
    [anon_sym_DOT] = ACTIONS(1229),
    [sym_identifier] = ACTIONS(1399),
    [anon_sym_DQUOTE] = ACTIONS(1233),
    [anon_sym_SQUOTE] = ACTIONS(1235),
    [anon_sym_DOLLAR] = ACTIONS(1237),
    [sym_numeric_literal] = ACTIONS(1239),
    [anon_sym_true] = ACTIONS(1401),
    [anon_sym_false] = ACTIONS(1401),
    [anon_sym_null] = ACTIONS(1403),
    [anon_sym_LT] = ACTIONS(137),
    [anon_sym_PLUS] = ACTIONS(1245),
    [anon_sym_DASH] = ACTIONS(1245),
    [anon_sym_BANG] = ACTIONS(1247),
    [anon_sym_TILDE] = ACTIONS(1247),
    [anon_sym_typeof] = ACTIONS(1245),
    [anon_sym_void] = ACTIONS(1245),
    [anon_sym_delete] = ACTIONS(1245),
    [anon_sym_await] = ACTIONS(1251),
    [anon_sym_LBRACK] = ACTIONS(1405),
    [anon_sym_async] = ACTIONS(1407),
    [anon_sym_abstract] = ACTIONS(1409),
    [anon_sym_class] = ACTIONS(1411),
    [anon_sym_function] = ACTIONS(1413),
    [anon_sym_BQUOTE] = ACTIONS(1257),
    [anon_sym_DOLLARr] = ACTIONS(1259),
    [anon_sym_PLUS_PLUS] = ACTIONS(1261),
    [anon_sym_DASH_DASH] = ACTIONS(1261),
    [anon_sym_new] = ACTIONS(1263),
  },
  [STATE(449)] = {
    [sym_comment] = STATE(449),
    [ts_builtin_sym_end] = ACTIONS(37),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(35),
    [anon_sym_import] = ACTIONS(37),
    [anon_sym_STAR] = ACTIONS(35),
    [anon_sym_as] = ACTIONS(35),
    [anon_sym_SEMI] = ACTIONS(37),
    [anon_sym_export] = ACTIONS(37),
    [anon_sym_AT] = ACTIONS(37),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_struct] = ACTIONS(37),
    [anon_sym_COLON] = ACTIONS(1272),
    [anon_sym_EQ] = ACTIONS(1274),
    [anon_sym_DOT] = ACTIONS(37),
    [anon_sym_PIPE_PIPE] = ACTIONS(37),
    [anon_sym_AMP_AMP] = ACTIONS(37),
    [anon_sym_PIPE] = ACTIONS(35),
    [anon_sym_CARET] = ACTIONS(35),
    [anon_sym_AMP] = ACTIONS(35),
    [anon_sym_EQ_EQ] = ACTIONS(35),
    [anon_sym_BANG_EQ] = ACTIONS(35),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(37),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(37),
    [anon_sym_LT] = ACTIONS(35),
    [anon_sym_GT] = ACTIONS(35),
    [anon_sym_LT_EQ] = ACTIONS(37),
    [anon_sym_GT_EQ] = ACTIONS(37),
    [anon_sym_instanceof] = ACTIONS(37),
    [anon_sym_in] = ACTIONS(35),
    [anon_sym_LT_LT] = ACTIONS(35),
    [anon_sym_GT_GT] = ACTIONS(35),
    [anon_sym_GT_GT_GT] = ACTIONS(35),
    [anon_sym_PLUS] = ACTIONS(35),
    [anon_sym_DASH] = ACTIONS(35),
    [anon_sym_PERCENT] = ACTIONS(35),
    [anon_sym_STAR_STAR] = ACTIONS(37),
    [anon_sym_PLUS_EQ] = ACTIONS(1276),
    [anon_sym_DASH_EQ] = ACTIONS(1276),
    [anon_sym_STAR_EQ] = ACTIONS(1276),
    [anon_sym_SLASH_EQ] = ACTIONS(1276),
    [anon_sym_PERCENT_EQ] = ACTIONS(1276),
    [anon_sym_AMP_EQ] = ACTIONS(1276),
    [anon_sym_PIPE_EQ] = ACTIONS(1276),
    [anon_sym_CARET_EQ] = ACTIONS(1276),
    [anon_sym_LT_LT_EQ] = ACTIONS(1276),
    [anon_sym_GT_GT_EQ] = ACTIONS(1276),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(1276),
    [anon_sym_QMARK] = ACTIONS(35),
    [anon_sym_EQ_GT] = ACTIONS(1278),
    [anon_sym_LBRACK] = ACTIONS(37),
    [anon_sym_async] = ACTIONS(37),
    [anon_sym_var] = ACTIONS(37),
    [anon_sym_let] = ACTIONS(37),
    [anon_sym_const] = ACTIONS(37),
    [anon_sym_QMARK_DOT] = ACTIONS(37),
    [anon_sym_interface] = ACTIONS(37),
    [anon_sym_type] = ACTIONS(37),
    [anon_sym_enum] = ACTIONS(37),
    [anon_sym_abstract] = ACTIONS(37),
    [anon_sym_class] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(37),
    [anon_sym_PLUS_PLUS] = ACTIONS(37),
    [anon_sym_DASH_DASH] = ACTIONS(37),
  },
  [STATE(450)] = {
    [sym_comment] = STATE(450),
    [ts_builtin_sym_end] = ACTIONS(70),
    [anon_sym_SLASH_SLASH] = ACTIONS(3),
    [anon_sym_SLASH_STAR] = ACTIONS(5),
    [anon_sym_SLASH] = ACTIONS(67),
    [anon_sym_import] = ACTIONS(70),
    [anon_sym_STAR] = ACTIONS(67),
    [anon_sym_as] = ACTIONS(67),
    [anon_sym_SEMI] = ACTIONS(70),
    [anon_sym_export] = ACTIONS(70),
    [anon_sym_AT] = ACTIONS(70),
    [anon_sym_LPAREN] = ACTIONS(72),
    [anon_sym_struct] = ACTIONS(70),
    [anon_sym_COLON] = ACTIONS(75),
    [anon_sym_EQ] = ACTIONS(77),
    [anon_sym_DOT] = ACTIONS(72),
    [anon_sym_PIPE_PIPE] = ACTIONS(72),
    [anon_sym_AMP_AMP] = ACTIONS(72),
    [anon_sym_PIPE] = ACTIONS(67),
    [anon_sym_CARET] = ACTIONS(67),
    [anon_sym_AMP] = ACTIONS(67),
    [anon_sym_EQ_EQ] = ACTIONS(67),
    [anon_sym_BANG_EQ] = ACTIONS(67),
    [anon_sym_EQ_EQ_EQ] = ACTIONS(72),
    [anon_sym_BANG_EQ_EQ] = ACTIONS(72),
    [anon_sym_LT] = ACTIONS(67),
    [anon_sym_GT] = ACTIONS(67),
    [anon_sym_LT_EQ] = ACTIONS(72),
    [anon_sym_GT_EQ] = ACTIONS(72),
    [anon_sym_instanceof] = ACTIONS(72),
    [anon_sym_in] = ACTIONS(67),
    [anon_sym_LT_LT] = ACTIONS(67),
    [anon_sym_GT_GT] = ACTIONS(67),
    [anon_sym_GT_GT_GT] = ACTIONS(67),
    [anon_sym_PLUS] = ACTIONS(67),
    [anon_sym_DASH] = ACTIONS(67),
    [anon_sym_PERCENT] = ACTIONS(67),
    [anon_sym_STAR_STAR] = ACTIONS(72),
    [anon_sym_PLUS_EQ] = ACTIONS(81),
    [anon_sym_DASH_EQ] = ACTIONS(81),
    [anon_sym_STAR_EQ] = ACTIONS(81),
    [anon_sym_SLASH_EQ] = ACTIONS(81),
    [anon_sym_PERCENT_EQ] = ACTIONS(81),
    [anon_sym_AMP_EQ] = ACTIONS(81),
    [anon_sym_PIPE_EQ] = ACTIONS(81),
    [anon_sym_CARET_EQ] = ACTIONS(81),
    [anon_sym_LT_LT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_GT_GT_GT_EQ] = ACTIONS(81),
    [anon_sym_QMARK] = ACTIONS(67),
    [anon_sym_EQ_GT] = ACTIONS(83),
    [anon_sym_LBRACK] = ACTIONS(72),
    [anon_sym_async] = ACTIONS(70),
    [anon_sym_var] = ACTIONS(70),
    [anon_sym_let] = ACTIONS(70),
    [anon_sym_const] = ACTIONS(70),
    [anon_sym_QMARK_DOT] = ACTIONS(72),
    [anon_sym_interface] = ACTIONS(70),
    [anon_sym_type] = ACTIONS(70),
    [anon_sym_enum] = ACTIONS(70),
    [anon_sym_abstract] = ACTIONS(70),
    [anon_sym_class] = ACTIONS(70),
    [anon_sym_function] = ACTIONS(70),
    [anon_sym_PLUS_PLUS] = ACTIONS(72),
    [anon_sym_DASH_DASH] = ACTIONS(72),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1274), 1,
      anon_sym_EQ,
    STATE(451), 1,
      sym_comment,
    ACTIONS(1276), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(35), 18,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
    ACTIONS(37), 30,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [78] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(77), 1,
      anon_sym_EQ,
    STATE(452), 1,
      sym_comment,
    ACTIONS(81), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(72), 14,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(70), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
    ACTIONS(67), 18,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
  [158] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(453), 1,
      sym_comment,
    ACTIONS(93), 19,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
    ACTIONS(95), 41,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [232] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1415), 1,
      anon_sym_LBRACK,
    STATE(454), 2,
      sym_comment,
      aux_sym_array_type_repeat1,
    ACTIONS(756), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(758), 41,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [306] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(455), 1,
      sym_comment,
    ACTIONS(756), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(758), 42,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [377] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(456), 1,
      sym_comment,
    ACTIONS(754), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(749), 42,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [448] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(457), 1,
      sym_comment,
    ACTIONS(847), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(849), 42,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [519] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(458), 1,
      sym_comment,
    ACTIONS(809), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(811), 42,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [590] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(459), 1,
      sym_comment,
    ACTIONS(851), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(853), 42,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [661] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1418), 1,
      anon_sym_SEMI,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(460), 1,
      sym_comment,
    STATE(720), 1,
      sym_variable_declaration,
    STATE(776), 1,
      sym_member_expression,
    STATE(1143), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1428), 3,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(461), 1,
      sym_comment,
    ACTIONS(61), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(39), 42,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [855] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(462), 1,
      sym_comment,
    ACTIONS(805), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(807), 42,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [926] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(463), 1,
      sym_comment,
    ACTIONS(836), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(838), 42,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [997] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(61), 1,
      anon_sym_extends,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(464), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(894), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(39), 4,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_RBRACK,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [1118] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1432), 1,
      anon_sym_SEMI,
    STATE(465), 1,
      sym_comment,
    STATE(586), 1,
      sym_variable_declaration,
    STATE(776), 1,
      sym_member_expression,
    STATE(1109), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1428), 3,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [1241] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(466), 1,
      sym_comment,
    ACTIONS(843), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(845), 42,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [1312] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1033), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1434), 1,
      anon_sym_RBRACK,
    STATE(467), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1051), 1,
      sym_expression,
    STATE(1702), 1,
      aux_sym_array_literal_repeat1,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [1436] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1059), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1436), 1,
      anon_sym_RBRACK,
    STATE(468), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1048), 1,
      sym_expression,
    STATE(1732), 1,
      aux_sym_array_literal_repeat1,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [1560] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1053), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1438), 1,
      anon_sym_RBRACK,
    STATE(469), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1045), 1,
      sym_expression,
    STATE(1821), 1,
      aux_sym_array_literal_repeat1,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [1684] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1033), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1434), 1,
      anon_sym_RBRACK,
    STATE(470), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1062), 1,
      sym_expression,
    STATE(1702), 1,
      aux_sym_array_literal_repeat1,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [1808] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1045), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1440), 1,
      anon_sym_RBRACK,
    STATE(471), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1065), 1,
      sym_expression,
    STATE(1756), 1,
      aux_sym_array_literal_repeat1,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [1932] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(61), 1,
      anon_sym_extends,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(472), 1,
      sym_comment,
    STATE(749), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(39), 3,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [2052] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(61), 1,
      anon_sym_extends,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(268), 1,
      sym_expression,
    STATE(473), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(39), 3,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [2172] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(474), 1,
      sym_comment,
    ACTIONS(871), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(873), 41,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [2242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(475), 1,
      sym_comment,
    ACTIONS(797), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(799), 41,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [2312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(476), 1,
      sym_comment,
    ACTIONS(933), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(935), 41,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [2382] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(61), 1,
      anon_sym_extends,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(105), 1,
      sym_expression,
    STATE(477), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(39), 3,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [2502] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(61), 1,
      anon_sym_extends,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(242), 1,
      sym_expression,
    STATE(478), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(39), 3,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [2622] = 32,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1049), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1444), 1,
      anon_sym_RBRACK,
    STATE(479), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1043), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1855), 1,
      aux_sym_array_literal_repeat1,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [2746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(480), 1,
      sym_comment,
    ACTIONS(817), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(819), 41,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_EQ_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_implements,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [2816] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(61), 1,
      anon_sym_extends,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(481), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(894), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(39), 3,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [2936] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_RPAREN,
    ACTIONS(1448), 1,
      sym_identifier,
    ACTIONS(1450), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(482), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1117), 1,
      sym_expression,
    STATE(1728), 1,
      sym_parameter,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [3057] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1452), 1,
      anon_sym_RPAREN,
    ACTIONS(1454), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(483), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1049), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1874), 1,
      sym_spread_element,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [3178] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1458), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(484), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1086), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1456), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [3297] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1454), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1460), 1,
      anon_sym_RPAREN,
    STATE(485), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1057), 1,
      sym_expression,
    STATE(1709), 1,
      sym_spread_element,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [3418] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1454), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1462), 1,
      anon_sym_RPAREN,
    STATE(486), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1053), 1,
      sym_expression,
    STATE(1737), 1,
      sym_spread_element,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [3539] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(39), 1,
      anon_sym_extends,
    ACTIONS(45), 1,
      anon_sym_DOT,
    ACTIONS(51), 1,
      anon_sym_LT,
    ACTIONS(58), 1,
      anon_sym_LBRACK,
    ACTIONS(1464), 1,
      anon_sym_COMMA,
    ACTIONS(1467), 1,
      anon_sym_COLON,
    ACTIONS(1469), 1,
      anon_sym_EQ,
    ACTIONS(1473), 1,
      anon_sym_EQ_GT,
    STATE(487), 1,
      sym_comment,
    STATE(1316), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1469), 1,
      aux_sym_array_type_repeat1,
    STATE(1519), 1,
      sym_type_arguments,
    ACTIONS(48), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(1471), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(35), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
    ACTIONS(37), 17,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [3634] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1454), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1475), 1,
      anon_sym_RPAREN,
    STATE(488), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1044), 1,
      sym_expression,
    STATE(1661), 1,
      sym_spread_element,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [3755] = 17,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(45), 1,
      anon_sym_DOT,
    ACTIONS(51), 1,
      anon_sym_LT,
    ACTIONS(58), 1,
      anon_sym_LBRACK,
    ACTIONS(75), 1,
      anon_sym_COLON,
    ACTIONS(77), 1,
      anon_sym_EQ,
    ACTIONS(83), 1,
      anon_sym_EQ_GT,
    STATE(489), 1,
      sym_comment,
    STATE(1316), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1469), 1,
      aux_sym_array_type_repeat1,
    STATE(1519), 1,
      sym_type_arguments,
    ACTIONS(39), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(48), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(81), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(35), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
    ACTIONS(37), 17,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [3848] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1454), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1477), 1,
      anon_sym_RPAREN,
    STATE(490), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1046), 1,
      sym_expression,
    STATE(1764), 1,
      sym_spread_element,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [3969] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_RPAREN,
    ACTIONS(1448), 1,
      sym_identifier,
    ACTIONS(1450), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(491), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1146), 1,
      sym_expression,
    STATE(1728), 1,
      sym_parameter,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [4090] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_RPAREN,
    ACTIONS(1448), 1,
      sym_identifier,
    ACTIONS(1450), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(492), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1092), 1,
      sym_expression,
    STATE(1728), 1,
      sym_parameter,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [4211] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_RPAREN,
    ACTIONS(1448), 1,
      sym_identifier,
    ACTIONS(1450), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(493), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1099), 1,
      sym_expression,
    STATE(1728), 1,
      sym_parameter,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [4332] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1446), 1,
      anon_sym_RPAREN,
    ACTIONS(1448), 1,
      sym_identifier,
    ACTIONS(1450), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(494), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1136), 1,
      sym_expression,
    STATE(1728), 1,
      sym_parameter,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [4453] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1479), 1,
      anon_sym_LBRACE,
    ACTIONS(1481), 1,
      anon_sym_RPAREN,
    STATE(495), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1128), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    STATE(2058), 1,
      sym_component_parameters,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [4571] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1454), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(496), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1085), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    STATE(1990), 1,
      sym_spread_element,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [4689] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1479), 1,
      anon_sym_LBRACE,
    ACTIONS(1483), 1,
      anon_sym_RPAREN,
    STATE(497), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1047), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    STATE(2050), 1,
      sym_component_parameters,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [4807] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(999), 1,
      anon_sym_DOT,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1454), 1,
      anon_sym_DOT_DOT_DOT,
    STATE(498), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1080), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    STATE(1990), 1,
      sym_spread_element,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [4925] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1479), 1,
      anon_sym_LBRACE,
    ACTIONS(1485), 1,
      anon_sym_RPAREN,
    STATE(499), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1066), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    STATE(2121), 1,
      sym_component_parameters,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [5043] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1487), 1,
      anon_sym_SEMI,
    STATE(500), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1090), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [5158] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    ACTIONS(1223), 1,
      anon_sym_LBRACE,
    STATE(49), 1,
      sym_member_expression,
    STATE(301), 1,
      sym_expression,
    STATE(432), 1,
      sym_block_statement,
    STATE(501), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [5273] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1489), 1,
      anon_sym_RPAREN,
    STATE(502), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1063), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [5388] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1150), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(212), 1,
      sym_expression,
    STATE(386), 1,
      sym_block_statement,
    STATE(503), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [5503] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    ACTIONS(1223), 1,
      anon_sym_LBRACE,
    STATE(49), 1,
      sym_member_expression,
    STATE(307), 1,
      sym_expression,
    STATE(428), 1,
      sym_block_statement,
    STATE(504), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [5618] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1225), 1,
      anon_sym_LBRACE,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(505), 1,
      sym_comment,
    STATE(767), 1,
      sym_expression,
    STATE(768), 1,
      sym_block_statement,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [5733] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1491), 1,
      anon_sym_RPAREN,
    STATE(506), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1061), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [5848] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1493), 1,
      anon_sym_RPAREN,
    STATE(507), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1064), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [5963] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1495), 1,
      anon_sym_RPAREN,
    STATE(508), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1121), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [6078] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1497), 1,
      anon_sym_SEMI,
    STATE(509), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1139), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [6193] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(510), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(960), 1,
      sym_expression,
    STATE(1016), 1,
      sym_block_statement,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [6308] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1225), 1,
      anon_sym_LBRACE,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(511), 1,
      sym_comment,
    STATE(752), 1,
      sym_expression,
    STATE(753), 1,
      sym_block_statement,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [6423] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1225), 1,
      anon_sym_LBRACE,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(512), 1,
      sym_comment,
    STATE(751), 1,
      sym_expression,
    STATE(754), 1,
      sym_block_statement,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [6538] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1134), 1,
      anon_sym_LBRACE,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(98), 1,
      sym_expression,
    STATE(183), 1,
      sym_block_statement,
    STATE(513), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [6653] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1499), 1,
      anon_sym_RPAREN,
    STATE(514), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1052), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [6768] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(515), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(911), 1,
      sym_expression,
    STATE(1030), 1,
      sym_block_statement,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [6883] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1501), 1,
      anon_sym_LBRACE,
    STATE(516), 1,
      sym_comment,
    STATE(754), 1,
      sym_block_statement,
    STATE(777), 1,
      sym_member_expression,
    STATE(926), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [6998] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1134), 1,
      anon_sym_LBRACE,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(99), 1,
      sym_expression,
    STATE(139), 1,
      sym_block_statement,
    STATE(517), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [7113] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(518), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(918), 1,
      sym_expression,
    STATE(1027), 1,
      sym_block_statement,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [7228] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1503), 1,
      anon_sym_RPAREN,
    STATE(519), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1058), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [7343] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1134), 1,
      anon_sym_LBRACE,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(97), 1,
      sym_expression,
    STATE(171), 1,
      sym_block_statement,
    STATE(520), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [7458] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1134), 1,
      anon_sym_LBRACE,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(96), 1,
      sym_expression,
    STATE(154), 1,
      sym_block_statement,
    STATE(521), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [7573] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1225), 1,
      anon_sym_LBRACE,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(522), 1,
      sym_comment,
    STATE(759), 1,
      sym_expression,
    STATE(762), 1,
      sym_block_statement,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [7688] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1505), 1,
      anon_sym_RPAREN,
    STATE(523), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1088), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [7803] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1507), 1,
      anon_sym_SEMI,
    STATE(524), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1113), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [7918] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    ACTIONS(1223), 1,
      anon_sym_LBRACE,
    STATE(49), 1,
      sym_member_expression,
    STATE(283), 1,
      sym_expression,
    STATE(413), 1,
      sym_block_statement,
    STATE(525), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [8033] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(526), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(907), 1,
      sym_expression,
    STATE(995), 1,
      sym_block_statement,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [8148] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1509), 1,
      anon_sym_SEMI,
    STATE(527), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1120), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [8263] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1501), 1,
      anon_sym_LBRACE,
    STATE(528), 1,
      sym_comment,
    STATE(753), 1,
      sym_block_statement,
    STATE(777), 1,
      sym_member_expression,
    STATE(934), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [8378] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1150), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(233), 1,
      sym_expression,
    STATE(314), 1,
      sym_block_statement,
    STATE(529), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [8493] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1501), 1,
      anon_sym_LBRACE,
    STATE(530), 1,
      sym_comment,
    STATE(762), 1,
      sym_block_statement,
    STATE(777), 1,
      sym_member_expression,
    STATE(935), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [8608] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    ACTIONS(1223), 1,
      anon_sym_LBRACE,
    STATE(49), 1,
      sym_member_expression,
    STATE(304), 1,
      sym_expression,
    STATE(446), 1,
      sym_block_statement,
    STATE(531), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [8723] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(532), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(943), 1,
      sym_expression,
    STATE(986), 1,
      sym_block_statement,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [8838] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1134), 1,
      anon_sym_LBRACE,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(84), 1,
      sym_expression,
    STATE(169), 1,
      sym_block_statement,
    STATE(533), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [8953] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1501), 1,
      anon_sym_LBRACE,
    STATE(534), 1,
      sym_comment,
    STATE(768), 1,
      sym_block_statement,
    STATE(777), 1,
      sym_member_expression,
    STATE(937), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [9068] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1150), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(238), 1,
      sym_expression,
    STATE(332), 1,
      sym_block_statement,
    STATE(535), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [9183] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1501), 1,
      anon_sym_LBRACE,
    STATE(536), 1,
      sym_comment,
    STATE(757), 1,
      sym_block_statement,
    STATE(777), 1,
      sym_member_expression,
    STATE(938), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [9298] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1511), 1,
      anon_sym_RPAREN,
    STATE(537), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1103), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [9413] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1513), 1,
      anon_sym_RPAREN,
    STATE(538), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1056), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [9528] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1515), 1,
      anon_sym_RPAREN,
    STATE(539), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1105), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [9643] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1517), 1,
      anon_sym_RPAREN,
    STATE(540), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1107), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [9758] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(541), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(926), 1,
      sym_expression,
    STATE(1016), 1,
      sym_block_statement,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [9873] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(542), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(934), 1,
      sym_expression,
    STATE(1027), 1,
      sym_block_statement,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [9988] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(543), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(935), 1,
      sym_expression,
    STATE(986), 1,
      sym_block_statement,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [10103] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(544), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(937), 1,
      sym_expression,
    STATE(995), 1,
      sym_block_statement,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [10218] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1165), 1,
      anon_sym_LBRACE,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(545), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(938), 1,
      sym_expression,
    STATE(1030), 1,
      sym_block_statement,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [10333] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1519), 1,
      anon_sym_RPAREN,
    STATE(546), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1135), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [10448] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    ACTIONS(1223), 1,
      anon_sym_LBRACE,
    STATE(49), 1,
      sym_member_expression,
    STATE(306), 1,
      sym_expression,
    STATE(393), 1,
      sym_block_statement,
    STATE(547), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [10563] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1225), 1,
      anon_sym_LBRACE,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(548), 1,
      sym_comment,
    STATE(756), 1,
      sym_expression,
    STATE(757), 1,
      sym_block_statement,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [10678] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1521), 1,
      anon_sym_SEMI,
    STATE(549), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1131), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [10793] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1523), 1,
      anon_sym_RPAREN,
    STATE(550), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1060), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [10908] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1525), 1,
      anon_sym_SEMI,
    STATE(551), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1132), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [11023] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    ACTIONS(1527), 1,
      anon_sym_RPAREN,
    STATE(552), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1050), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [11138] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1150), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(237), 1,
      sym_expression,
    STATE(329), 1,
      sym_block_statement,
    STATE(553), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [11253] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1150), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(204), 1,
      sym_expression,
    STATE(324), 1,
      sym_block_statement,
    STATE(554), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [11368] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(555), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1127), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [11480] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(556), 1,
      sym_comment,
    STATE(726), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [11592] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(557), 1,
      sym_comment,
    STATE(750), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [11704] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(558), 1,
      sym_comment,
    STATE(730), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [11816] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(559), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1108), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [11928] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(560), 1,
      sym_comment,
    STATE(731), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [12040] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(561), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1129), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [12152] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(562), 1,
      sym_comment,
    STATE(732), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [12264] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(563), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1079), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [12376] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(564), 1,
      sym_comment,
    STATE(733), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [12488] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(565), 1,
      sym_comment,
    STATE(734), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [12600] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(105), 1,
      sym_expression,
    STATE(566), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [12712] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(111), 1,
      sym_expression,
    STATE(567), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [12824] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(112), 1,
      sym_expression,
    STATE(568), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [12936] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(113), 1,
      sym_expression,
    STATE(569), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [13048] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(570), 1,
      sym_comment,
    STATE(735), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [13160] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(83), 1,
      sym_expression,
    STATE(571), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [13272] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(572), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1089), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [13384] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(573), 1,
      sym_comment,
    STATE(740), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [13496] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(85), 1,
      sym_expression,
    STATE(574), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [13608] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(86), 1,
      sym_expression,
    STATE(575), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [13720] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(87), 1,
      sym_expression,
    STATE(576), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [13832] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(88), 1,
      sym_expression,
    STATE(577), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [13944] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(89), 1,
      sym_expression,
    STATE(578), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [14056] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(90), 1,
      sym_expression,
    STATE(579), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [14168] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(91), 1,
      sym_expression,
    STATE(580), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [14280] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(92), 1,
      sym_expression,
    STATE(581), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [14392] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(93), 1,
      sym_expression,
    STATE(582), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [14504] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(94), 1,
      sym_expression,
    STATE(583), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [14616] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(95), 1,
      sym_expression,
    STATE(584), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [14728] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(585), 1,
      sym_comment,
    STATE(741), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [14840] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(586), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1120), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [14952] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(587), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1069), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [15064] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(588), 1,
      sym_comment,
    STATE(742), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [15176] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(589), 1,
      sym_comment,
    STATE(743), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [15288] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(590), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1145), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [15400] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(591), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1122), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [15512] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(592), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1124), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [15624] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(39), 1,
      anon_sym_extends,
    ACTIONS(45), 1,
      anon_sym_DOT,
    ACTIONS(48), 1,
      anon_sym_PIPE,
    ACTIONS(1467), 1,
      anon_sym_COLON,
    ACTIONS(1469), 1,
      anon_sym_EQ,
    ACTIONS(1473), 1,
      anon_sym_EQ_GT,
    ACTIONS(1529), 1,
      anon_sym_LT,
    ACTIONS(1532), 1,
      anon_sym_LBRACK,
    STATE(463), 1,
      sym_type_arguments,
    STATE(593), 1,
      sym_comment,
    STATE(1316), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1382), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(1464), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1471), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(37), 13,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(35), 15,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
  [15716] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(594), 1,
      sym_comment,
    STATE(746), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [15828] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(595), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1073), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [15940] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(596), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1101), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [16052] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(597), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1106), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [16164] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(105), 1,
      anon_sym_LBRACE,
    ACTIONS(109), 1,
      anon_sym_LPAREN,
    ACTIONS(111), 1,
      anon_sym_DOT,
    ACTIONS(125), 1,
      anon_sym_DQUOTE,
    ACTIONS(127), 1,
      anon_sym_SQUOTE,
    ACTIONS(129), 1,
      anon_sym_DOLLAR,
    ACTIONS(131), 1,
      sym_numeric_literal,
    ACTIONS(135), 1,
      anon_sym_null,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(143), 1,
      anon_sym_await,
    ACTIONS(145), 1,
      anon_sym_LBRACK,
    ACTIONS(149), 1,
      anon_sym_async,
    ACTIONS(151), 1,
      anon_sym_BQUOTE,
    ACTIONS(153), 1,
      anon_sym_DOLLARr,
    ACTIONS(157), 1,
      anon_sym_new,
    ACTIONS(1442), 1,
      sym_identifier,
    STATE(8), 1,
      sym_member_expression,
    STATE(82), 1,
      sym_expression,
    STATE(598), 1,
      sym_comment,
    STATE(1861), 1,
      sym_type_parameters,
    STATE(1922), 1,
      sym_parameter_list,
    ACTIONS(133), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(141), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(155), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(139), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(141), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [16276] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(599), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1137), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [16388] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(600), 1,
      sym_comment,
    STATE(769), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [16500] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(601), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1097), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [16612] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(602), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1138), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [16724] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(603), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1071), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [16836] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(604), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1072), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [16948] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(242), 1,
      sym_expression,
    STATE(605), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [17060] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(243), 1,
      sym_expression,
    STATE(606), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [17172] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(244), 1,
      sym_expression,
    STATE(607), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [17284] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(248), 1,
      sym_expression,
    STATE(608), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [17396] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(208), 1,
      sym_expression,
    STATE(609), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [17508] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(610), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1096), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [17620] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(213), 1,
      sym_expression,
    STATE(611), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [17732] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(215), 1,
      sym_expression,
    STATE(612), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [17844] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(216), 1,
      sym_expression,
    STATE(613), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [17956] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(217), 1,
      sym_expression,
    STATE(614), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [18068] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(218), 1,
      sym_expression,
    STATE(615), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [18180] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(219), 1,
      sym_expression,
    STATE(616), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [18292] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(220), 1,
      sym_expression,
    STATE(617), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [18404] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(221), 1,
      sym_expression,
    STATE(618), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [18516] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(222), 1,
      sym_expression,
    STATE(619), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [18628] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(223), 1,
      sym_expression,
    STATE(620), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [18740] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(251), 1,
      sym_expression,
    STATE(621), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [18852] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(622), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1070), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [18964] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1535), 1,
      sym_identifier,
    STATE(452), 1,
      sym_member_expression,
    STATE(623), 1,
      sym_comment,
    STATE(1147), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [19076] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(624), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1133), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [19188] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(625), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1076), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [19300] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(626), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1074), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [19412] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(627), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(894), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [19524] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(628), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(895), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [19636] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(629), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(896), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [19748] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(630), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(897), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [19860] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(631), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(959), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [19972] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(632), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1095), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [20084] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(569), 1,
      anon_sym_LPAREN,
    ACTIONS(571), 1,
      anon_sym_DOT,
    ACTIONS(573), 1,
      sym_identifier,
    ACTIONS(575), 1,
      anon_sym_DQUOTE,
    ACTIONS(577), 1,
      anon_sym_SQUOTE,
    ACTIONS(579), 1,
      anon_sym_DOLLAR,
    ACTIONS(581), 1,
      sym_numeric_literal,
    ACTIONS(585), 1,
      anon_sym_null,
    ACTIONS(591), 1,
      anon_sym_await,
    ACTIONS(593), 1,
      anon_sym_LBRACK,
    ACTIONS(597), 1,
      anon_sym_async,
    ACTIONS(615), 1,
      anon_sym_BQUOTE,
    ACTIONS(617), 1,
      anon_sym_DOLLARr,
    ACTIONS(621), 1,
      anon_sym_new,
    ACTIONS(1203), 1,
      anon_sym_LBRACE,
    STATE(39), 1,
      sym_member_expression,
    STATE(236), 1,
      sym_expression,
    STATE(633), 1,
      sym_comment,
    STATE(1866), 1,
      sym_type_parameters,
    STATE(1982), 1,
      sym_parameter_list,
    ACTIONS(583), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(589), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(619), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(587), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(372), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [20196] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(634), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(963), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [20308] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(635), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(964), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [20420] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(636), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(966), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [20532] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(637), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(967), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [20644] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(638), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(968), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [20756] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(639), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(969), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [20868] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(640), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(970), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [20980] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(641), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(975), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [21092] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(642), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(976), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [21204] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(643), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(977), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [21316] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(644), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(882), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [21428] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(305), 1,
      sym_expression,
    STATE(645), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [21540] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(646), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1082), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [21652] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(647), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(978), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [21764] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(268), 1,
      sym_expression,
    STATE(648), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [21876] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(270), 1,
      sym_expression,
    STATE(649), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [21988] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(271), 1,
      sym_expression,
    STATE(650), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [22100] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(279), 1,
      sym_expression,
    STATE(651), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [22212] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(652), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1098), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [22324] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1537), 1,
      sym_identifier,
    STATE(653), 1,
      sym_comment,
    STATE(763), 1,
      sym_member_expression,
    STATE(1152), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [22436] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(282), 1,
      sym_expression,
    STATE(654), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [22548] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(655), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1081), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [22660] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(285), 1,
      sym_expression,
    STATE(656), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [22772] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(287), 1,
      sym_expression,
    STATE(657), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [22884] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(289), 1,
      sym_expression,
    STATE(658), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [22996] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(290), 1,
      sym_expression,
    STATE(659), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [23108] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(291), 1,
      sym_expression,
    STATE(660), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [23220] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(293), 1,
      sym_expression,
    STATE(661), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [23332] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(294), 1,
      sym_expression,
    STATE(662), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [23444] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(295), 1,
      sym_expression,
    STATE(663), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [23556] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(297), 1,
      sym_expression,
    STATE(664), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [23668] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(298), 1,
      sym_expression,
    STATE(665), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [23780] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1539), 1,
      sym_identifier,
    STATE(55), 1,
      sym_member_expression,
    STATE(666), 1,
      sym_comment,
    STATE(1149), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [23892] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(159), 1,
      anon_sym_LBRACE,
    ACTIONS(165), 1,
      anon_sym_LPAREN,
    ACTIONS(171), 1,
      anon_sym_DQUOTE,
    ACTIONS(173), 1,
      anon_sym_SQUOTE,
    ACTIONS(175), 1,
      anon_sym_DOLLAR,
    ACTIONS(181), 1,
      anon_sym_null,
    ACTIONS(187), 1,
      anon_sym_await,
    ACTIONS(193), 1,
      anon_sym_async,
    ACTIONS(213), 1,
      anon_sym_BQUOTE,
    ACTIONS(215), 1,
      anon_sym_DOLLARr,
    ACTIONS(219), 1,
      anon_sym_new,
    ACTIONS(428), 1,
      anon_sym_DOT,
    ACTIONS(430), 1,
      sym_identifier,
    ACTIONS(432), 1,
      sym_numeric_literal,
    ACTIONS(434), 1,
      anon_sym_LBRACK,
    STATE(49), 1,
      sym_member_expression,
    STATE(252), 1,
      sym_expression,
    STATE(667), 1,
      sym_comment,
    STATE(1856), 1,
      sym_type_parameters,
    STATE(1956), 1,
      sym_parameter_list,
    ACTIONS(179), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(185), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(217), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(183), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(396), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [24004] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(668), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1083), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [24116] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(669), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1141), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [24228] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1541), 1,
      sym_identifier,
    STATE(9), 1,
      sym_member_expression,
    STATE(670), 1,
      sym_comment,
    STATE(1153), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [24340] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(671), 1,
      sym_comment,
    STATE(744), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [24452] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(672), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1078), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [24564] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(673), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1075), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [24676] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(674), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1077), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [24788] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1543), 1,
      sym_identifier,
    STATE(38), 1,
      sym_member_expression,
    STATE(675), 1,
      sym_comment,
    STATE(1148), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [24900] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(676), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1087), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [25012] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(677), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1084), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [25124] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(678), 1,
      sym_comment,
    STATE(749), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [25236] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(679), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1067), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [25348] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(680), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1102), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [25460] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(681), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1104), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [25572] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(682), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1112), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [25684] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(683), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1114), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [25796] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(684), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1118), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [25908] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(685), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1119), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [26020] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(686), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1123), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [26132] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(687), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1130), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [26244] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(688), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1134), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [26356] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(689), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(925), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [26468] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(690), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(928), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [26580] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(691), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(929), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [26692] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(692), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(930), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [26804] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(693), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(931), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [26916] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(694), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(932), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [27028] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(695), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(933), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [27140] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(696), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(936), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [27252] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(697), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1055), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [27364] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(698), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1116), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [27476] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(699), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1111), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [27588] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(700), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1054), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [27700] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(701), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1059), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [27812] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(702), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1110), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [27924] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(703), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1126), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [28036] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(704), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(1068), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [28148] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(705), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1125), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [28260] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(706), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1144), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [28372] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(707), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1140), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [28484] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(708), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1100), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [28596] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(1227), 1,
      anon_sym_LPAREN,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(1237), 1,
      anon_sym_DOLLAR,
    ACTIONS(1239), 1,
      sym_numeric_literal,
    ACTIONS(1251), 1,
      anon_sym_await,
    ACTIONS(1255), 1,
      anon_sym_async,
    ACTIONS(1257), 1,
      anon_sym_BQUOTE,
    ACTIONS(1259), 1,
      anon_sym_DOLLARr,
    ACTIONS(1263), 1,
      anon_sym_new,
    ACTIONS(1288), 1,
      anon_sym_LBRACE,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1403), 1,
      anon_sym_null,
    ACTIONS(1405), 1,
      anon_sym_LBRACK,
    STATE(451), 1,
      sym_member_expression,
    STATE(709), 1,
      sym_comment,
    STATE(761), 1,
      sym_expression,
    STATE(1851), 1,
      sym_type_parameters,
    STATE(1975), 1,
      sym_parameter_list,
    ACTIONS(1247), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1261), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1401), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1245), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(787), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [28708] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(710), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(894), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [28820] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(711), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(895), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [28932] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(712), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(896), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [29044] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(713), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(897), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [29156] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(714), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(979), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [29268] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(715), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(980), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [29380] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(716), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(981), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [29492] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(717), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(982), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [29604] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1021), 1,
      anon_sym_await,
    ACTIONS(1031), 1,
      anon_sym_async,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1041), 1,
      anon_sym_new,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    ACTIONS(1430), 1,
      sym_identifier,
    STATE(718), 1,
      sym_comment,
    STATE(777), 1,
      sym_member_expression,
    STATE(882), 1,
      sym_expression,
    STATE(1849), 1,
      sym_type_parameters,
    STATE(1960), 1,
      sym_parameter_list,
    ACTIONS(1017), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1039), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1015), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [29716] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(719), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1091), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [29828] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(720), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1131), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [29940] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(993), 1,
      anon_sym_LBRACE,
    ACTIONS(997), 1,
      anon_sym_LPAREN,
    ACTIONS(1003), 1,
      anon_sym_DQUOTE,
    ACTIONS(1005), 1,
      anon_sym_SQUOTE,
    ACTIONS(1007), 1,
      anon_sym_DOLLAR,
    ACTIONS(1009), 1,
      sym_numeric_literal,
    ACTIONS(1035), 1,
      anon_sym_BQUOTE,
    ACTIONS(1037), 1,
      anon_sym_DOLLARr,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1181), 1,
      anon_sym_await,
    ACTIONS(1185), 1,
      anon_sym_async,
    ACTIONS(1189), 1,
      anon_sym_new,
    ACTIONS(1420), 1,
      sym_identifier,
    ACTIONS(1424), 1,
      anon_sym_null,
    ACTIONS(1426), 1,
      anon_sym_LBRACK,
    STATE(721), 1,
      sym_comment,
    STATE(776), 1,
      sym_member_expression,
    STATE(1142), 1,
      sym_expression,
    STATE(1815), 1,
      sym_type_parameters,
    STATE(1959), 1,
      sym_parameter_list,
    ACTIONS(1177), 2,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(1187), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1422), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(1175), 5,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
    STATE(1000), 21,
      sym_modifier_chain_expression,
      sym_string_literal,
      sym_state_binding_expression,
      sym_boolean_literal,
      sym_null_literal,
      sym_binary_expression,
      sym_unary_expression,
      sym_assignment_expression,
      sym_conditional_expression,
      sym_await_expression,
      sym_as_expression,
      sym_arrow_function,
      sym_call_expression,
      sym_subscript_expression,
      sym_parenthesized_expression,
      sym_array_literal,
      sym_object_literal,
      sym_template_literal,
      sym_resource_expression,
      sym_update_expression,
      sym_new_expression,
  [30052] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1545), 1,
      anon_sym_DOT,
    ACTIONS(1548), 1,
      anon_sym_LT,
    ACTIONS(1551), 1,
      anon_sym_LBRACK,
    STATE(463), 1,
      sym_type_arguments,
    STATE(722), 1,
      sym_comment,
    STATE(727), 1,
      aux_sym_qualified_type_repeat1,
    STATE(728), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(61), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(39), 33,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [30130] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(75), 1,
      anon_sym_COLON,
    ACTIONS(77), 1,
      anon_sym_EQ,
    ACTIONS(83), 1,
      anon_sym_EQ_GT,
    STATE(723), 1,
      sym_comment,
    ACTIONS(70), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(81), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(72), 15,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(67), 17,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
  [30205] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1467), 1,
      anon_sym_COLON,
    ACTIONS(1469), 1,
      anon_sym_EQ,
    ACTIONS(1473), 1,
      anon_sym_EQ_GT,
    STATE(724), 1,
      sym_comment,
    ACTIONS(1471), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(35), 17,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
    ACTIONS(37), 20,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [30278] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1551), 1,
      anon_sym_LBRACK,
    STATE(725), 1,
      sym_comment,
    STATE(728), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(61), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(39), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [30346] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    STATE(726), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(702), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(704), 31,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [30418] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(727), 1,
      sym_comment,
    STATE(729), 1,
      aux_sym_qualified_type_repeat1,
    ACTIONS(767), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(769), 35,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [30484] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1558), 1,
      anon_sym_LBRACK,
    STATE(454), 1,
      aux_sym_array_type_repeat1,
    STATE(728), 1,
      sym_comment,
    ACTIONS(771), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(773), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [30552] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1561), 1,
      anon_sym_DOT,
    STATE(729), 2,
      sym_comment,
      aux_sym_qualified_type_repeat1,
    ACTIONS(778), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(780), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [30618] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1568), 1,
      anon_sym_PIPE,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1578), 1,
      anon_sym_LT,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    STATE(730), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(702), 2,
      anon_sym_as,
      anon_sym_QMARK,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 20,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [30720] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1568), 1,
      anon_sym_PIPE,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1578), 1,
      anon_sym_LT,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    STATE(731), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(702), 2,
      anon_sym_as,
      anon_sym_QMARK,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 21,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [30820] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1578), 1,
      anon_sym_LT,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    STATE(732), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(702), 3,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_QMARK,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 21,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [30918] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1578), 1,
      anon_sym_LT,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    STATE(733), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(702), 3,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_QMARK,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 22,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [31014] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1578), 1,
      anon_sym_LT,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    STATE(734), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(702), 4,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(704), 22,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [31108] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1578), 1,
      anon_sym_LT,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    STATE(735), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(702), 6,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
    ACTIONS(704), 24,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [31198] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(736), 1,
      sym_comment,
    ACTIONS(39), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(735), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(731), 12,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(733), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [31266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(737), 1,
      sym_comment,
    ACTIONS(973), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(975), 36,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [31330] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(738), 1,
      sym_comment,
    ACTIONS(39), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(742), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(738), 12,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(740), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [31398] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1595), 1,
      anon_sym_PIPE,
    ACTIONS(1597), 1,
      anon_sym_extends,
    STATE(739), 1,
      sym_comment,
    STATE(778), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(797), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(799), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [31468] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    STATE(740), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(702), 9,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
    ACTIONS(704), 27,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [31552] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    STATE(741), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(702), 10,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
    ACTIONS(704), 29,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [31632] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    STATE(742), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(702), 12,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(704), 29,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [31710] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(743), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(702), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(704), 32,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [31780] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1568), 1,
      anon_sym_PIPE,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    ACTIONS(1599), 1,
      anon_sym_as,
    ACTIONS(1601), 1,
      anon_sym_LPAREN,
    ACTIONS(1605), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1607), 1,
      anon_sym_LT,
    ACTIONS(1609), 1,
      anon_sym_QMARK,
    STATE(744), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1603), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(688), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [31890] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(745), 1,
      sym_comment,
    ACTIONS(93), 18,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
    ACTIONS(95), 32,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [31954] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(746), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(789), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(791), 32,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [32024] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(747), 1,
      sym_comment,
    ACTIONS(883), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(885), 36,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [32088] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    STATE(748), 1,
      sym_comment,
    STATE(781), 1,
      sym_modifier_chain_expression,
    ACTIONS(824), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(826), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [32156] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(749), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(763), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(765), 32,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [32226] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(750), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(785), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(787), 32,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [32296] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1568), 1,
      anon_sym_PIPE,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    ACTIONS(1599), 1,
      anon_sym_as,
    ACTIONS(1601), 1,
      anon_sym_LPAREN,
    ACTIONS(1605), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1607), 1,
      anon_sym_LT,
    ACTIONS(1609), 1,
      anon_sym_QMARK,
    STATE(751), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1603), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(698), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [32406] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1568), 1,
      anon_sym_PIPE,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    ACTIONS(1599), 1,
      anon_sym_as,
    ACTIONS(1601), 1,
      anon_sym_LPAREN,
    ACTIONS(1605), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1607), 1,
      anon_sym_LT,
    ACTIONS(1609), 1,
      anon_sym_QMARK,
    STATE(752), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1603), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(709), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [32516] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(753), 1,
      sym_comment,
    ACTIONS(711), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(709), 36,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [32580] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(754), 1,
      sym_comment,
    ACTIONS(700), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(698), 36,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [32644] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(755), 1,
      sym_comment,
    ACTIONS(961), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(963), 36,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [32708] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1568), 1,
      anon_sym_PIPE,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    ACTIONS(1599), 1,
      anon_sym_as,
    ACTIONS(1601), 1,
      anon_sym_LPAREN,
    ACTIONS(1605), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1607), 1,
      anon_sym_LT,
    ACTIONS(1609), 1,
      anon_sym_QMARK,
    STATE(756), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1603), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(721), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [32818] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(757), 1,
      sym_comment,
    ACTIONS(723), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(721), 36,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [32882] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    STATE(758), 1,
      sym_comment,
    STATE(772), 1,
      sym_modifier_chain_expression,
    ACTIONS(855), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(857), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [32950] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1568), 1,
      anon_sym_PIPE,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    ACTIONS(1599), 1,
      anon_sym_as,
    ACTIONS(1601), 1,
      anon_sym_LPAREN,
    ACTIONS(1605), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1607), 1,
      anon_sym_LT,
    ACTIONS(1609), 1,
      anon_sym_QMARK,
    STATE(759), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1603), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(713), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [33060] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(760), 1,
      sym_comment,
    ACTIONS(749), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(751), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(745), 12,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(747), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [33128] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1568), 1,
      anon_sym_PIPE,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    ACTIONS(1599), 1,
      anon_sym_as,
    ACTIONS(1605), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1609), 1,
      anon_sym_QMARK,
    ACTIONS(1611), 1,
      anon_sym_LT,
    STATE(761), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(645), 19,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [33234] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(762), 1,
      sym_comment,
    ACTIONS(715), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(713), 36,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [33298] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(77), 1,
      anon_sym_EQ,
    STATE(763), 1,
      sym_comment,
    ACTIONS(70), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
    ACTIONS(81), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(72), 15,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(67), 17,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
  [33368] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1568), 1,
      anon_sym_PIPE,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    ACTIONS(1599), 1,
      anon_sym_as,
    ACTIONS(1601), 1,
      anon_sym_LPAREN,
    ACTIONS(1605), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1607), 1,
      anon_sym_LT,
    ACTIONS(1609), 1,
      anon_sym_QMARK,
    ACTIONS(1616), 1,
      anon_sym_SEMI,
    STATE(764), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1603), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(1614), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [33480] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(75), 1,
      anon_sym_COLON,
    ACTIONS(77), 1,
      anon_sym_EQ,
    ACTIONS(83), 1,
      anon_sym_EQ_GT,
    STATE(765), 1,
      sym_comment,
    ACTIONS(81), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(35), 17,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
    ACTIONS(37), 19,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [33552] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    STATE(766), 1,
      sym_comment,
    STATE(779), 1,
      sym_modifier_chain_expression,
    ACTIONS(828), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(830), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [33620] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1554), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1566), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1568), 1,
      anon_sym_PIPE,
    ACTIONS(1570), 1,
      anon_sym_CARET,
    ACTIONS(1572), 1,
      anon_sym_AMP,
    ACTIONS(1587), 1,
      anon_sym_GT_GT,
    ACTIONS(1591), 1,
      anon_sym_PERCENT,
    ACTIONS(1593), 1,
      anon_sym_LBRACK,
    ACTIONS(1599), 1,
      anon_sym_as,
    ACTIONS(1601), 1,
      anon_sym_LPAREN,
    ACTIONS(1605), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1607), 1,
      anon_sym_LT,
    ACTIONS(1609), 1,
      anon_sym_QMARK,
    STATE(767), 1,
      sym_comment,
    STATE(811), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_type_arguments,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1564), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1574), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1576), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1581), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1585), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1589), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1603), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1583), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(717), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [33730] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(768), 1,
      sym_comment,
    ACTIONS(719), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(717), 36,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [33794] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(769), 1,
      sym_comment,
    STATE(775), 1,
      sym_type_arguments,
    STATE(811), 1,
      sym_argument_list,
    ACTIONS(1556), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(793), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(795), 32,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [33864] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1548), 1,
      anon_sym_LT,
    STATE(463), 1,
      sym_type_arguments,
    STATE(770), 1,
      sym_comment,
    ACTIONS(61), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(39), 35,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [33932] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(1618), 1,
      anon_sym_LPAREN,
    STATE(771), 1,
      sym_comment,
    STATE(780), 1,
      sym_modifier_chain_expression,
    ACTIONS(865), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(867), 33,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34002] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(772), 1,
      sym_comment,
    ACTIONS(828), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(830), 35,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34065] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1620), 1,
      anon_sym_PIPE,
    STATE(773), 2,
      sym_comment,
      aux_sym_union_type_repeat1,
    ACTIONS(817), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(819), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34130] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(774), 1,
      sym_comment,
    ACTIONS(778), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(780), 35,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_extends,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34193] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(775), 1,
      sym_comment,
    STATE(784), 1,
      sym_argument_list,
    ACTIONS(832), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(834), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34258] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(77), 1,
      anon_sym_EQ,
    STATE(776), 1,
      sym_comment,
    ACTIONS(81), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(35), 17,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
    ACTIONS(37), 20,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34325] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1469), 1,
      anon_sym_EQ,
    STATE(777), 1,
      sym_comment,
    ACTIONS(1471), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(35), 17,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
      anon_sym_QMARK,
    ACTIONS(37), 20,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34392] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(773), 1,
      aux_sym_union_type_repeat1,
    STATE(778), 1,
      sym_comment,
    ACTIONS(813), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(815), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(779), 1,
      sym_comment,
    ACTIONS(981), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(983), 35,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34520] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(780), 1,
      sym_comment,
    ACTIONS(887), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(889), 35,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(781), 1,
      sym_comment,
    ACTIONS(855), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(857), 35,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34646] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(782), 1,
      sym_comment,
    ACTIONS(895), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(897), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34708] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(783), 1,
      sym_comment,
    ACTIONS(977), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(979), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(784), 1,
      sym_comment,
    ACTIONS(899), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(901), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34832] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(785), 1,
      sym_comment,
    ACTIONS(891), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(893), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34894] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(786), 1,
      sym_comment,
    ACTIONS(879), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(881), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [34956] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(787), 1,
      sym_comment,
    ACTIONS(35), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(37), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(788), 1,
      sym_comment,
    ACTIONS(731), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(733), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35080] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(789), 1,
      sym_comment,
    ACTIONS(903), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(905), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(790), 1,
      sym_comment,
    ACTIONS(738), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(740), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35204] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(791), 1,
      sym_comment,
    ACTIONS(907), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(910), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35266] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(792), 1,
      sym_comment,
    ACTIONS(913), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(915), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35328] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(793), 1,
      sym_comment,
    ACTIONS(969), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(971), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35390] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(794), 1,
      sym_comment,
    ACTIONS(949), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(951), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35452] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(795), 1,
      sym_comment,
    ACTIONS(965), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(967), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35514] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(796), 1,
      sym_comment,
    ACTIONS(917), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(919), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35576] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(797), 1,
      sym_comment,
    ACTIONS(921), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(923), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35638] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(798), 1,
      sym_comment,
    ACTIONS(957), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(959), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35700] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(799), 1,
      sym_comment,
    ACTIONS(875), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(877), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35762] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(800), 1,
      sym_comment,
    ACTIONS(953), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(955), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35824] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(83), 1,
      anon_sym_EQ_GT,
    ACTIONS(1623), 1,
      anon_sym_COMMA,
    ACTIONS(1625), 1,
      anon_sym_RPAREN,
    ACTIONS(1628), 1,
      anon_sym_COLON,
    ACTIONS(1630), 1,
      anon_sym_EQ,
    ACTIONS(1632), 1,
      anon_sym_QMARK,
    STATE(801), 1,
      sym_comment,
    ACTIONS(81), 11,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_STAR_EQ,
      anon_sym_SLASH_EQ,
      anon_sym_PERCENT_EQ,
      anon_sym_AMP_EQ,
      anon_sym_PIPE_EQ,
      anon_sym_CARET_EQ,
      anon_sym_LT_LT_EQ,
      anon_sym_GT_GT_EQ,
      anon_sym_GT_GT_GT_EQ,
    ACTIONS(37), 15,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(35), 16,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_CARET,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_LT_LT,
      anon_sym_GT_GT,
      anon_sym_GT_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PERCENT,
  [35900] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(802), 1,
      sym_comment,
    ACTIONS(745), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(747), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [35962] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(803), 1,
      sym_comment,
    ACTIONS(925), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(927), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [36024] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(804), 1,
      sym_comment,
    ACTIONS(941), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(943), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [36086] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(805), 1,
      sym_comment,
    ACTIONS(945), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(947), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [36148] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(806), 1,
      sym_comment,
    ACTIONS(969), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(971), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [36210] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(807), 1,
      sym_comment,
    ACTIONS(929), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(931), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [36272] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(808), 1,
      sym_comment,
    ACTIONS(949), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(951), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [36334] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(809), 1,
      sym_comment,
    ACTIONS(937), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(939), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [36396] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(810), 1,
      sym_comment,
    ACTIONS(789), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(791), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [36458] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(811), 1,
      sym_comment,
    ACTIONS(985), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(987), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [36520] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(812), 1,
      sym_comment,
    ACTIONS(989), 14,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_as,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(991), 34,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_LPAREN,
      anon_sym_struct,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_QMARK_DOT,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [36582] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1635), 1,
      anon_sym_DOT,
    STATE(813), 1,
      sym_comment,
    STATE(844), 1,
      sym_modifier_chain_expression,
    ACTIONS(857), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(855), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [36647] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1641), 1,
      anon_sym_else,
    STATE(814), 1,
      sym_comment,
    ACTIONS(1637), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1639), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [36710] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1645), 1,
      anon_sym_SEMI,
    STATE(815), 1,
      sym_comment,
    ACTIONS(1643), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1647), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [36773] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1649), 1,
      anon_sym_LBRACE,
    STATE(816), 1,
      sym_comment,
    STATE(825), 1,
      sym_container_content_body,
    ACTIONS(1651), 13,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1653), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [36838] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1659), 1,
      anon_sym_else,
    STATE(817), 1,
      sym_comment,
    ACTIONS(1655), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1657), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [36901] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1635), 1,
      anon_sym_DOT,
    STATE(818), 1,
      sym_comment,
    STATE(838), 1,
      sym_modifier_chain_expression,
    ACTIONS(826), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(824), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [36966] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1635), 1,
      anon_sym_DOT,
    ACTIONS(1661), 1,
      anon_sym_LPAREN,
    STATE(819), 1,
      sym_comment,
    STATE(830), 1,
      sym_modifier_chain_expression,
    ACTIONS(867), 12,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(865), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37033] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1635), 1,
      anon_sym_DOT,
    STATE(820), 1,
      sym_comment,
    STATE(831), 1,
      sym_modifier_chain_expression,
    ACTIONS(1663), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1665), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37098] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1667), 1,
      anon_sym_SEMI,
    STATE(821), 1,
      sym_comment,
    ACTIONS(1651), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1653), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37161] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1649), 1,
      anon_sym_LBRACE,
    STATE(822), 1,
      sym_comment,
    STATE(843), 1,
      sym_container_content_body,
    ACTIONS(1669), 13,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1671), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37226] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1673), 1,
      anon_sym_SEMI,
    STATE(823), 1,
      sym_comment,
    ACTIONS(1669), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1671), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37289] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1635), 1,
      anon_sym_DOT,
    STATE(824), 1,
      sym_comment,
    STATE(837), 1,
      sym_modifier_chain_expression,
    ACTIONS(830), 13,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(828), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(825), 1,
      sym_comment,
    ACTIONS(1643), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1647), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37414] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(826), 1,
      sym_comment,
    ACTIONS(1675), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1677), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37474] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(827), 1,
      sym_comment,
    ACTIONS(1679), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1681), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37534] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(828), 1,
      sym_comment,
    ACTIONS(1683), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1685), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37594] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(829), 1,
      sym_comment,
    ACTIONS(1687), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1689), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37654] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(830), 1,
      sym_comment,
    ACTIONS(889), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(887), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37714] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(831), 1,
      sym_comment,
    ACTIONS(1691), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1693), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37774] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(832), 1,
      sym_comment,
    ACTIONS(1695), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1697), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37834] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(833), 1,
      sym_comment,
    ACTIONS(1699), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1701), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37894] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(834), 1,
      sym_comment,
    ACTIONS(1703), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1705), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [37954] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(835), 1,
      sym_comment,
    ACTIONS(1707), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1709), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38014] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(836), 1,
      sym_comment,
    ACTIONS(1669), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1671), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38074] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(837), 1,
      sym_comment,
    ACTIONS(983), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(981), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(838), 1,
      sym_comment,
    ACTIONS(857), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(855), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38194] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(839), 1,
      sym_comment,
    ACTIONS(1711), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1713), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38254] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(840), 1,
      sym_comment,
    ACTIONS(1715), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1717), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38314] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(841), 1,
      sym_comment,
    ACTIONS(1719), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1721), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38374] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(842), 1,
      sym_comment,
    ACTIONS(1723), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1725), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38434] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(843), 1,
      sym_comment,
    ACTIONS(1651), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1653), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38494] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(844), 1,
      sym_comment,
    ACTIONS(830), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(828), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38554] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(845), 1,
      sym_comment,
    ACTIONS(1727), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1729), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38614] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(846), 1,
      sym_comment,
    ACTIONS(1731), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1733), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38674] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(847), 1,
      sym_comment,
    ACTIONS(1735), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1737), 32,
      anon_sym_Text,
      anon_sym_Button,
      anon_sym_Image,
      anon_sym_TextInput,
      anon_sym_TextArea,
      anon_sym_Column,
      anon_sym_Row,
      anon_sym_Stack,
      anon_sym_Flex,
      anon_sym_Grid,
      anon_sym_GridRow,
      anon_sym_GridCol,
      anon_sym_List,
      anon_sym_ScrollList,
      anon_sym_ListItem,
      anon_sym_GridItem,
      anon_sym_ForEach,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38734] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1743), 1,
      anon_sym_catch,
    ACTIONS(1745), 1,
      anon_sym_finally,
    STATE(848), 1,
      sym_comment,
    STATE(851), 1,
      sym_catch_clause,
    STATE(872), 1,
      sym_finally_clause,
    ACTIONS(1739), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1741), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38800] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1747), 1,
      anon_sym_catch,
    ACTIONS(1749), 1,
      anon_sym_finally,
    STATE(849), 1,
      sym_comment,
    STATE(854), 1,
      sym_catch_clause,
    STATE(944), 1,
      sym_finally_clause,
    ACTIONS(1739), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1741), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38865] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1751), 1,
      anon_sym_DOT,
    ACTIONS(1754), 1,
      anon_sym_LT,
    ACTIONS(1757), 1,
      anon_sym_LBRACK,
    STATE(850), 1,
      sym_comment,
    STATE(902), 1,
      aux_sym_qualified_type_repeat1,
    STATE(903), 1,
      aux_sym_array_type_repeat1,
    STATE(917), 1,
      sym_type_arguments,
    ACTIONS(61), 12,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(39), 24,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [38933] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1745), 1,
      anon_sym_finally,
    STATE(851), 1,
      sym_comment,
    STATE(878), 1,
      sym_finally_clause,
    ACTIONS(1760), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1762), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [38993] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(852), 1,
      sym_comment,
    ACTIONS(975), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(973), 28,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39049] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(853), 1,
      sym_comment,
    ACTIONS(1764), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1766), 28,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39105] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1749), 1,
      anon_sym_finally,
    STATE(854), 1,
      sym_comment,
    STATE(958), 1,
      sym_finally_clause,
    ACTIONS(1760), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1762), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39164] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(855), 1,
      sym_comment,
    ACTIONS(975), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(973), 27,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39219] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(856), 1,
      sym_comment,
    ACTIONS(1764), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1766), 27,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39274] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(857), 1,
      sym_comment,
    ACTIONS(1768), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1770), 27,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39329] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(858), 1,
      sym_comment,
    ACTIONS(1772), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1774), 27,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39384] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(859), 1,
      sym_comment,
    ACTIONS(1776), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1778), 27,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39439] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(860), 1,
      sym_comment,
    ACTIONS(1764), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1766), 27,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39494] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(861), 1,
      sym_comment,
    ACTIONS(975), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(973), 27,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_catch,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39549] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(862), 1,
      sym_comment,
    ACTIONS(1780), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1782), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39603] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(863), 1,
      sym_comment,
    ACTIONS(1784), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1786), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39657] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1788), 1,
      anon_sym_PIPE,
    ACTIONS(1790), 1,
      anon_sym_extends,
    STATE(864), 1,
      sym_comment,
    STATE(971), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(797), 12,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(799), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [39717] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(865), 1,
      sym_comment,
    ACTIONS(1792), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1794), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39771] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1796), 1,
      anon_sym_DOT,
    STATE(866), 2,
      sym_comment,
      aux_sym_qualified_type_repeat1,
    ACTIONS(778), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(780), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [39827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(867), 1,
      sym_comment,
    ACTIONS(975), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(973), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39881] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(868), 1,
      sym_comment,
    ACTIONS(1799), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1801), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39935] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(869), 1,
      sym_comment,
    ACTIONS(1803), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1805), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [39989] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(870), 1,
      sym_comment,
    ACTIONS(1807), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1809), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40043] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(871), 1,
      sym_comment,
    ACTIONS(1811), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1813), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40097] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(872), 1,
      sym_comment,
    ACTIONS(1760), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1762), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40151] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(873), 1,
      sym_comment,
    ACTIONS(1815), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1817), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40205] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(874), 1,
      sym_comment,
    ACTIONS(1819), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1821), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40259] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(875), 1,
      sym_comment,
    ACTIONS(1823), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1825), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40313] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(876), 1,
      sym_comment,
    ACTIONS(1764), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1766), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40367] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(877), 1,
      sym_comment,
    ACTIONS(1827), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1829), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40421] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(878), 1,
      sym_comment,
    ACTIONS(1831), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1833), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(879), 1,
      sym_comment,
    ACTIONS(975), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(973), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40529] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(880), 1,
      sym_comment,
    ACTIONS(1835), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1837), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(881), 1,
      sym_comment,
    ACTIONS(1839), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1841), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40637] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(882), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(702), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(704), 23,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [40697] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(883), 1,
      sym_comment,
    ACTIONS(1845), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1847), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40751] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(884), 1,
      sym_comment,
    ACTIONS(1849), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1851), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40805] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(885), 1,
      sym_comment,
    ACTIONS(1853), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1855), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40859] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(886), 1,
      sym_comment,
    ACTIONS(1857), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1859), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40913] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1865), 1,
      anon_sym_else,
    STATE(887), 1,
      sym_comment,
    ACTIONS(1861), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1863), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [40969] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(888), 1,
      sym_comment,
    ACTIONS(1776), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1778), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [41023] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1867), 1,
      anon_sym_LBRACK,
    STATE(889), 2,
      sym_comment,
      aux_sym_array_type_repeat1,
    ACTIONS(756), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(758), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [41079] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(890), 1,
      sym_comment,
    ACTIONS(1719), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1721), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [41133] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(891), 1,
      sym_comment,
    ACTIONS(1764), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1766), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [41187] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1757), 1,
      anon_sym_LBRACK,
    STATE(892), 1,
      sym_comment,
    STATE(903), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(61), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(39), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [41245] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1754), 1,
      anon_sym_LT,
    STATE(893), 1,
      sym_comment,
    STATE(917), 1,
      sym_type_arguments,
    ACTIONS(61), 12,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(39), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [41303] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(894), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(763), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(765), 23,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [41363] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(895), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(785), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(787), 23,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [41423] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(896), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(789), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(791), 23,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [41483] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(897), 1,
      sym_comment,
    STATE(962), 1,
      sym_type_arguments,
    STATE(1002), 1,
      sym_argument_list,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(793), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(795), 23,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [41543] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(898), 1,
      sym_comment,
    ACTIONS(1870), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1872), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [41597] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(899), 1,
      sym_comment,
    ACTIONS(1768), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1770), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [41651] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(900), 1,
      sym_comment,
    ACTIONS(1772), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1774), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_finally,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [41705] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1874), 1,
      anon_sym_else,
    STATE(901), 1,
      sym_comment,
    ACTIONS(1861), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1863), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [41761] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(866), 1,
      aux_sym_qualified_type_repeat1,
    STATE(902), 1,
      sym_comment,
    ACTIONS(767), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(769), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [41817] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1876), 1,
      anon_sym_LBRACK,
    STATE(889), 1,
      aux_sym_array_type_repeat1,
    STATE(903), 1,
      sym_comment,
    ACTIONS(771), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(773), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [41875] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(904), 1,
      sym_comment,
    ACTIONS(1879), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1882), 26,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_else,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [41929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(905), 1,
      sym_comment,
    ACTIONS(1792), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1794), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [41982] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    STATE(906), 1,
      sym_comment,
    STATE(1028), 1,
      sym_modifier_chain_expression,
    ACTIONS(828), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(830), 24,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42039] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(907), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(717), 5,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [42138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(908), 1,
      sym_comment,
    ACTIONS(1823), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1825), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [42191] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(909), 1,
      sym_comment,
    ACTIONS(749), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(751), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(745), 11,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(747), 24,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(910), 1,
      sym_comment,
    ACTIONS(847), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(849), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42301] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(911), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(721), 5,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [42400] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    STATE(912), 1,
      sym_comment,
    STATE(1036), 1,
      sym_modifier_chain_expression,
    ACTIONS(824), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(826), 24,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42457] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(913), 1,
      sym_comment,
    ACTIONS(754), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(749), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42510] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1927), 1,
      anon_sym_PIPE,
    STATE(914), 2,
      sym_comment,
      aux_sym_union_type_repeat1,
    ACTIONS(817), 12,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(819), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42565] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(915), 1,
      sym_comment,
    ACTIONS(61), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(39), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42618] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(916), 1,
      sym_comment,
    ACTIONS(778), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(780), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42671] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(917), 1,
      sym_comment,
    ACTIONS(836), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(838), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42724] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(918), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(709), 5,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [42823] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(919), 1,
      sym_comment,
    ACTIONS(1857), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1859), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [42876] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(920), 1,
      sym_comment,
    ACTIONS(756), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(758), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42929] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(921), 1,
      sym_comment,
    ACTIONS(805), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(807), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [42982] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(922), 1,
      sym_comment,
    ACTIONS(809), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(811), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [43035] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(923), 1,
      sym_comment,
    ACTIONS(1835), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1837), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [43088] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(924), 1,
      sym_comment,
    ACTIONS(1870), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1872), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [43141] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(925), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(688), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [43240] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(926), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(698), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [43339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(927), 1,
      sym_comment,
    ACTIONS(1780), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1782), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [43392] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(702), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1964), 1,
      anon_sym_LT,
    STATE(928), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 10,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [43483] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(702), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1964), 1,
      anon_sym_LT,
    STATE(929), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 11,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [43572] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1964), 1,
      anon_sym_LT,
    STATE(930), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(702), 2,
      anon_sym_PIPE,
      anon_sym_QMARK,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 11,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [43659] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1964), 1,
      anon_sym_LT,
    STATE(931), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(702), 2,
      anon_sym_PIPE,
      anon_sym_QMARK,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 12,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [43744] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1964), 1,
      anon_sym_LT,
    STATE(932), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(702), 3,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 12,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [43827] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1964), 1,
      anon_sym_LT,
    STATE(933), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(702), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
    ACTIONS(704), 14,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [43906] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(934), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(709), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [44005] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(935), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(713), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [44104] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1967), 1,
      anon_sym_LT,
    STATE(936), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(645), 8,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [44199] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(937), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(717), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [44298] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(938), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(721), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
  [44397] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    ACTIONS(1970), 1,
      anon_sym_LPAREN,
    STATE(939), 1,
      sym_comment,
    STATE(1042), 1,
      sym_modifier_chain_expression,
    ACTIONS(865), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(867), 23,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [44456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(940), 1,
      sym_comment,
    ACTIONS(1839), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1841), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [44509] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1167), 1,
      anon_sym_DOT,
    STATE(941), 1,
      sym_comment,
    STATE(1015), 1,
      sym_modifier_chain_expression,
    ACTIONS(855), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(857), 24,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [44566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(942), 1,
      sym_comment,
    ACTIONS(1807), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1809), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [44619] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(943), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(713), 5,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [44718] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(944), 1,
      sym_comment,
    ACTIONS(1760), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1762), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [44771] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(945), 1,
      sym_comment,
    ACTIONS(1853), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1855), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [44824] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(946), 1,
      sym_comment,
    ACTIONS(1819), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1821), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [44877] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(947), 1,
      sym_comment,
    ACTIONS(1784), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1786), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [44930] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(948), 1,
      sym_comment,
    ACTIONS(1972), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1974), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [44983] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(949), 1,
      sym_comment,
    ACTIONS(1815), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1817), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [45036] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(950), 1,
      sym_comment,
    ACTIONS(1811), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1813), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [45089] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(951), 1,
      sym_comment,
    ACTIONS(1719), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1721), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [45142] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(952), 1,
      sym_comment,
    ACTIONS(1879), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1882), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [45195] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(953), 1,
      sym_comment,
    ACTIONS(1845), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1847), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [45248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(954), 1,
      sym_comment,
    ACTIONS(1849), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1851), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [45301] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(955), 1,
      sym_comment,
    ACTIONS(1827), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1829), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [45354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(956), 1,
      sym_comment,
    ACTIONS(1803), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1805), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [45407] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(957), 1,
      sym_comment,
    ACTIONS(851), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(853), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [45460] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(958), 1,
      sym_comment,
    ACTIONS(1831), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1833), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [45513] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(959), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(688), 5,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [45612] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(960), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(698), 5,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_RBRACK,
  [45711] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(961), 1,
      sym_comment,
    ACTIONS(1799), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1801), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [45764] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(962), 1,
      sym_comment,
    STATE(1037), 1,
      sym_argument_list,
    ACTIONS(832), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(834), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [45819] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    STATE(963), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(702), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(704), 21,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [45880] = 24,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(702), 1,
      anon_sym_QMARK,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1976), 1,
      anon_sym_LT,
    STATE(964), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 10,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [45971] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(965), 1,
      sym_comment,
    ACTIONS(1764), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1766), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [46024] = 23,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(702), 1,
      anon_sym_QMARK,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1976), 1,
      anon_sym_LT,
    STATE(966), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 11,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [46113] = 22,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1976), 1,
      anon_sym_LT,
    STATE(967), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(702), 2,
      anon_sym_PIPE,
      anon_sym_QMARK,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 11,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [46200] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1976), 1,
      anon_sym_LT,
    STATE(968), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(702), 2,
      anon_sym_PIPE,
      anon_sym_QMARK,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 12,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [46285] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1976), 1,
      anon_sym_LT,
    STATE(969), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(702), 3,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(704), 12,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [46368] = 18,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1976), 1,
      anon_sym_LT,
    STATE(970), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(702), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_QMARK,
    ACTIONS(704), 14,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [46447] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(914), 1,
      aux_sym_union_type_repeat1,
    STATE(971), 1,
      sym_comment,
    ACTIONS(813), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(815), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [46502] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(972), 1,
      sym_comment,
    ACTIONS(39), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(735), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(731), 11,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(733), 24,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [46559] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(973), 1,
      sym_comment,
    ACTIONS(39), 2,
      anon_sym_COMMA,
      anon_sym_extends,
    ACTIONS(742), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(738), 11,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(740), 24,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [46616] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(974), 1,
      sym_comment,
    ACTIONS(843), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(845), 26,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [46669] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(975), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(702), 8,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
    ACTIONS(704), 17,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [46742] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(976), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(702), 9,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
    ACTIONS(704), 19,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [46811] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(977), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(702), 11,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(704), 19,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [46878] = 26,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1979), 1,
      anon_sym_LT,
    STATE(978), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
    ACTIONS(645), 8,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [46973] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    STATE(979), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(702), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(704), 21,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [47034] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    STATE(980), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(702), 8,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_QMARK,
    ACTIONS(704), 17,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [47107] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    STATE(981), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(702), 9,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_QMARK,
    ACTIONS(704), 19,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [47176] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    STATE(982), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(702), 11,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(704), 19,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
  [47243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(983), 1,
      sym_comment,
    ACTIONS(975), 14,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(973), 25,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_if,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_return,
      anon_sym_try,
      anon_sym_throw,
      anon_sym_for,
      anon_sym_while,
      anon_sym_break,
      anon_sym_continue,
      anon_sym_DOLLARr,
      anon_sym_new,
  [47296] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 1,
      anon_sym_COMMA,
    ACTIONS(1984), 1,
      anon_sym_RPAREN,
    STATE(984), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1744), 1,
      aux_sym_argument_list_repeat1,
    STATE(1750), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [47400] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(749), 1,
      anon_sym_extends,
    ACTIONS(1986), 1,
      anon_sym_COMMA,
    STATE(985), 1,
      sym_comment,
    ACTIONS(751), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(745), 11,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(747), 23,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [47458] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(986), 1,
      sym_comment,
    ACTIONS(715), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(713), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [47510] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 1,
      anon_sym_COMMA,
    ACTIONS(1989), 1,
      anon_sym_RPAREN,
    STATE(987), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1744), 1,
      aux_sym_argument_list_repeat1,
    STATE(1748), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [47614] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(988), 1,
      sym_comment,
    ACTIONS(973), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(975), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [47666] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(989), 1,
      sym_comment,
    ACTIONS(745), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(747), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [47718] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(990), 1,
      sym_comment,
    ACTIONS(977), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(979), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [47770] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 1,
      anon_sym_COMMA,
    ACTIONS(1991), 1,
      anon_sym_RPAREN,
    STATE(991), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1770), 1,
      aux_sym_argument_list_repeat1,
    STATE(1774), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [47874] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 1,
      anon_sym_COMMA,
    ACTIONS(1993), 1,
      anon_sym_RPAREN,
    STATE(992), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1770), 1,
      aux_sym_argument_list_repeat1,
    STATE(1775), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [47978] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 1,
      anon_sym_COMMA,
    ACTIONS(1995), 1,
      anon_sym_RPAREN,
    STATE(993), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1659), 1,
      aux_sym_argument_list_repeat1,
    STATE(1666), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [48082] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(994), 1,
      sym_comment,
    ACTIONS(945), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(947), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(995), 1,
      sym_comment,
    ACTIONS(719), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(717), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48186] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 1,
      anon_sym_COMMA,
    ACTIONS(1997), 1,
      anon_sym_RPAREN,
    STATE(996), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1659), 1,
      aux_sym_argument_list_repeat1,
    STATE(1672), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [48290] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 1,
      anon_sym_COMMA,
    ACTIONS(1999), 1,
      anon_sym_RPAREN,
    STATE(997), 1,
      sym_comment,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1731), 1,
      aux_sym_argument_list_repeat1,
    STATE(1831), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [48394] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(39), 1,
      anon_sym_extends,
    ACTIONS(2001), 1,
      anon_sym_COMMA,
    STATE(998), 1,
      sym_comment,
    ACTIONS(735), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(731), 11,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(733), 23,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48452] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(39), 1,
      anon_sym_extends,
    ACTIONS(2004), 1,
      anon_sym_COMMA,
    STATE(999), 1,
      sym_comment,
    ACTIONS(742), 2,
      anon_sym_PIPE,
      anon_sym_GT,
    ACTIONS(738), 11,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(740), 23,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48510] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1000), 1,
      sym_comment,
    ACTIONS(35), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(37), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48562] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1001), 1,
      sym_comment,
    ACTIONS(789), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(791), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48614] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1002), 1,
      sym_comment,
    ACTIONS(985), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(987), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48666] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1003), 1,
      sym_comment,
    ACTIONS(731), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(733), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48718] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1004), 1,
      sym_comment,
    ACTIONS(949), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(951), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48770] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1005), 1,
      sym_comment,
    ACTIONS(738), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(740), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48822] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1006), 1,
      sym_comment,
    ACTIONS(949), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(951), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48874] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1007), 1,
      sym_comment,
    ACTIONS(903), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(905), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48926] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1008), 1,
      sym_comment,
    ACTIONS(925), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(927), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [48978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1009), 1,
      sym_comment,
    ACTIONS(953), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(955), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49030] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1010), 1,
      sym_comment,
    ACTIONS(941), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(943), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49082] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1011), 1,
      sym_comment,
    ACTIONS(879), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(881), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1012), 1,
      sym_comment,
    ACTIONS(907), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(910), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49186] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1013), 1,
      sym_comment,
    ACTIONS(913), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(915), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49238] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1014), 1,
      sym_comment,
    ACTIONS(969), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(971), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49290] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1015), 1,
      sym_comment,
    ACTIONS(828), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(830), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49342] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1016), 1,
      sym_comment,
    ACTIONS(700), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(698), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49394] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1017), 1,
      sym_comment,
    ACTIONS(961), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(963), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49446] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 1,
      anon_sym_COMMA,
    ACTIONS(2007), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1018), 1,
      sym_comment,
    STATE(1731), 1,
      aux_sym_argument_list_repeat1,
    STATE(1877), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [49550] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1019), 1,
      sym_comment,
    ACTIONS(965), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(967), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49602] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1020), 1,
      sym_comment,
    ACTIONS(797), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(799), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49654] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1021), 1,
      sym_comment,
    ACTIONS(969), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(971), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49706] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1022), 1,
      sym_comment,
    ACTIONS(937), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(939), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49758] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1023), 1,
      sym_comment,
    ACTIONS(917), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(919), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1024), 1,
      sym_comment,
    ACTIONS(891), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(893), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49862] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1025), 1,
      sym_comment,
    ACTIONS(895), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(897), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49914] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1026), 1,
      sym_comment,
    ACTIONS(989), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(991), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [49966] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1027), 1,
      sym_comment,
    ACTIONS(711), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(709), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50018] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1028), 1,
      sym_comment,
    ACTIONS(981), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(983), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50070] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1029), 1,
      sym_comment,
    ACTIONS(921), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(923), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50122] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1030), 1,
      sym_comment,
    ACTIONS(723), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(721), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50174] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1031), 1,
      sym_comment,
    ACTIONS(957), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(959), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50226] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1032), 1,
      sym_comment,
    ACTIONS(875), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(877), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50278] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1033), 1,
      sym_comment,
    ACTIONS(817), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(819), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50330] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1034), 1,
      sym_comment,
    ACTIONS(933), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(935), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50382] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1035), 1,
      sym_comment,
    ACTIONS(929), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(931), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50434] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1036), 1,
      sym_comment,
    ACTIONS(855), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(857), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50486] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1037), 1,
      sym_comment,
    ACTIONS(899), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(901), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50538] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 1,
      anon_sym_COMMA,
    ACTIONS(2009), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1038), 1,
      sym_comment,
    STATE(1717), 1,
      aux_sym_argument_list_repeat1,
    STATE(1722), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [50642] = 31,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(1982), 1,
      anon_sym_COMMA,
    ACTIONS(2011), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1039), 1,
      sym_comment,
    STATE(1717), 1,
      aux_sym_argument_list_repeat1,
    STATE(1723), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [50746] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1040), 1,
      sym_comment,
    ACTIONS(883), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(885), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50798] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1041), 1,
      sym_comment,
    ACTIONS(871), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(873), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50850] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1042), 1,
      sym_comment,
    ACTIONS(887), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(889), 25,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_as,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [50902] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2013), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1043), 1,
      sym_comment,
    STATE(1872), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [51003] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(2017), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1044), 1,
      sym_comment,
    STATE(1731), 1,
      aux_sym_argument_list_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [51104] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2019), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1045), 1,
      sym_comment,
    STATE(1840), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [51205] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(2021), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1046), 1,
      sym_comment,
    STATE(1770), 1,
      aux_sym_argument_list_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [51306] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(2025), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1047), 1,
      sym_comment,
    STATE(1738), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [51407] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2027), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1048), 1,
      sym_comment,
    STATE(1735), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [51508] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(2029), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1049), 1,
      sym_comment,
    STATE(1659), 1,
      aux_sym_argument_list_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [51609] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(2031), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1050), 1,
      sym_comment,
    STATE(1665), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [51710] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2033), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1051), 1,
      sym_comment,
    STATE(1708), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [51811] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(2035), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1052), 1,
      sym_comment,
    STATE(1773), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [51912] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(2037), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1053), 1,
      sym_comment,
    STATE(1744), 1,
      aux_sym_argument_list_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52013] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2039), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1054), 1,
      sym_comment,
    STATE(1707), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52114] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2041), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1055), 1,
      sym_comment,
    STATE(1716), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52215] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(2043), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1056), 1,
      sym_comment,
    STATE(1885), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52316] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(2045), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1057), 1,
      sym_comment,
    STATE(1717), 1,
      aux_sym_argument_list_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52417] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(2047), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1058), 1,
      sym_comment,
    STATE(1786), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52518] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2049), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1059), 1,
      sym_comment,
    STATE(1743), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52619] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(2051), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1060), 1,
      sym_comment,
    STATE(1721), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52720] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(2053), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1061), 1,
      sym_comment,
    STATE(1857), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52821] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2055), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1062), 1,
      sym_comment,
    STATE(1708), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [52922] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(2057), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1063), 1,
      sym_comment,
    STATE(1699), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53023] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(2059), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1064), 1,
      sym_comment,
    STATE(1747), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53124] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2061), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1065), 1,
      sym_comment,
    STATE(1762), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53225] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(2063), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1066), 1,
      sym_comment,
    STATE(1873), 1,
      aux_sym_decorator_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53326] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2065), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1067), 1,
      sym_comment,
    STATE(1785), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53427] = 30,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2067), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1068), 1,
      sym_comment,
    STATE(1769), 1,
      aux_sym_array_literal_repeat1,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53528] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1069), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2069), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53624] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1070), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2071), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53720] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1071), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2073), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53816] = 29,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(688), 1,
      anon_sym_RPAREN,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2075), 1,
      anon_sym_COMMA,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1072), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [53914] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1073), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2077), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54010] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1074), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2079), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54106] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1075), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2081), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54202] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1076), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2083), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54298] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1077), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2075), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54394] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1078), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2085), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54490] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1079), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2087), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54586] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1080), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2089), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54682] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1081), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2091), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54778] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1082), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2093), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54874] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1083), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2095), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [54970] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1084), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2097), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [55066] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1085), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2099), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [55162] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1086), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(2102), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [55258] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2104), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1087), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [55353] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2106), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1088), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [55448] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2108), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1089), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [55543] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2110), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1090), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [55638] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2112), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1091), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [55733] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2114), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1092), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [55828] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(39), 1,
      anon_sym_extends,
    ACTIONS(735), 1,
      anon_sym_PIPE,
    STATE(1093), 1,
      sym_comment,
    ACTIONS(2001), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(731), 12,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(733), 19,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [55883] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(39), 1,
      anon_sym_extends,
    ACTIONS(742), 1,
      anon_sym_PIPE,
    STATE(1094), 1,
      sym_comment,
    ACTIONS(2004), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(738), 12,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(740), 19,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [55938] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2116), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1095), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56033] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2118), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1096), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56128] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2120), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1097), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56223] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2122), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1098), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56318] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2124), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1099), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56413] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2126), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1100), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56508] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2128), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1101), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56603] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2130), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1102), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56698] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1515), 1,
      anon_sym_RPAREN,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1103), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56793] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2132), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1104), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56888] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1517), 1,
      anon_sym_RPAREN,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1105), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [56983] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2063), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1106), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [57078] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2134), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1107), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [57173] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2136), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1108), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [57268] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2138), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1109), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [57363] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2140), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1110), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [57458] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2142), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1111), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [57553] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2144), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1112), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [57648] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2146), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1113), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [57743] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2148), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1114), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [57838] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(749), 1,
      anon_sym_extends,
    ACTIONS(751), 1,
      anon_sym_PIPE,
    STATE(1115), 1,
      sym_comment,
    ACTIONS(1986), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(745), 12,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(747), 19,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [57893] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2150), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1116), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [57988] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2152), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1117), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [58083] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2154), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1118), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [58178] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2156), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1119), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [58273] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1497), 1,
      anon_sym_SEMI,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1120), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [58368] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1505), 1,
      anon_sym_RPAREN,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1121), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [58463] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2158), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1122), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [58558] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2160), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1123), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [58653] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2162), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1124), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [58748] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2164), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1125), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [58843] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2166), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1126), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [58938] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2168), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1127), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59033] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2170), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1128), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59128] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2172), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1129), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59223] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2174), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1130), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59318] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1525), 1,
      anon_sym_SEMI,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1131), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59413] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2176), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1132), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59508] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2178), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1133), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59603] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2180), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1134), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59698] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1495), 1,
      anon_sym_RPAREN,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1135), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59793] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2182), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1136), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59888] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(1932), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1934), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1936), 1,
      anon_sym_PIPE,
    ACTIONS(1938), 1,
      anon_sym_CARET,
    ACTIONS(1940), 1,
      anon_sym_AMP,
    ACTIONS(1946), 1,
      anon_sym_LT,
    ACTIONS(1954), 1,
      anon_sym_GT_GT,
    ACTIONS(1958), 1,
      anon_sym_PERCENT,
    ACTIONS(1960), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1962), 1,
      anon_sym_QMARK,
    ACTIONS(2184), 1,
      anon_sym_COMMA,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1137), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1930), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1942), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1944), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1948), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1952), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1956), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1950), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [59983] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2186), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1138), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60078] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2188), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1139), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60173] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2190), 1,
      anon_sym_COLON,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1140), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60268] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2192), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1141), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60363] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2194), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1142), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60458] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2196), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1143), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60553] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2198), 1,
      anon_sym_RBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1144), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60648] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2200), 1,
      anon_sym_SEMI,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1145), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60743] = 28,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    ACTIONS(2202), 1,
      anon_sym_RPAREN,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1146), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60838] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1147), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1603), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [60930] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1148), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1096), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [61022] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1149), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1325), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [61114] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1150), 1,
      sym_comment,
    ACTIONS(910), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(957), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(959), 19,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [61164] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2204), 1,
      anon_sym_RPAREN,
    STATE(1151), 1,
      sym_comment,
    ACTIONS(957), 13,
      anon_sym_SLASH,
      anon_sym_STAR,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_in,
      anon_sym_GT_GT,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_QMARK,
    ACTIONS(959), 20,
      anon_sym_COMMA,
      anon_sym_as,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_PIPE_PIPE,
      anon_sym_AMP_AMP,
      anon_sym_CARET,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
      anon_sym_PERCENT,
      anon_sym_STAR_STAR,
      anon_sym_LBRACK,
      anon_sym_QMARK_DOT,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
  [61214] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1152), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1891), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [61306] = 27,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1887), 1,
      anon_sym_as,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    ACTIONS(1893), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1895), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1897), 1,
      anon_sym_PIPE,
    ACTIONS(1899), 1,
      anon_sym_CARET,
    ACTIONS(1901), 1,
      anon_sym_AMP,
    ACTIONS(1907), 1,
      anon_sym_LT,
    ACTIONS(1915), 1,
      anon_sym_GT_GT,
    ACTIONS(1919), 1,
      anon_sym_PERCENT,
    ACTIONS(1921), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1923), 1,
      anon_sym_QMARK,
    ACTIONS(1925), 1,
      anon_sym_LBRACK,
    STATE(1002), 1,
      sym_argument_list,
    STATE(1153), 1,
      sym_comment,
    STATE(1978), 1,
      sym_type_arguments,
    ACTIONS(692), 2,
      anon_sym_DOT,
      anon_sym_QMARK_DOT,
    ACTIONS(1843), 2,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1885), 2,
      anon_sym_SLASH,
      anon_sym_STAR,
    ACTIONS(1903), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(1905), 2,
      anon_sym_EQ_EQ_EQ,
      anon_sym_BANG_EQ_EQ,
    ACTIONS(1909), 2,
      anon_sym_GT,
      anon_sym_in,
    ACTIONS(1913), 2,
      anon_sym_LT_LT,
      anon_sym_GT_GT_GT,
    ACTIONS(1917), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1911), 3,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_instanceof,
  [61398] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1154), 1,
      sym_comment,
    ACTIONS(1870), 13,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1872), 14,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [61439] = 20,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2207), 1,
      ts_builtin_sym_end,
    ACTIONS(2209), 1,
      anon_sym_import,
    ACTIONS(2212), 1,
      anon_sym_export,
    ACTIONS(2215), 1,
      anon_sym_AT,
    ACTIONS(2218), 1,
      anon_sym_struct,
    ACTIONS(2221), 1,
      anon_sym_async,
    ACTIONS(2227), 1,
      anon_sym_const,
    ACTIONS(2230), 1,
      anon_sym_interface,
    ACTIONS(2233), 1,
      anon_sym_type,
    ACTIONS(2236), 1,
      anon_sym_enum,
    ACTIONS(2239), 1,
      anon_sym_abstract,
    ACTIONS(2242), 1,
      anon_sym_class,
    ACTIONS(2245), 1,
      anon_sym_function,
    STATE(1459), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1500), 1,
      sym_decorator,
    ACTIONS(2224), 2,
      anon_sym_var,
      anon_sym_let,
    STATE(1155), 2,
      sym_comment,
      aux_sym_source_file_repeat1,
    STATE(1368), 9,
      sym_import_declaration,
      sym_export_declaration,
      sym_component_declaration,
      sym_variable_declaration,
      sym_interface_declaration,
      sym_type_declaration,
      sym_enum_declaration,
      sym_class_declaration,
      sym_function_declaration,
  [61510] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(9), 1,
      anon_sym_import,
    ACTIONS(11), 1,
      anon_sym_export,
    ACTIONS(13), 1,
      anon_sym_AT,
    ACTIONS(15), 1,
      anon_sym_struct,
    ACTIONS(17), 1,
      anon_sym_async,
    ACTIONS(21), 1,
      anon_sym_const,
    ACTIONS(23), 1,
      anon_sym_interface,
    ACTIONS(25), 1,
      anon_sym_type,
    ACTIONS(27), 1,
      anon_sym_enum,
    ACTIONS(29), 1,
      anon_sym_abstract,
    ACTIONS(31), 1,
      anon_sym_class,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(2248), 1,
      ts_builtin_sym_end,
    STATE(1155), 1,
      aux_sym_source_file_repeat1,
    STATE(1156), 1,
      sym_comment,
    STATE(1459), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1500), 1,
      sym_decorator,
    ACTIONS(19), 2,
      anon_sym_var,
      anon_sym_let,
    STATE(1368), 9,
      sym_import_declaration,
      sym_export_declaration,
      sym_component_declaration,
      sym_variable_declaration,
      sym_interface_declaration,
      sym_type_declaration,
      sym_enum_declaration,
      sym_class_declaration,
      sym_function_declaration,
  [61583] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1157), 1,
      sym_comment,
    ACTIONS(1803), 13,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1805), 14,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [61624] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1158), 1,
      sym_comment,
    ACTIONS(1792), 13,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_DQUOTE,
      anon_sym_SQUOTE,
      sym_numeric_literal,
      anon_sym_LT,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_LBRACK,
      anon_sym_BQUOTE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
    ACTIONS(1794), 14,
      sym_identifier,
      anon_sym_DOLLAR,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_typeof,
      anon_sym_void,
      anon_sym_delete,
      anon_sym_await,
      anon_sym_async,
      anon_sym_DOLLARr,
      anon_sym_new,
  [61665] = 21,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13), 1,
      anon_sym_AT,
    ACTIONS(17), 1,
      anon_sym_async,
    ACTIONS(21), 1,
      anon_sym_const,
    ACTIONS(23), 1,
      anon_sym_interface,
    ACTIONS(25), 1,
      anon_sym_type,
    ACTIONS(27), 1,
      anon_sym_enum,
    ACTIONS(29), 1,
      anon_sym_abstract,
    ACTIONS(31), 1,
      anon_sym_class,
    ACTIONS(33), 1,
      anon_sym_function,
    ACTIONS(2250), 1,
      anon_sym_LBRACE,
    ACTIONS(2252), 1,
      anon_sym_STAR,
    ACTIONS(2254), 1,
      anon_sym_export,
    ACTIONS(2256), 1,
      anon_sym_default,
    ACTIONS(2258), 1,
      anon_sym_struct,
    STATE(1159), 1,
      sym_comment,
    STATE(1459), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1500), 1,
      sym_decorator,
    ACTIONS(19), 2,
      anon_sym_var,
      anon_sym_let,
    STATE(1340), 7,
      sym_component_declaration,
      sym_variable_declaration,
      sym_interface_declaration,
      sym_type_declaration,
      sym_enum_declaration,
      sym_class_declaration,
      sym_function_declaration,
  [61736] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2264), 1,
      anon_sym_GT,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1160), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1804), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [61793] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2272), 1,
      anon_sym_RBRACK,
    STATE(1161), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1810), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [61850] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    ACTIONS(2274), 1,
      anon_sym_GT,
    STATE(1162), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1875), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [61907] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2276), 1,
      anon_sym_RBRACK,
    STATE(1163), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1794), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [61964] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2278), 1,
      anon_sym_RBRACK,
    STATE(1164), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1713), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62021] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    ACTIONS(2280), 1,
      anon_sym_GT,
    STATE(1165), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1739), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62078] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2282), 1,
      anon_sym_RBRACK,
    STATE(1166), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1752), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62135] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2284), 1,
      anon_sym_RBRACK,
    STATE(1167), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1888), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62192] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2286), 1,
      anon_sym_RBRACK,
    STATE(1168), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1767), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62249] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    ACTIONS(2288), 1,
      anon_sym_GT,
    STATE(1169), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1809), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62306] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    ACTIONS(2290), 1,
      anon_sym_GT,
    STATE(1170), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1710), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62363] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    ACTIONS(2292), 1,
      anon_sym_GT,
    STATE(1171), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1793), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62420] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1205), 1,
      anon_sym_GT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1172), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1686), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62477] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2294), 1,
      anon_sym_RBRACK,
    STATE(1173), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1801), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62534] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2296), 1,
      anon_sym_RBRACK,
    STATE(1174), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1782), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62591] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2298), 1,
      anon_sym_RBRACK,
    STATE(1175), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1805), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62648] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2300), 1,
      anon_sym_RBRACK,
    STATE(1176), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1740), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62705] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2302), 1,
      anon_sym_RBRACK,
    STATE(1177), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1789), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62762] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    ACTIONS(2304), 1,
      anon_sym_GT,
    STATE(1178), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1781), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62819] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    ACTIONS(2306), 1,
      anon_sym_GT,
    STATE(1179), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1800), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62876] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    ACTIONS(2308), 1,
      anon_sym_GT,
    STATE(1180), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1788), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62933] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    ACTIONS(2310), 1,
      anon_sym_GT,
    STATE(1181), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1765), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [62990] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1182), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(2168), 1,
      sym_type_annotation,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63044] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1183), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(2119), 1,
      sym_type_annotation,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63098] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2312), 1,
      sym_identifier,
    ACTIONS(2318), 1,
      anon_sym_LBRACK,
    STATE(1184), 1,
      sym_comment,
    STATE(1483), 1,
      sym_qualified_type,
    STATE(1513), 1,
      sym_primary_type,
    STATE(1652), 1,
      sym_type_annotation,
    STATE(2155), 1,
      sym_parameter_list,
    STATE(1461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2316), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2314), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63152] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1185), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1694), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63206] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1186), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1965), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63260] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1187), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1928), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63314] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1188), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1498), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63368] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1189), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1763), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63422] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1190), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2048), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63476] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2320), 1,
      sym_identifier,
    ACTIONS(2326), 1,
      anon_sym_LBRACK,
    STATE(864), 1,
      sym_primary_type,
    STATE(893), 1,
      sym_qualified_type,
    STATE(1041), 1,
      sym_type_annotation,
    STATE(1191), 1,
      sym_comment,
    STATE(2158), 1,
      sym_parameter_list,
    STATE(915), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(1020), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2324), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2322), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63530] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1192), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1613), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63584] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1193), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1889), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63638] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1194), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1923), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63692] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(474), 1,
      sym_type_annotation,
    STATE(1195), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63746] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1196), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1862), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63800] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1197), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1712), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63854] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1198), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(2132), 1,
      sym_type_annotation,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63908] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2312), 1,
      sym_identifier,
    ACTIONS(2318), 1,
      anon_sym_LBRACK,
    STATE(1199), 1,
      sym_comment,
    STATE(1483), 1,
      sym_qualified_type,
    STATE(1498), 1,
      sym_type_annotation,
    STATE(1513), 1,
      sym_primary_type,
    STATE(2155), 1,
      sym_parameter_list,
    STATE(1461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2316), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2314), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [63962] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1200), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1615), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64016] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1201), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1814), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64070] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1202), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1914), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64124] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1203), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1688), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64178] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1204), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2068), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64232] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2312), 1,
      sym_identifier,
    ACTIONS(2318), 1,
      anon_sym_LBRACK,
    STATE(1205), 1,
      sym_comment,
    STATE(1483), 1,
      sym_qualified_type,
    STATE(1488), 1,
      sym_type_annotation,
    STATE(1513), 1,
      sym_primary_type,
    STATE(2155), 1,
      sym_parameter_list,
    STATE(1461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2316), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2314), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64286] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2328), 1,
      sym_identifier,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    STATE(281), 1,
      sym_primary_type,
    STATE(284), 1,
      sym_qualified_type,
    STATE(440), 1,
      sym_type_annotation,
    STATE(1206), 1,
      sym_comment,
    STATE(2159), 1,
      sym_parameter_list,
    STATE(392), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(409), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2332), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2330), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64340] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1207), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1817), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64394] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1208), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2104), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64448] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2328), 1,
      sym_identifier,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    STATE(281), 1,
      sym_primary_type,
    STATE(284), 1,
      sym_qualified_type,
    STATE(444), 1,
      sym_type_annotation,
    STATE(1209), 1,
      sym_comment,
    STATE(2159), 1,
      sym_parameter_list,
    STATE(392), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(409), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2332), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2330), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64502] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1210), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1612), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64556] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2336), 1,
      sym_identifier,
    ACTIONS(2342), 1,
      anon_sym_LBRACK,
    STATE(107), 1,
      sym_qualified_type,
    STATE(114), 1,
      sym_primary_type,
    STATE(161), 1,
      sym_type_annotation,
    STATE(1211), 1,
      sym_comment,
    STATE(2044), 1,
      sym_parameter_list,
    STATE(120), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(153), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2340), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2338), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64610] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1212), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1993), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64664] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2336), 1,
      sym_identifier,
    ACTIONS(2342), 1,
      anon_sym_LBRACK,
    STATE(107), 1,
      sym_qualified_type,
    STATE(114), 1,
      sym_primary_type,
    STATE(138), 1,
      sym_type_annotation,
    STATE(1213), 1,
      sym_comment,
    STATE(2044), 1,
      sym_parameter_list,
    STATE(120), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(153), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2340), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2338), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64718] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1214), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1768), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64772] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2344), 1,
      sym_identifier,
    ACTIONS(2350), 1,
      anon_sym_LBRACK,
    STATE(228), 1,
      sym_qualified_type,
    STATE(239), 1,
      sym_primary_type,
    STATE(322), 1,
      sym_type_annotation,
    STATE(1215), 1,
      sym_comment,
    STATE(2074), 1,
      sym_parameter_list,
    STATE(300), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(383), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2348), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2346), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64826] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1216), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(2017), 1,
      sym_type_annotation,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64880] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2344), 1,
      sym_identifier,
    ACTIONS(2350), 1,
      anon_sym_LBRACK,
    STATE(228), 1,
      sym_qualified_type,
    STATE(239), 1,
      sym_primary_type,
    STATE(334), 1,
      sym_type_annotation,
    STATE(1217), 1,
      sym_comment,
    STATE(2074), 1,
      sym_parameter_list,
    STATE(300), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(383), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2348), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2346), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64934] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(476), 1,
      sym_type_annotation,
    STATE(1218), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [64988] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2312), 1,
      sym_identifier,
    ACTIONS(2318), 1,
      anon_sym_LBRACK,
    STATE(1219), 1,
      sym_comment,
    STATE(1483), 1,
      sym_qualified_type,
    STATE(1513), 1,
      sym_primary_type,
    STATE(1643), 1,
      sym_type_annotation,
    STATE(2155), 1,
      sym_parameter_list,
    STATE(1461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2316), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2314), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65042] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1220), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1599), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65096] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2352), 1,
      sym_identifier,
    STATE(476), 1,
      sym_type_annotation,
    STATE(739), 1,
      sym_primary_type,
    STATE(770), 1,
      sym_qualified_type,
    STATE(1221), 1,
      sym_comment,
    STATE(2118), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2354), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65150] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1222), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1811), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65204] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1223), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1881), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65258] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2320), 1,
      sym_identifier,
    ACTIONS(2326), 1,
      anon_sym_LBRACK,
    STATE(864), 1,
      sym_primary_type,
    STATE(893), 1,
      sym_qualified_type,
    STATE(1024), 1,
      sym_type_annotation,
    STATE(1224), 1,
      sym_comment,
    STATE(2158), 1,
      sym_parameter_list,
    STATE(915), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(1020), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2324), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2322), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65312] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1225), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1848), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65366] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2352), 1,
      sym_identifier,
    STATE(474), 1,
      sym_type_annotation,
    STATE(739), 1,
      sym_primary_type,
    STATE(770), 1,
      sym_qualified_type,
    STATE(1226), 1,
      sym_comment,
    STATE(2118), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2354), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65420] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2328), 1,
      sym_identifier,
    ACTIONS(2334), 1,
      anon_sym_LBRACK,
    STATE(281), 1,
      sym_primary_type,
    STATE(284), 1,
      sym_qualified_type,
    STATE(418), 1,
      sym_type_annotation,
    STATE(1227), 1,
      sym_comment,
    STATE(2159), 1,
      sym_parameter_list,
    STATE(392), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(409), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2332), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2330), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65474] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1228), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(2116), 1,
      sym_type_annotation,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65528] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1229), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2027), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65582] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2336), 1,
      sym_identifier,
    ACTIONS(2342), 1,
      anon_sym_LBRACK,
    STATE(107), 1,
      sym_qualified_type,
    STATE(114), 1,
      sym_primary_type,
    STATE(146), 1,
      sym_type_annotation,
    STATE(1230), 1,
      sym_comment,
    STATE(2044), 1,
      sym_parameter_list,
    STATE(120), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(153), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2340), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2338), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65636] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1231), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1881), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65690] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1232), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1995), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65744] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2344), 1,
      sym_identifier,
    ACTIONS(2350), 1,
      anon_sym_LBRACK,
    STATE(228), 1,
      sym_qualified_type,
    STATE(239), 1,
      sym_primary_type,
    STATE(391), 1,
      sym_type_annotation,
    STATE(1233), 1,
      sym_comment,
    STATE(2074), 1,
      sym_parameter_list,
    STATE(300), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(383), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2348), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2346), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65798] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1234), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1779), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65852] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1235), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1842), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65906] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1236), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(2173), 1,
      sym_type_annotation,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [65960] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2312), 1,
      sym_identifier,
    ACTIONS(2318), 1,
      anon_sym_LBRACK,
    STATE(1237), 1,
      sym_comment,
    STATE(1483), 1,
      sym_qualified_type,
    STATE(1513), 1,
      sym_primary_type,
    STATE(1653), 1,
      sym_type_annotation,
    STATE(2155), 1,
      sym_parameter_list,
    STATE(1461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2316), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2314), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66014] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1238), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(2124), 1,
      sym_type_annotation,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66068] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1239), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2003), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66122] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1240), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1920), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66176] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1241), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(2147), 1,
      sym_type_annotation,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66230] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1242), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1966), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66284] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1243), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1670), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66338] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1244), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1909), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66392] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1245), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1673), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66446] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1246), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(2183), 1,
      sym_type_annotation,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66500] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1247), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1937), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66554] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1248), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1676), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66608] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2320), 1,
      sym_identifier,
    ACTIONS(2326), 1,
      anon_sym_LBRACK,
    STATE(864), 1,
      sym_primary_type,
    STATE(893), 1,
      sym_qualified_type,
    STATE(1034), 1,
      sym_type_annotation,
    STATE(1249), 1,
      sym_comment,
    STATE(2158), 1,
      sym_parameter_list,
    STATE(915), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(1020), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2324), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2322), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66662] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1250), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1679), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66716] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1251), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1971), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66770] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1252), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1681), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66824] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1253), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1683), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66878] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1254), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1633), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66932] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1255), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2076), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [66986] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2352), 1,
      sym_identifier,
    STATE(739), 1,
      sym_primary_type,
    STATE(770), 1,
      sym_qualified_type,
    STATE(785), 1,
      sym_type_annotation,
    STATE(1256), 1,
      sym_comment,
    STATE(2118), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2354), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67040] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1257), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1887), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67094] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1258), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2078), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67148] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1259), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2079), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67202] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1260), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2087), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67256] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1261), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2004), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67310] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1262), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2028), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67364] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1263), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2075), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67418] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1264), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2100), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67472] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1265), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2020), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67526] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1266), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(1973), 1,
      sym_type_annotation,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67580] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1267), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2073), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67634] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1268), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2090), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67688] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1269), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2095), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67742] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1270), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(2161), 1,
      sym_type_annotation,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67796] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1271), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2033), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67850] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1272), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2070), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67904] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1273), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2037), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [67958] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1274), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(2182), 1,
      sym_type_annotation,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68012] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1275), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2019), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68066] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1276), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2034), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68120] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1277), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2067), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68174] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1278), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2091), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68228] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1279), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(2059), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68282] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1280), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1488), 1,
      sym_type_annotation,
    STATE(1493), 1,
      sym_primary_type,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68336] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1281), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1979), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68390] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1282), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(2140), 1,
      sym_type_annotation,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68444] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(1283), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(1383), 1,
      sym_primary_type,
    STATE(1703), 1,
      sym_type_annotation,
    STATE(2105), 1,
      sym_parameter_list,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(475), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68498] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1284), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(2166), 1,
      sym_type_annotation,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68552] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1285), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(2170), 1,
      sym_type_annotation,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68606] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1286), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(2171), 1,
      sym_type_annotation,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68660] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2262), 1,
      sym_identifier,
    ACTIONS(2266), 1,
      anon_sym_LBRACK,
    STATE(1287), 1,
      sym_comment,
    STATE(1480), 1,
      sym_qualified_type,
    STATE(1493), 1,
      sym_primary_type,
    STATE(2014), 1,
      sym_parameter_list,
    STATE(2172), 1,
      sym_type_annotation,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    STATE(1532), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1144), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1146), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68714] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2312), 1,
      sym_identifier,
    ACTIONS(2318), 1,
      anon_sym_LBRACK,
    STATE(1288), 1,
      sym_comment,
    STATE(1483), 1,
      sym_qualified_type,
    STATE(1513), 1,
      sym_primary_type,
    STATE(1607), 1,
      sym_type_annotation,
    STATE(2155), 1,
      sym_parameter_list,
    STATE(1461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    STATE(1515), 3,
      sym_union_type,
      sym_function_type,
      sym_conditional_type,
    ACTIONS(2316), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2314), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [68768] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1289), 1,
      sym_comment,
    ACTIONS(2356), 19,
      anon_sym_Entry,
      anon_sym_Component,
      anon_sym_State,
      anon_sym_Prop,
      anon_sym_Link,
      anon_sym_Provide,
      anon_sym_Consume,
      anon_sym_Builder,
      anon_sym_Styles,
      anon_sym_Extend,
      anon_sym_AnimatableExtend,
      anon_sym_Watch,
      anon_sym_StorageLink,
      anon_sym_StorageProp,
      anon_sym_LocalStorageLink,
      anon_sym_LocalStorageProp,
      anon_sym_ObjectLink,
      anon_sym_Observed,
      sym_identifier,
  [68799] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1290), 1,
      sym_comment,
    ACTIONS(2358), 19,
      anon_sym_Entry,
      anon_sym_Component,
      anon_sym_State,
      anon_sym_Prop,
      anon_sym_Link,
      anon_sym_Provide,
      anon_sym_Consume,
      anon_sym_Builder,
      anon_sym_Styles,
      anon_sym_Extend,
      anon_sym_AnimatableExtend,
      anon_sym_Watch,
      anon_sym_StorageLink,
      anon_sym_StorageProp,
      anon_sym_LocalStorageLink,
      anon_sym_LocalStorageProp,
      anon_sym_ObjectLink,
      anon_sym_Observed,
      sym_identifier,
  [68830] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2362), 1,
      anon_sym_from,
    ACTIONS(2364), 1,
      anon_sym_SEMI,
    STATE(1291), 1,
      sym_comment,
    ACTIONS(2360), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [68863] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1616), 1,
      anon_sym_SEMI,
    ACTIONS(2366), 1,
      anon_sym_from,
    STATE(1292), 1,
      sym_comment,
    ACTIONS(1614), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [68896] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2370), 1,
      anon_sym_from,
    ACTIONS(2372), 1,
      anon_sym_SEMI,
    STATE(1293), 1,
      sym_comment,
    ACTIONS(2368), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [68929] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2376), 1,
      anon_sym_from,
    ACTIONS(2378), 1,
      anon_sym_SEMI,
    STATE(1294), 1,
      sym_comment,
    ACTIONS(2374), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [68962] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(61), 1,
      anon_sym_EQ,
    ACTIONS(2380), 1,
      anon_sym_DOT,
    ACTIONS(2382), 1,
      anon_sym_LT,
    ACTIONS(2384), 1,
      anon_sym_LBRACK,
    STATE(463), 1,
      sym_type_arguments,
    STATE(1295), 1,
      sym_comment,
    STATE(1316), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1382), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(39), 10,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_implements,
  [69005] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2388), 1,
      anon_sym_from,
    ACTIONS(2390), 1,
      anon_sym_SEMI,
    STATE(1296), 1,
      sym_comment,
    ACTIONS(2386), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69038] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2392), 1,
      anon_sym_RBRACE,
    ACTIONS(2394), 1,
      anon_sym_AT,
    ACTIONS(2398), 1,
      anon_sym_static,
    ACTIONS(2400), 1,
      anon_sym_readonly,
    ACTIONS(2402), 1,
      anon_sym_build,
    ACTIONS(2404), 1,
      sym_identifier,
    ACTIONS(2406), 1,
      anon_sym_async,
    STATE(1297), 1,
      sym_comment,
    STATE(1314), 1,
      aux_sym_component_body_repeat1,
    STATE(1432), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1470), 1,
      sym_decorator,
    ACTIONS(2396), 3,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
    STATE(1452), 3,
      sym_property_declaration,
      sym_build_method,
      sym_method_declaration,
  [69088] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1298), 1,
      sym_comment,
    ACTIONS(2408), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69116] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2412), 1,
      anon_sym_SEMI,
    STATE(1299), 1,
      sym_comment,
    ACTIONS(2410), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69146] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1616), 1,
      anon_sym_SEMI,
    STATE(1300), 1,
      sym_comment,
    ACTIONS(1614), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69176] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2414), 1,
      sym_identifier,
    ACTIONS(2420), 1,
      anon_sym_LBRACK,
    STATE(346), 1,
      sym_qualified_type,
    STATE(439), 1,
      sym_primary_type,
    STATE(1301), 1,
      sym_comment,
    STATE(438), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(2418), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2416), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [69216] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2394), 1,
      anon_sym_AT,
    ACTIONS(2398), 1,
      anon_sym_static,
    ACTIONS(2400), 1,
      anon_sym_readonly,
    ACTIONS(2402), 1,
      anon_sym_build,
    ACTIONS(2404), 1,
      sym_identifier,
    ACTIONS(2406), 1,
      anon_sym_async,
    ACTIONS(2422), 1,
      anon_sym_RBRACE,
    STATE(1297), 1,
      aux_sym_component_body_repeat1,
    STATE(1302), 1,
      sym_comment,
    STATE(1432), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1470), 1,
      sym_decorator,
    ACTIONS(2396), 3,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
    STATE(1452), 3,
      sym_property_declaration,
      sym_build_method,
      sym_method_declaration,
  [69266] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1303), 1,
      sym_comment,
    ACTIONS(2424), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69294] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1304), 1,
      sym_comment,
    ACTIONS(2426), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69322] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1305), 1,
      sym_comment,
    ACTIONS(1792), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69350] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1306), 1,
      sym_comment,
    ACTIONS(2428), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69378] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2424), 1,
      anon_sym_SEMI,
    STATE(1307), 1,
      sym_comment,
    ACTIONS(2430), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69408] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1308), 1,
      sym_comment,
    ACTIONS(2433), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69436] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2394), 1,
      anon_sym_AT,
    ACTIONS(2435), 1,
      anon_sym_RBRACE,
    ACTIONS(2439), 1,
      anon_sym_static,
    ACTIONS(2441), 1,
      anon_sym_readonly,
    ACTIONS(2443), 1,
      sym_identifier,
    ACTIONS(2445), 1,
      anon_sym_async,
    ACTIONS(2447), 1,
      anon_sym_constructor,
    STATE(1309), 1,
      sym_comment,
    STATE(1358), 1,
      aux_sym_class_body_repeat1,
    STATE(1416), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1470), 1,
      sym_decorator,
    ACTIONS(2437), 3,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
    STATE(1434), 3,
      sym_property_declaration,
      sym_method_declaration,
      sym_constructor_declaration,
  [69486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1310), 1,
      sym_comment,
    ACTIONS(2449), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69514] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2426), 1,
      anon_sym_SEMI,
    STATE(1311), 1,
      sym_comment,
    ACTIONS(2451), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69544] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2454), 1,
      sym_identifier,
    ACTIONS(2460), 1,
      anon_sym_LBRACK,
    STATE(132), 1,
      sym_qualified_type,
    STATE(159), 1,
      sym_primary_type,
    STATE(1312), 1,
      sym_comment,
    STATE(160), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(2458), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2456), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [69584] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1313), 1,
      sym_comment,
    ACTIONS(2462), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69612] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2464), 1,
      anon_sym_RBRACE,
    ACTIONS(2466), 1,
      anon_sym_AT,
    ACTIONS(2472), 1,
      anon_sym_static,
    ACTIONS(2475), 1,
      anon_sym_readonly,
    ACTIONS(2478), 1,
      anon_sym_build,
    ACTIONS(2481), 1,
      sym_identifier,
    ACTIONS(2484), 1,
      anon_sym_async,
    STATE(1432), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1470), 1,
      sym_decorator,
    STATE(1314), 2,
      sym_comment,
      aux_sym_component_body_repeat1,
    ACTIONS(2469), 3,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
    STATE(1452), 3,
      sym_property_declaration,
      sym_build_method,
      sym_method_declaration,
  [69660] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1315), 1,
      sym_comment,
    ACTIONS(2487), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69688] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(767), 1,
      anon_sym_EQ,
    ACTIONS(2380), 1,
      anon_sym_DOT,
    STATE(1316), 1,
      sym_comment,
    STATE(1339), 1,
      aux_sym_qualified_type_repeat1,
    ACTIONS(769), 13,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_implements,
  [69722] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2268), 1,
      sym_identifier,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    STATE(480), 1,
      sym_primary_type,
    STATE(1317), 1,
      sym_comment,
    STATE(1381), 1,
      sym_qualified_type,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(1023), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [69762] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1318), 1,
      sym_comment,
    ACTIONS(2489), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69790] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1319), 1,
      sym_comment,
    ACTIONS(2491), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69818] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1320), 1,
      sym_comment,
    ACTIONS(2493), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69846] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1321), 1,
      sym_comment,
    ACTIONS(2495), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1322), 1,
      sym_comment,
    ACTIONS(2497), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69902] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2270), 1,
      anon_sym_LBRACK,
    ACTIONS(2352), 1,
      sym_identifier,
    STATE(480), 1,
      sym_primary_type,
    STATE(770), 1,
      sym_qualified_type,
    STATE(1323), 1,
      sym_comment,
    STATE(461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(2354), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(1025), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [69942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1324), 1,
      sym_comment,
    ACTIONS(2499), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [69970] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2501), 1,
      anon_sym_RBRACE,
    ACTIONS(2503), 1,
      anon_sym_AT,
    ACTIONS(2509), 1,
      anon_sym_static,
    ACTIONS(2512), 1,
      anon_sym_readonly,
    ACTIONS(2515), 1,
      sym_identifier,
    ACTIONS(2518), 1,
      anon_sym_async,
    ACTIONS(2521), 1,
      anon_sym_constructor,
    STATE(1416), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1470), 1,
      sym_decorator,
    STATE(1325), 2,
      sym_comment,
      aux_sym_class_body_repeat1,
    ACTIONS(2506), 3,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
    STATE(1434), 3,
      sym_property_declaration,
      sym_method_declaration,
      sym_constructor_declaration,
  [70018] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2320), 1,
      sym_identifier,
    ACTIONS(2326), 1,
      anon_sym_LBRACK,
    STATE(893), 1,
      sym_qualified_type,
    STATE(1033), 1,
      sym_primary_type,
    STATE(1326), 1,
      sym_comment,
    STATE(915), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(2324), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2322), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [70058] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1327), 1,
      sym_comment,
    ACTIONS(1764), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70086] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2526), 1,
      anon_sym_SEMI,
    STATE(1328), 1,
      sym_comment,
    ACTIONS(2524), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70116] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1329), 1,
      sym_comment,
    ACTIONS(2528), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70144] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1330), 1,
      sym_comment,
    ACTIONS(2530), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70172] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2534), 1,
      anon_sym_SEMI,
    STATE(1331), 1,
      sym_comment,
    ACTIONS(2532), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70202] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2536), 1,
      sym_identifier,
    ACTIONS(2542), 1,
      anon_sym_LBRACK,
    STATE(1332), 1,
      sym_comment,
    STATE(1479), 1,
      sym_primary_type,
    STATE(1495), 1,
      sym_qualified_type,
    STATE(1569), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(2540), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2538), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [70242] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2364), 1,
      anon_sym_SEMI,
    STATE(1333), 1,
      sym_comment,
    ACTIONS(2360), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70272] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1334), 1,
      sym_comment,
    ACTIONS(1803), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70300] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2544), 1,
      sym_identifier,
    ACTIONS(2550), 1,
      anon_sym_LBRACK,
    STATE(261), 1,
      sym_qualified_type,
    STATE(321), 1,
      sym_primary_type,
    STATE(1335), 1,
      sym_comment,
    STATE(356), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(2548), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2546), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [70340] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1336), 1,
      sym_comment,
    ACTIONS(2552), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70368] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1337), 1,
      sym_comment,
    ACTIONS(2554), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70396] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1338), 1,
      sym_comment,
    ACTIONS(2556), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70424] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(778), 1,
      anon_sym_EQ,
    ACTIONS(2558), 1,
      anon_sym_DOT,
    STATE(1339), 2,
      sym_comment,
      aux_sym_qualified_type_repeat1,
    ACTIONS(780), 13,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_implements,
  [70456] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2563), 1,
      anon_sym_SEMI,
    STATE(1340), 1,
      sym_comment,
    ACTIONS(2561), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70486] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1341), 1,
      sym_comment,
    ACTIONS(2565), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70514] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1342), 1,
      sym_comment,
    ACTIONS(2567), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70542] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1343), 1,
      sym_comment,
    ACTIONS(2569), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70570] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1344), 1,
      sym_comment,
    ACTIONS(2571), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70598] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1345), 1,
      sym_comment,
    ACTIONS(1870), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70626] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1346), 1,
      sym_comment,
    ACTIONS(2573), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70654] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1347), 1,
      sym_comment,
    ACTIONS(2575), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70682] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2579), 1,
      anon_sym_SEMI,
    STATE(1348), 1,
      sym_comment,
    ACTIONS(2577), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70712] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2318), 1,
      anon_sym_LBRACK,
    ACTIONS(2581), 1,
      sym_identifier,
    STATE(1349), 1,
      sym_comment,
    STATE(1479), 1,
      sym_primary_type,
    STATE(1487), 1,
      sym_qualified_type,
    STATE(1461), 3,
      sym_generic_type,
      sym_array_type,
      sym_tuple_type,
    ACTIONS(2583), 4,
      anon_sym_number,
      anon_sym_string,
      anon_sym_boolean,
      anon_sym_any,
    ACTIONS(2314), 5,
      anon_sym_true,
      anon_sym_false,
      anon_sym_null,
      anon_sym_void,
      anon_sym_undefined,
  [70752] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1350), 1,
      sym_comment,
    ACTIONS(2585), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70780] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1351), 1,
      sym_comment,
    ACTIONS(2587), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70808] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1352), 1,
      sym_comment,
    ACTIONS(2589), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70836] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1353), 1,
      sym_comment,
    ACTIONS(2591), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70864] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1354), 1,
      sym_comment,
    ACTIONS(2593), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70892] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1355), 1,
      sym_comment,
    ACTIONS(2595), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70920] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2599), 1,
      anon_sym_SEMI,
    STATE(1356), 1,
      sym_comment,
    ACTIONS(2597), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70950] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2372), 1,
      anon_sym_SEMI,
    STATE(1357), 1,
      sym_comment,
    ACTIONS(2368), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [70980] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2394), 1,
      anon_sym_AT,
    ACTIONS(2439), 1,
      anon_sym_static,
    ACTIONS(2441), 1,
      anon_sym_readonly,
    ACTIONS(2443), 1,
      sym_identifier,
    ACTIONS(2445), 1,
      anon_sym_async,
    ACTIONS(2447), 1,
      anon_sym_constructor,
    ACTIONS(2601), 1,
      anon_sym_RBRACE,
    STATE(1325), 1,
      aux_sym_class_body_repeat1,
    STATE(1358), 1,
      sym_comment,
    STATE(1416), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1470), 1,
      sym_decorator,
    ACTIONS(2437), 3,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
    STATE(1434), 3,
      sym_property_declaration,
      sym_method_declaration,
      sym_constructor_declaration,
  [71030] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1359), 1,
      sym_comment,
    ACTIONS(2603), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71058] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1360), 1,
      sym_comment,
    ACTIONS(2605), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71086] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1361), 1,
      sym_comment,
    ACTIONS(2607), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71114] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2611), 1,
      anon_sym_SEMI,
    STATE(1362), 1,
      sym_comment,
    ACTIONS(2609), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71144] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2378), 1,
      anon_sym_SEMI,
    STATE(1363), 1,
      sym_comment,
    ACTIONS(2374), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71174] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1364), 1,
      sym_comment,
    ACTIONS(2613), 16,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71202] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2390), 1,
      anon_sym_SEMI,
    STATE(1365), 1,
      sym_comment,
    ACTIONS(2386), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71232] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1366), 1,
      sym_comment,
    ACTIONS(2532), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71259] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1367), 1,
      sym_comment,
    ACTIONS(2360), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71286] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1368), 1,
      sym_comment,
    ACTIONS(2615), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71313] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1369), 1,
      sym_comment,
    ACTIONS(2386), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71340] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1370), 1,
      sym_comment,
    ACTIONS(2577), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71367] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1371), 1,
      sym_comment,
    ACTIONS(1614), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71394] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1372), 1,
      sym_comment,
    ACTIONS(2597), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71421] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1373), 1,
      sym_comment,
    ACTIONS(2410), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71448] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1374), 1,
      sym_comment,
    ACTIONS(2368), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71475] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(778), 1,
      anon_sym_EQ,
    STATE(1375), 1,
      sym_comment,
    ACTIONS(780), 14,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_DOT,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_implements,
  [71504] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1376), 1,
      sym_comment,
    ACTIONS(2617), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1377), 1,
      sym_comment,
    ACTIONS(2619), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71558] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1378), 1,
      sym_comment,
    ACTIONS(2609), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71585] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1379), 1,
      sym_comment,
    ACTIONS(2374), 15,
      ts_builtin_sym_end,
      anon_sym_import,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_var,
      anon_sym_let,
      anon_sym_const,
      anon_sym_interface,
      anon_sym_type,
      anon_sym_enum,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [71612] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(61), 1,
      anon_sym_EQ,
    ACTIONS(2384), 1,
      anon_sym_LBRACK,
    STATE(1380), 1,
      sym_comment,
    STATE(1382), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(39), 10,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_implements,
  [71643] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(61), 1,
      anon_sym_EQ,
    ACTIONS(2382), 1,
      anon_sym_LT,
    STATE(463), 1,
      sym_type_arguments,
    STATE(1381), 1,
      sym_comment,
    ACTIONS(39), 10,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_implements,
  [71674] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(771), 1,
      anon_sym_EQ,
    ACTIONS(2384), 1,
      anon_sym_LBRACK,
    STATE(454), 1,
      aux_sym_array_type_repeat1,
    STATE(1382), 1,
      sym_comment,
    ACTIONS(773), 10,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_PIPE,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_extends,
      anon_sym_implements,
  [71705] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(797), 1,
      anon_sym_EQ,
    ACTIONS(2621), 1,
      anon_sym_PIPE,
    ACTIONS(2623), 1,
      anon_sym_extends,
    STATE(1383), 1,
      sym_comment,
    STATE(1394), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(799), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_implements,
  [71737] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2380), 1,
      anon_sym_DOT,
    ACTIONS(2625), 1,
      anon_sym_LT,
    ACTIONS(2627), 1,
      anon_sym_LBRACK,
    STATE(1316), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1384), 1,
      sym_comment,
    STATE(1469), 1,
      aux_sym_array_type_repeat1,
    STATE(1519), 1,
      sym_type_arguments,
    ACTIONS(39), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [71773] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2629), 1,
      anon_sym_DOT,
    ACTIONS(2631), 1,
      anon_sym_LT,
    ACTIONS(2633), 1,
      anon_sym_LBRACK,
    STATE(1385), 1,
      sym_comment,
    STATE(1464), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1466), 1,
      sym_type_arguments,
    STATE(1473), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(61), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(39), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [71811] = 15,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      anon_sym_COMMA,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2635), 1,
      anon_sym_RBRACE,
    ACTIONS(2637), 1,
      sym_identifier,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    STATE(1386), 1,
      sym_comment,
    STATE(1719), 1,
      sym_component_parameter,
    STATE(1850), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [71857] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(221), 1,
      anon_sym_COMMA,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2643), 1,
      anon_sym_RBRACE,
    ACTIONS(2645), 1,
      sym_identifier,
    STATE(1387), 1,
      sym_comment,
    STATE(1704), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [71900] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2647), 1,
      anon_sym_DOT,
    ACTIONS(2649), 1,
      anon_sym_LT,
    ACTIONS(2651), 1,
      anon_sym_LBRACK,
    STATE(1388), 1,
      sym_comment,
    STATE(1468), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1516), 1,
      aux_sym_array_type_repeat1,
    STATE(1567), 1,
      sym_type_arguments,
    ACTIONS(39), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [71935] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2653), 1,
      anon_sym_LBRACK,
    ACTIONS(756), 2,
      sym_identifier,
      anon_sym_extends,
    STATE(1389), 2,
      sym_comment,
      aux_sym_array_type_repeat1,
    ACTIONS(758), 7,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [71962] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(311), 1,
      anon_sym_COMMA,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2656), 1,
      anon_sym_RBRACE,
    STATE(1390), 1,
      sym_comment,
    STATE(1698), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72005] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2380), 1,
      anon_sym_DOT,
    ACTIONS(2625), 1,
      anon_sym_LT,
    ACTIONS(2633), 1,
      anon_sym_LBRACK,
    STATE(1316), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1391), 1,
      sym_comment,
    STATE(1466), 1,
      sym_type_arguments,
    STATE(1489), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(39), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [72040] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(321), 1,
      anon_sym_COMMA,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2658), 1,
      anon_sym_RBRACE,
    STATE(1392), 1,
      sym_comment,
    STATE(1730), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72083] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(315), 1,
      anon_sym_COMMA,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2660), 1,
      anon_sym_RBRACE,
    STATE(1393), 1,
      sym_comment,
    STATE(1754), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72126] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(813), 1,
      anon_sym_EQ,
    ACTIONS(2621), 1,
      anon_sym_PIPE,
    STATE(1394), 1,
      sym_comment,
    STATE(1395), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(815), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_implements,
  [72155] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(817), 1,
      anon_sym_EQ,
    ACTIONS(2662), 1,
      anon_sym_PIPE,
    STATE(1395), 2,
      sym_comment,
      aux_sym_union_type_repeat1,
    ACTIONS(819), 8,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COLON,
      anon_sym_EQ_GT,
      anon_sym_RBRACK,
      anon_sym_implements,
  [72182] = 14,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(161), 1,
      anon_sym_COMMA,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2665), 1,
      anon_sym_RBRACE,
    STATE(1396), 1,
      sym_comment,
    STATE(1850), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72225] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1397), 1,
      sym_comment,
    ACTIONS(2667), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2669), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [72249] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2671), 1,
      anon_sym_RBRACE,
    STATE(1398), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72289] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1399), 1,
      sym_comment,
    ACTIONS(2673), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2675), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [72313] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2677), 1,
      anon_sym_RBRACE,
    STATE(1400), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72353] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2679), 1,
      anon_sym_RBRACE,
    STATE(1401), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72393] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1402), 1,
      sym_comment,
    ACTIONS(2681), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2683), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [72417] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1403), 1,
      sym_comment,
    ACTIONS(975), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(973), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [72441] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2685), 1,
      anon_sym_RBRACE,
    STATE(1404), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72481] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1405), 1,
      sym_comment,
    ACTIONS(2673), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2675), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [72505] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1406), 1,
      sym_comment,
    ACTIONS(756), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(758), 8,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
  [72529] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2687), 1,
      anon_sym_RBRACE,
    STATE(1407), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72569] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2689), 1,
      anon_sym_AT,
    STATE(1470), 1,
      sym_decorator,
    STATE(1408), 2,
      sym_comment,
      aux_sym_component_declaration_repeat1,
    ACTIONS(2692), 7,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
  [72595] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1409), 1,
      sym_comment,
    ACTIONS(2694), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2696), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [72619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1410), 1,
      sym_comment,
    ACTIONS(2698), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2700), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [72643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1411), 1,
      sym_comment,
    ACTIONS(2702), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2704), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [72667] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1412), 1,
      sym_comment,
    ACTIONS(2706), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2708), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [72691] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2710), 1,
      anon_sym_RBRACE,
    STATE(1413), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1414), 1,
      sym_comment,
    ACTIONS(2712), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2714), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [72755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1415), 1,
      sym_comment,
    ACTIONS(2716), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2718), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [72779] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2394), 1,
      anon_sym_AT,
    ACTIONS(2722), 1,
      anon_sym_static,
    ACTIONS(2724), 1,
      anon_sym_readonly,
    ACTIONS(2726), 1,
      sym_identifier,
    ACTIONS(2728), 1,
      anon_sym_async,
    STATE(1408), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1416), 1,
      sym_comment,
    STATE(1470), 1,
      sym_decorator,
    ACTIONS(2720), 3,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
  [72815] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1417), 1,
      sym_comment,
    ACTIONS(1764), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(1766), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [72839] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2730), 1,
      anon_sym_RBRACE,
    STATE(1418), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72879] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1419), 1,
      sym_comment,
    ACTIONS(2732), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2734), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [72903] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2736), 1,
      anon_sym_RBRACE,
    STATE(1420), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [72943] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1421), 1,
      sym_comment,
    ACTIONS(2738), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2740), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [72967] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1422), 1,
      sym_comment,
    ACTIONS(2742), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2744), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [72991] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1423), 1,
      sym_comment,
    ACTIONS(1764), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(1766), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73015] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1424), 1,
      sym_comment,
    ACTIONS(2746), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2748), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73039] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1425), 1,
      sym_comment,
    ACTIONS(2716), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2718), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73063] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1426), 1,
      sym_comment,
    ACTIONS(2667), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2669), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73087] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1427), 1,
      sym_comment,
    ACTIONS(2698), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2700), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73111] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1428), 1,
      sym_comment,
    ACTIONS(2694), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2696), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73135] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1429), 1,
      sym_comment,
    ACTIONS(2750), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2752), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73159] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1430), 1,
      sym_comment,
    ACTIONS(2754), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2756), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73183] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1431), 1,
      sym_comment,
    ACTIONS(2754), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2756), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73207] = 11,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2394), 1,
      anon_sym_AT,
    ACTIONS(2760), 1,
      anon_sym_static,
    ACTIONS(2762), 1,
      anon_sym_readonly,
    ACTIONS(2764), 1,
      sym_identifier,
    ACTIONS(2766), 1,
      anon_sym_async,
    STATE(1408), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1432), 1,
      sym_comment,
    STATE(1470), 1,
      sym_decorator,
    ACTIONS(2758), 3,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
  [73243] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1433), 1,
      sym_comment,
    ACTIONS(975), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(973), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73267] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1434), 1,
      sym_comment,
    ACTIONS(2768), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2770), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73291] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1435), 1,
      sym_comment,
    ACTIONS(2772), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2774), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73315] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1436), 1,
      sym_comment,
    ACTIONS(2776), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2778), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73339] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1437), 1,
      sym_comment,
    ACTIONS(2780), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2782), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73363] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1438), 1,
      sym_comment,
    ACTIONS(2784), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2786), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73387] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1439), 1,
      sym_comment,
    ACTIONS(2702), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2704), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73411] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1440), 1,
      sym_comment,
    ACTIONS(2788), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2790), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73435] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1441), 1,
      sym_comment,
    ACTIONS(2792), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2794), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73459] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1442), 1,
      sym_comment,
    ACTIONS(2772), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2774), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73483] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1443), 1,
      sym_comment,
    ACTIONS(2796), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2798), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73507] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1444), 1,
      sym_comment,
    ACTIONS(2784), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2786), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73531] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1445), 1,
      sym_comment,
    ACTIONS(2800), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2802), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73555] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1446), 1,
      sym_comment,
    ACTIONS(2681), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2683), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73579] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2804), 1,
      anon_sym_RBRACE,
    STATE(1447), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [73619] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1448), 1,
      sym_comment,
    ACTIONS(2738), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2740), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73643] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1449), 1,
      sym_comment,
    ACTIONS(2788), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2790), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73667] = 13,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    ACTIONS(2806), 1,
      anon_sym_RBRACE,
    STATE(1450), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [73707] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1451), 1,
      sym_comment,
    ACTIONS(2742), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2744), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73731] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1452), 1,
      sym_comment,
    ACTIONS(2808), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2810), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73755] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1453), 1,
      sym_comment,
    ACTIONS(2706), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2708), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
      anon_sym_constructor,
  [73779] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1454), 1,
      sym_comment,
    ACTIONS(2792), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2794), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73803] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1455), 1,
      sym_comment,
    ACTIONS(2800), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2802), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73827] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1456), 1,
      sym_comment,
    ACTIONS(2750), 2,
      anon_sym_RBRACE,
      anon_sym_AT,
    ACTIONS(2752), 8,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      anon_sym_build,
      sym_identifier,
      anon_sym_async,
  [73851] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2814), 1,
      anon_sym_AT,
    STATE(1500), 1,
      sym_decorator,
    STATE(1457), 2,
      sym_comment,
      aux_sym_component_declaration_repeat1,
    ACTIONS(2812), 6,
      anon_sym_export,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [73876] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1458), 1,
      sym_comment,
    ACTIONS(754), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(749), 7,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [73899] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(13), 1,
      anon_sym_AT,
    ACTIONS(2817), 1,
      anon_sym_export,
    ACTIONS(2819), 1,
      anon_sym_struct,
    ACTIONS(2821), 1,
      anon_sym_async,
    ACTIONS(2823), 1,
      anon_sym_abstract,
    ACTIONS(2825), 1,
      anon_sym_class,
    ACTIONS(2827), 1,
      anon_sym_function,
    STATE(1457), 1,
      aux_sym_component_declaration_repeat1,
    STATE(1459), 1,
      sym_comment,
    STATE(1500), 1,
      sym_decorator,
  [73936] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2829), 1,
      anon_sym_DOT,
    ACTIONS(778), 2,
      sym_identifier,
      anon_sym_extends,
    STATE(1460), 2,
      sym_comment,
      aux_sym_qualified_type_repeat1,
    ACTIONS(780), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_LT,
  [73961] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1461), 1,
      sym_comment,
    ACTIONS(61), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(39), 7,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [73984] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1462), 1,
      sym_comment,
    ACTIONS(809), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(811), 7,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [74007] = 12,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(195), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    ACTIONS(2639), 1,
      sym_numeric_literal,
    ACTIONS(2641), 1,
      anon_sym_LBRACK,
    ACTIONS(2645), 1,
      sym_identifier,
    STATE(1463), 1,
      sym_comment,
    STATE(1947), 1,
      sym_property_assignment,
    STATE(2065), 1,
      sym_property_name,
    STATE(2066), 1,
      sym_string_literal,
  [74044] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2629), 1,
      anon_sym_DOT,
    STATE(1460), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1464), 1,
      sym_comment,
    ACTIONS(767), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(769), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_LT,
  [74071] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1465), 1,
      sym_comment,
    ACTIONS(805), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(807), 7,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [74094] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1466), 1,
      sym_comment,
    ACTIONS(836), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(838), 7,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [74117] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2832), 1,
      anon_sym_AT,
    ACTIONS(2834), 1,
      anon_sym_LPAREN,
    STATE(1467), 1,
      sym_comment,
    ACTIONS(2836), 7,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
  [74142] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2647), 1,
      anon_sym_DOT,
    STATE(1468), 1,
      sym_comment,
    STATE(1472), 1,
      aux_sym_qualified_type_repeat1,
    ACTIONS(769), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
      anon_sym_LT,
  [74166] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2627), 1,
      anon_sym_LBRACK,
    STATE(1469), 1,
      sym_comment,
    STATE(1475), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(773), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [74190] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2838), 1,
      anon_sym_AT,
    STATE(1470), 1,
      sym_comment,
    ACTIONS(2840), 7,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
  [74212] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1471), 1,
      sym_comment,
    ACTIONS(778), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(780), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_PIPE,
      anon_sym_LT,
  [74234] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2842), 1,
      anon_sym_DOT,
    STATE(1472), 2,
      sym_comment,
      aux_sym_qualified_type_repeat1,
    ACTIONS(780), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
      anon_sym_LT,
  [74256] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2633), 1,
      anon_sym_LBRACK,
    STATE(1389), 1,
      aux_sym_array_type_repeat1,
    STATE(1473), 1,
      sym_comment,
    ACTIONS(771), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(773), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [74282] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2845), 1,
      anon_sym_AT,
    STATE(1474), 1,
      sym_comment,
    ACTIONS(2847), 7,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
  [74304] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2849), 1,
      anon_sym_LBRACK,
    STATE(1475), 2,
      sym_comment,
      aux_sym_array_type_repeat1,
    ACTIONS(758), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [74326] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2852), 1,
      anon_sym_LPAREN,
    STATE(1476), 1,
      sym_comment,
    ACTIONS(2832), 7,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [74348] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2854), 1,
      anon_sym_AT,
    STATE(1477), 1,
      sym_comment,
    ACTIONS(2856), 7,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
  [74370] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2627), 1,
      anon_sym_LBRACK,
    STATE(1469), 1,
      aux_sym_array_type_repeat1,
    STATE(1478), 1,
      sym_comment,
    ACTIONS(39), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [74394] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1479), 1,
      sym_comment,
    ACTIONS(819), 8,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [74414] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2625), 1,
      anon_sym_LT,
    STATE(1480), 1,
      sym_comment,
    STATE(1519), 1,
      sym_type_arguments,
    ACTIONS(39), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [74438] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2858), 1,
      anon_sym_AT,
    STATE(1481), 1,
      sym_comment,
    ACTIONS(2860), 7,
      anon_sym_private,
      anon_sym_public,
      anon_sym_protected,
      anon_sym_static,
      anon_sym_readonly,
      sym_identifier,
      anon_sym_async,
  [74460] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2633), 1,
      anon_sym_LBRACK,
    STATE(1473), 1,
      aux_sym_array_type_repeat1,
    STATE(1482), 1,
      sym_comment,
    ACTIONS(61), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(39), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [74486] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2631), 1,
      anon_sym_LT,
    STATE(1466), 1,
      sym_type_arguments,
    STATE(1483), 1,
      sym_comment,
    ACTIONS(61), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(39), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [74512] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1484), 1,
      sym_comment,
    ACTIONS(2858), 7,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [74531] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1485), 1,
      sym_comment,
    ACTIONS(758), 7,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_extends,
  [74550] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    ACTIONS(2864), 1,
      anon_sym_LT,
    ACTIONS(2866), 1,
      anon_sym_extends,
    ACTIONS(2868), 1,
      anon_sym_implements,
    STATE(1353), 1,
      sym_class_body,
    STATE(1486), 1,
      sym_comment,
    STATE(1545), 1,
      sym_type_parameters,
    STATE(1932), 1,
      sym_implements_clause,
  [74581] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2625), 1,
      anon_sym_LT,
    STATE(1466), 1,
      sym_type_arguments,
    STATE(1487), 1,
      sym_comment,
    ACTIONS(39), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [74604] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1488), 1,
      sym_comment,
    ACTIONS(873), 7,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_GT,
      anon_sym_QMARK,
  [74623] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2633), 1,
      anon_sym_LBRACK,
    STATE(1389), 1,
      aux_sym_array_type_repeat1,
    STATE(1489), 1,
      sym_comment,
    ACTIONS(773), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [74646] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2651), 1,
      anon_sym_LBRACK,
    STATE(1490), 1,
      sym_comment,
    STATE(1516), 1,
      aux_sym_array_type_repeat1,
    ACTIONS(39), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [74669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1491), 1,
      sym_comment,
    ACTIONS(2870), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      sym_identifier,
      anon_sym_EQ_GT,
  [74688] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1492), 1,
      sym_comment,
    ACTIONS(2872), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      sym_identifier,
      anon_sym_EQ_GT,
  [74707] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2874), 1,
      anon_sym_PIPE,
    ACTIONS(2876), 1,
      anon_sym_extends,
    STATE(1493), 1,
      sym_comment,
    STATE(1528), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(799), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_QMARK,
  [74732] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1494), 1,
      sym_comment,
    ACTIONS(2845), 7,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [74751] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2649), 1,
      anon_sym_LT,
    STATE(1495), 1,
      sym_comment,
    STATE(1567), 1,
      sym_type_arguments,
    ACTIONS(39), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [74774] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1496), 1,
      sym_comment,
    ACTIONS(780), 7,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_DOT,
      sym_identifier,
      anon_sym_PIPE,
      anon_sym_LT,
  [74793] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2878), 1,
      anon_sym_SEMI,
    ACTIONS(2880), 1,
      anon_sym_COLON,
    ACTIONS(2882), 1,
      anon_sym_EQ,
    STATE(1497), 1,
      sym_comment,
    STATE(1602), 1,
      sym_parameter_list,
    STATE(1985), 1,
      sym_type_parameters,
  [74824] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1498), 1,
      sym_comment,
    ACTIONS(935), 7,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_GT,
      anon_sym_QMARK,
  [74843] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2884), 1,
      anon_sym_SEMI,
    ACTIONS(2886), 1,
      anon_sym_COLON,
    ACTIONS(2888), 1,
      anon_sym_EQ,
    STATE(1499), 1,
      sym_comment,
    STATE(1629), 1,
      sym_parameter_list,
    STATE(1936), 1,
      sym_type_parameters,
  [74874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1500), 1,
      sym_comment,
    ACTIONS(2838), 7,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [74893] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2633), 1,
      anon_sym_LBRACK,
    STATE(1489), 1,
      aux_sym_array_type_repeat1,
    STATE(1501), 1,
      sym_comment,
    ACTIONS(39), 5,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
  [74916] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2380), 1,
      anon_sym_DOT,
    ACTIONS(2382), 1,
      anon_sym_LT,
    ACTIONS(2890), 1,
      anon_sym_LBRACE,
    ACTIONS(2892), 1,
      anon_sym_COMMA,
    STATE(463), 1,
      sym_type_arguments,
    STATE(1316), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1502), 1,
      sym_comment,
    STATE(1825), 1,
      aux_sym_implements_clause_repeat1,
  [74947] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    ACTIONS(2864), 1,
      anon_sym_LT,
    ACTIONS(2868), 1,
      anon_sym_implements,
    ACTIONS(2894), 1,
      anon_sym_extends,
    STATE(1310), 1,
      sym_class_body,
    STATE(1503), 1,
      sym_comment,
    STATE(1560), 1,
      sym_type_parameters,
    STATE(1952), 1,
      sym_implements_clause,
  [74978] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2896), 1,
      anon_sym_LBRACK,
    STATE(1504), 2,
      sym_comment,
      aux_sym_array_type_repeat1,
    ACTIONS(758), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [74999] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1505), 1,
      sym_comment,
    ACTIONS(2854), 7,
      anon_sym_export,
      anon_sym_AT,
      anon_sym_struct,
      anon_sym_async,
      anon_sym_abstract,
      anon_sym_class,
      anon_sym_function,
  [75018] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2192), 1,
      anon_sym_SEMI,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2899), 1,
      anon_sym_COLON,
    ACTIONS(2901), 1,
      anon_sym_EQ,
    STATE(1506), 1,
      sym_comment,
    STATE(1645), 1,
      sym_parameter_list,
    STATE(1994), 1,
      sym_type_parameters,
  [75049] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2903), 1,
      anon_sym_SEMI,
    ACTIONS(2905), 1,
      anon_sym_COLON,
    ACTIONS(2907), 1,
      anon_sym_EQ,
    STATE(1507), 1,
      sym_comment,
    STATE(1639), 1,
      sym_parameter_list,
    STATE(1938), 1,
      sym_type_parameters,
  [75080] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1508), 1,
      sym_comment,
    ACTIONS(2909), 7,
      anon_sym_LBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_COLON,
      sym_identifier,
      anon_sym_EQ_GT,
  [75099] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    ACTIONS(2864), 1,
      anon_sym_LT,
    ACTIONS(2868), 1,
      anon_sym_implements,
    ACTIONS(2911), 1,
      anon_sym_extends,
    STATE(1322), 1,
      sym_class_body,
    STATE(1509), 1,
      sym_comment,
    STATE(1537), 1,
      sym_type_parameters,
    STATE(1911), 1,
      sym_implements_clause,
  [75130] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2913), 1,
      anon_sym_SEMI,
    ACTIONS(2915), 1,
      anon_sym_COLON,
    ACTIONS(2917), 1,
      anon_sym_EQ,
    STATE(1510), 1,
      sym_comment,
    STATE(1617), 1,
      sym_parameter_list,
    STATE(1903), 1,
      sym_type_parameters,
  [75161] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2144), 1,
      anon_sym_SEMI,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2919), 1,
      anon_sym_COLON,
    ACTIONS(2921), 1,
      anon_sym_EQ,
    STATE(1511), 1,
      sym_comment,
    STATE(1640), 1,
      sym_parameter_list,
    STATE(1940), 1,
      sym_type_parameters,
  [75192] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2154), 1,
      anon_sym_SEMI,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2923), 1,
      anon_sym_COLON,
    ACTIONS(2925), 1,
      anon_sym_EQ,
    STATE(1512), 1,
      sym_comment,
    STATE(1647), 1,
      sym_parameter_list,
    STATE(1943), 1,
      sym_type_parameters,
  [75223] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(797), 1,
      sym_identifier,
    ACTIONS(2927), 1,
      anon_sym_PIPE,
    ACTIONS(2929), 1,
      anon_sym_extends,
    STATE(1513), 1,
      sym_comment,
    STATE(1521), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(799), 3,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
  [75250] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2112), 1,
      anon_sym_SEMI,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2931), 1,
      anon_sym_COLON,
    ACTIONS(2933), 1,
      anon_sym_EQ,
    STATE(1514), 1,
      sym_comment,
    STATE(1598), 1,
      sym_parameter_list,
    STATE(1924), 1,
      sym_type_parameters,
  [75281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1515), 1,
      sym_comment,
    ACTIONS(799), 7,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_GT,
      anon_sym_QMARK,
  [75300] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2651), 1,
      anon_sym_LBRACK,
    STATE(1504), 1,
      aux_sym_array_type_repeat1,
    STATE(1516), 1,
      sym_comment,
    ACTIONS(773), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [75323] = 10,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2935), 1,
      sym_identifier,
    ACTIONS(2937), 1,
      anon_sym_async,
    STATE(1517), 1,
      sym_comment,
    STATE(1871), 1,
      sym_type_parameters,
    STATE(1901), 1,
      sym_parameter_list,
    STATE(1907), 1,
      sym_arrow_function,
  [75354] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1518), 1,
      sym_comment,
    ACTIONS(851), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(853), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [75374] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1519), 1,
      sym_comment,
    ACTIONS(838), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [75392] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1520), 1,
      sym_comment,
    ACTIONS(807), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [75410] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2927), 1,
      anon_sym_PIPE,
    STATE(1521), 1,
      sym_comment,
    STATE(1529), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(815), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
  [75432] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1522), 1,
      sym_comment,
    ACTIONS(749), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [75450] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2380), 1,
      anon_sym_DOT,
    ACTIONS(2382), 1,
      anon_sym_LT,
    STATE(463), 1,
      sym_type_arguments,
    STATE(1316), 1,
      aux_sym_qualified_type_repeat1,
    STATE(1523), 1,
      sym_comment,
    ACTIONS(2939), 2,
      anon_sym_LBRACE,
      anon_sym_COMMA,
  [75476] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1524), 1,
      sym_comment,
    ACTIONS(845), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [75494] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1525), 1,
      sym_comment,
    ACTIONS(758), 6,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
      anon_sym_LBRACK,
  [75512] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2941), 1,
      anon_sym_COLON,
    ACTIONS(2943), 1,
      anon_sym_QMARK,
    STATE(1526), 1,
      sym_comment,
    STATE(1564), 1,
      sym_parameter_list,
    STATE(1997), 1,
      sym_type_parameters,
  [75540] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1527), 1,
      sym_comment,
    ACTIONS(847), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(849), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [75560] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2874), 1,
      anon_sym_PIPE,
    STATE(1528), 1,
      sym_comment,
    STATE(1531), 1,
      aux_sym_union_type_repeat1,
    ACTIONS(815), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_QMARK,
  [75582] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2945), 1,
      anon_sym_PIPE,
    STATE(1529), 2,
      sym_comment,
      aux_sym_union_type_repeat1,
    ACTIONS(819), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
  [75602] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1530), 1,
      sym_comment,
    ACTIONS(849), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [75620] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2948), 1,
      anon_sym_PIPE,
    STATE(1531), 2,
      sym_comment,
      aux_sym_union_type_repeat1,
    ACTIONS(819), 4,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_GT,
      anon_sym_QMARK,
  [75640] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1532), 1,
      sym_comment,
    ACTIONS(39), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [75658] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1533), 1,
      sym_comment,
    ACTIONS(853), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [75676] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1534), 1,
      sym_comment,
    ACTIONS(843), 2,
      sym_identifier,
      anon_sym_extends,
    ACTIONS(845), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [75696] = 9,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(2951), 1,
      sym_identifier,
    ACTIONS(2953), 1,
      anon_sym_function,
    STATE(1535), 1,
      sym_comment,
    STATE(1826), 1,
      sym_type_parameters,
    STATE(1931), 1,
      sym_parameter_list,
  [75724] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1536), 1,
      sym_comment,
    ACTIONS(811), 6,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_GT,
      anon_sym_QMARK,
      anon_sym_extends,
  [75742] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    ACTIONS(2868), 1,
      anon_sym_implements,
    ACTIONS(2955), 1,
      anon_sym_extends,
    STATE(1344), 1,
      sym_class_body,
    STATE(1537), 1,
      sym_comment,
    STATE(1915), 1,
      sym_implements_clause,
  [75767] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2961), 1,
      anon_sym_DOLLAR,
    ACTIONS(2963), 1,
      anon_sym_BQUOTE,
    ACTIONS(2965), 1,
      sym_template_chars,
    STATE(1538), 1,
      sym_comment,
    STATE(1548), 1,
      aux_sym_template_literal_repeat1,
    STATE(1832), 1,
      sym_template_substitution,
  [75792] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2967), 1,
      anon_sym_DQUOTE,
    ACTIONS(2969), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2971), 1,
      anon_sym_BSLASH,
    STATE(1539), 1,
      sym_comment,
    STATE(1553), 1,
      aux_sym_string_literal_repeat1,
    STATE(1736), 1,
      sym_escape_sequence,
  [75817] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2969), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2971), 1,
      anon_sym_BSLASH,
    ACTIONS(2973), 1,
      anon_sym_DQUOTE,
    STATE(1540), 1,
      sym_comment,
    STATE(1549), 1,
      aux_sym_string_literal_repeat1,
    STATE(1736), 1,
      sym_escape_sequence,
  [75842] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2973), 1,
      anon_sym_SQUOTE,
    ACTIONS(2975), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2977), 1,
      anon_sym_BSLASH,
    STATE(1541), 1,
      sym_comment,
    STATE(1550), 1,
      aux_sym_string_literal_repeat2,
    STATE(1753), 1,
      sym_escape_sequence,
  [75867] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2967), 1,
      anon_sym_SQUOTE,
    ACTIONS(2975), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2977), 1,
      anon_sym_BSLASH,
    STATE(1542), 1,
      sym_comment,
    STATE(1556), 1,
      aux_sym_string_literal_repeat2,
    STATE(1753), 1,
      sym_escape_sequence,
  [75892] = 7,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2979), 1,
      anon_sym_SQUOTE,
    ACTIONS(2981), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2984), 1,
      anon_sym_BSLASH,
    STATE(1753), 1,
      sym_escape_sequence,
    STATE(1543), 2,
      sym_comment,
      aux_sym_string_literal_repeat2,
  [75915] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2961), 1,
      anon_sym_DOLLAR,
    ACTIONS(2965), 1,
      sym_template_chars,
    ACTIONS(2987), 1,
      anon_sym_BQUOTE,
    STATE(1544), 1,
      sym_comment,
    STATE(1552), 1,
      aux_sym_template_literal_repeat1,
    STATE(1832), 1,
      sym_template_substitution,
  [75940] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    ACTIONS(2868), 1,
      anon_sym_implements,
    ACTIONS(2911), 1,
      anon_sym_extends,
    STATE(1322), 1,
      sym_class_body,
    STATE(1545), 1,
      sym_comment,
    STATE(1911), 1,
      sym_implements_clause,
  [75965] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2961), 1,
      anon_sym_DOLLAR,
    ACTIONS(2965), 1,
      sym_template_chars,
    ACTIONS(2989), 1,
      anon_sym_BQUOTE,
    STATE(1546), 1,
      sym_comment,
    STATE(1557), 1,
      aux_sym_template_literal_repeat1,
    STATE(1832), 1,
      sym_template_substitution,
  [75990] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2993), 1,
      anon_sym_COLON,
    STATE(1547), 1,
      sym_comment,
    ACTIONS(2991), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
  [76009] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2961), 1,
      anon_sym_DOLLAR,
    ACTIONS(2965), 1,
      sym_template_chars,
    ACTIONS(2995), 1,
      anon_sym_BQUOTE,
    STATE(1548), 1,
      sym_comment,
    STATE(1558), 1,
      aux_sym_template_literal_repeat1,
    STATE(1832), 1,
      sym_template_substitution,
  [76034] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2969), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2971), 1,
      anon_sym_BSLASH,
    ACTIONS(2997), 1,
      anon_sym_DQUOTE,
    STATE(1549), 1,
      sym_comment,
    STATE(1591), 1,
      aux_sym_string_literal_repeat1,
    STATE(1736), 1,
      sym_escape_sequence,
  [76059] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2975), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2977), 1,
      anon_sym_BSLASH,
    ACTIONS(2997), 1,
      anon_sym_SQUOTE,
    STATE(1543), 1,
      aux_sym_string_literal_repeat2,
    STATE(1550), 1,
      sym_comment,
    STATE(1753), 1,
      sym_escape_sequence,
  [76084] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2969), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2971), 1,
      anon_sym_BSLASH,
    ACTIONS(2999), 1,
      anon_sym_DQUOTE,
    STATE(1551), 1,
      sym_comment,
    STATE(1591), 1,
      aux_sym_string_literal_repeat1,
    STATE(1736), 1,
      sym_escape_sequence,
  [76109] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2961), 1,
      anon_sym_DOLLAR,
    ACTIONS(2965), 1,
      sym_template_chars,
    ACTIONS(3001), 1,
      anon_sym_BQUOTE,
    STATE(1552), 1,
      sym_comment,
    STATE(1558), 1,
      aux_sym_template_literal_repeat1,
    STATE(1832), 1,
      sym_template_substitution,
  [76134] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2969), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2971), 1,
      anon_sym_BSLASH,
    ACTIONS(3003), 1,
      anon_sym_DQUOTE,
    STATE(1553), 1,
      sym_comment,
    STATE(1591), 1,
      aux_sym_string_literal_repeat1,
    STATE(1736), 1,
      sym_escape_sequence,
  [76159] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3005), 1,
      sym_identifier,
    STATE(1554), 1,
      sym_comment,
    STATE(1826), 1,
      sym_type_parameters,
    STATE(1931), 1,
      sym_parameter_list,
  [76184] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1555), 1,
      sym_comment,
    ACTIONS(849), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [76201] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2975), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2977), 1,
      anon_sym_BSLASH,
    ACTIONS(3003), 1,
      anon_sym_SQUOTE,
    STATE(1543), 1,
      aux_sym_string_literal_repeat2,
    STATE(1556), 1,
      sym_comment,
    STATE(1753), 1,
      sym_escape_sequence,
  [76226] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2961), 1,
      anon_sym_DOLLAR,
    ACTIONS(2965), 1,
      sym_template_chars,
    ACTIONS(3007), 1,
      anon_sym_BQUOTE,
    STATE(1557), 1,
      sym_comment,
    STATE(1558), 1,
      aux_sym_template_literal_repeat1,
    STATE(1832), 1,
      sym_template_substitution,
  [76251] = 7,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3009), 1,
      anon_sym_DOLLAR,
    ACTIONS(3012), 1,
      anon_sym_BQUOTE,
    ACTIONS(3014), 1,
      sym_template_chars,
    STATE(1832), 1,
      sym_template_substitution,
    STATE(1558), 2,
      sym_comment,
      aux_sym_template_literal_repeat1,
  [76274] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3017), 1,
      sym_identifier,
    STATE(1559), 1,
      sym_comment,
    STATE(1858), 1,
      sym_type_parameters,
    STATE(1977), 1,
      sym_parameter_list,
  [76299] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    ACTIONS(2866), 1,
      anon_sym_extends,
    ACTIONS(2868), 1,
      anon_sym_implements,
    STATE(1353), 1,
      sym_class_body,
    STATE(1560), 1,
      sym_comment,
    STATE(1932), 1,
      sym_implements_clause,
  [76324] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1561), 1,
      sym_comment,
    ACTIONS(845), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [76341] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2975), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2977), 1,
      anon_sym_BSLASH,
    ACTIONS(2999), 1,
      anon_sym_SQUOTE,
    STATE(1543), 1,
      aux_sym_string_literal_repeat2,
    STATE(1562), 1,
      sym_comment,
    STATE(1753), 1,
      sym_escape_sequence,
  [76366] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1563), 1,
      sym_comment,
    ACTIONS(807), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [76383] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3021), 1,
      anon_sym_COLON,
    STATE(1564), 1,
      sym_comment,
    ACTIONS(3019), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
  [76402] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3023), 1,
      sym_identifier,
    STATE(1565), 1,
      sym_comment,
    STATE(1863), 1,
      sym_type_parameters,
    STATE(1926), 1,
      sym_parameter_list,
  [76427] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2969), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2971), 1,
      anon_sym_BSLASH,
    ACTIONS(3025), 1,
      anon_sym_DQUOTE,
    STATE(1566), 1,
      sym_comment,
    STATE(1591), 1,
      aux_sym_string_literal_repeat1,
    STATE(1736), 1,
      sym_escape_sequence,
  [76452] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1567), 1,
      sym_comment,
    ACTIONS(838), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [76469] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2961), 1,
      anon_sym_DOLLAR,
    ACTIONS(2965), 1,
      sym_template_chars,
    ACTIONS(3027), 1,
      anon_sym_BQUOTE,
    STATE(1558), 1,
      aux_sym_template_literal_repeat1,
    STATE(1568), 1,
      sym_comment,
    STATE(1832), 1,
      sym_template_substitution,
  [76494] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1569), 1,
      sym_comment,
    ACTIONS(39), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [76511] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3029), 1,
      sym_identifier,
    STATE(1570), 1,
      sym_comment,
    STATE(1868), 1,
      sym_type_parameters,
    STATE(1988), 1,
      sym_parameter_list,
  [76536] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2975), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2977), 1,
      anon_sym_BSLASH,
    ACTIONS(3031), 1,
      anon_sym_SQUOTE,
    STATE(1562), 1,
      aux_sym_string_literal_repeat2,
    STATE(1571), 1,
      sym_comment,
    STATE(1753), 1,
      sym_escape_sequence,
  [76561] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3033), 1,
      anon_sym_COLON,
    ACTIONS(3035), 1,
      anon_sym_EQ,
    ACTIONS(3037), 1,
      anon_sym_QMARK,
    STATE(1572), 1,
      sym_comment,
    ACTIONS(1623), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [76584] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2969), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2971), 1,
      anon_sym_BSLASH,
    ACTIONS(3039), 1,
      anon_sym_DQUOTE,
    STATE(1573), 1,
      sym_comment,
    STATE(1580), 1,
      aux_sym_string_literal_repeat1,
    STATE(1736), 1,
      sym_escape_sequence,
  [76609] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1574), 1,
      sym_comment,
    ACTIONS(853), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [76626] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3041), 1,
      sym_identifier,
    STATE(1575), 1,
      sym_comment,
    STATE(1657), 1,
      sym_type_parameters,
    STATE(1902), 1,
      sym_parameter_list,
  [76651] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2975), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2977), 1,
      anon_sym_BSLASH,
    ACTIONS(3039), 1,
      anon_sym_SQUOTE,
    STATE(1576), 1,
      sym_comment,
    STATE(1582), 1,
      aux_sym_string_literal_repeat2,
    STATE(1753), 1,
      sym_escape_sequence,
  [76676] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3043), 1,
      sym_identifier,
    STATE(1577), 1,
      sym_comment,
    STATE(1819), 1,
      sym_type_parameters,
    STATE(1972), 1,
      sym_parameter_list,
  [76701] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2961), 1,
      anon_sym_DOLLAR,
    ACTIONS(2965), 1,
      sym_template_chars,
    ACTIONS(3045), 1,
      anon_sym_BQUOTE,
    STATE(1578), 1,
      sym_comment,
    STATE(1583), 1,
      aux_sym_template_literal_repeat1,
    STATE(1832), 1,
      sym_template_substitution,
  [76726] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2969), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2971), 1,
      anon_sym_BSLASH,
    ACTIONS(3031), 1,
      anon_sym_DQUOTE,
    STATE(1551), 1,
      aux_sym_string_literal_repeat1,
    STATE(1579), 1,
      sym_comment,
    STATE(1736), 1,
      sym_escape_sequence,
  [76751] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2969), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2971), 1,
      anon_sym_BSLASH,
    ACTIONS(3047), 1,
      anon_sym_DQUOTE,
    STATE(1580), 1,
      sym_comment,
    STATE(1591), 1,
      aux_sym_string_literal_repeat1,
    STATE(1736), 1,
      sym_escape_sequence,
  [76776] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2961), 1,
      anon_sym_DOLLAR,
    ACTIONS(2965), 1,
      sym_template_chars,
    ACTIONS(3049), 1,
      anon_sym_BQUOTE,
    STATE(1568), 1,
      aux_sym_template_literal_repeat1,
    STATE(1581), 1,
      sym_comment,
    STATE(1832), 1,
      sym_template_substitution,
  [76801] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2975), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2977), 1,
      anon_sym_BSLASH,
    ACTIONS(3047), 1,
      anon_sym_SQUOTE,
    STATE(1543), 1,
      aux_sym_string_literal_repeat2,
    STATE(1582), 1,
      sym_comment,
    STATE(1753), 1,
      sym_escape_sequence,
  [76826] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2961), 1,
      anon_sym_DOLLAR,
    ACTIONS(2965), 1,
      sym_template_chars,
    ACTIONS(3051), 1,
      anon_sym_BQUOTE,
    STATE(1558), 1,
      aux_sym_template_literal_repeat1,
    STATE(1583), 1,
      sym_comment,
    STATE(1832), 1,
      sym_template_substitution,
  [76851] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3053), 1,
      sym_identifier,
    STATE(1584), 1,
      sym_comment,
    STATE(1852), 1,
      sym_type_parameters,
    STATE(1961), 1,
      sym_parameter_list,
  [76876] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1585), 1,
      sym_comment,
    ACTIONS(811), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [76893] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2975), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2977), 1,
      anon_sym_BSLASH,
    ACTIONS(3025), 1,
      anon_sym_SQUOTE,
    STATE(1543), 1,
      aux_sym_string_literal_repeat2,
    STATE(1586), 1,
      sym_comment,
    STATE(1753), 1,
      sym_escape_sequence,
  [76918] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1587), 1,
      sym_comment,
    ACTIONS(749), 5,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
      anon_sym_PIPE,
  [76935] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3057), 1,
      anon_sym_COLON,
    ACTIONS(3059), 1,
      anon_sym_EQ,
    ACTIONS(3061), 1,
      anon_sym_QMARK,
    STATE(1588), 1,
      sym_comment,
    ACTIONS(3055), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [76958] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2969), 1,
      aux_sym_string_literal_token1,
    ACTIONS(2971), 1,
      anon_sym_BSLASH,
    ACTIONS(3063), 1,
      anon_sym_DQUOTE,
    STATE(1566), 1,
      aux_sym_string_literal_repeat1,
    STATE(1589), 1,
      sym_comment,
    STATE(1736), 1,
      sym_escape_sequence,
  [76983] = 8,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2975), 1,
      aux_sym_string_literal_token2,
    ACTIONS(2977), 1,
      anon_sym_BSLASH,
    ACTIONS(3063), 1,
      anon_sym_SQUOTE,
    STATE(1586), 1,
      aux_sym_string_literal_repeat2,
    STATE(1590), 1,
      sym_comment,
    STATE(1753), 1,
      sym_escape_sequence,
  [77008] = 7,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3065), 1,
      anon_sym_DQUOTE,
    ACTIONS(3067), 1,
      aux_sym_string_literal_token1,
    ACTIONS(3070), 1,
      anon_sym_BSLASH,
    STATE(1736), 1,
      sym_escape_sequence,
    STATE(1591), 2,
      sym_comment,
      aux_sym_string_literal_repeat1,
  [77031] = 8,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2722), 1,
      anon_sym_static,
    ACTIONS(2724), 1,
      anon_sym_readonly,
    ACTIONS(2726), 1,
      sym_identifier,
    ACTIONS(2728), 1,
      anon_sym_async,
    ACTIONS(3073), 1,
      anon_sym_constructor,
    STATE(1592), 1,
      sym_comment,
  [77056] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1593), 1,
      sym_comment,
    STATE(1639), 1,
      sym_parameter_list,
    STATE(1938), 1,
      sym_type_parameters,
  [77078] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3075), 1,
      anon_sym_LBRACE,
    ACTIONS(3077), 1,
      anon_sym_COLON,
    STATE(1594), 1,
      sym_comment,
    STATE(1298), 2,
      sym_block_statement,
      sym_extend_function_body,
  [77098] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3079), 1,
      anon_sym_RBRACE,
    ACTIONS(3081), 1,
      anon_sym_DOT,
    STATE(1950), 1,
      sym_modifier_chain_expression,
    STATE(1595), 2,
      sym_comment,
      aux_sym_extend_function_body_repeat1,
  [77118] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(3084), 1,
      anon_sym_LBRACE,
    STATE(1303), 1,
      sym_component_body,
    STATE(1596), 1,
      sym_comment,
    STATE(2001), 1,
      sym_type_parameters,
  [77140] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3086), 1,
      anon_sym_RBRACE,
    ACTIONS(3088), 1,
      sym_identifier,
    STATE(1614), 1,
      sym_type_member,
    STATE(1597), 2,
      sym_comment,
      aux_sym_object_type_repeat1,
  [77160] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3093), 1,
      anon_sym_SEMI,
    ACTIONS(3095), 1,
      anon_sym_COLON,
    STATE(1430), 1,
      sym_block_statement,
    STATE(1598), 1,
      sym_comment,
  [77182] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    ACTIONS(2868), 1,
      anon_sym_implements,
    STATE(1329), 1,
      sym_class_body,
    STATE(1599), 1,
      sym_comment,
    STATE(1949), 1,
      sym_implements_clause,
  [77204] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1600), 1,
      sym_comment,
    STATE(1621), 1,
      sym_parameter_list,
    STATE(1955), 1,
      sym_type_parameters,
  [77226] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1601), 1,
      sym_comment,
    ACTIONS(3097), 4,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_EQ,
      sym_identifier,
  [77242] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3099), 1,
      anon_sym_SEMI,
    ACTIONS(3101), 1,
      anon_sym_COLON,
    STATE(1451), 1,
      sym_block_statement,
    STATE(1602), 1,
      sym_comment,
  [77264] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3103), 1,
      anon_sym_LBRACE,
    ACTIONS(3105), 1,
      sym_identifier,
    STATE(1603), 1,
      sym_comment,
    STATE(1835), 1,
      sym_generic_type,
    STATE(1969), 1,
      sym_qualified_type,
  [77286] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(3084), 1,
      anon_sym_LBRACE,
    STATE(1307), 1,
      sym_component_body,
    STATE(1604), 1,
      sym_comment,
    STATE(1974), 1,
      sym_type_parameters,
  [77308] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3075), 1,
      anon_sym_LBRACE,
    ACTIONS(3107), 1,
      anon_sym_COLON,
    STATE(1605), 1,
      sym_comment,
    STATE(1359), 2,
      sym_block_statement,
      sym_extend_function_body,
  [77328] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3109), 1,
      anon_sym_SEMI,
    ACTIONS(3111), 1,
      anon_sym_COLON,
    STATE(1444), 1,
      sym_block_statement,
    STATE(1606), 1,
      sym_comment,
  [77350] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1607), 1,
      sym_comment,
    ACTIONS(3113), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
  [77366] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3117), 1,
      anon_sym_COLON,
    ACTIONS(3119), 1,
      anon_sym_EQ,
    STATE(1608), 1,
      sym_comment,
    ACTIONS(3115), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [77386] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1609), 1,
      sym_comment,
    STATE(1645), 1,
      sym_parameter_list,
    STATE(1994), 1,
      sym_type_parameters,
  [77408] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1446), 1,
      anon_sym_RPAREN,
    ACTIONS(1450), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(3121), 1,
      sym_identifier,
    STATE(1610), 1,
      sym_comment,
    STATE(1728), 1,
      sym_parameter,
  [77430] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3123), 1,
      anon_sym_COMMA,
    ACTIONS(3125), 1,
      anon_sym_RBRACE,
    ACTIONS(3127), 1,
      sym_identifier,
    STATE(1611), 1,
      sym_comment,
    STATE(1714), 1,
      sym_enum_member,
  [77452] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    ACTIONS(2868), 1,
      anon_sym_implements,
    STATE(1322), 1,
      sym_class_body,
    STATE(1612), 1,
      sym_comment,
    STATE(1911), 1,
      sym_implements_clause,
  [77474] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    ACTIONS(2868), 1,
      anon_sym_implements,
    STATE(1344), 1,
      sym_class_body,
    STATE(1613), 1,
      sym_comment,
    STATE(1915), 1,
      sym_implements_clause,
  [77496] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1614), 1,
      sym_comment,
    ACTIONS(3129), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(3131), 2,
      anon_sym_RBRACE,
      sym_identifier,
  [77514] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3133), 1,
      anon_sym_EQ,
    ACTIONS(3135), 1,
      anon_sym_EQ_GT,
    STATE(1615), 1,
      sym_comment,
    ACTIONS(2075), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [77534] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1605), 1,
      sym_parameter_list,
    STATE(1616), 1,
      sym_comment,
    STATE(1954), 1,
      sym_type_parameters,
  [77556] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3137), 1,
      anon_sym_SEMI,
    ACTIONS(3139), 1,
      anon_sym_COLON,
    STATE(1405), 1,
      sym_block_statement,
    STATE(1617), 1,
      sym_comment,
  [77578] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3141), 1,
      anon_sym_static,
    ACTIONS(3143), 1,
      anon_sym_readonly,
    ACTIONS(3145), 1,
      sym_identifier,
    ACTIONS(3147), 1,
      anon_sym_async,
    STATE(1618), 1,
      sym_comment,
  [77600] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3057), 1,
      anon_sym_COLON,
    ACTIONS(3059), 1,
      anon_sym_EQ,
    STATE(1619), 1,
      sym_comment,
    ACTIONS(3055), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [77620] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3149), 1,
      anon_sym_RBRACE,
    ACTIONS(3151), 1,
      sym_identifier,
    STATE(1597), 1,
      aux_sym_object_type_repeat1,
    STATE(1614), 1,
      sym_type_member,
    STATE(1620), 1,
      sym_comment,
  [77642] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3075), 1,
      anon_sym_LBRACE,
    ACTIONS(3153), 1,
      anon_sym_COLON,
    STATE(1621), 1,
      sym_comment,
    STATE(1315), 2,
      sym_block_statement,
      sym_extend_function_body,
  [77662] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1606), 1,
      sym_parameter_list,
    STATE(1622), 1,
      sym_comment,
    STATE(1958), 1,
      sym_type_parameters,
  [77684] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1623), 1,
      sym_comment,
    ACTIONS(3155), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [77700] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1624), 1,
      sym_comment,
    STATE(1647), 1,
      sym_parameter_list,
    STATE(1943), 1,
      sym_type_parameters,
  [77722] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(3084), 1,
      anon_sym_LBRACE,
    STATE(1330), 1,
      sym_component_body,
    STATE(1625), 1,
      sym_comment,
    STATE(1983), 1,
      sym_type_parameters,
  [77744] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3157), 1,
      anon_sym_COLON,
    ACTIONS(3159), 1,
      anon_sym_EQ,
    STATE(1626), 1,
      sym_comment,
    ACTIONS(2075), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [77764] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1627), 1,
      sym_comment,
    ACTIONS(3161), 4,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_EQ,
      sym_identifier,
  [77780] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3151), 1,
      sym_identifier,
    ACTIONS(3163), 1,
      anon_sym_RBRACE,
    STATE(1614), 1,
      sym_type_member,
    STATE(1620), 1,
      aux_sym_object_type_repeat1,
    STATE(1628), 1,
      sym_comment,
  [77802] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3167), 1,
      anon_sym_SEMI,
    ACTIONS(3169), 1,
      anon_sym_COLON,
    STATE(1399), 1,
      sym_block_statement,
    STATE(1629), 1,
      sym_comment,
  [77824] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3171), 1,
      anon_sym_SEMI,
    ACTIONS(3173), 1,
      sym_identifier,
    ACTIONS(3175), 1,
      anon_sym_enum,
    STATE(1630), 1,
      sym_comment,
    STATE(1818), 1,
      sym_variable_declarator,
  [77846] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1602), 1,
      sym_parameter_list,
    STATE(1631), 1,
      sym_comment,
    STATE(1985), 1,
      sym_type_parameters,
  [77868] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1632), 1,
      sym_comment,
    STATE(1642), 1,
      sym_parameter_list,
    STATE(1984), 1,
      sym_type_parameters,
  [77890] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    ACTIONS(2868), 1,
      anon_sym_implements,
    STATE(1341), 1,
      sym_class_body,
    STATE(1633), 1,
      sym_comment,
    STATE(1967), 1,
      sym_implements_clause,
  [77912] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1634), 1,
      sym_comment,
    STATE(1650), 1,
      sym_parameter_list,
    STATE(2002), 1,
      sym_type_parameters,
  [77934] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3179), 1,
      anon_sym_EQ,
    ACTIONS(3181), 1,
      anon_sym_extends,
    STATE(1635), 1,
      sym_comment,
    ACTIONS(3177), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [77954] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1636), 1,
      sym_comment,
    ACTIONS(3183), 4,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_EQ,
      sym_identifier,
  [77970] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2760), 1,
      anon_sym_static,
    ACTIONS(2762), 1,
      anon_sym_readonly,
    ACTIONS(2764), 1,
      sym_identifier,
    ACTIONS(2766), 1,
      anon_sym_async,
    STATE(1637), 1,
      sym_comment,
  [77992] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(3084), 1,
      anon_sym_LBRACE,
    STATE(1304), 1,
      sym_component_body,
    STATE(1638), 1,
      sym_comment,
    STATE(1992), 1,
      sym_type_parameters,
  [78014] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3185), 1,
      anon_sym_SEMI,
    ACTIONS(3187), 1,
      anon_sym_COLON,
    STATE(1422), 1,
      sym_block_statement,
    STATE(1639), 1,
      sym_comment,
  [78036] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3189), 1,
      anon_sym_SEMI,
    ACTIONS(3191), 1,
      anon_sym_COLON,
    STATE(1428), 1,
      sym_block_statement,
    STATE(1640), 1,
      sym_comment,
  [78058] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3193), 1,
      anon_sym_static,
    ACTIONS(3195), 1,
      anon_sym_readonly,
    ACTIONS(3197), 1,
      sym_identifier,
    ACTIONS(3199), 1,
      anon_sym_async,
    STATE(1641), 1,
      sym_comment,
  [78080] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3075), 1,
      anon_sym_LBRACE,
    ACTIONS(3201), 1,
      anon_sym_COLON,
    STATE(1642), 1,
      sym_comment,
    STATE(1338), 2,
      sym_block_statement,
      sym_extend_function_body,
  [78100] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1643), 1,
      sym_comment,
    ACTIONS(2991), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
  [78116] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3203), 1,
      anon_sym_SEMI,
    ACTIONS(3205), 1,
      anon_sym_COLON,
    STATE(1455), 1,
      sym_block_statement,
    STATE(1644), 1,
      sym_comment,
  [78138] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3207), 1,
      anon_sym_SEMI,
    ACTIONS(3209), 1,
      anon_sym_COLON,
    STATE(1409), 1,
      sym_block_statement,
    STATE(1645), 1,
      sym_comment,
  [78160] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1598), 1,
      sym_parameter_list,
    STATE(1646), 1,
      sym_comment,
    STATE(1924), 1,
      sym_type_parameters,
  [78182] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3211), 1,
      anon_sym_SEMI,
    ACTIONS(3213), 1,
      anon_sym_COLON,
    STATE(1431), 1,
      sym_block_statement,
    STATE(1647), 1,
      sym_comment,
  [78204] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1648), 1,
      sym_comment,
    ACTIONS(3215), 4,
      aux_sym_escape_sequence_token1,
      aux_sym_escape_sequence_token2,
      aux_sym_escape_sequence_token3,
      aux_sym_escape_sequence_token4,
  [78220] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1229), 1,
      anon_sym_DOT,
    ACTIONS(3217), 1,
      anon_sym_RBRACE,
    STATE(1595), 1,
      aux_sym_extend_function_body_repeat1,
    STATE(1649), 1,
      sym_comment,
    STATE(1950), 1,
      sym_modifier_chain_expression,
  [78242] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3219), 1,
      anon_sym_SEMI,
    ACTIONS(3221), 1,
      anon_sym_COLON,
    STATE(1438), 1,
      sym_block_statement,
    STATE(1650), 1,
      sym_comment,
  [78264] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3223), 1,
      anon_sym_COMMA,
    ACTIONS(3225), 1,
      anon_sym_RBRACE,
    ACTIONS(3227), 1,
      anon_sym_as,
    STATE(1651), 1,
      sym_comment,
    STATE(1682), 1,
      aux_sym_export_declaration_repeat1,
  [78286] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1652), 1,
      sym_comment,
    ACTIONS(3229), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
  [78302] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1653), 1,
      sym_comment,
    ACTIONS(3113), 4,
      anon_sym_COMMA,
      anon_sym_RBRACE,
      anon_sym_SEMI,
      sym_identifier,
  [78318] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(3231), 1,
      anon_sym_LBRACE,
    STATE(1306), 1,
      sym_object_type,
    STATE(1654), 1,
      sym_comment,
    STATE(1976), 1,
      sym_type_parameters,
  [78340] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3233), 1,
      anon_sym_SEMI,
    ACTIONS(3235), 1,
      anon_sym_COLON,
    STATE(1445), 1,
      sym_block_statement,
    STATE(1655), 1,
      sym_comment,
  [78362] = 7,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1640), 1,
      sym_parameter_list,
    STATE(1656), 1,
      sym_comment,
    STATE(1940), 1,
      sym_type_parameters,
  [78384] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3237), 1,
      sym_identifier,
    STATE(1657), 1,
      sym_comment,
    STATE(1891), 1,
      sym_parameter_list,
  [78403] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3223), 1,
      anon_sym_COMMA,
    ACTIONS(3239), 1,
      anon_sym_RBRACE,
    STATE(1658), 1,
      sym_comment,
    STATE(1701), 1,
      aux_sym_export_declaration_repeat1,
  [78422] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(3241), 1,
      anon_sym_RPAREN,
    STATE(1659), 1,
      sym_comment,
    STATE(1880), 1,
      aux_sym_argument_list_repeat1,
  [78441] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3245), 1,
      anon_sym_GT,
    STATE(1660), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [78460] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(2017), 1,
      anon_sym_RPAREN,
    STATE(1661), 1,
      sym_comment,
    STATE(1731), 1,
      aux_sym_argument_list_repeat1,
  [78479] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2144), 1,
      anon_sym_SEMI,
    ACTIONS(2919), 1,
      anon_sym_COLON,
    ACTIONS(2921), 1,
      anon_sym_EQ,
    STATE(1662), 1,
      sym_comment,
  [78498] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1357), 1,
      sym_string_literal,
    STATE(1663), 1,
      sym_comment,
  [78517] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3249), 1,
      anon_sym_RBRACK,
    STATE(1664), 1,
      sym_comment,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
  [78536] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3251), 1,
      anon_sym_RPAREN,
    STATE(1665), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
  [78555] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3253), 1,
      anon_sym_RPAREN,
    STATE(1666), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
  [78574] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3255), 1,
      anon_sym_COMMA,
    ACTIONS(3258), 1,
      anon_sym_RBRACK,
    STATE(1667), 2,
      sym_comment,
      aux_sym_type_arguments_repeat1,
  [78591] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2154), 1,
      anon_sym_SEMI,
    ACTIONS(2923), 1,
      anon_sym_COLON,
    ACTIONS(2925), 1,
      anon_sym_EQ,
    STATE(1668), 1,
      sym_comment,
  [78610] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3260), 1,
      anon_sym_LBRACE,
    ACTIONS(3262), 1,
      anon_sym_LPAREN,
    STATE(899), 1,
      sym_block_statement,
    STATE(1669), 1,
      sym_comment,
  [78629] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3189), 1,
      anon_sym_SEMI,
    STATE(1428), 1,
      sym_block_statement,
    STATE(1670), 1,
      sym_comment,
  [78648] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3264), 1,
      anon_sym_LBRACE,
    ACTIONS(3266), 1,
      anon_sym_LPAREN,
    STATE(857), 1,
      sym_block_statement,
    STATE(1671), 1,
      sym_comment,
  [78667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3268), 1,
      anon_sym_RPAREN,
    STATE(1672), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
  [78686] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3211), 1,
      anon_sym_SEMI,
    STATE(1431), 1,
      sym_block_statement,
    STATE(1673), 1,
      sym_comment,
  [78705] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2156), 1,
      anon_sym_SEMI,
    ACTIONS(3270), 1,
      anon_sym_COLON,
    ACTIONS(3272), 1,
      anon_sym_EQ,
    STATE(1674), 1,
      sym_comment,
  [78724] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1331), 1,
      sym_string_literal,
    STATE(1675), 1,
      sym_comment,
  [78743] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3219), 1,
      anon_sym_SEMI,
    STATE(1438), 1,
      sym_block_statement,
    STATE(1676), 1,
      sym_comment,
  [78762] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3274), 1,
      anon_sym_COMMA,
    ACTIONS(3276), 1,
      anon_sym_SEMI,
    STATE(1677), 1,
      sym_comment,
    STATE(1839), 1,
      aux_sym_variable_declaration_repeat1,
  [78781] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3278), 1,
      anon_sym_COMMA,
    ACTIONS(3281), 1,
      anon_sym_RBRACE,
    STATE(1678), 2,
      sym_comment,
      aux_sym_object_literal_repeat1,
  [78798] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3233), 1,
      anon_sym_SEMI,
    STATE(1445), 1,
      sym_block_statement,
    STATE(1679), 1,
      sym_comment,
  [78817] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3283), 1,
      anon_sym_RBRACE,
    ACTIONS(3285), 1,
      sym_identifier,
    STATE(1680), 1,
      sym_comment,
    STATE(1719), 1,
      sym_component_parameter,
  [78836] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3287), 1,
      anon_sym_SEMI,
    STATE(1397), 1,
      sym_block_statement,
    STATE(1681), 1,
      sym_comment,
  [78855] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3223), 1,
      anon_sym_COMMA,
    ACTIONS(3289), 1,
      anon_sym_RBRACE,
    STATE(1682), 1,
      sym_comment,
    STATE(1701), 1,
      aux_sym_export_declaration_repeat1,
  [78874] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    ACTIONS(3291), 1,
      anon_sym_SEMI,
    STATE(1425), 1,
      sym_block_statement,
    STATE(1683), 1,
      sym_comment,
  [78893] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3293), 1,
      anon_sym_COMMA,
    ACTIONS(3296), 1,
      anon_sym_RPAREN,
    STATE(1684), 2,
      sym_comment,
      aux_sym_parameter_list_repeat1,
  [78910] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3298), 1,
      anon_sym_COMMA,
    ACTIONS(3301), 1,
      anon_sym_RBRACE,
    STATE(1685), 2,
      sym_comment,
      aux_sym_import_declaration_repeat1,
  [78927] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3303), 1,
      anon_sym_GT,
    STATE(1686), 1,
      sym_comment,
    STATE(1734), 1,
      aux_sym_type_arguments_repeat1,
  [78946] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1380), 1,
      anon_sym_COLON,
    STATE(1687), 1,
      sym_comment,
    ACTIONS(329), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [78963] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3307), 1,
      anon_sym_EQ,
    STATE(1688), 1,
      sym_comment,
    ACTIONS(3305), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [78980] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1689), 1,
      sym_comment,
    ACTIONS(3183), 3,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_implements,
  [78995] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3311), 1,
      anon_sym_as,
    STATE(1690), 1,
      sym_comment,
    ACTIONS(3309), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [79012] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1365), 1,
      sym_string_literal,
    STATE(1691), 1,
      sym_comment,
  [79031] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3313), 1,
      anon_sym_SEMI,
    ACTIONS(3315), 1,
      sym_identifier,
    STATE(1692), 1,
      sym_comment,
    STATE(1693), 1,
      sym_variable_declarator,
  [79050] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3274), 1,
      anon_sym_COMMA,
    ACTIONS(3317), 1,
      anon_sym_SEMI,
    STATE(1693), 1,
      sym_comment,
    STATE(1697), 1,
      aux_sym_variable_declaration_repeat1,
  [79069] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3075), 1,
      anon_sym_LBRACE,
    STATE(1694), 1,
      sym_comment,
    STATE(1360), 2,
      sym_block_statement,
      sym_extend_function_body,
  [79086] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3319), 1,
      anon_sym_COMMA,
    ACTIONS(3322), 1,
      anon_sym_GT,
    STATE(1695), 2,
      sym_comment,
      aux_sym_type_parameters_repeat1,
  [79103] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3223), 1,
      anon_sym_COMMA,
    ACTIONS(3324), 1,
      anon_sym_RBRACE,
    STATE(1658), 1,
      aux_sym_export_declaration_repeat1,
    STATE(1696), 1,
      sym_comment,
  [79122] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3274), 1,
      anon_sym_COMMA,
    ACTIONS(3326), 1,
      anon_sym_SEMI,
    STATE(1697), 1,
      sym_comment,
    STATE(1839), 1,
      aux_sym_variable_declaration_repeat1,
  [79141] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3328), 1,
      anon_sym_COMMA,
    ACTIONS(3330), 1,
      anon_sym_RBRACE,
    STATE(1698), 1,
      sym_comment,
    STATE(1706), 1,
      aux_sym_object_literal_repeat1,
  [79160] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3332), 1,
      anon_sym_RPAREN,
    STATE(1699), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
  [79179] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3195), 1,
      anon_sym_readonly,
    ACTIONS(3197), 1,
      sym_identifier,
    ACTIONS(3199), 1,
      anon_sym_async,
    STATE(1700), 1,
      sym_comment,
  [79198] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3309), 1,
      anon_sym_RBRACE,
    ACTIONS(3334), 1,
      anon_sym_COMMA,
    STATE(1701), 2,
      sym_comment,
      aux_sym_export_declaration_repeat1,
  [79215] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(2033), 1,
      anon_sym_RBRACK,
    STATE(1702), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [79234] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3093), 1,
      anon_sym_SEMI,
    STATE(1430), 1,
      sym_block_statement,
    STATE(1703), 1,
      sym_comment,
  [79253] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3337), 1,
      anon_sym_COMMA,
    ACTIONS(3339), 1,
      anon_sym_RBRACE,
    STATE(1704), 1,
      sym_comment,
    STATE(1726), 1,
      aux_sym_object_literal_repeat1,
  [79272] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2878), 1,
      anon_sym_SEMI,
    ACTIONS(2880), 1,
      anon_sym_COLON,
    ACTIONS(2882), 1,
      anon_sym_EQ,
    STATE(1705), 1,
      sym_comment,
  [79291] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2804), 1,
      anon_sym_RBRACE,
    ACTIONS(3341), 1,
      anon_sym_COMMA,
    STATE(1678), 1,
      aux_sym_object_literal_repeat1,
    STATE(1706), 1,
      sym_comment,
  [79310] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(3343), 1,
      anon_sym_RBRACK,
    STATE(1707), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [79329] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(2041), 1,
      anon_sym_RBRACK,
    STATE(1708), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [79348] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(2045), 1,
      anon_sym_RPAREN,
    STATE(1709), 1,
      sym_comment,
    STATE(1717), 1,
      aux_sym_argument_list_repeat1,
  [79367] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3345), 1,
      anon_sym_GT,
    STATE(1710), 1,
      sym_comment,
    STATE(1718), 1,
      aux_sym_type_arguments_repeat1,
  [79386] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3349), 1,
      anon_sym_EQ,
    STATE(1711), 1,
      sym_comment,
    ACTIONS(3347), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [79403] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3351), 1,
      anon_sym_SEMI,
    STATE(1426), 1,
      sym_block_statement,
    STATE(1712), 1,
      sym_comment,
  [79422] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3353), 1,
      anon_sym_RBRACK,
    STATE(1713), 1,
      sym_comment,
    STATE(1720), 1,
      aux_sym_type_arguments_repeat1,
  [79441] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3355), 1,
      anon_sym_COMMA,
    ACTIONS(3357), 1,
      anon_sym_RBRACE,
    STATE(1714), 1,
      sym_comment,
    STATE(1778), 1,
      aux_sym_enum_body_repeat1,
  [79460] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3359), 1,
      anon_sym_COLON,
    STATE(1715), 1,
      sym_comment,
    ACTIONS(329), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [79477] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(3361), 1,
      anon_sym_RBRACK,
    STATE(1716), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [79496] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(3363), 1,
      anon_sym_RPAREN,
    STATE(1717), 1,
      sym_comment,
    STATE(1880), 1,
      aux_sym_argument_list_repeat1,
  [79515] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3365), 1,
      anon_sym_GT,
    STATE(1718), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [79534] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3367), 1,
      anon_sym_COMMA,
    ACTIONS(3369), 1,
      anon_sym_RBRACE,
    STATE(1719), 1,
      sym_comment,
    STATE(1783), 1,
      aux_sym_component_parameters_repeat1,
  [79553] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3371), 1,
      anon_sym_RBRACK,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1720), 1,
      sym_comment,
  [79572] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3373), 1,
      anon_sym_RPAREN,
    STATE(1721), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
  [79591] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3375), 1,
      anon_sym_RPAREN,
    STATE(1722), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
  [79610] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3377), 1,
      anon_sym_RPAREN,
    STATE(1723), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
  [79629] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3315), 1,
      sym_identifier,
    ACTIONS(3379), 1,
      anon_sym_SEMI,
    STATE(1724), 1,
      sym_comment,
    STATE(1725), 1,
      sym_variable_declarator,
  [79648] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3274), 1,
      anon_sym_COMMA,
    ACTIONS(3381), 1,
      anon_sym_SEMI,
    STATE(1725), 1,
      sym_comment,
    STATE(1729), 1,
      aux_sym_variable_declaration_repeat1,
  [79667] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2806), 1,
      anon_sym_RBRACE,
    ACTIONS(3383), 1,
      anon_sym_COMMA,
    STATE(1678), 1,
      aux_sym_object_literal_repeat1,
    STATE(1726), 1,
      sym_comment,
  [79686] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3171), 1,
      anon_sym_SEMI,
    ACTIONS(3315), 1,
      sym_identifier,
    STATE(1727), 1,
      sym_comment,
    STATE(1818), 1,
      sym_variable_declarator,
  [79705] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3385), 1,
      anon_sym_COMMA,
    ACTIONS(3387), 1,
      anon_sym_RPAREN,
    STATE(1728), 1,
      sym_comment,
    STATE(1757), 1,
      aux_sym_parameter_list_repeat1,
  [79724] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3274), 1,
      anon_sym_COMMA,
    ACTIONS(3389), 1,
      anon_sym_SEMI,
    STATE(1729), 1,
      sym_comment,
    STATE(1839), 1,
      aux_sym_variable_declaration_repeat1,
  [79743] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3391), 1,
      anon_sym_COMMA,
    ACTIONS(3393), 1,
      anon_sym_RBRACE,
    STATE(1730), 1,
      sym_comment,
    STATE(1733), 1,
      aux_sym_object_literal_repeat1,
  [79762] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(3395), 1,
      anon_sym_RPAREN,
    STATE(1731), 1,
      sym_comment,
    STATE(1880), 1,
      aux_sym_argument_list_repeat1,
  [79781] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(2027), 1,
      anon_sym_RBRACK,
    STATE(1732), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [79800] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2677), 1,
      anon_sym_RBRACE,
    ACTIONS(3397), 1,
      anon_sym_COMMA,
    STATE(1678), 1,
      aux_sym_object_literal_repeat1,
    STATE(1733), 1,
      sym_comment,
  [79819] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3399), 1,
      anon_sym_GT,
    STATE(1734), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [79838] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(2049), 1,
      anon_sym_RBRACK,
    STATE(1735), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [79857] = 4,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    STATE(1736), 1,
      sym_comment,
    ACTIONS(3401), 3,
      anon_sym_DQUOTE,
      aux_sym_string_literal_token1,
      anon_sym_BSLASH,
  [79872] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(2037), 1,
      anon_sym_RPAREN,
    STATE(1737), 1,
      sym_comment,
    STATE(1744), 1,
      aux_sym_argument_list_repeat1,
  [79891] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3403), 1,
      anon_sym_RPAREN,
    STATE(1738), 1,
      sym_comment,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
  [79910] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3405), 1,
      anon_sym_GT,
    STATE(1739), 1,
      sym_comment,
    STATE(1745), 1,
      aux_sym_type_arguments_repeat1,
  [79929] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3407), 1,
      anon_sym_RBRACK,
    STATE(1740), 1,
      sym_comment,
    STATE(1746), 1,
      aux_sym_type_arguments_repeat1,
  [79948] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2095), 1,
      anon_sym_RPAREN,
    ACTIONS(3409), 1,
      anon_sym_COMMA,
    STATE(1741), 2,
      sym_comment,
      aux_sym_decorator_repeat1,
  [79965] = 4,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    STATE(1742), 1,
      sym_comment,
    ACTIONS(3412), 3,
      anon_sym_SQUOTE,
      aux_sym_string_literal_token2,
      anon_sym_BSLASH,
  [79980] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(3414), 1,
      anon_sym_RBRACK,
    STATE(1743), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [79999] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(3416), 1,
      anon_sym_RPAREN,
    STATE(1744), 1,
      sym_comment,
    STATE(1880), 1,
      aux_sym_argument_list_repeat1,
  [80018] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3418), 1,
      anon_sym_GT,
    STATE(1745), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [80037] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3420), 1,
      anon_sym_RBRACK,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1746), 1,
      sym_comment,
  [80056] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3422), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1747), 1,
      sym_comment,
  [80075] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3424), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1748), 1,
      sym_comment,
  [80094] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2192), 1,
      anon_sym_SEMI,
    ACTIONS(2899), 1,
      anon_sym_COLON,
    ACTIONS(2901), 1,
      anon_sym_EQ,
    STATE(1749), 1,
      sym_comment,
  [80113] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3426), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1750), 1,
      sym_comment,
  [80132] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1751), 1,
      sym_comment,
    ACTIONS(3097), 3,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_implements,
  [80147] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3428), 1,
      anon_sym_RBRACK,
    STATE(1752), 1,
      sym_comment,
    STATE(1777), 1,
      aux_sym_type_arguments_repeat1,
  [80166] = 4,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    STATE(1753), 1,
      sym_comment,
    ACTIONS(3430), 3,
      anon_sym_SQUOTE,
      aux_sym_string_literal_token2,
      anon_sym_BSLASH,
  [80181] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3432), 1,
      anon_sym_COMMA,
    ACTIONS(3434), 1,
      anon_sym_RBRACE,
    STATE(1754), 1,
      sym_comment,
    STATE(1760), 1,
      aux_sym_object_literal_repeat1,
  [80200] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1450), 1,
      anon_sym_DOT_DOT_DOT,
    ACTIONS(3121), 1,
      sym_identifier,
    STATE(1755), 1,
      sym_comment,
    STATE(1900), 1,
      sym_parameter,
  [80219] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(2061), 1,
      anon_sym_RBRACK,
    STATE(1756), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [80238] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3385), 1,
      anon_sym_COMMA,
    ACTIONS(3436), 1,
      anon_sym_RPAREN,
    STATE(1684), 1,
      aux_sym_parameter_list_repeat1,
    STATE(1757), 1,
      sym_comment,
  [80257] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3438), 1,
      sym_identifier,
    ACTIONS(3440), 1,
      anon_sym_GT,
    STATE(1758), 1,
      sym_comment,
    STATE(1780), 1,
      sym_type_parameter,
  [80276] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3442), 1,
      anon_sym_LBRACE,
    ACTIONS(3444), 1,
      anon_sym_COLON,
    STATE(1443), 1,
      sym_build_body,
    STATE(1759), 1,
      sym_comment,
  [80295] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2685), 1,
      anon_sym_RBRACE,
    ACTIONS(3446), 1,
      anon_sym_COMMA,
    STATE(1678), 1,
      aux_sym_object_literal_repeat1,
    STATE(1760), 1,
      sym_comment,
  [80314] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3448), 1,
      anon_sym_LBRACE,
    ACTIONS(3450), 1,
      anon_sym_STAR,
    ACTIONS(3452), 1,
      sym_identifier,
    STATE(1761), 1,
      sym_comment,
  [80333] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(2067), 1,
      anon_sym_RBRACK,
    STATE(1762), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [80352] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3109), 1,
      anon_sym_SEMI,
    STATE(1444), 1,
      sym_block_statement,
    STATE(1763), 1,
      sym_comment,
  [80371] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(2021), 1,
      anon_sym_RPAREN,
    STATE(1764), 1,
      sym_comment,
    STATE(1770), 1,
      aux_sym_argument_list_repeat1,
  [80390] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3454), 1,
      anon_sym_GT,
    STATE(1765), 1,
      sym_comment,
    STATE(1771), 1,
      aux_sym_type_arguments_repeat1,
  [80409] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3456), 1,
      anon_sym_readonly,
    ACTIONS(3458), 1,
      sym_identifier,
    ACTIONS(3460), 1,
      anon_sym_async,
    STATE(1766), 1,
      sym_comment,
  [80428] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3462), 1,
      anon_sym_RBRACK,
    STATE(1767), 1,
      sym_comment,
    STATE(1772), 1,
      aux_sym_type_arguments_repeat1,
  [80447] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3075), 1,
      anon_sym_LBRACE,
    STATE(1768), 1,
      sym_comment,
    STATE(1298), 2,
      sym_block_statement,
      sym_extend_function_body,
  [80464] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(3464), 1,
      anon_sym_RBRACK,
    STATE(1769), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [80483] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(3466), 1,
      anon_sym_RPAREN,
    STATE(1770), 1,
      sym_comment,
    STATE(1880), 1,
      aux_sym_argument_list_repeat1,
  [80502] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3468), 1,
      anon_sym_GT,
    STATE(1771), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [80521] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3470), 1,
      anon_sym_RBRACK,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1772), 1,
      sym_comment,
  [80540] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3472), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1773), 1,
      sym_comment,
  [80559] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3474), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1774), 1,
      sym_comment,
  [80578] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3476), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1775), 1,
      sym_comment,
  [80597] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3127), 1,
      sym_identifier,
    ACTIONS(3478), 1,
      anon_sym_RBRACE,
    STATE(1776), 1,
      sym_comment,
    STATE(1913), 1,
      sym_enum_member,
  [80616] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3480), 1,
      anon_sym_RBRACK,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1777), 1,
      sym_comment,
  [80635] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3478), 1,
      anon_sym_RBRACE,
    ACTIONS(3482), 1,
      anon_sym_COMMA,
    STATE(1778), 1,
      sym_comment,
    STATE(1795), 1,
      aux_sym_enum_body_repeat1,
  [80654] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3207), 1,
      anon_sym_SEMI,
    STATE(1409), 1,
      sym_block_statement,
    STATE(1779), 1,
      sym_comment,
  [80673] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3484), 1,
      anon_sym_COMMA,
    ACTIONS(3486), 1,
      anon_sym_GT,
    STATE(1780), 1,
      sym_comment,
    STATE(1833), 1,
      aux_sym_type_parameters_repeat1,
  [80692] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3488), 1,
      anon_sym_GT,
    STATE(1781), 1,
      sym_comment,
    STATE(1784), 1,
      aux_sym_type_arguments_repeat1,
  [80711] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3490), 1,
      anon_sym_RBRACK,
    STATE(1782), 1,
      sym_comment,
    STATE(1890), 1,
      aux_sym_type_arguments_repeat1,
  [80730] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3367), 1,
      anon_sym_COMMA,
    ACTIONS(3492), 1,
      anon_sym_RBRACE,
    STATE(1783), 1,
      sym_comment,
    STATE(1827), 1,
      aux_sym_component_parameters_repeat1,
  [80749] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3494), 1,
      anon_sym_GT,
    STATE(1784), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [80768] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(3496), 1,
      anon_sym_RBRACK,
    STATE(1785), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [80787] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3498), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1786), 1,
      sym_comment,
  [80806] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1333), 1,
      sym_string_literal,
    STATE(1787), 1,
      sym_comment,
  [80825] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3500), 1,
      anon_sym_GT,
    STATE(1788), 1,
      sym_comment,
    STATE(1790), 1,
      aux_sym_type_arguments_repeat1,
  [80844] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3502), 1,
      anon_sym_RBRACK,
    STATE(1789), 1,
      sym_comment,
    STATE(1791), 1,
      aux_sym_type_arguments_repeat1,
  [80863] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3504), 1,
      anon_sym_GT,
    STATE(1790), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [80882] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3506), 1,
      anon_sym_RBRACK,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1791), 1,
      sym_comment,
  [80901] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3127), 1,
      sym_identifier,
    ACTIONS(3508), 1,
      anon_sym_RBRACE,
    STATE(1792), 1,
      sym_comment,
    STATE(1913), 1,
      sym_enum_member,
  [80920] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3510), 1,
      anon_sym_GT,
    STATE(1793), 1,
      sym_comment,
    STATE(1796), 1,
      aux_sym_type_arguments_repeat1,
  [80939] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3512), 1,
      anon_sym_RBRACK,
    STATE(1794), 1,
      sym_comment,
    STATE(1798), 1,
      aux_sym_type_arguments_repeat1,
  [80958] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3514), 1,
      anon_sym_COMMA,
    ACTIONS(3517), 1,
      anon_sym_RBRACE,
    STATE(1795), 2,
      sym_comment,
      aux_sym_enum_body_repeat1,
  [80975] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3519), 1,
      anon_sym_GT,
    STATE(1796), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [80994] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1485), 1,
      anon_sym_RPAREN,
    ACTIONS(3521), 1,
      anon_sym_LBRACE,
    STATE(1797), 1,
      sym_comment,
    STATE(2121), 1,
      sym_component_parameters,
  [81013] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3523), 1,
      anon_sym_RBRACK,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1798), 1,
      sym_comment,
  [81032] = 4,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    STATE(1799), 1,
      sym_comment,
    ACTIONS(3412), 3,
      anon_sym_DQUOTE,
      aux_sym_string_literal_token1,
      anon_sym_BSLASH,
  [81047] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3525), 1,
      anon_sym_GT,
    STATE(1800), 1,
      sym_comment,
    STATE(1802), 1,
      aux_sym_type_arguments_repeat1,
  [81066] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3527), 1,
      anon_sym_RBRACK,
    STATE(1801), 1,
      sym_comment,
    STATE(1803), 1,
      aux_sym_type_arguments_repeat1,
  [81085] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3529), 1,
      anon_sym_GT,
    STATE(1802), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [81104] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3531), 1,
      anon_sym_RBRACK,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1803), 1,
      sym_comment,
  [81123] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3533), 1,
      anon_sym_GT,
    STATE(1804), 1,
      sym_comment,
    STATE(1806), 1,
      aux_sym_type_arguments_repeat1,
  [81142] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3535), 1,
      anon_sym_RBRACK,
    STATE(1805), 1,
      sym_comment,
    STATE(1807), 1,
      aux_sym_type_arguments_repeat1,
  [81161] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3537), 1,
      anon_sym_GT,
    STATE(1806), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [81180] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3539), 1,
      anon_sym_RBRACK,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1807), 1,
      sym_comment,
  [81199] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2939), 1,
      anon_sym_LBRACE,
    ACTIONS(3541), 1,
      anon_sym_COMMA,
    STATE(1808), 2,
      sym_comment,
      aux_sym_implements_clause_repeat1,
  [81216] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3544), 1,
      anon_sym_GT,
    STATE(1809), 1,
      sym_comment,
    STATE(1812), 1,
      aux_sym_type_arguments_repeat1,
  [81235] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3546), 1,
      anon_sym_RBRACK,
    STATE(1810), 1,
      sym_comment,
    STATE(1813), 1,
      aux_sym_type_arguments_repeat1,
  [81254] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3159), 1,
      anon_sym_EQ,
    STATE(1811), 1,
      sym_comment,
    ACTIONS(2075), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [81271] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3548), 1,
      anon_sym_GT,
    STATE(1812), 1,
      sym_comment,
    STATE(1882), 1,
      aux_sym_type_arguments_repeat1,
  [81290] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3550), 1,
      anon_sym_RBRACK,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1813), 1,
      sym_comment,
  [81309] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3552), 1,
      anon_sym_SEMI,
    STATE(1415), 1,
      sym_block_statement,
    STATE(1814), 1,
      sym_comment,
  [81328] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3043), 1,
      sym_identifier,
    STATE(1815), 1,
      sym_comment,
    STATE(1972), 1,
      sym_parameter_list,
  [81347] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1481), 1,
      anon_sym_RPAREN,
    ACTIONS(3521), 1,
      anon_sym_LBRACE,
    STATE(1816), 1,
      sym_comment,
    STATE(2058), 1,
      sym_component_parameters,
  [81366] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3554), 1,
      anon_sym_EQ,
    STATE(1817), 1,
      sym_comment,
    ACTIONS(2079), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [81383] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3274), 1,
      anon_sym_COMMA,
    ACTIONS(3556), 1,
      anon_sym_SEMI,
    STATE(1677), 1,
      aux_sym_variable_declaration_repeat1,
    STATE(1818), 1,
      sym_comment,
  [81402] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3558), 1,
      sym_identifier,
    STATE(1819), 1,
      sym_comment,
    STATE(1986), 1,
      sym_parameter_list,
  [81421] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1820), 1,
      sym_comment,
    STATE(2131), 1,
      sym_string_literal,
  [81440] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(2019), 1,
      anon_sym_RBRACK,
    STATE(1821), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [81459] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2724), 1,
      anon_sym_readonly,
    ACTIONS(2726), 1,
      sym_identifier,
    ACTIONS(2728), 1,
      anon_sym_async,
    STATE(1822), 1,
      sym_comment,
  [81478] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3560), 1,
      sym_identifier,
    STATE(1823), 1,
      sym_comment,
    STATE(1921), 1,
      sym_generic_type,
    STATE(1969), 1,
      sym_qualified_type,
  [81497] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3143), 1,
      anon_sym_readonly,
    ACTIONS(3145), 1,
      sym_identifier,
    ACTIONS(3147), 1,
      anon_sym_async,
    STATE(1824), 1,
      sym_comment,
  [81516] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2892), 1,
      anon_sym_COMMA,
    ACTIONS(3562), 1,
      anon_sym_LBRACE,
    STATE(1808), 1,
      aux_sym_implements_clause_repeat1,
    STATE(1825), 1,
      sym_comment,
  [81535] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3564), 1,
      sym_identifier,
    STATE(1826), 1,
      sym_comment,
    STATE(1968), 1,
      sym_parameter_list,
  [81554] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3566), 1,
      anon_sym_COMMA,
    ACTIONS(3569), 1,
      anon_sym_RBRACE,
    STATE(1827), 2,
      sym_comment,
      aux_sym_component_parameters_repeat1,
  [81571] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1828), 1,
      sym_comment,
    ACTIONS(3161), 3,
      anon_sym_LBRACE,
      anon_sym_extends,
      anon_sym_implements,
  [81586] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3571), 1,
      anon_sym_readonly,
    ACTIONS(3573), 1,
      sym_identifier,
    ACTIONS(3575), 1,
      anon_sym_async,
    STATE(1829), 1,
      sym_comment,
  [81605] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1362), 1,
      sym_string_literal,
    STATE(1830), 1,
      sym_comment,
  [81624] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3577), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1831), 1,
      sym_comment,
  [81643] = 4,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    STATE(1832), 1,
      sym_comment,
    ACTIONS(3579), 3,
      anon_sym_DOLLAR,
      anon_sym_BQUOTE,
      sym_template_chars,
  [81658] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3484), 1,
      anon_sym_COMMA,
    ACTIONS(3581), 1,
      anon_sym_GT,
    STATE(1695), 1,
      aux_sym_type_parameters_repeat1,
    STATE(1833), 1,
      sym_comment,
  [81677] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3583), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      anon_sym_RBRACE,
    STATE(1685), 1,
      aux_sym_import_declaration_repeat1,
    STATE(1834), 1,
      sym_comment,
  [81696] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2890), 1,
      anon_sym_LBRACE,
    ACTIONS(2892), 1,
      anon_sym_COMMA,
    STATE(1825), 1,
      aux_sym_implements_clause_repeat1,
    STATE(1835), 1,
      sym_comment,
  [81715] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3315), 1,
      sym_identifier,
    ACTIONS(3587), 1,
      anon_sym_SEMI,
    STATE(1836), 1,
      sym_comment,
    STATE(1838), 1,
      sym_variable_declarator,
  [81734] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1837), 1,
      sym_comment,
    STATE(2106), 1,
      sym_string_literal,
  [81753] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3274), 1,
      anon_sym_COMMA,
    ACTIONS(3589), 1,
      anon_sym_SEMI,
    STATE(1838), 1,
      sym_comment,
    STATE(1847), 1,
      aux_sym_variable_declaration_repeat1,
  [81772] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3591), 1,
      anon_sym_COMMA,
    ACTIONS(3594), 1,
      anon_sym_SEMI,
    STATE(1839), 2,
      sym_comment,
      aux_sym_variable_declaration_repeat1,
  [81789] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(2039), 1,
      anon_sym_RBRACK,
    STATE(1840), 1,
      sym_comment,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
  [81808] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2102), 1,
      anon_sym_RBRACK,
    ACTIONS(3596), 1,
      anon_sym_COMMA,
    STATE(1841), 2,
      sym_comment,
      aux_sym_array_literal_repeat1,
  [81825] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3075), 1,
      anon_sym_LBRACE,
    STATE(1842), 1,
      sym_comment,
    STATE(1337), 2,
      sym_block_statement,
      sym_extend_function_body,
  [81842] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3438), 1,
      sym_identifier,
    ACTIONS(3599), 1,
      anon_sym_GT,
    STATE(1843), 1,
      sym_comment,
    STATE(1854), 1,
      sym_type_parameter,
  [81861] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1363), 1,
      sym_string_literal,
    STATE(1844), 1,
      sym_comment,
  [81880] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1299), 1,
      sym_string_literal,
    STATE(1845), 1,
      sym_comment,
  [81899] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(137), 1,
      anon_sym_LT,
    ACTIONS(3601), 1,
      anon_sym_EQ,
    STATE(1846), 1,
      sym_comment,
    STATE(2136), 1,
      sym_type_parameters,
  [81918] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3274), 1,
      anon_sym_COMMA,
    ACTIONS(3603), 1,
      anon_sym_SEMI,
    STATE(1839), 1,
      aux_sym_variable_declaration_repeat1,
    STATE(1847), 1,
      sym_comment,
  [81937] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3605), 1,
      anon_sym_EQ,
    STATE(1848), 1,
      sym_comment,
    ACTIONS(2097), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [81954] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3053), 1,
      sym_identifier,
    STATE(1849), 1,
      sym_comment,
    STATE(1961), 1,
      sym_parameter_list,
  [81973] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3607), 1,
      anon_sym_COMMA,
    ACTIONS(3609), 1,
      anon_sym_RBRACE,
    STATE(1850), 1,
      sym_comment,
    STATE(1867), 1,
      aux_sym_object_literal_repeat1,
  [81992] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3005), 1,
      sym_identifier,
    STATE(1851), 1,
      sym_comment,
    STATE(1931), 1,
      sym_parameter_list,
  [82011] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3611), 1,
      sym_identifier,
    STATE(1852), 1,
      sym_comment,
    STATE(1962), 1,
      sym_parameter_list,
  [82030] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1853), 1,
      sym_comment,
    STATE(2008), 1,
      sym_string_literal,
  [82049] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3484), 1,
      anon_sym_COMMA,
    ACTIONS(3613), 1,
      anon_sym_GT,
    STATE(1854), 1,
      sym_comment,
    STATE(1869), 1,
      aux_sym_type_parameters_repeat1,
  [82068] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(2013), 1,
      anon_sym_RBRACK,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
    STATE(1855), 1,
      sym_comment,
  [82087] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3017), 1,
      sym_identifier,
    STATE(1856), 1,
      sym_comment,
    STATE(1977), 1,
      sym_parameter_list,
  [82106] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3615), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1857), 1,
      sym_comment,
  [82125] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3617), 1,
      sym_identifier,
    STATE(1858), 1,
      sym_comment,
    STATE(1897), 1,
      sym_parameter_list,
  [82144] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1859), 1,
      sym_comment,
    STATE(2038), 1,
      sym_string_literal,
  [82163] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2108), 1,
      anon_sym_SEMI,
    ACTIONS(3619), 1,
      anon_sym_COLON,
    ACTIONS(3621), 1,
      anon_sym_EQ,
    STATE(1860), 1,
      sym_comment,
  [82182] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3023), 1,
      sym_identifier,
    STATE(1861), 1,
      sym_comment,
    STATE(1926), 1,
      sym_parameter_list,
  [82201] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3075), 1,
      anon_sym_LBRACE,
    STATE(1862), 1,
      sym_comment,
    STATE(1338), 2,
      sym_block_statement,
      sym_extend_function_body,
  [82218] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3623), 1,
      sym_identifier,
    STATE(1863), 1,
      sym_comment,
    STATE(1942), 1,
      sym_parameter_list,
  [82237] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1864), 1,
      sym_comment,
    STATE(2102), 1,
      sym_string_literal,
  [82256] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1348), 1,
      sym_string_literal,
    STATE(1865), 1,
      sym_comment,
  [82275] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3029), 1,
      sym_identifier,
    STATE(1866), 1,
      sym_comment,
    STATE(1988), 1,
      sym_parameter_list,
  [82294] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2710), 1,
      anon_sym_RBRACE,
    ACTIONS(3625), 1,
      anon_sym_COMMA,
    STATE(1678), 1,
      aux_sym_object_literal_repeat1,
    STATE(1867), 1,
      sym_comment,
  [82313] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3627), 1,
      sym_identifier,
    STATE(1868), 1,
      sym_comment,
    STATE(1951), 1,
      sym_parameter_list,
  [82332] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3484), 1,
      anon_sym_COMMA,
    ACTIONS(3629), 1,
      anon_sym_GT,
    STATE(1695), 1,
      aux_sym_type_parameters_repeat1,
    STATE(1869), 1,
      sym_comment,
  [82351] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2762), 1,
      anon_sym_readonly,
    ACTIONS(2764), 1,
      sym_identifier,
    ACTIONS(2766), 1,
      anon_sym_async,
    STATE(1870), 1,
      sym_comment,
  [82370] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    ACTIONS(3041), 1,
      sym_identifier,
    STATE(1871), 1,
      sym_comment,
    STATE(1902), 1,
      sym_parameter_list,
  [82389] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(995), 1,
      anon_sym_COMMA,
    ACTIONS(2065), 1,
      anon_sym_RBRACK,
    STATE(1841), 1,
      aux_sym_array_literal_repeat1,
    STATE(1872), 1,
      sym_comment,
  [82408] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3631), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1873), 1,
      sym_comment,
  [82427] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2015), 1,
      anon_sym_COMMA,
    ACTIONS(2029), 1,
      anon_sym_RPAREN,
    STATE(1659), 1,
      aux_sym_argument_list_repeat1,
    STATE(1874), 1,
      sym_comment,
  [82446] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3243), 1,
      anon_sym_COMMA,
    ACTIONS(3633), 1,
      anon_sym_GT,
    STATE(1660), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1875), 1,
      sym_comment,
  [82465] = 4,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    STATE(1876), 1,
      sym_comment,
    ACTIONS(3635), 3,
      anon_sym_DOLLAR,
      anon_sym_BQUOTE,
      sym_template_chars,
  [82480] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3637), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1877), 1,
      sym_comment,
  [82499] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1356), 1,
      sym_string_literal,
    STATE(1878), 1,
      sym_comment,
  [82518] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3583), 1,
      anon_sym_COMMA,
    ACTIONS(3639), 1,
      anon_sym_RBRACE,
    STATE(1834), 1,
      aux_sym_import_declaration_repeat1,
    STATE(1879), 1,
      sym_comment,
  [82537] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2089), 1,
      anon_sym_RPAREN,
    ACTIONS(3641), 1,
      anon_sym_COMMA,
    STATE(1880), 2,
      sym_comment,
      aux_sym_argument_list_repeat1,
  [82554] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1881), 1,
      sym_comment,
    ACTIONS(3258), 3,
      anon_sym_COMMA,
      anon_sym_GT,
      anon_sym_RBRACK,
  [82569] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3258), 1,
      anon_sym_GT,
    ACTIONS(3644), 1,
      anon_sym_COMMA,
    STATE(1882), 2,
      sym_comment,
      aux_sym_type_arguments_repeat1,
  [82586] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1233), 1,
      anon_sym_DQUOTE,
    ACTIONS(1235), 1,
      anon_sym_SQUOTE,
    STATE(1328), 1,
      sym_string_literal,
    STATE(1883), 1,
      sym_comment,
  [82605] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2112), 1,
      anon_sym_SEMI,
    ACTIONS(2931), 1,
      anon_sym_COLON,
    ACTIONS(2933), 1,
      anon_sym_EQ,
    STATE(1884), 1,
      sym_comment,
  [82624] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2023), 1,
      anon_sym_COMMA,
    ACTIONS(3647), 1,
      anon_sym_RPAREN,
    STATE(1741), 1,
      aux_sym_decorator_repeat1,
    STATE(1885), 1,
      sym_comment,
  [82643] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2903), 1,
      anon_sym_SEMI,
    ACTIONS(2905), 1,
      anon_sym_COLON,
    ACTIONS(2907), 1,
      anon_sym_EQ,
    STATE(1886), 1,
      sym_comment,
  [82662] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3649), 1,
      anon_sym_EQ,
    STATE(1887), 1,
      sym_comment,
    ACTIONS(2087), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [82679] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3651), 1,
      anon_sym_RBRACK,
    STATE(1664), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1888), 1,
      sym_comment,
  [82698] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3091), 1,
      anon_sym_LBRACE,
    ACTIONS(3203), 1,
      anon_sym_SEMI,
    STATE(1455), 1,
      sym_block_statement,
    STATE(1889), 1,
      sym_comment,
  [82717] = 6,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3247), 1,
      anon_sym_COMMA,
    ACTIONS(3653), 1,
      anon_sym_RBRACK,
    STATE(1667), 1,
      aux_sym_type_arguments_repeat1,
    STATE(1890), 1,
      sym_comment,
  [82736] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3655), 1,
      anon_sym_COLON,
    ACTIONS(3657), 1,
      anon_sym_EQ_GT,
    STATE(1891), 1,
      sym_comment,
  [82752] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1892), 1,
      sym_comment,
    ACTIONS(3301), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [82766] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1893), 1,
      sym_comment,
    ACTIONS(3086), 2,
      anon_sym_RBRACE,
      sym_identifier,
  [82780] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(97), 1,
      anon_sym_COLON,
    ACTIONS(3659), 1,
      anon_sym_EQ_GT,
    STATE(1894), 1,
      sym_comment,
  [82796] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1895), 1,
      sym_comment,
    ACTIONS(3594), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [82810] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3285), 1,
      sym_identifier,
    STATE(1896), 1,
      sym_comment,
    STATE(1933), 1,
      sym_component_parameter,
  [82826] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3661), 1,
      anon_sym_COLON,
    ACTIONS(3663), 1,
      anon_sym_EQ_GT,
    STATE(1897), 1,
      sym_comment,
  [82842] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3264), 1,
      anon_sym_LBRACE,
    STATE(859), 1,
      sym_block_statement,
    STATE(1898), 1,
      sym_comment,
  [82858] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1467), 1,
      anon_sym_COLON,
    ACTIONS(3665), 1,
      anon_sym_EQ_GT,
    STATE(1899), 1,
      sym_comment,
  [82874] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1900), 1,
      sym_comment,
    ACTIONS(3296), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [82888] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3667), 1,
      anon_sym_COLON,
    ACTIONS(3669), 1,
      anon_sym_EQ_GT,
    STATE(1901), 1,
      sym_comment,
  [82904] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3671), 1,
      anon_sym_COLON,
    ACTIONS(3673), 1,
      anon_sym_EQ_GT,
    STATE(1902), 1,
      sym_comment,
  [82920] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1602), 1,
      sym_parameter_list,
    STATE(1903), 1,
      sym_comment,
  [82936] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3675), 1,
      anon_sym_LBRACE,
    STATE(877), 1,
      sym_block_statement,
    STATE(1904), 1,
      sym_comment,
  [82952] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(41), 1,
      anon_sym_COLON,
    ACTIONS(3677), 1,
      anon_sym_EQ_GT,
    STATE(1905), 1,
      sym_comment,
  [82968] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3679), 1,
      anon_sym_RBRACE,
    ACTIONS(3681), 1,
      sym_identifier,
    STATE(1906), 1,
      sym_comment,
  [82984] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3683), 1,
      anon_sym_COMMA,
    ACTIONS(3685), 1,
      anon_sym_RPAREN,
    STATE(1907), 1,
      sym_comment,
  [83000] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(85), 1,
      anon_sym_COLON,
    ACTIONS(3687), 1,
      anon_sym_EQ_GT,
    STATE(1908), 1,
      sym_comment,
  [83016] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2156), 1,
      anon_sym_SEMI,
    ACTIONS(3272), 1,
      anon_sym_EQ,
    STATE(1909), 1,
      sym_comment,
  [83032] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1910), 1,
      sym_comment,
    STATE(1919), 1,
      sym_parameter_list,
  [83048] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    STATE(1344), 1,
      sym_class_body,
    STATE(1911), 1,
      sym_comment,
  [83064] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1912), 1,
      sym_comment,
    STATE(1918), 1,
      sym_parameter_list,
  [83080] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1913), 1,
      sym_comment,
    ACTIONS(3517), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [83094] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1914), 1,
      sym_comment,
    ACTIONS(3305), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [83108] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    STATE(1329), 1,
      sym_class_body,
    STATE(1915), 1,
      sym_comment,
  [83124] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1916), 1,
      sym_comment,
    ACTIONS(3322), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [83138] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1272), 1,
      anon_sym_COLON,
    ACTIONS(3689), 1,
      anon_sym_EQ_GT,
    STATE(1917), 1,
      sym_comment,
  [83154] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    STATE(1419), 1,
      sym_block_statement,
    STATE(1918), 1,
      sym_comment,
  [83170] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3165), 1,
      anon_sym_LBRACE,
    STATE(1414), 1,
      sym_block_statement,
    STATE(1919), 1,
      sym_comment,
  [83186] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2144), 1,
      anon_sym_SEMI,
    ACTIONS(2921), 1,
      anon_sym_EQ,
    STATE(1920), 1,
      sym_comment,
  [83202] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1921), 1,
      sym_comment,
    ACTIONS(2939), 2,
      anon_sym_LBRACE,
      anon_sym_COMMA,
  [83216] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(41), 1,
      anon_sym_COLON,
    ACTIONS(56), 1,
      anon_sym_EQ_GT,
    STATE(1922), 1,
      sym_comment,
  [83232] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2128), 1,
      anon_sym_SEMI,
    ACTIONS(3691), 1,
      anon_sym_EQ,
    STATE(1923), 1,
      sym_comment,
  [83248] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1606), 1,
      sym_parameter_list,
    STATE(1924), 1,
      sym_comment,
  [83264] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3260), 1,
      anon_sym_LBRACE,
    STATE(888), 1,
      sym_block_statement,
    STATE(1925), 1,
      sym_comment,
  [83280] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3693), 1,
      anon_sym_COLON,
    ACTIONS(3695), 1,
      anon_sym_EQ_GT,
    STATE(1926), 1,
      sym_comment,
  [83296] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3127), 1,
      sym_identifier,
    STATE(1913), 1,
      sym_enum_member,
    STATE(1927), 1,
      sym_comment,
  [83312] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2200), 1,
      anon_sym_SEMI,
    ACTIONS(3697), 1,
      anon_sym_EQ,
    STATE(1928), 1,
      sym_comment,
  [83328] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3699), 1,
      anon_sym_RBRACE,
    ACTIONS(3701), 1,
      sym_identifier,
    STATE(1929), 1,
      sym_comment,
  [83344] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(690), 1,
      anon_sym_LPAREN,
    STATE(148), 1,
      sym_argument_list,
    STATE(1930), 1,
      sym_comment,
  [83360] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3703), 1,
      anon_sym_COLON,
    ACTIONS(3705), 1,
      anon_sym_EQ_GT,
    STATE(1931), 1,
      sym_comment,
  [83376] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    STATE(1322), 1,
      sym_class_body,
    STATE(1932), 1,
      sym_comment,
  [83392] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1933), 1,
      sym_comment,
    ACTIONS(3569), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [83406] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3315), 1,
      sym_identifier,
    STATE(1895), 1,
      sym_variable_declarator,
    STATE(1934), 1,
      sym_comment,
  [83422] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3707), 1,
      anon_sym_from,
    ACTIONS(3709), 1,
      anon_sym_as,
    STATE(1935), 1,
      sym_comment,
  [83438] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1639), 1,
      sym_parameter_list,
    STATE(1936), 1,
      sym_comment,
  [83454] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2160), 1,
      anon_sym_SEMI,
    ACTIONS(3711), 1,
      anon_sym_EQ,
    STATE(1937), 1,
      sym_comment,
  [83470] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1640), 1,
      sym_parameter_list,
    STATE(1938), 1,
      sym_comment,
  [83486] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3438), 1,
      sym_identifier,
    STATE(1916), 1,
      sym_type_parameter,
    STATE(1939), 1,
      sym_comment,
  [83502] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1647), 1,
      sym_parameter_list,
    STATE(1940), 1,
      sym_comment,
  [83518] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3713), 1,
      anon_sym_LBRACE,
    STATE(849), 1,
      sym_block_statement,
    STATE(1941), 1,
      sym_comment,
  [83534] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3715), 1,
      anon_sym_COLON,
    ACTIONS(3717), 1,
      anon_sym_EQ_GT,
    STATE(1942), 1,
      sym_comment,
  [83550] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1650), 1,
      sym_parameter_list,
    STATE(1943), 1,
      sym_comment,
  [83566] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3719), 1,
      anon_sym_SEMI,
    ACTIONS(3721), 1,
      sym_identifier,
    STATE(1944), 1,
      sym_comment,
  [83582] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3723), 1,
      anon_sym_SEMI,
    ACTIONS(3725), 1,
      sym_identifier,
    STATE(1945), 1,
      sym_comment,
  [83598] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3260), 1,
      anon_sym_LBRACE,
    STATE(900), 1,
      sym_block_statement,
    STATE(1946), 1,
      sym_comment,
  [83614] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1947), 1,
      sym_comment,
    ACTIONS(3281), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [83628] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3727), 1,
      anon_sym_RPAREN,
    ACTIONS(3729), 1,
      anon_sym_COLON,
    STATE(1948), 1,
      sym_comment,
  [83644] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    STATE(1341), 1,
      sym_class_body,
    STATE(1949), 1,
      sym_comment,
  [83660] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1950), 1,
      sym_comment,
    ACTIONS(3731), 2,
      anon_sym_RBRACE,
      anon_sym_DOT,
  [83674] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3733), 1,
      anon_sym_COLON,
    ACTIONS(3735), 1,
      anon_sym_EQ_GT,
    STATE(1951), 1,
      sym_comment,
  [83690] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    STATE(1353), 1,
      sym_class_body,
    STATE(1952), 1,
      sym_comment,
  [83706] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1467), 1,
      anon_sym_COLON,
    ACTIONS(3737), 1,
      anon_sym_EQ_GT,
    STATE(1953), 1,
      sym_comment,
  [83722] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1621), 1,
      sym_parameter_list,
    STATE(1954), 1,
      sym_comment,
  [83738] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1642), 1,
      sym_parameter_list,
    STATE(1955), 1,
      sym_comment,
  [83754] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(97), 1,
      anon_sym_COLON,
    ACTIONS(103), 1,
      anon_sym_EQ_GT,
    STATE(1956), 1,
      sym_comment,
  [83770] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1957), 1,
      sym_comment,
    ACTIONS(3739), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [83784] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1644), 1,
      sym_parameter_list,
    STATE(1958), 1,
      sym_comment,
  [83800] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(75), 1,
      anon_sym_COLON,
    ACTIONS(83), 1,
      anon_sym_EQ_GT,
    STATE(1959), 1,
      sym_comment,
  [83816] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1467), 1,
      anon_sym_COLON,
    ACTIONS(1473), 1,
      anon_sym_EQ_GT,
    STATE(1960), 1,
      sym_comment,
  [83832] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3741), 1,
      anon_sym_COLON,
    ACTIONS(3743), 1,
      anon_sym_EQ_GT,
    STATE(1961), 1,
      sym_comment,
  [83848] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3745), 1,
      anon_sym_COLON,
    ACTIONS(3747), 1,
      anon_sym_EQ_GT,
    STATE(1962), 1,
      sym_comment,
  [83864] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3749), 1,
      anon_sym_LBRACE,
    STATE(1308), 1,
      sym_enum_body,
    STATE(1963), 1,
      sym_comment,
  [83880] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3749), 1,
      anon_sym_LBRACE,
    STATE(1336), 1,
      sym_enum_body,
    STATE(1964), 1,
      sym_comment,
  [83896] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3442), 1,
      anon_sym_LBRACE,
    STATE(1437), 1,
      sym_build_body,
    STATE(1965), 1,
      sym_comment,
  [83912] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2154), 1,
      anon_sym_SEMI,
    ACTIONS(2925), 1,
      anon_sym_EQ,
    STATE(1966), 1,
      sym_comment,
  [83928] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2862), 1,
      anon_sym_LBRACE,
    STATE(1361), 1,
      sym_class_body,
    STATE(1967), 1,
      sym_comment,
  [83944] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3751), 1,
      anon_sym_COLON,
    ACTIONS(3753), 1,
      anon_sym_EQ_GT,
    STATE(1968), 1,
      sym_comment,
  [83960] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2382), 1,
      anon_sym_LT,
    STATE(463), 1,
      sym_type_arguments,
    STATE(1969), 1,
      sym_comment,
  [83976] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3755), 1,
      anon_sym_RPAREN,
    ACTIONS(3757), 1,
      anon_sym_COLON,
    STATE(1970), 1,
      sym_comment,
  [83992] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2168), 1,
      anon_sym_SEMI,
    ACTIONS(3759), 1,
      anon_sym_EQ,
    STATE(1971), 1,
      sym_comment,
  [84008] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3761), 1,
      anon_sym_COLON,
    ACTIONS(3763), 1,
      anon_sym_EQ_GT,
    STATE(1972), 1,
      sym_comment,
  [84024] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1973), 1,
      sym_comment,
    ACTIONS(3765), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [84038] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3084), 1,
      anon_sym_LBRACE,
    STATE(1311), 1,
      sym_component_body,
    STATE(1974), 1,
      sym_comment,
  [84054] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1272), 1,
      anon_sym_COLON,
    ACTIONS(1278), 1,
      anon_sym_EQ_GT,
    STATE(1975), 1,
      sym_comment,
  [84070] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3231), 1,
      anon_sym_LBRACE,
    STATE(1347), 1,
      sym_object_type,
    STATE(1976), 1,
      sym_comment,
  [84086] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3767), 1,
      anon_sym_COLON,
    ACTIONS(3769), 1,
      anon_sym_EQ_GT,
    STATE(1977), 1,
      sym_comment,
  [84102] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1889), 1,
      anon_sym_LPAREN,
    STATE(1037), 1,
      sym_argument_list,
    STATE(1978), 1,
      sym_comment,
  [84118] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2108), 1,
      anon_sym_SEMI,
    ACTIONS(3621), 1,
      anon_sym_EQ,
    STATE(1979), 1,
      sym_comment,
  [84134] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3264), 1,
      anon_sym_LBRACE,
    STATE(858), 1,
      sym_block_statement,
    STATE(1980), 1,
      sym_comment,
  [84150] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3771), 1,
      anon_sym_LBRACE,
    STATE(955), 1,
      sym_block_statement,
    STATE(1981), 1,
      sym_comment,
  [84166] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(85), 1,
      anon_sym_COLON,
    ACTIONS(91), 1,
      anon_sym_EQ_GT,
    STATE(1982), 1,
      sym_comment,
  [84182] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3084), 1,
      anon_sym_LBRACE,
    STATE(1354), 1,
      sym_component_body,
    STATE(1983), 1,
      sym_comment,
  [84198] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1594), 1,
      sym_parameter_list,
    STATE(1984), 1,
      sym_comment,
  [84214] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1645), 1,
      sym_parameter_list,
    STATE(1985), 1,
      sym_comment,
  [84230] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3135), 1,
      anon_sym_EQ_GT,
    ACTIONS(3773), 1,
      anon_sym_COLON,
    STATE(1986), 1,
      sym_comment,
  [84246] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1323), 1,
      anon_sym_LPAREN,
    STATE(425), 1,
      sym_argument_list,
    STATE(1987), 1,
      sym_comment,
  [84262] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3775), 1,
      anon_sym_COLON,
    ACTIONS(3777), 1,
      anon_sym_EQ_GT,
    STATE(1988), 1,
      sym_comment,
  [84278] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(75), 1,
      anon_sym_COLON,
    ACTIONS(3779), 1,
      anon_sym_EQ_GT,
    STATE(1989), 1,
      sym_comment,
  [84294] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    STATE(1990), 1,
      sym_comment,
    ACTIONS(2089), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [84308] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1094), 1,
      anon_sym_LPAREN,
    STATE(312), 1,
      sym_argument_list,
    STATE(1991), 1,
      sym_comment,
  [84324] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3084), 1,
      anon_sym_LBRACE,
    STATE(1330), 1,
      sym_component_body,
    STATE(1992), 1,
      sym_comment,
  [84340] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2192), 1,
      anon_sym_SEMI,
    ACTIONS(2901), 1,
      anon_sym_EQ,
    STATE(1993), 1,
      sym_comment,
  [84356] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1598), 1,
      sym_parameter_list,
    STATE(1994), 1,
      sym_comment,
  [84372] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2112), 1,
      anon_sym_SEMI,
    ACTIONS(2933), 1,
      anon_sym_EQ,
    STATE(1995), 1,
      sym_comment,
  [84388] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1601), 1,
      anon_sym_LPAREN,
    STATE(784), 1,
      sym_argument_list,
    STATE(1996), 1,
      sym_comment,
  [84404] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1547), 1,
      sym_parameter_list,
    STATE(1997), 1,
      sym_comment,
  [84420] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3781), 1,
      anon_sym_LBRACE,
    STATE(848), 1,
      sym_block_statement,
    STATE(1998), 1,
      sym_comment,
  [84436] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3783), 1,
      anon_sym_SEMI,
    ACTIONS(3785), 1,
      sym_identifier,
    STATE(1999), 1,
      sym_comment,
  [84452] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3787), 1,
      anon_sym_SEMI,
    ACTIONS(3789), 1,
      sym_identifier,
    STATE(2000), 1,
      sym_comment,
  [84468] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3084), 1,
      anon_sym_LBRACE,
    STATE(1304), 1,
      sym_component_body,
    STATE(2001), 1,
      sym_comment,
  [84484] = 5,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2260), 1,
      anon_sym_LPAREN,
    STATE(1655), 1,
      sym_parameter_list,
    STATE(2002), 1,
      sym_comment,
  [84500] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3791), 1,
      anon_sym_EQ_GT,
    STATE(2003), 1,
      sym_comment,
  [84513] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3663), 1,
      anon_sym_EQ_GT,
    STATE(2004), 1,
      sym_comment,
  [84526] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3793), 1,
      anon_sym_RPAREN,
    STATE(2005), 1,
      sym_comment,
  [84539] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2827), 1,
      anon_sym_function,
    STATE(2006), 1,
      sym_comment,
  [84552] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3795), 1,
      sym_identifier,
    STATE(2007), 1,
      sym_comment,
  [84565] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3797), 1,
      anon_sym_RPAREN,
    STATE(2008), 1,
      sym_comment,
  [84578] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3799), 1,
      sym_identifier,
    STATE(2009), 1,
      sym_comment,
  [84591] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3801), 1,
      anon_sym_RBRACK,
    STATE(2010), 1,
      sym_comment,
  [84604] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3803), 1,
      sym_identifier,
    STATE(2011), 1,
      sym_comment,
  [84617] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3805), 1,
      anon_sym_SEMI,
    STATE(2012), 1,
      sym_comment,
  [84630] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3807), 1,
      anon_sym_RPAREN,
    STATE(2013), 1,
      sym_comment,
  [84643] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3809), 1,
      anon_sym_EQ_GT,
    STATE(2014), 1,
      sym_comment,
  [84656] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3811), 1,
      sym_identifier,
    STATE(2015), 1,
      sym_comment,
  [84669] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3813), 1,
      sym_identifier,
    STATE(2016), 1,
      sym_comment,
  [84682] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3815), 1,
      anon_sym_QMARK,
    STATE(2017), 1,
      sym_comment,
  [84695] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2362), 1,
      anon_sym_from,
    STATE(2018), 1,
      sym_comment,
  [84708] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3817), 1,
      anon_sym_EQ_GT,
    STATE(2019), 1,
      sym_comment,
  [84721] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3717), 1,
      anon_sym_EQ_GT,
    STATE(2020), 1,
      sym_comment,
  [84734] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3819), 1,
      sym_identifier,
    STATE(2021), 1,
      sym_comment,
  [84747] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3821), 1,
      anon_sym_LBRACE,
    STATE(2022), 1,
      sym_comment,
  [84760] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3823), 1,
      sym_identifier,
    STATE(2023), 1,
      sym_comment,
  [84773] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3825), 1,
      sym_identifier,
    STATE(2024), 1,
      sym_comment,
  [84786] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3339), 1,
      anon_sym_RBRACE,
    STATE(2025), 1,
      sym_comment,
  [84799] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3827), 1,
      sym_identifier,
    STATE(2026), 1,
      sym_comment,
  [84812] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3753), 1,
      anon_sym_EQ_GT,
    STATE(2027), 1,
      sym_comment,
  [84825] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3829), 1,
      anon_sym_EQ_GT,
    STATE(2028), 1,
      sym_comment,
  [84838] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3831), 1,
      anon_sym_LPAREN,
    STATE(2029), 1,
      sym_comment,
  [84851] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2819), 1,
      anon_sym_struct,
    STATE(2030), 1,
      sym_comment,
  [84864] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3357), 1,
      anon_sym_RBRACE,
    STATE(2031), 1,
      sym_comment,
  [84877] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3833), 1,
      anon_sym_SEMI,
    STATE(2032), 1,
      sym_comment,
  [84890] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3835), 1,
      anon_sym_EQ_GT,
    STATE(2033), 1,
      sym_comment,
  [84903] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3837), 1,
      anon_sym_EQ_GT,
    STATE(2034), 1,
      sym_comment,
  [84916] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3839), 1,
      sym_identifier,
    STATE(2035), 1,
      sym_comment,
  [84929] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3841), 1,
      sym_identifier,
    STATE(2036), 1,
      sym_comment,
  [84942] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3843), 1,
      anon_sym_COLON,
    STATE(2037), 1,
      sym_comment,
  [84955] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3845), 1,
      anon_sym_RPAREN,
    STATE(2038), 1,
      sym_comment,
  [84968] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3847), 1,
      anon_sym_LPAREN,
    STATE(2039), 1,
      sym_comment,
  [84981] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3849), 1,
      anon_sym_LPAREN,
    STATE(2040), 1,
      sym_comment,
  [84994] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3851), 1,
      sym_identifier,
    STATE(2041), 1,
      sym_comment,
  [85007] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3853), 1,
      sym_identifier,
    STATE(2042), 1,
      sym_comment,
  [85020] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2825), 1,
      anon_sym_class,
    STATE(2043), 1,
      sym_comment,
  [85033] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3855), 1,
      anon_sym_EQ_GT,
    STATE(2044), 1,
      sym_comment,
  [85046] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3857), 1,
      anon_sym_from,
    STATE(2045), 1,
      sym_comment,
  [85059] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3859), 1,
      sym_identifier,
    STATE(2046), 1,
      sym_comment,
  [85072] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3861), 1,
      sym_identifier,
    STATE(2047), 1,
      sym_comment,
  [85085] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3863), 1,
      anon_sym_SEMI,
    STATE(2048), 1,
      sym_comment,
  [85098] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3865), 1,
      sym_identifier,
    STATE(2049), 1,
      sym_comment,
  [85111] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2025), 1,
      anon_sym_RPAREN,
    STATE(2050), 1,
      sym_comment,
  [85124] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3867), 1,
      anon_sym_SEMI,
    STATE(2051), 1,
      sym_comment,
  [85137] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3869), 1,
      anon_sym_LPAREN,
    STATE(2052), 1,
      sym_comment,
  [85150] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3871), 1,
      sym_identifier,
    STATE(2053), 1,
      sym_comment,
  [85163] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3873), 1,
      ts_builtin_sym_end,
    STATE(2054), 1,
      sym_comment,
  [85176] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3875), 1,
      anon_sym_RBRACK,
    STATE(2055), 1,
      sym_comment,
  [85189] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3877), 1,
      anon_sym_SEMI,
    STATE(2056), 1,
      sym_comment,
  [85202] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3879), 1,
      sym_identifier,
    STATE(2057), 1,
      sym_comment,
  [85215] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2170), 1,
      anon_sym_RPAREN,
    STATE(2058), 1,
      sym_comment,
  [85228] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3881), 1,
      anon_sym_RPAREN,
    STATE(2059), 1,
      sym_comment,
  [85241] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3883), 1,
      anon_sym_RBRACK,
    STATE(2060), 1,
      sym_comment,
  [85254] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3885), 1,
      sym_identifier,
    STATE(2061), 1,
      sym_comment,
  [85267] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3887), 1,
      sym_identifier,
    STATE(2062), 1,
      sym_comment,
  [85280] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3889), 1,
      anon_sym_RBRACK,
    STATE(2063), 1,
      sym_comment,
  [85293] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1393), 1,
      anon_sym_COLON,
    STATE(2064), 1,
      sym_comment,
  [85306] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3891), 1,
      anon_sym_COLON,
    STATE(2065), 1,
      sym_comment,
  [85319] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(1380), 1,
      anon_sym_COLON,
    STATE(2066), 1,
      sym_comment,
  [85332] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3893), 1,
      anon_sym_COLON,
    STATE(2067), 1,
      sym_comment,
  [85345] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3895), 1,
      anon_sym_EQ_GT,
    STATE(2068), 1,
      sym_comment,
  [85358] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3897), 1,
      sym_identifier,
    STATE(2069), 1,
      sym_comment,
  [85371] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3899), 1,
      anon_sym_EQ_GT,
    STATE(2070), 1,
      sym_comment,
  [85384] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3901), 1,
      anon_sym_LBRACE,
    STATE(2071), 1,
      sym_comment,
  [85397] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3903), 1,
      sym_identifier,
    STATE(2072), 1,
      sym_comment,
  [85410] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3905), 1,
      anon_sym_EQ_GT,
    STATE(2073), 1,
      sym_comment,
  [85423] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3907), 1,
      anon_sym_EQ_GT,
    STATE(2074), 1,
      sym_comment,
  [85436] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3909), 1,
      anon_sym_EQ_GT,
    STATE(2075), 1,
      sym_comment,
  [85449] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3747), 1,
      anon_sym_EQ_GT,
    STATE(2076), 1,
      sym_comment,
  [85462] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3911), 1,
      sym_identifier,
    STATE(2077), 1,
      sym_comment,
  [85475] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3913), 1,
      anon_sym_EQ_GT,
    STATE(2078), 1,
      sym_comment,
  [85488] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3915), 1,
      anon_sym_EQ_GT,
    STATE(2079), 1,
      sym_comment,
  [85501] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3917), 1,
      anon_sym_LBRACE,
    STATE(2080), 1,
      sym_comment,
  [85514] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3330), 1,
      anon_sym_RBRACE,
    STATE(2081), 1,
      sym_comment,
  [85527] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3609), 1,
      anon_sym_RBRACE,
    STATE(2082), 1,
      sym_comment,
  [85540] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3919), 1,
      anon_sym_RBRACK,
    STATE(2083), 1,
      sym_comment,
  [85553] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3921), 1,
      sym_identifier,
    STATE(2084), 1,
      sym_comment,
  [85566] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3923), 1,
      sym_identifier,
    STATE(2085), 1,
      sym_comment,
  [85579] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3925), 1,
      sym_identifier,
    STATE(2086), 1,
      sym_comment,
  [85592] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3927), 1,
      anon_sym_COLON,
    STATE(2087), 1,
      sym_comment,
  [85605] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3929), 1,
      anon_sym_as,
    STATE(2088), 1,
      sym_comment,
  [85618] = 4,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3931), 1,
      aux_sym_comment_token2,
    STATE(2089), 1,
      sym_comment,
  [85631] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3933), 1,
      anon_sym_EQ_GT,
    STATE(2090), 1,
      sym_comment,
  [85644] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3935), 1,
      anon_sym_COLON,
    STATE(2091), 1,
      sym_comment,
  [85657] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3937), 1,
      anon_sym_RPAREN,
    STATE(2092), 1,
      sym_comment,
  [85670] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3939), 1,
      anon_sym_RBRACK,
    STATE(2093), 1,
      sym_comment,
  [85683] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3941), 1,
      sym_identifier,
    STATE(2094), 1,
      sym_comment,
  [85696] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3943), 1,
      anon_sym_COLON,
    STATE(2095), 1,
      sym_comment,
  [85709] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3945), 1,
      sym_identifier,
    STATE(2096), 1,
      sym_comment,
  [85722] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3947), 1,
      anon_sym_RBRACK,
    STATE(2097), 1,
      sym_comment,
  [85735] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3949), 1,
      sym_identifier,
    STATE(2098), 1,
      sym_comment,
  [85748] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3951), 1,
      sym_identifier,
    STATE(2099), 1,
      sym_comment,
  [85761] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3953), 1,
      anon_sym_COLON,
    STATE(2100), 1,
      sym_comment,
  [85774] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3955), 1,
      sym_identifier,
    STATE(2101), 1,
      sym_comment,
  [85787] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3957), 1,
      anon_sym_RPAREN,
    STATE(2102), 1,
      sym_comment,
  [85800] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3959), 1,
      sym_identifier,
    STATE(2103), 1,
      sym_comment,
  [85813] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3961), 1,
      anon_sym_SEMI,
    STATE(2104), 1,
      sym_comment,
  [85826] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3963), 1,
      anon_sym_EQ_GT,
    STATE(2105), 1,
      sym_comment,
  [85839] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3965), 1,
      anon_sym_RPAREN,
    STATE(2106), 1,
      sym_comment,
  [85852] = 4,
    ACTIONS(2957), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(2959), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3967), 1,
      aux_sym_comment_token1,
    STATE(2107), 1,
      sym_comment,
  [85865] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3969), 1,
      sym_identifier,
    STATE(2108), 1,
      sym_comment,
  [85878] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3971), 1,
      anon_sym_LBRACE,
    STATE(2109), 1,
      sym_comment,
  [85891] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3973), 1,
      anon_sym_LPAREN,
    STATE(2110), 1,
      sym_comment,
  [85904] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3975), 1,
      anon_sym_RPAREN,
    STATE(2111), 1,
      sym_comment,
  [85917] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3977), 1,
      anon_sym_struct,
    STATE(2112), 1,
      sym_comment,
  [85930] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3979), 1,
      sym_identifier,
    STATE(2113), 1,
      sym_comment,
  [85943] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3981), 1,
      sym_identifier,
    STATE(2114), 1,
      sym_comment,
  [85956] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3983), 1,
      sym_identifier,
    STATE(2115), 1,
      sym_comment,
  [85969] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3985), 1,
      anon_sym_EQ_GT,
    STATE(2116), 1,
      sym_comment,
  [85982] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3987), 1,
      anon_sym_LPAREN,
    STATE(2117), 1,
      sym_comment,
  [85995] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3989), 1,
      anon_sym_EQ_GT,
    STATE(2118), 1,
      sym_comment,
  [86008] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3991), 1,
      anon_sym_COLON,
    STATE(2119), 1,
      sym_comment,
  [86021] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3993), 1,
      sym_identifier,
    STATE(2120), 1,
      sym_comment,
  [86034] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(2063), 1,
      anon_sym_RPAREN,
    STATE(2121), 1,
      sym_comment,
  [86047] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3995), 1,
      sym_identifier,
    STATE(2122), 1,
      sym_comment,
  [86060] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3434), 1,
      anon_sym_RBRACE,
    STATE(2123), 1,
      sym_comment,
  [86073] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3135), 1,
      anon_sym_EQ_GT,
    STATE(2124), 1,
      sym_comment,
  [86086] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3997), 1,
      anon_sym_RBRACK,
    STATE(2125), 1,
      sym_comment,
  [86099] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3999), 1,
      anon_sym_SLASH,
    STATE(2126), 1,
      sym_comment,
  [86112] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4001), 1,
      anon_sym_from,
    STATE(2127), 1,
      sym_comment,
  [86125] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4003), 1,
      sym_identifier,
    STATE(2128), 1,
      sym_comment,
  [86138] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4005), 1,
      sym_identifier,
    STATE(2129), 1,
      sym_comment,
  [86151] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4007), 1,
      sym_identifier,
    STATE(2130), 1,
      sym_comment,
  [86164] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4009), 1,
      anon_sym_RPAREN,
    STATE(2131), 1,
      sym_comment,
  [86177] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4011), 1,
      anon_sym_RPAREN,
    STATE(2132), 1,
      sym_comment,
  [86190] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3359), 1,
      anon_sym_COLON,
    STATE(2133), 1,
      sym_comment,
  [86203] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4013), 1,
      sym_identifier,
    STATE(2134), 1,
      sym_comment,
  [86216] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4015), 1,
      anon_sym_LPAREN,
    STATE(2135), 1,
      sym_comment,
  [86229] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4017), 1,
      anon_sym_EQ,
    STATE(2136), 1,
      sym_comment,
  [86242] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4019), 1,
      sym_identifier,
    STATE(2137), 1,
      sym_comment,
  [86255] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4021), 1,
      sym_identifier,
    STATE(2138), 1,
      sym_comment,
  [86268] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4023), 1,
      sym_identifier,
    STATE(2139), 1,
      sym_comment,
  [86281] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4025), 1,
      anon_sym_QMARK,
    STATE(2140), 1,
      sym_comment,
  [86294] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4027), 1,
      sym_identifier,
    STATE(2141), 1,
      sym_comment,
  [86307] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4029), 1,
      sym_identifier,
    STATE(2142), 1,
      sym_comment,
  [86320] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4031), 1,
      anon_sym_function,
    STATE(2143), 1,
      sym_comment,
  [86333] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4033), 1,
      anon_sym_class,
    STATE(2144), 1,
      sym_comment,
  [86346] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4035), 1,
      sym_identifier,
    STATE(2145), 1,
      sym_comment,
  [86359] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4037), 1,
      sym_identifier,
    STATE(2146), 1,
      sym_comment,
  [86372] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4039), 1,
      anon_sym_EQ_GT,
    STATE(2147), 1,
      sym_comment,
  [86385] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4041), 1,
      sym_identifier,
    STATE(2148), 1,
      sym_comment,
  [86398] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4043), 1,
      anon_sym_from,
    STATE(2149), 1,
      sym_comment,
  [86411] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3393), 1,
      anon_sym_RBRACE,
    STATE(2150), 1,
      sym_comment,
  [86424] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4045), 1,
      sym_identifier,
    STATE(2151), 1,
      sym_comment,
  [86437] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4047), 1,
      sym_identifier,
    STATE(2152), 1,
      sym_comment,
  [86450] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4049), 1,
      sym_identifier,
    STATE(2153), 1,
      sym_comment,
  [86463] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3639), 1,
      sym_identifier,
    STATE(2154), 1,
      sym_comment,
  [86476] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4051), 1,
      anon_sym_EQ_GT,
    STATE(2155), 1,
      sym_comment,
  [86489] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4053), 1,
      anon_sym_RBRACK,
    STATE(2156), 1,
      sym_comment,
  [86502] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4055), 1,
      anon_sym_COLON,
    STATE(2157), 1,
      sym_comment,
  [86515] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4057), 1,
      anon_sym_EQ_GT,
    STATE(2158), 1,
      sym_comment,
  [86528] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4059), 1,
      anon_sym_EQ_GT,
    STATE(2159), 1,
      sym_comment,
  [86541] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4061), 1,
      sym_identifier,
    STATE(2160), 1,
      sym_comment,
  [86554] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3735), 1,
      anon_sym_EQ_GT,
    STATE(2161), 1,
      sym_comment,
  [86567] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4063), 1,
      anon_sym_LPAREN,
    STATE(2162), 1,
      sym_comment,
  [86580] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4065), 1,
      sym_identifier,
    STATE(2163), 1,
      sym_comment,
  [86593] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4067), 1,
      sym_identifier,
    STATE(2164), 1,
      sym_comment,
  [86606] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4069), 1,
      anon_sym_LPAREN,
    STATE(2165), 1,
      sym_comment,
  [86619] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4071), 1,
      anon_sym_QMARK,
    STATE(2166), 1,
      sym_comment,
  [86632] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4073), 1,
      anon_sym_LPAREN,
    STATE(2167), 1,
      sym_comment,
  [86645] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4075), 1,
      anon_sym_QMARK,
    STATE(2168), 1,
      sym_comment,
  [86658] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4077), 1,
      anon_sym_LPAREN,
    STATE(2169), 1,
      sym_comment,
  [86671] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4079), 1,
      anon_sym_QMARK,
    STATE(2170), 1,
      sym_comment,
  [86684] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4081), 1,
      anon_sym_QMARK,
    STATE(2171), 1,
      sym_comment,
  [86697] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4083), 1,
      anon_sym_QMARK,
    STATE(2172), 1,
      sym_comment,
  [86710] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4085), 1,
      anon_sym_QMARK,
    STATE(2173), 1,
      sym_comment,
  [86723] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4087), 1,
      anon_sym_RBRACK,
    STATE(2174), 1,
      sym_comment,
  [86736] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4089), 1,
      anon_sym_LPAREN,
    STATE(2175), 1,
      sym_comment,
  [86749] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4091), 1,
      anon_sym_LPAREN,
    STATE(2176), 1,
      sym_comment,
  [86762] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4093), 1,
      anon_sym_LPAREN,
    STATE(2177), 1,
      sym_comment,
  [86775] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4095), 1,
      sym_identifier,
    STATE(2178), 1,
      sym_comment,
  [86788] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4097), 1,
      anon_sym_from,
    STATE(2179), 1,
      sym_comment,
  [86801] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4099), 1,
      sym_identifier,
    STATE(2180), 1,
      sym_comment,
  [86814] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4101), 1,
      sym_identifier,
    STATE(2181), 1,
      sym_comment,
  [86827] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(3657), 1,
      anon_sym_EQ_GT,
    STATE(2182), 1,
      sym_comment,
  [86840] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4103), 1,
      anon_sym_COLON,
    STATE(2183), 1,
      sym_comment,
  [86853] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4105), 1,
      anon_sym_RBRACK,
    STATE(2184), 1,
      sym_comment,
  [86866] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4107), 1,
      anon_sym_LPAREN,
    STATE(2185), 1,
      sym_comment,
  [86879] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4109), 1,
      anon_sym_LPAREN,
    STATE(2186), 1,
      sym_comment,
  [86892] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4111), 1,
      anon_sym_LPAREN,
    STATE(2187), 1,
      sym_comment,
  [86905] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4113), 1,
      anon_sym_LPAREN,
    STATE(2188), 1,
      sym_comment,
  [86918] = 4,
    ACTIONS(3), 1,
      anon_sym_SLASH_SLASH,
    ACTIONS(5), 1,
      anon_sym_SLASH_STAR,
    ACTIONS(4115), 1,
      sym_identifier,
    STATE(2189), 1,
      sym_comment,
  [86931] = 1,
    ACTIONS(4117), 1,
      ts_builtin_sym_end,
  [86935] = 1,
    ACTIONS(4119), 1,
      ts_builtin_sym_end,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(451)] = 0,
  [SMALL_STATE(452)] = 78,
  [SMALL_STATE(453)] = 158,
  [SMALL_STATE(454)] = 232,
  [SMALL_STATE(455)] = 306,
  [SMALL_STATE(456)] = 377,
  [SMALL_STATE(457)] = 448,
  [SMALL_STATE(458)] = 519,
  [SMALL_STATE(459)] = 590,
  [SMALL_STATE(460)] = 661,
  [SMALL_STATE(461)] = 784,
  [SMALL_STATE(462)] = 855,
  [SMALL_STATE(463)] = 926,
  [SMALL_STATE(464)] = 997,
  [SMALL_STATE(465)] = 1118,
  [SMALL_STATE(466)] = 1241,
  [SMALL_STATE(467)] = 1312,
  [SMALL_STATE(468)] = 1436,
  [SMALL_STATE(469)] = 1560,
  [SMALL_STATE(470)] = 1684,
  [SMALL_STATE(471)] = 1808,
  [SMALL_STATE(472)] = 1932,
  [SMALL_STATE(473)] = 2052,
  [SMALL_STATE(474)] = 2172,
  [SMALL_STATE(475)] = 2242,
  [SMALL_STATE(476)] = 2312,
  [SMALL_STATE(477)] = 2382,
  [SMALL_STATE(478)] = 2502,
  [SMALL_STATE(479)] = 2622,
  [SMALL_STATE(480)] = 2746,
  [SMALL_STATE(481)] = 2816,
  [SMALL_STATE(482)] = 2936,
  [SMALL_STATE(483)] = 3057,
  [SMALL_STATE(484)] = 3178,
  [SMALL_STATE(485)] = 3297,
  [SMALL_STATE(486)] = 3418,
  [SMALL_STATE(487)] = 3539,
  [SMALL_STATE(488)] = 3634,
  [SMALL_STATE(489)] = 3755,
  [SMALL_STATE(490)] = 3848,
  [SMALL_STATE(491)] = 3969,
  [SMALL_STATE(492)] = 4090,
  [SMALL_STATE(493)] = 4211,
  [SMALL_STATE(494)] = 4332,
  [SMALL_STATE(495)] = 4453,
  [SMALL_STATE(496)] = 4571,
  [SMALL_STATE(497)] = 4689,
  [SMALL_STATE(498)] = 4807,
  [SMALL_STATE(499)] = 4925,
  [SMALL_STATE(500)] = 5043,
  [SMALL_STATE(501)] = 5158,
  [SMALL_STATE(502)] = 5273,
  [SMALL_STATE(503)] = 5388,
  [SMALL_STATE(504)] = 5503,
  [SMALL_STATE(505)] = 5618,
  [SMALL_STATE(506)] = 5733,
  [SMALL_STATE(507)] = 5848,
  [SMALL_STATE(508)] = 5963,
  [SMALL_STATE(509)] = 6078,
  [SMALL_STATE(510)] = 6193,
  [SMALL_STATE(511)] = 6308,
  [SMALL_STATE(512)] = 6423,
  [SMALL_STATE(513)] = 6538,
  [SMALL_STATE(514)] = 6653,
  [SMALL_STATE(515)] = 6768,
  [SMALL_STATE(516)] = 6883,
  [SMALL_STATE(517)] = 6998,
  [SMALL_STATE(518)] = 7113,
  [SMALL_STATE(519)] = 7228,
  [SMALL_STATE(520)] = 7343,
  [SMALL_STATE(521)] = 7458,
  [SMALL_STATE(522)] = 7573,
  [SMALL_STATE(523)] = 7688,
  [SMALL_STATE(524)] = 7803,
  [SMALL_STATE(525)] = 7918,
  [SMALL_STATE(526)] = 8033,
  [SMALL_STATE(527)] = 8148,
  [SMALL_STATE(528)] = 8263,
  [SMALL_STATE(529)] = 8378,
  [SMALL_STATE(530)] = 8493,
  [SMALL_STATE(531)] = 8608,
  [SMALL_STATE(532)] = 8723,
  [SMALL_STATE(533)] = 8838,
  [SMALL_STATE(534)] = 8953,
  [SMALL_STATE(535)] = 9068,
  [SMALL_STATE(536)] = 9183,
  [SMALL_STATE(537)] = 9298,
  [SMALL_STATE(538)] = 9413,
  [SMALL_STATE(539)] = 9528,
  [SMALL_STATE(540)] = 9643,
  [SMALL_STATE(541)] = 9758,
  [SMALL_STATE(542)] = 9873,
  [SMALL_STATE(543)] = 9988,
  [SMALL_STATE(544)] = 10103,
  [SMALL_STATE(545)] = 10218,
  [SMALL_STATE(546)] = 10333,
  [SMALL_STATE(547)] = 10448,
  [SMALL_STATE(548)] = 10563,
  [SMALL_STATE(549)] = 10678,
  [SMALL_STATE(550)] = 10793,
  [SMALL_STATE(551)] = 10908,
  [SMALL_STATE(552)] = 11023,
  [SMALL_STATE(553)] = 11138,
  [SMALL_STATE(554)] = 11253,
  [SMALL_STATE(555)] = 11368,
  [SMALL_STATE(556)] = 11480,
  [SMALL_STATE(557)] = 11592,
  [SMALL_STATE(558)] = 11704,
  [SMALL_STATE(559)] = 11816,
  [SMALL_STATE(560)] = 11928,
  [SMALL_STATE(561)] = 12040,
  [SMALL_STATE(562)] = 12152,
  [SMALL_STATE(563)] = 12264,
  [SMALL_STATE(564)] = 12376,
  [SMALL_STATE(565)] = 12488,
  [SMALL_STATE(566)] = 12600,
  [SMALL_STATE(567)] = 12712,
  [SMALL_STATE(568)] = 12824,
  [SMALL_STATE(569)] = 12936,
  [SMALL_STATE(570)] = 13048,
  [SMALL_STATE(571)] = 13160,
  [SMALL_STATE(572)] = 13272,
  [SMALL_STATE(573)] = 13384,
  [SMALL_STATE(574)] = 13496,
  [SMALL_STATE(575)] = 13608,
  [SMALL_STATE(576)] = 13720,
  [SMALL_STATE(577)] = 13832,
  [SMALL_STATE(578)] = 13944,
  [SMALL_STATE(579)] = 14056,
  [SMALL_STATE(580)] = 14168,
  [SMALL_STATE(581)] = 14280,
  [SMALL_STATE(582)] = 14392,
  [SMALL_STATE(583)] = 14504,
  [SMALL_STATE(584)] = 14616,
  [SMALL_STATE(585)] = 14728,
  [SMALL_STATE(586)] = 14840,
  [SMALL_STATE(587)] = 14952,
  [SMALL_STATE(588)] = 15064,
  [SMALL_STATE(589)] = 15176,
  [SMALL_STATE(590)] = 15288,
  [SMALL_STATE(591)] = 15400,
  [SMALL_STATE(592)] = 15512,
  [SMALL_STATE(593)] = 15624,
  [SMALL_STATE(594)] = 15716,
  [SMALL_STATE(595)] = 15828,
  [SMALL_STATE(596)] = 15940,
  [SMALL_STATE(597)] = 16052,
  [SMALL_STATE(598)] = 16164,
  [SMALL_STATE(599)] = 16276,
  [SMALL_STATE(600)] = 16388,
  [SMALL_STATE(601)] = 16500,
  [SMALL_STATE(602)] = 16612,
  [SMALL_STATE(603)] = 16724,
  [SMALL_STATE(604)] = 16836,
  [SMALL_STATE(605)] = 16948,
  [SMALL_STATE(606)] = 17060,
  [SMALL_STATE(607)] = 17172,
  [SMALL_STATE(608)] = 17284,
  [SMALL_STATE(609)] = 17396,
  [SMALL_STATE(610)] = 17508,
  [SMALL_STATE(611)] = 17620,
  [SMALL_STATE(612)] = 17732,
  [SMALL_STATE(613)] = 17844,
  [SMALL_STATE(614)] = 17956,
  [SMALL_STATE(615)] = 18068,
  [SMALL_STATE(616)] = 18180,
  [SMALL_STATE(617)] = 18292,
  [SMALL_STATE(618)] = 18404,
  [SMALL_STATE(619)] = 18516,
  [SMALL_STATE(620)] = 18628,
  [SMALL_STATE(621)] = 18740,
  [SMALL_STATE(622)] = 18852,
  [SMALL_STATE(623)] = 18964,
  [SMALL_STATE(624)] = 19076,
  [SMALL_STATE(625)] = 19188,
  [SMALL_STATE(626)] = 19300,
  [SMALL_STATE(627)] = 19412,
  [SMALL_STATE(628)] = 19524,
  [SMALL_STATE(629)] = 19636,
  [SMALL_STATE(630)] = 19748,
  [SMALL_STATE(631)] = 19860,
  [SMALL_STATE(632)] = 19972,
  [SMALL_STATE(633)] = 20084,
  [SMALL_STATE(634)] = 20196,
  [SMALL_STATE(635)] = 20308,
  [SMALL_STATE(636)] = 20420,
  [SMALL_STATE(637)] = 20532,
  [SMALL_STATE(638)] = 20644,
  [SMALL_STATE(639)] = 20756,
  [SMALL_STATE(640)] = 20868,
  [SMALL_STATE(641)] = 20980,
  [SMALL_STATE(642)] = 21092,
  [SMALL_STATE(643)] = 21204,
  [SMALL_STATE(644)] = 21316,
  [SMALL_STATE(645)] = 21428,
  [SMALL_STATE(646)] = 21540,
  [SMALL_STATE(647)] = 21652,
  [SMALL_STATE(648)] = 21764,
  [SMALL_STATE(649)] = 21876,
  [SMALL_STATE(650)] = 21988,
  [SMALL_STATE(651)] = 22100,
  [SMALL_STATE(652)] = 22212,
  [SMALL_STATE(653)] = 22324,
  [SMALL_STATE(654)] = 22436,
  [SMALL_STATE(655)] = 22548,
  [SMALL_STATE(656)] = 22660,
  [SMALL_STATE(657)] = 22772,
  [SMALL_STATE(658)] = 22884,
  [SMALL_STATE(659)] = 22996,
  [SMALL_STATE(660)] = 23108,
  [SMALL_STATE(661)] = 23220,
  [SMALL_STATE(662)] = 23332,
  [SMALL_STATE(663)] = 23444,
  [SMALL_STATE(664)] = 23556,
  [SMALL_STATE(665)] = 23668,
  [SMALL_STATE(666)] = 23780,
  [SMALL_STATE(667)] = 23892,
  [SMALL_STATE(668)] = 24004,
  [SMALL_STATE(669)] = 24116,
  [SMALL_STATE(670)] = 24228,
  [SMALL_STATE(671)] = 24340,
  [SMALL_STATE(672)] = 24452,
  [SMALL_STATE(673)] = 24564,
  [SMALL_STATE(674)] = 24676,
  [SMALL_STATE(675)] = 24788,
  [SMALL_STATE(676)] = 24900,
  [SMALL_STATE(677)] = 25012,
  [SMALL_STATE(678)] = 25124,
  [SMALL_STATE(679)] = 25236,
  [SMALL_STATE(680)] = 25348,
  [SMALL_STATE(681)] = 25460,
  [SMALL_STATE(682)] = 25572,
  [SMALL_STATE(683)] = 25684,
  [SMALL_STATE(684)] = 25796,
  [SMALL_STATE(685)] = 25908,
  [SMALL_STATE(686)] = 26020,
  [SMALL_STATE(687)] = 26132,
  [SMALL_STATE(688)] = 26244,
  [SMALL_STATE(689)] = 26356,
  [SMALL_STATE(690)] = 26468,
  [SMALL_STATE(691)] = 26580,
  [SMALL_STATE(692)] = 26692,
  [SMALL_STATE(693)] = 26804,
  [SMALL_STATE(694)] = 26916,
  [SMALL_STATE(695)] = 27028,
  [SMALL_STATE(696)] = 27140,
  [SMALL_STATE(697)] = 27252,
  [SMALL_STATE(698)] = 27364,
  [SMALL_STATE(699)] = 27476,
  [SMALL_STATE(700)] = 27588,
  [SMALL_STATE(701)] = 27700,
  [SMALL_STATE(702)] = 27812,
  [SMALL_STATE(703)] = 27924,
  [SMALL_STATE(704)] = 28036,
  [SMALL_STATE(705)] = 28148,
  [SMALL_STATE(706)] = 28260,
  [SMALL_STATE(707)] = 28372,
  [SMALL_STATE(708)] = 28484,
  [SMALL_STATE(709)] = 28596,
  [SMALL_STATE(710)] = 28708,
  [SMALL_STATE(711)] = 28820,
  [SMALL_STATE(712)] = 28932,
  [SMALL_STATE(713)] = 29044,
  [SMALL_STATE(714)] = 29156,
  [SMALL_STATE(715)] = 29268,
  [SMALL_STATE(716)] = 29380,
  [SMALL_STATE(717)] = 29492,
  [SMALL_STATE(718)] = 29604,
  [SMALL_STATE(719)] = 29716,
  [SMALL_STATE(720)] = 29828,
  [SMALL_STATE(721)] = 29940,
  [SMALL_STATE(722)] = 30052,
  [SMALL_STATE(723)] = 30130,
  [SMALL_STATE(724)] = 30205,
  [SMALL_STATE(725)] = 30278,
  [SMALL_STATE(726)] = 30346,
  [SMALL_STATE(727)] = 30418,
  [SMALL_STATE(728)] = 30484,
  [SMALL_STATE(729)] = 30552,
  [SMALL_STATE(730)] = 30618,
  [SMALL_STATE(731)] = 30720,
  [SMALL_STATE(732)] = 30820,
  [SMALL_STATE(733)] = 30918,
  [SMALL_STATE(734)] = 31014,
  [SMALL_STATE(735)] = 31108,
  [SMALL_STATE(736)] = 31198,
  [SMALL_STATE(737)] = 31266,
  [SMALL_STATE(738)] = 31330,
  [SMALL_STATE(739)] = 31398,
  [SMALL_STATE(740)] = 31468,
  [SMALL_STATE(741)] = 31552,
  [SMALL_STATE(742)] = 31632,
  [SMALL_STATE(743)] = 31710,
  [SMALL_STATE(744)] = 31780,
  [SMALL_STATE(745)] = 31890,
  [SMALL_STATE(746)] = 31954,
  [SMALL_STATE(747)] = 32024,
  [SMALL_STATE(748)] = 32088,
  [SMALL_STATE(749)] = 32156,
  [SMALL_STATE(750)] = 32226,
  [SMALL_STATE(751)] = 32296,
  [SMALL_STATE(752)] = 32406,
  [SMALL_STATE(753)] = 32516,
  [SMALL_STATE(754)] = 32580,
  [SMALL_STATE(755)] = 32644,
  [SMALL_STATE(756)] = 32708,
  [SMALL_STATE(757)] = 32818,
  [SMALL_STATE(758)] = 32882,
  [SMALL_STATE(759)] = 32950,
  [SMALL_STATE(760)] = 33060,
  [SMALL_STATE(761)] = 33128,
  [SMALL_STATE(762)] = 33234,
  [SMALL_STATE(763)] = 33298,
  [SMALL_STATE(764)] = 33368,
  [SMALL_STATE(765)] = 33480,
  [SMALL_STATE(766)] = 33552,
  [SMALL_STATE(767)] = 33620,
  [SMALL_STATE(768)] = 33730,
  [SMALL_STATE(769)] = 33794,
  [SMALL_STATE(770)] = 33864,
  [SMALL_STATE(771)] = 33932,
  [SMALL_STATE(772)] = 34002,
  [SMALL_STATE(773)] = 34065,
  [SMALL_STATE(774)] = 34130,
  [SMALL_STATE(775)] = 34193,
  [SMALL_STATE(776)] = 34258,
  [SMALL_STATE(777)] = 34325,
  [SMALL_STATE(778)] = 34392,
  [SMALL_STATE(779)] = 34457,
  [SMALL_STATE(780)] = 34520,
  [SMALL_STATE(781)] = 34583,
  [SMALL_STATE(782)] = 34646,
  [SMALL_STATE(783)] = 34708,
  [SMALL_STATE(784)] = 34770,
  [SMALL_STATE(785)] = 34832,
  [SMALL_STATE(786)] = 34894,
  [SMALL_STATE(787)] = 34956,
  [SMALL_STATE(788)] = 35018,
  [SMALL_STATE(789)] = 35080,
  [SMALL_STATE(790)] = 35142,
  [SMALL_STATE(791)] = 35204,
  [SMALL_STATE(792)] = 35266,
  [SMALL_STATE(793)] = 35328,
  [SMALL_STATE(794)] = 35390,
  [SMALL_STATE(795)] = 35452,
  [SMALL_STATE(796)] = 35514,
  [SMALL_STATE(797)] = 35576,
  [SMALL_STATE(798)] = 35638,
  [SMALL_STATE(799)] = 35700,
  [SMALL_STATE(800)] = 35762,
  [SMALL_STATE(801)] = 35824,
  [SMALL_STATE(802)] = 35900,
  [SMALL_STATE(803)] = 35962,
  [SMALL_STATE(804)] = 36024,
  [SMALL_STATE(805)] = 36086,
  [SMALL_STATE(806)] = 36148,
  [SMALL_STATE(807)] = 36210,
  [SMALL_STATE(808)] = 36272,
  [SMALL_STATE(809)] = 36334,
  [SMALL_STATE(810)] = 36396,
  [SMALL_STATE(811)] = 36458,
  [SMALL_STATE(812)] = 36520,
  [SMALL_STATE(813)] = 36582,
  [SMALL_STATE(814)] = 36647,
  [SMALL_STATE(815)] = 36710,
  [SMALL_STATE(816)] = 36773,
  [SMALL_STATE(817)] = 36838,
  [SMALL_STATE(818)] = 36901,
  [SMALL_STATE(819)] = 36966,
  [SMALL_STATE(820)] = 37033,
  [SMALL_STATE(821)] = 37098,
  [SMALL_STATE(822)] = 37161,
  [SMALL_STATE(823)] = 37226,
  [SMALL_STATE(824)] = 37289,
  [SMALL_STATE(825)] = 37354,
  [SMALL_STATE(826)] = 37414,
  [SMALL_STATE(827)] = 37474,
  [SMALL_STATE(828)] = 37534,
  [SMALL_STATE(829)] = 37594,
  [SMALL_STATE(830)] = 37654,
  [SMALL_STATE(831)] = 37714,
  [SMALL_STATE(832)] = 37774,
  [SMALL_STATE(833)] = 37834,
  [SMALL_STATE(834)] = 37894,
  [SMALL_STATE(835)] = 37954,
  [SMALL_STATE(836)] = 38014,
  [SMALL_STATE(837)] = 38074,
  [SMALL_STATE(838)] = 38134,
  [SMALL_STATE(839)] = 38194,
  [SMALL_STATE(840)] = 38254,
  [SMALL_STATE(841)] = 38314,
  [SMALL_STATE(842)] = 38374,
  [SMALL_STATE(843)] = 38434,
  [SMALL_STATE(844)] = 38494,
  [SMALL_STATE(845)] = 38554,
  [SMALL_STATE(846)] = 38614,
  [SMALL_STATE(847)] = 38674,
  [SMALL_STATE(848)] = 38734,
  [SMALL_STATE(849)] = 38800,
  [SMALL_STATE(850)] = 38865,
  [SMALL_STATE(851)] = 38933,
  [SMALL_STATE(852)] = 38993,
  [SMALL_STATE(853)] = 39049,
  [SMALL_STATE(854)] = 39105,
  [SMALL_STATE(855)] = 39164,
  [SMALL_STATE(856)] = 39219,
  [SMALL_STATE(857)] = 39274,
  [SMALL_STATE(858)] = 39329,
  [SMALL_STATE(859)] = 39384,
  [SMALL_STATE(860)] = 39439,
  [SMALL_STATE(861)] = 39494,
  [SMALL_STATE(862)] = 39549,
  [SMALL_STATE(863)] = 39603,
  [SMALL_STATE(864)] = 39657,
  [SMALL_STATE(865)] = 39717,
  [SMALL_STATE(866)] = 39771,
  [SMALL_STATE(867)] = 39827,
  [SMALL_STATE(868)] = 39881,
  [SMALL_STATE(869)] = 39935,
  [SMALL_STATE(870)] = 39989,
  [SMALL_STATE(871)] = 40043,
  [SMALL_STATE(872)] = 40097,
  [SMALL_STATE(873)] = 40151,
  [SMALL_STATE(874)] = 40205,
  [SMALL_STATE(875)] = 40259,
  [SMALL_STATE(876)] = 40313,
  [SMALL_STATE(877)] = 40367,
  [SMALL_STATE(878)] = 40421,
  [SMALL_STATE(879)] = 40475,
  [SMALL_STATE(880)] = 40529,
  [SMALL_STATE(881)] = 40583,
  [SMALL_STATE(882)] = 40637,
  [SMALL_STATE(883)] = 40697,
  [SMALL_STATE(884)] = 40751,
  [SMALL_STATE(885)] = 40805,
  [SMALL_STATE(886)] = 40859,
  [SMALL_STATE(887)] = 40913,
  [SMALL_STATE(888)] = 40969,
  [SMALL_STATE(889)] = 41023,
  [SMALL_STATE(890)] = 41079,
  [SMALL_STATE(891)] = 41133,
  [SMALL_STATE(892)] = 41187,
  [SMALL_STATE(893)] = 41245,
  [SMALL_STATE(894)] = 41303,
  [SMALL_STATE(895)] = 41363,
  [SMALL_STATE(896)] = 41423,
  [SMALL_STATE(897)] = 41483,
  [SMALL_STATE(898)] = 41543,
  [SMALL_STATE(899)] = 41597,
  [SMALL_STATE(900)] = 41651,
  [SMALL_STATE(901)] = 41705,
  [SMALL_STATE(902)] = 41761,
  [SMALL_STATE(903)] = 41817,
  [SMALL_STATE(904)] = 41875,
  [SMALL_STATE(905)] = 41929,
  [SMALL_STATE(906)] = 41982,
  [SMALL_STATE(907)] = 42039,
  [SMALL_STATE(908)] = 42138,
  [SMALL_STATE(909)] = 42191,
  [SMALL_STATE(910)] = 42248,
  [SMALL_STATE(911)] = 42301,
  [SMALL_STATE(912)] = 42400,
  [SMALL_STATE(913)] = 42457,
  [SMALL_STATE(914)] = 42510,
  [SMALL_STATE(915)] = 42565,
  [SMALL_STATE(916)] = 42618,
  [SMALL_STATE(917)] = 42671,
  [SMALL_STATE(918)] = 42724,
  [SMALL_STATE(919)] = 42823,
  [SMALL_STATE(920)] = 42876,
  [SMALL_STATE(921)] = 42929,
  [SMALL_STATE(922)] = 42982,
  [SMALL_STATE(923)] = 43035,
  [SMALL_STATE(924)] = 43088,
  [SMALL_STATE(925)] = 43141,
  [SMALL_STATE(926)] = 43240,
  [SMALL_STATE(927)] = 43339,
  [SMALL_STATE(928)] = 43392,
  [SMALL_STATE(929)] = 43483,
  [SMALL_STATE(930)] = 43572,
  [SMALL_STATE(931)] = 43659,
  [SMALL_STATE(932)] = 43744,
  [SMALL_STATE(933)] = 43827,
  [SMALL_STATE(934)] = 43906,
  [SMALL_STATE(935)] = 44005,
  [SMALL_STATE(936)] = 44104,
  [SMALL_STATE(937)] = 44199,
  [SMALL_STATE(938)] = 44298,
  [SMALL_STATE(939)] = 44397,
  [SMALL_STATE(940)] = 44456,
  [SMALL_STATE(941)] = 44509,
  [SMALL_STATE(942)] = 44566,
  [SMALL_STATE(943)] = 44619,
  [SMALL_STATE(944)] = 44718,
  [SMALL_STATE(945)] = 44771,
  [SMALL_STATE(946)] = 44824,
  [SMALL_STATE(947)] = 44877,
  [SMALL_STATE(948)] = 44930,
  [SMALL_STATE(949)] = 44983,
  [SMALL_STATE(950)] = 45036,
  [SMALL_STATE(951)] = 45089,
  [SMALL_STATE(952)] = 45142,
  [SMALL_STATE(953)] = 45195,
  [SMALL_STATE(954)] = 45248,
  [SMALL_STATE(955)] = 45301,
  [SMALL_STATE(956)] = 45354,
  [SMALL_STATE(957)] = 45407,
  [SMALL_STATE(958)] = 45460,
  [SMALL_STATE(959)] = 45513,
  [SMALL_STATE(960)] = 45612,
  [SMALL_STATE(961)] = 45711,
  [SMALL_STATE(962)] = 45764,
  [SMALL_STATE(963)] = 45819,
  [SMALL_STATE(964)] = 45880,
  [SMALL_STATE(965)] = 45971,
  [SMALL_STATE(966)] = 46024,
  [SMALL_STATE(967)] = 46113,
  [SMALL_STATE(968)] = 46200,
  [SMALL_STATE(969)] = 46285,
  [SMALL_STATE(970)] = 46368,
  [SMALL_STATE(971)] = 46447,
  [SMALL_STATE(972)] = 46502,
  [SMALL_STATE(973)] = 46559,
  [SMALL_STATE(974)] = 46616,
  [SMALL_STATE(975)] = 46669,
  [SMALL_STATE(976)] = 46742,
  [SMALL_STATE(977)] = 46811,
  [SMALL_STATE(978)] = 46878,
  [SMALL_STATE(979)] = 46973,
  [SMALL_STATE(980)] = 47034,
  [SMALL_STATE(981)] = 47107,
  [SMALL_STATE(982)] = 47176,
  [SMALL_STATE(983)] = 47243,
  [SMALL_STATE(984)] = 47296,
  [SMALL_STATE(985)] = 47400,
  [SMALL_STATE(986)] = 47458,
  [SMALL_STATE(987)] = 47510,
  [SMALL_STATE(988)] = 47614,
  [SMALL_STATE(989)] = 47666,
  [SMALL_STATE(990)] = 47718,
  [SMALL_STATE(991)] = 47770,
  [SMALL_STATE(992)] = 47874,
  [SMALL_STATE(993)] = 47978,
  [SMALL_STATE(994)] = 48082,
  [SMALL_STATE(995)] = 48134,
  [SMALL_STATE(996)] = 48186,
  [SMALL_STATE(997)] = 48290,
  [SMALL_STATE(998)] = 48394,
  [SMALL_STATE(999)] = 48452,
  [SMALL_STATE(1000)] = 48510,
  [SMALL_STATE(1001)] = 48562,
  [SMALL_STATE(1002)] = 48614,
  [SMALL_STATE(1003)] = 48666,
  [SMALL_STATE(1004)] = 48718,
  [SMALL_STATE(1005)] = 48770,
  [SMALL_STATE(1006)] = 48822,
  [SMALL_STATE(1007)] = 48874,
  [SMALL_STATE(1008)] = 48926,
  [SMALL_STATE(1009)] = 48978,
  [SMALL_STATE(1010)] = 49030,
  [SMALL_STATE(1011)] = 49082,
  [SMALL_STATE(1012)] = 49134,
  [SMALL_STATE(1013)] = 49186,
  [SMALL_STATE(1014)] = 49238,
  [SMALL_STATE(1015)] = 49290,
  [SMALL_STATE(1016)] = 49342,
  [SMALL_STATE(1017)] = 49394,
  [SMALL_STATE(1018)] = 49446,
  [SMALL_STATE(1019)] = 49550,
  [SMALL_STATE(1020)] = 49602,
  [SMALL_STATE(1021)] = 49654,
  [SMALL_STATE(1022)] = 49706,
  [SMALL_STATE(1023)] = 49758,
  [SMALL_STATE(1024)] = 49810,
  [SMALL_STATE(1025)] = 49862,
  [SMALL_STATE(1026)] = 49914,
  [SMALL_STATE(1027)] = 49966,
  [SMALL_STATE(1028)] = 50018,
  [SMALL_STATE(1029)] = 50070,
  [SMALL_STATE(1030)] = 50122,
  [SMALL_STATE(1031)] = 50174,
  [SMALL_STATE(1032)] = 50226,
  [SMALL_STATE(1033)] = 50278,
  [SMALL_STATE(1034)] = 50330,
  [SMALL_STATE(1035)] = 50382,
  [SMALL_STATE(1036)] = 50434,
  [SMALL_STATE(1037)] = 50486,
  [SMALL_STATE(1038)] = 50538,
  [SMALL_STATE(1039)] = 50642,
  [SMALL_STATE(1040)] = 50746,
  [SMALL_STATE(1041)] = 50798,
  [SMALL_STATE(1042)] = 50850,
  [SMALL_STATE(1043)] = 50902,
  [SMALL_STATE(1044)] = 51003,
  [SMALL_STATE(1045)] = 51104,
  [SMALL_STATE(1046)] = 51205,
  [SMALL_STATE(1047)] = 51306,
  [SMALL_STATE(1048)] = 51407,
  [SMALL_STATE(1049)] = 51508,
  [SMALL_STATE(1050)] = 51609,
  [SMALL_STATE(1051)] = 51710,
  [SMALL_STATE(1052)] = 51811,
  [SMALL_STATE(1053)] = 51912,
  [SMALL_STATE(1054)] = 52013,
  [SMALL_STATE(1055)] = 52114,
  [SMALL_STATE(1056)] = 52215,
  [SMALL_STATE(1057)] = 52316,
  [SMALL_STATE(1058)] = 52417,
  [SMALL_STATE(1059)] = 52518,
  [SMALL_STATE(1060)] = 52619,
  [SMALL_STATE(1061)] = 52720,
  [SMALL_STATE(1062)] = 52821,
  [SMALL_STATE(1063)] = 52922,
  [SMALL_STATE(1064)] = 53023,
  [SMALL_STATE(1065)] = 53124,
  [SMALL_STATE(1066)] = 53225,
  [SMALL_STATE(1067)] = 53326,
  [SMALL_STATE(1068)] = 53427,
  [SMALL_STATE(1069)] = 53528,
  [SMALL_STATE(1070)] = 53624,
  [SMALL_STATE(1071)] = 53720,
  [SMALL_STATE(1072)] = 53816,
  [SMALL_STATE(1073)] = 53914,
  [SMALL_STATE(1074)] = 54010,
  [SMALL_STATE(1075)] = 54106,
  [SMALL_STATE(1076)] = 54202,
  [SMALL_STATE(1077)] = 54298,
  [SMALL_STATE(1078)] = 54394,
  [SMALL_STATE(1079)] = 54490,
  [SMALL_STATE(1080)] = 54586,
  [SMALL_STATE(1081)] = 54682,
  [SMALL_STATE(1082)] = 54778,
  [SMALL_STATE(1083)] = 54874,
  [SMALL_STATE(1084)] = 54970,
  [SMALL_STATE(1085)] = 55066,
  [SMALL_STATE(1086)] = 55162,
  [SMALL_STATE(1087)] = 55258,
  [SMALL_STATE(1088)] = 55353,
  [SMALL_STATE(1089)] = 55448,
  [SMALL_STATE(1090)] = 55543,
  [SMALL_STATE(1091)] = 55638,
  [SMALL_STATE(1092)] = 55733,
  [SMALL_STATE(1093)] = 55828,
  [SMALL_STATE(1094)] = 55883,
  [SMALL_STATE(1095)] = 55938,
  [SMALL_STATE(1096)] = 56033,
  [SMALL_STATE(1097)] = 56128,
  [SMALL_STATE(1098)] = 56223,
  [SMALL_STATE(1099)] = 56318,
  [SMALL_STATE(1100)] = 56413,
  [SMALL_STATE(1101)] = 56508,
  [SMALL_STATE(1102)] = 56603,
  [SMALL_STATE(1103)] = 56698,
  [SMALL_STATE(1104)] = 56793,
  [SMALL_STATE(1105)] = 56888,
  [SMALL_STATE(1106)] = 56983,
  [SMALL_STATE(1107)] = 57078,
  [SMALL_STATE(1108)] = 57173,
  [SMALL_STATE(1109)] = 57268,
  [SMALL_STATE(1110)] = 57363,
  [SMALL_STATE(1111)] = 57458,
  [SMALL_STATE(1112)] = 57553,
  [SMALL_STATE(1113)] = 57648,
  [SMALL_STATE(1114)] = 57743,
  [SMALL_STATE(1115)] = 57838,
  [SMALL_STATE(1116)] = 57893,
  [SMALL_STATE(1117)] = 57988,
  [SMALL_STATE(1118)] = 58083,
  [SMALL_STATE(1119)] = 58178,
  [SMALL_STATE(1120)] = 58273,
  [SMALL_STATE(1121)] = 58368,
  [SMALL_STATE(1122)] = 58463,
  [SMALL_STATE(1123)] = 58558,
  [SMALL_STATE(1124)] = 58653,
  [SMALL_STATE(1125)] = 58748,
  [SMALL_STATE(1126)] = 58843,
  [SMALL_STATE(1127)] = 58938,
  [SMALL_STATE(1128)] = 59033,
  [SMALL_STATE(1129)] = 59128,
  [SMALL_STATE(1130)] = 59223,
  [SMALL_STATE(1131)] = 59318,
  [SMALL_STATE(1132)] = 59413,
  [SMALL_STATE(1133)] = 59508,
  [SMALL_STATE(1134)] = 59603,
  [SMALL_STATE(1135)] = 59698,
  [SMALL_STATE(1136)] = 59793,
  [SMALL_STATE(1137)] = 59888,
  [SMALL_STATE(1138)] = 59983,
  [SMALL_STATE(1139)] = 60078,
  [SMALL_STATE(1140)] = 60173,
  [SMALL_STATE(1141)] = 60268,
  [SMALL_STATE(1142)] = 60363,
  [SMALL_STATE(1143)] = 60458,
  [SMALL_STATE(1144)] = 60553,
  [SMALL_STATE(1145)] = 60648,
  [SMALL_STATE(1146)] = 60743,
  [SMALL_STATE(1147)] = 60838,
  [SMALL_STATE(1148)] = 60930,
  [SMALL_STATE(1149)] = 61022,
  [SMALL_STATE(1150)] = 61114,
  [SMALL_STATE(1151)] = 61164,
  [SMALL_STATE(1152)] = 61214,
  [SMALL_STATE(1153)] = 61306,
  [SMALL_STATE(1154)] = 61398,
  [SMALL_STATE(1155)] = 61439,
  [SMALL_STATE(1156)] = 61510,
  [SMALL_STATE(1157)] = 61583,
  [SMALL_STATE(1158)] = 61624,
  [SMALL_STATE(1159)] = 61665,
  [SMALL_STATE(1160)] = 61736,
  [SMALL_STATE(1161)] = 61793,
  [SMALL_STATE(1162)] = 61850,
  [SMALL_STATE(1163)] = 61907,
  [SMALL_STATE(1164)] = 61964,
  [SMALL_STATE(1165)] = 62021,
  [SMALL_STATE(1166)] = 62078,
  [SMALL_STATE(1167)] = 62135,
  [SMALL_STATE(1168)] = 62192,
  [SMALL_STATE(1169)] = 62249,
  [SMALL_STATE(1170)] = 62306,
  [SMALL_STATE(1171)] = 62363,
  [SMALL_STATE(1172)] = 62420,
  [SMALL_STATE(1173)] = 62477,
  [SMALL_STATE(1174)] = 62534,
  [SMALL_STATE(1175)] = 62591,
  [SMALL_STATE(1176)] = 62648,
  [SMALL_STATE(1177)] = 62705,
  [SMALL_STATE(1178)] = 62762,
  [SMALL_STATE(1179)] = 62819,
  [SMALL_STATE(1180)] = 62876,
  [SMALL_STATE(1181)] = 62933,
  [SMALL_STATE(1182)] = 62990,
  [SMALL_STATE(1183)] = 63044,
  [SMALL_STATE(1184)] = 63098,
  [SMALL_STATE(1185)] = 63152,
  [SMALL_STATE(1186)] = 63206,
  [SMALL_STATE(1187)] = 63260,
  [SMALL_STATE(1188)] = 63314,
  [SMALL_STATE(1189)] = 63368,
  [SMALL_STATE(1190)] = 63422,
  [SMALL_STATE(1191)] = 63476,
  [SMALL_STATE(1192)] = 63530,
  [SMALL_STATE(1193)] = 63584,
  [SMALL_STATE(1194)] = 63638,
  [SMALL_STATE(1195)] = 63692,
  [SMALL_STATE(1196)] = 63746,
  [SMALL_STATE(1197)] = 63800,
  [SMALL_STATE(1198)] = 63854,
  [SMALL_STATE(1199)] = 63908,
  [SMALL_STATE(1200)] = 63962,
  [SMALL_STATE(1201)] = 64016,
  [SMALL_STATE(1202)] = 64070,
  [SMALL_STATE(1203)] = 64124,
  [SMALL_STATE(1204)] = 64178,
  [SMALL_STATE(1205)] = 64232,
  [SMALL_STATE(1206)] = 64286,
  [SMALL_STATE(1207)] = 64340,
  [SMALL_STATE(1208)] = 64394,
  [SMALL_STATE(1209)] = 64448,
  [SMALL_STATE(1210)] = 64502,
  [SMALL_STATE(1211)] = 64556,
  [SMALL_STATE(1212)] = 64610,
  [SMALL_STATE(1213)] = 64664,
  [SMALL_STATE(1214)] = 64718,
  [SMALL_STATE(1215)] = 64772,
  [SMALL_STATE(1216)] = 64826,
  [SMALL_STATE(1217)] = 64880,
  [SMALL_STATE(1218)] = 64934,
  [SMALL_STATE(1219)] = 64988,
  [SMALL_STATE(1220)] = 65042,
  [SMALL_STATE(1221)] = 65096,
  [SMALL_STATE(1222)] = 65150,
  [SMALL_STATE(1223)] = 65204,
  [SMALL_STATE(1224)] = 65258,
  [SMALL_STATE(1225)] = 65312,
  [SMALL_STATE(1226)] = 65366,
  [SMALL_STATE(1227)] = 65420,
  [SMALL_STATE(1228)] = 65474,
  [SMALL_STATE(1229)] = 65528,
  [SMALL_STATE(1230)] = 65582,
  [SMALL_STATE(1231)] = 65636,
  [SMALL_STATE(1232)] = 65690,
  [SMALL_STATE(1233)] = 65744,
  [SMALL_STATE(1234)] = 65798,
  [SMALL_STATE(1235)] = 65852,
  [SMALL_STATE(1236)] = 65906,
  [SMALL_STATE(1237)] = 65960,
  [SMALL_STATE(1238)] = 66014,
  [SMALL_STATE(1239)] = 66068,
  [SMALL_STATE(1240)] = 66122,
  [SMALL_STATE(1241)] = 66176,
  [SMALL_STATE(1242)] = 66230,
  [SMALL_STATE(1243)] = 66284,
  [SMALL_STATE(1244)] = 66338,
  [SMALL_STATE(1245)] = 66392,
  [SMALL_STATE(1246)] = 66446,
  [SMALL_STATE(1247)] = 66500,
  [SMALL_STATE(1248)] = 66554,
  [SMALL_STATE(1249)] = 66608,
  [SMALL_STATE(1250)] = 66662,
  [SMALL_STATE(1251)] = 66716,
  [SMALL_STATE(1252)] = 66770,
  [SMALL_STATE(1253)] = 66824,
  [SMALL_STATE(1254)] = 66878,
  [SMALL_STATE(1255)] = 66932,
  [SMALL_STATE(1256)] = 66986,
  [SMALL_STATE(1257)] = 67040,
  [SMALL_STATE(1258)] = 67094,
  [SMALL_STATE(1259)] = 67148,
  [SMALL_STATE(1260)] = 67202,
  [SMALL_STATE(1261)] = 67256,
  [SMALL_STATE(1262)] = 67310,
  [SMALL_STATE(1263)] = 67364,
  [SMALL_STATE(1264)] = 67418,
  [SMALL_STATE(1265)] = 67472,
  [SMALL_STATE(1266)] = 67526,
  [SMALL_STATE(1267)] = 67580,
  [SMALL_STATE(1268)] = 67634,
  [SMALL_STATE(1269)] = 67688,
  [SMALL_STATE(1270)] = 67742,
  [SMALL_STATE(1271)] = 67796,
  [SMALL_STATE(1272)] = 67850,
  [SMALL_STATE(1273)] = 67904,
  [SMALL_STATE(1274)] = 67958,
  [SMALL_STATE(1275)] = 68012,
  [SMALL_STATE(1276)] = 68066,
  [SMALL_STATE(1277)] = 68120,
  [SMALL_STATE(1278)] = 68174,
  [SMALL_STATE(1279)] = 68228,
  [SMALL_STATE(1280)] = 68282,
  [SMALL_STATE(1281)] = 68336,
  [SMALL_STATE(1282)] = 68390,
  [SMALL_STATE(1283)] = 68444,
  [SMALL_STATE(1284)] = 68498,
  [SMALL_STATE(1285)] = 68552,
  [SMALL_STATE(1286)] = 68606,
  [SMALL_STATE(1287)] = 68660,
  [SMALL_STATE(1288)] = 68714,
  [SMALL_STATE(1289)] = 68768,
  [SMALL_STATE(1290)] = 68799,
  [SMALL_STATE(1291)] = 68830,
  [SMALL_STATE(1292)] = 68863,
  [SMALL_STATE(1293)] = 68896,
  [SMALL_STATE(1294)] = 68929,
  [SMALL_STATE(1295)] = 68962,
  [SMALL_STATE(1296)] = 69005,
  [SMALL_STATE(1297)] = 69038,
  [SMALL_STATE(1298)] = 69088,
  [SMALL_STATE(1299)] = 69116,
  [SMALL_STATE(1300)] = 69146,
  [SMALL_STATE(1301)] = 69176,
  [SMALL_STATE(1302)] = 69216,
  [SMALL_STATE(1303)] = 69266,
  [SMALL_STATE(1304)] = 69294,
  [SMALL_STATE(1305)] = 69322,
  [SMALL_STATE(1306)] = 69350,
  [SMALL_STATE(1307)] = 69378,
  [SMALL_STATE(1308)] = 69408,
  [SMALL_STATE(1309)] = 69436,
  [SMALL_STATE(1310)] = 69486,
  [SMALL_STATE(1311)] = 69514,
  [SMALL_STATE(1312)] = 69544,
  [SMALL_STATE(1313)] = 69584,
  [SMALL_STATE(1314)] = 69612,
  [SMALL_STATE(1315)] = 69660,
  [SMALL_STATE(1316)] = 69688,
  [SMALL_STATE(1317)] = 69722,
  [SMALL_STATE(1318)] = 69762,
  [SMALL_STATE(1319)] = 69790,
  [SMALL_STATE(1320)] = 69818,
  [SMALL_STATE(1321)] = 69846,
  [SMALL_STATE(1322)] = 69874,
  [SMALL_STATE(1323)] = 69902,
  [SMALL_STATE(1324)] = 69942,
  [SMALL_STATE(1325)] = 69970,
  [SMALL_STATE(1326)] = 70018,
  [SMALL_STATE(1327)] = 70058,
  [SMALL_STATE(1328)] = 70086,
  [SMALL_STATE(1329)] = 70116,
  [SMALL_STATE(1330)] = 70144,
  [SMALL_STATE(1331)] = 70172,
  [SMALL_STATE(1332)] = 70202,
  [SMALL_STATE(1333)] = 70242,
  [SMALL_STATE(1334)] = 70272,
  [SMALL_STATE(1335)] = 70300,
  [SMALL_STATE(1336)] = 70340,
  [SMALL_STATE(1337)] = 70368,
  [SMALL_STATE(1338)] = 70396,
  [SMALL_STATE(1339)] = 70424,
  [SMALL_STATE(1340)] = 70456,
  [SMALL_STATE(1341)] = 70486,
  [SMALL_STATE(1342)] = 70514,
  [SMALL_STATE(1343)] = 70542,
  [SMALL_STATE(1344)] = 70570,
  [SMALL_STATE(1345)] = 70598,
  [SMALL_STATE(1346)] = 70626,
  [SMALL_STATE(1347)] = 70654,
  [SMALL_STATE(1348)] = 70682,
  [SMALL_STATE(1349)] = 70712,
  [SMALL_STATE(1350)] = 70752,
  [SMALL_STATE(1351)] = 70780,
  [SMALL_STATE(1352)] = 70808,
  [SMALL_STATE(1353)] = 70836,
  [SMALL_STATE(1354)] = 70864,
  [SMALL_STATE(1355)] = 70892,
  [SMALL_STATE(1356)] = 70920,
  [SMALL_STATE(1357)] = 70950,
  [SMALL_STATE(1358)] = 70980,
  [SMALL_STATE(1359)] = 71030,
  [SMALL_STATE(1360)] = 71058,
  [SMALL_STATE(1361)] = 71086,
  [SMALL_STATE(1362)] = 71114,
  [SMALL_STATE(1363)] = 71144,
  [SMALL_STATE(1364)] = 71174,
  [SMALL_STATE(1365)] = 71202,
  [SMALL_STATE(1366)] = 71232,
  [SMALL_STATE(1367)] = 71259,
  [SMALL_STATE(1368)] = 71286,
  [SMALL_STATE(1369)] = 71313,
  [SMALL_STATE(1370)] = 71340,
  [SMALL_STATE(1371)] = 71367,
  [SMALL_STATE(1372)] = 71394,
  [SMALL_STATE(1373)] = 71421,
  [SMALL_STATE(1374)] = 71448,
  [SMALL_STATE(1375)] = 71475,
  [SMALL_STATE(1376)] = 71504,
  [SMALL_STATE(1377)] = 71531,
  [SMALL_STATE(1378)] = 71558,
  [SMALL_STATE(1379)] = 71585,
  [SMALL_STATE(1380)] = 71612,
  [SMALL_STATE(1381)] = 71643,
  [SMALL_STATE(1382)] = 71674,
  [SMALL_STATE(1383)] = 71705,
  [SMALL_STATE(1384)] = 71737,
  [SMALL_STATE(1385)] = 71773,
  [SMALL_STATE(1386)] = 71811,
  [SMALL_STATE(1387)] = 71857,
  [SMALL_STATE(1388)] = 71900,
  [SMALL_STATE(1389)] = 71935,
  [SMALL_STATE(1390)] = 71962,
  [SMALL_STATE(1391)] = 72005,
  [SMALL_STATE(1392)] = 72040,
  [SMALL_STATE(1393)] = 72083,
  [SMALL_STATE(1394)] = 72126,
  [SMALL_STATE(1395)] = 72155,
  [SMALL_STATE(1396)] = 72182,
  [SMALL_STATE(1397)] = 72225,
  [SMALL_STATE(1398)] = 72249,
  [SMALL_STATE(1399)] = 72289,
  [SMALL_STATE(1400)] = 72313,
  [SMALL_STATE(1401)] = 72353,
  [SMALL_STATE(1402)] = 72393,
  [SMALL_STATE(1403)] = 72417,
  [SMALL_STATE(1404)] = 72441,
  [SMALL_STATE(1405)] = 72481,
  [SMALL_STATE(1406)] = 72505,
  [SMALL_STATE(1407)] = 72529,
  [SMALL_STATE(1408)] = 72569,
  [SMALL_STATE(1409)] = 72595,
  [SMALL_STATE(1410)] = 72619,
  [SMALL_STATE(1411)] = 72643,
  [SMALL_STATE(1412)] = 72667,
  [SMALL_STATE(1413)] = 72691,
  [SMALL_STATE(1414)] = 72731,
  [SMALL_STATE(1415)] = 72755,
  [SMALL_STATE(1416)] = 72779,
  [SMALL_STATE(1417)] = 72815,
  [SMALL_STATE(1418)] = 72839,
  [SMALL_STATE(1419)] = 72879,
  [SMALL_STATE(1420)] = 72903,
  [SMALL_STATE(1421)] = 72943,
  [SMALL_STATE(1422)] = 72967,
  [SMALL_STATE(1423)] = 72991,
  [SMALL_STATE(1424)] = 73015,
  [SMALL_STATE(1425)] = 73039,
  [SMALL_STATE(1426)] = 73063,
  [SMALL_STATE(1427)] = 73087,
  [SMALL_STATE(1428)] = 73111,
  [SMALL_STATE(1429)] = 73135,
  [SMALL_STATE(1430)] = 73159,
  [SMALL_STATE(1431)] = 73183,
  [SMALL_STATE(1432)] = 73207,
  [SMALL_STATE(1433)] = 73243,
  [SMALL_STATE(1434)] = 73267,
  [SMALL_STATE(1435)] = 73291,
  [SMALL_STATE(1436)] = 73315,
  [SMALL_STATE(1437)] = 73339,
  [SMALL_STATE(1438)] = 73363,
  [SMALL_STATE(1439)] = 73387,
  [SMALL_STATE(1440)] = 73411,
  [SMALL_STATE(1441)] = 73435,
  [SMALL_STATE(1442)] = 73459,
  [SMALL_STATE(1443)] = 73483,
  [SMALL_STATE(1444)] = 73507,
  [SMALL_STATE(1445)] = 73531,
  [SMALL_STATE(1446)] = 73555,
  [SMALL_STATE(1447)] = 73579,
  [SMALL_STATE(1448)] = 73619,
  [SMALL_STATE(1449)] = 73643,
  [SMALL_STATE(1450)] = 73667,
  [SMALL_STATE(1451)] = 73707,
  [SMALL_STATE(1452)] = 73731,
  [SMALL_STATE(1453)] = 73755,
  [SMALL_STATE(1454)] = 73779,
  [SMALL_STATE(1455)] = 73803,
  [SMALL_STATE(1456)] = 73827,
  [SMALL_STATE(1457)] = 73851,
  [SMALL_STATE(1458)] = 73876,
  [SMALL_STATE(1459)] = 73899,
  [SMALL_STATE(1460)] = 73936,
  [SMALL_STATE(1461)] = 73961,
  [SMALL_STATE(1462)] = 73984,
  [SMALL_STATE(1463)] = 74007,
  [SMALL_STATE(1464)] = 74044,
  [SMALL_STATE(1465)] = 74071,
  [SMALL_STATE(1466)] = 74094,
  [SMALL_STATE(1467)] = 74117,
  [SMALL_STATE(1468)] = 74142,
  [SMALL_STATE(1469)] = 74166,
  [SMALL_STATE(1470)] = 74190,
  [SMALL_STATE(1471)] = 74212,
  [SMALL_STATE(1472)] = 74234,
  [SMALL_STATE(1473)] = 74256,
  [SMALL_STATE(1474)] = 74282,
  [SMALL_STATE(1475)] = 74304,
  [SMALL_STATE(1476)] = 74326,
  [SMALL_STATE(1477)] = 74348,
  [SMALL_STATE(1478)] = 74370,
  [SMALL_STATE(1479)] = 74394,
  [SMALL_STATE(1480)] = 74414,
  [SMALL_STATE(1481)] = 74438,
  [SMALL_STATE(1482)] = 74460,
  [SMALL_STATE(1483)] = 74486,
  [SMALL_STATE(1484)] = 74512,
  [SMALL_STATE(1485)] = 74531,
  [SMALL_STATE(1486)] = 74550,
  [SMALL_STATE(1487)] = 74581,
  [SMALL_STATE(1488)] = 74604,
  [SMALL_STATE(1489)] = 74623,
  [SMALL_STATE(1490)] = 74646,
  [SMALL_STATE(1491)] = 74669,
  [SMALL_STATE(1492)] = 74688,
  [SMALL_STATE(1493)] = 74707,
  [SMALL_STATE(1494)] = 74732,
  [SMALL_STATE(1495)] = 74751,
  [SMALL_STATE(1496)] = 74774,
  [SMALL_STATE(1497)] = 74793,
  [SMALL_STATE(1498)] = 74824,
  [SMALL_STATE(1499)] = 74843,
  [SMALL_STATE(1500)] = 74874,
  [SMALL_STATE(1501)] = 74893,
  [SMALL_STATE(1502)] = 74916,
  [SMALL_STATE(1503)] = 74947,
  [SMALL_STATE(1504)] = 74978,
  [SMALL_STATE(1505)] = 74999,
  [SMALL_STATE(1506)] = 75018,
  [SMALL_STATE(1507)] = 75049,
  [SMALL_STATE(1508)] = 75080,
  [SMALL_STATE(1509)] = 75099,
  [SMALL_STATE(1510)] = 75130,
  [SMALL_STATE(1511)] = 75161,
  [SMALL_STATE(1512)] = 75192,
  [SMALL_STATE(1513)] = 75223,
  [SMALL_STATE(1514)] = 75250,
  [SMALL_STATE(1515)] = 75281,
  [SMALL_STATE(1516)] = 75300,
  [SMALL_STATE(1517)] = 75323,
  [SMALL_STATE(1518)] = 75354,
  [SMALL_STATE(1519)] = 75374,
  [SMALL_STATE(1520)] = 75392,
  [SMALL_STATE(1521)] = 75410,
  [SMALL_STATE(1522)] = 75432,
  [SMALL_STATE(1523)] = 75450,
  [SMALL_STATE(1524)] = 75476,
  [SMALL_STATE(1525)] = 75494,
  [SMALL_STATE(1526)] = 75512,
  [SMALL_STATE(1527)] = 75540,
  [SMALL_STATE(1528)] = 75560,
  [SMALL_STATE(1529)] = 75582,
  [SMALL_STATE(1530)] = 75602,
  [SMALL_STATE(1531)] = 75620,
  [SMALL_STATE(1532)] = 75640,
  [SMALL_STATE(1533)] = 75658,
  [SMALL_STATE(1534)] = 75676,
  [SMALL_STATE(1535)] = 75696,
  [SMALL_STATE(1536)] = 75724,
  [SMALL_STATE(1537)] = 75742,
  [SMALL_STATE(1538)] = 75767,
  [SMALL_STATE(1539)] = 75792,
  [SMALL_STATE(1540)] = 75817,
  [SMALL_STATE(1541)] = 75842,
  [SMALL_STATE(1542)] = 75867,
  [SMALL_STATE(1543)] = 75892,
  [SMALL_STATE(1544)] = 75915,
  [SMALL_STATE(1545)] = 75940,
  [SMALL_STATE(1546)] = 75965,
  [SMALL_STATE(1547)] = 75990,
  [SMALL_STATE(1548)] = 76009,
  [SMALL_STATE(1549)] = 76034,
  [SMALL_STATE(1550)] = 76059,
  [SMALL_STATE(1551)] = 76084,
  [SMALL_STATE(1552)] = 76109,
  [SMALL_STATE(1553)] = 76134,
  [SMALL_STATE(1554)] = 76159,
  [SMALL_STATE(1555)] = 76184,
  [SMALL_STATE(1556)] = 76201,
  [SMALL_STATE(1557)] = 76226,
  [SMALL_STATE(1558)] = 76251,
  [SMALL_STATE(1559)] = 76274,
  [SMALL_STATE(1560)] = 76299,
  [SMALL_STATE(1561)] = 76324,
  [SMALL_STATE(1562)] = 76341,
  [SMALL_STATE(1563)] = 76366,
  [SMALL_STATE(1564)] = 76383,
  [SMALL_STATE(1565)] = 76402,
  [SMALL_STATE(1566)] = 76427,
  [SMALL_STATE(1567)] = 76452,
  [SMALL_STATE(1568)] = 76469,
  [SMALL_STATE(1569)] = 76494,
  [SMALL_STATE(1570)] = 76511,
  [SMALL_STATE(1571)] = 76536,
  [SMALL_STATE(1572)] = 76561,
  [SMALL_STATE(1573)] = 76584,
  [SMALL_STATE(1574)] = 76609,
  [SMALL_STATE(1575)] = 76626,
  [SMALL_STATE(1576)] = 76651,
  [SMALL_STATE(1577)] = 76676,
  [SMALL_STATE(1578)] = 76701,
  [SMALL_STATE(1579)] = 76726,
  [SMALL_STATE(1580)] = 76751,
  [SMALL_STATE(1581)] = 76776,
  [SMALL_STATE(1582)] = 76801,
  [SMALL_STATE(1583)] = 76826,
  [SMALL_STATE(1584)] = 76851,
  [SMALL_STATE(1585)] = 76876,
  [SMALL_STATE(1586)] = 76893,
  [SMALL_STATE(1587)] = 76918,
  [SMALL_STATE(1588)] = 76935,
  [SMALL_STATE(1589)] = 76958,
  [SMALL_STATE(1590)] = 76983,
  [SMALL_STATE(1591)] = 77008,
  [SMALL_STATE(1592)] = 77031,
  [SMALL_STATE(1593)] = 77056,
  [SMALL_STATE(1594)] = 77078,
  [SMALL_STATE(1595)] = 77098,
  [SMALL_STATE(1596)] = 77118,
  [SMALL_STATE(1597)] = 77140,
  [SMALL_STATE(1598)] = 77160,
  [SMALL_STATE(1599)] = 77182,
  [SMALL_STATE(1600)] = 77204,
  [SMALL_STATE(1601)] = 77226,
  [SMALL_STATE(1602)] = 77242,
  [SMALL_STATE(1603)] = 77264,
  [SMALL_STATE(1604)] = 77286,
  [SMALL_STATE(1605)] = 77308,
  [SMALL_STATE(1606)] = 77328,
  [SMALL_STATE(1607)] = 77350,
  [SMALL_STATE(1608)] = 77366,
  [SMALL_STATE(1609)] = 77386,
  [SMALL_STATE(1610)] = 77408,
  [SMALL_STATE(1611)] = 77430,
  [SMALL_STATE(1612)] = 77452,
  [SMALL_STATE(1613)] = 77474,
  [SMALL_STATE(1614)] = 77496,
  [SMALL_STATE(1615)] = 77514,
  [SMALL_STATE(1616)] = 77534,
  [SMALL_STATE(1617)] = 77556,
  [SMALL_STATE(1618)] = 77578,
  [SMALL_STATE(1619)] = 77600,
  [SMALL_STATE(1620)] = 77620,
  [SMALL_STATE(1621)] = 77642,
  [SMALL_STATE(1622)] = 77662,
  [SMALL_STATE(1623)] = 77684,
  [SMALL_STATE(1624)] = 77700,
  [SMALL_STATE(1625)] = 77722,
  [SMALL_STATE(1626)] = 77744,
  [SMALL_STATE(1627)] = 77764,
  [SMALL_STATE(1628)] = 77780,
  [SMALL_STATE(1629)] = 77802,
  [SMALL_STATE(1630)] = 77824,
  [SMALL_STATE(1631)] = 77846,
  [SMALL_STATE(1632)] = 77868,
  [SMALL_STATE(1633)] = 77890,
  [SMALL_STATE(1634)] = 77912,
  [SMALL_STATE(1635)] = 77934,
  [SMALL_STATE(1636)] = 77954,
  [SMALL_STATE(1637)] = 77970,
  [SMALL_STATE(1638)] = 77992,
  [SMALL_STATE(1639)] = 78014,
  [SMALL_STATE(1640)] = 78036,
  [SMALL_STATE(1641)] = 78058,
  [SMALL_STATE(1642)] = 78080,
  [SMALL_STATE(1643)] = 78100,
  [SMALL_STATE(1644)] = 78116,
  [SMALL_STATE(1645)] = 78138,
  [SMALL_STATE(1646)] = 78160,
  [SMALL_STATE(1647)] = 78182,
  [SMALL_STATE(1648)] = 78204,
  [SMALL_STATE(1649)] = 78220,
  [SMALL_STATE(1650)] = 78242,
  [SMALL_STATE(1651)] = 78264,
  [SMALL_STATE(1652)] = 78286,
  [SMALL_STATE(1653)] = 78302,
  [SMALL_STATE(1654)] = 78318,
  [SMALL_STATE(1655)] = 78340,
  [SMALL_STATE(1656)] = 78362,
  [SMALL_STATE(1657)] = 78384,
  [SMALL_STATE(1658)] = 78403,
  [SMALL_STATE(1659)] = 78422,
  [SMALL_STATE(1660)] = 78441,
  [SMALL_STATE(1661)] = 78460,
  [SMALL_STATE(1662)] = 78479,
  [SMALL_STATE(1663)] = 78498,
  [SMALL_STATE(1664)] = 78517,
  [SMALL_STATE(1665)] = 78536,
  [SMALL_STATE(1666)] = 78555,
  [SMALL_STATE(1667)] = 78574,
  [SMALL_STATE(1668)] = 78591,
  [SMALL_STATE(1669)] = 78610,
  [SMALL_STATE(1670)] = 78629,
  [SMALL_STATE(1671)] = 78648,
  [SMALL_STATE(1672)] = 78667,
  [SMALL_STATE(1673)] = 78686,
  [SMALL_STATE(1674)] = 78705,
  [SMALL_STATE(1675)] = 78724,
  [SMALL_STATE(1676)] = 78743,
  [SMALL_STATE(1677)] = 78762,
  [SMALL_STATE(1678)] = 78781,
  [SMALL_STATE(1679)] = 78798,
  [SMALL_STATE(1680)] = 78817,
  [SMALL_STATE(1681)] = 78836,
  [SMALL_STATE(1682)] = 78855,
  [SMALL_STATE(1683)] = 78874,
  [SMALL_STATE(1684)] = 78893,
  [SMALL_STATE(1685)] = 78910,
  [SMALL_STATE(1686)] = 78927,
  [SMALL_STATE(1687)] = 78946,
  [SMALL_STATE(1688)] = 78963,
  [SMALL_STATE(1689)] = 78980,
  [SMALL_STATE(1690)] = 78995,
  [SMALL_STATE(1691)] = 79012,
  [SMALL_STATE(1692)] = 79031,
  [SMALL_STATE(1693)] = 79050,
  [SMALL_STATE(1694)] = 79069,
  [SMALL_STATE(1695)] = 79086,
  [SMALL_STATE(1696)] = 79103,
  [SMALL_STATE(1697)] = 79122,
  [SMALL_STATE(1698)] = 79141,
  [SMALL_STATE(1699)] = 79160,
  [SMALL_STATE(1700)] = 79179,
  [SMALL_STATE(1701)] = 79198,
  [SMALL_STATE(1702)] = 79215,
  [SMALL_STATE(1703)] = 79234,
  [SMALL_STATE(1704)] = 79253,
  [SMALL_STATE(1705)] = 79272,
  [SMALL_STATE(1706)] = 79291,
  [SMALL_STATE(1707)] = 79310,
  [SMALL_STATE(1708)] = 79329,
  [SMALL_STATE(1709)] = 79348,
  [SMALL_STATE(1710)] = 79367,
  [SMALL_STATE(1711)] = 79386,
  [SMALL_STATE(1712)] = 79403,
  [SMALL_STATE(1713)] = 79422,
  [SMALL_STATE(1714)] = 79441,
  [SMALL_STATE(1715)] = 79460,
  [SMALL_STATE(1716)] = 79477,
  [SMALL_STATE(1717)] = 79496,
  [SMALL_STATE(1718)] = 79515,
  [SMALL_STATE(1719)] = 79534,
  [SMALL_STATE(1720)] = 79553,
  [SMALL_STATE(1721)] = 79572,
  [SMALL_STATE(1722)] = 79591,
  [SMALL_STATE(1723)] = 79610,
  [SMALL_STATE(1724)] = 79629,
  [SMALL_STATE(1725)] = 79648,
  [SMALL_STATE(1726)] = 79667,
  [SMALL_STATE(1727)] = 79686,
  [SMALL_STATE(1728)] = 79705,
  [SMALL_STATE(1729)] = 79724,
  [SMALL_STATE(1730)] = 79743,
  [SMALL_STATE(1731)] = 79762,
  [SMALL_STATE(1732)] = 79781,
  [SMALL_STATE(1733)] = 79800,
  [SMALL_STATE(1734)] = 79819,
  [SMALL_STATE(1735)] = 79838,
  [SMALL_STATE(1736)] = 79857,
  [SMALL_STATE(1737)] = 79872,
  [SMALL_STATE(1738)] = 79891,
  [SMALL_STATE(1739)] = 79910,
  [SMALL_STATE(1740)] = 79929,
  [SMALL_STATE(1741)] = 79948,
  [SMALL_STATE(1742)] = 79965,
  [SMALL_STATE(1743)] = 79980,
  [SMALL_STATE(1744)] = 79999,
  [SMALL_STATE(1745)] = 80018,
  [SMALL_STATE(1746)] = 80037,
  [SMALL_STATE(1747)] = 80056,
  [SMALL_STATE(1748)] = 80075,
  [SMALL_STATE(1749)] = 80094,
  [SMALL_STATE(1750)] = 80113,
  [SMALL_STATE(1751)] = 80132,
  [SMALL_STATE(1752)] = 80147,
  [SMALL_STATE(1753)] = 80166,
  [SMALL_STATE(1754)] = 80181,
  [SMALL_STATE(1755)] = 80200,
  [SMALL_STATE(1756)] = 80219,
  [SMALL_STATE(1757)] = 80238,
  [SMALL_STATE(1758)] = 80257,
  [SMALL_STATE(1759)] = 80276,
  [SMALL_STATE(1760)] = 80295,
  [SMALL_STATE(1761)] = 80314,
  [SMALL_STATE(1762)] = 80333,
  [SMALL_STATE(1763)] = 80352,
  [SMALL_STATE(1764)] = 80371,
  [SMALL_STATE(1765)] = 80390,
  [SMALL_STATE(1766)] = 80409,
  [SMALL_STATE(1767)] = 80428,
  [SMALL_STATE(1768)] = 80447,
  [SMALL_STATE(1769)] = 80464,
  [SMALL_STATE(1770)] = 80483,
  [SMALL_STATE(1771)] = 80502,
  [SMALL_STATE(1772)] = 80521,
  [SMALL_STATE(1773)] = 80540,
  [SMALL_STATE(1774)] = 80559,
  [SMALL_STATE(1775)] = 80578,
  [SMALL_STATE(1776)] = 80597,
  [SMALL_STATE(1777)] = 80616,
  [SMALL_STATE(1778)] = 80635,
  [SMALL_STATE(1779)] = 80654,
  [SMALL_STATE(1780)] = 80673,
  [SMALL_STATE(1781)] = 80692,
  [SMALL_STATE(1782)] = 80711,
  [SMALL_STATE(1783)] = 80730,
  [SMALL_STATE(1784)] = 80749,
  [SMALL_STATE(1785)] = 80768,
  [SMALL_STATE(1786)] = 80787,
  [SMALL_STATE(1787)] = 80806,
  [SMALL_STATE(1788)] = 80825,
  [SMALL_STATE(1789)] = 80844,
  [SMALL_STATE(1790)] = 80863,
  [SMALL_STATE(1791)] = 80882,
  [SMALL_STATE(1792)] = 80901,
  [SMALL_STATE(1793)] = 80920,
  [SMALL_STATE(1794)] = 80939,
  [SMALL_STATE(1795)] = 80958,
  [SMALL_STATE(1796)] = 80975,
  [SMALL_STATE(1797)] = 80994,
  [SMALL_STATE(1798)] = 81013,
  [SMALL_STATE(1799)] = 81032,
  [SMALL_STATE(1800)] = 81047,
  [SMALL_STATE(1801)] = 81066,
  [SMALL_STATE(1802)] = 81085,
  [SMALL_STATE(1803)] = 81104,
  [SMALL_STATE(1804)] = 81123,
  [SMALL_STATE(1805)] = 81142,
  [SMALL_STATE(1806)] = 81161,
  [SMALL_STATE(1807)] = 81180,
  [SMALL_STATE(1808)] = 81199,
  [SMALL_STATE(1809)] = 81216,
  [SMALL_STATE(1810)] = 81235,
  [SMALL_STATE(1811)] = 81254,
  [SMALL_STATE(1812)] = 81271,
  [SMALL_STATE(1813)] = 81290,
  [SMALL_STATE(1814)] = 81309,
  [SMALL_STATE(1815)] = 81328,
  [SMALL_STATE(1816)] = 81347,
  [SMALL_STATE(1817)] = 81366,
  [SMALL_STATE(1818)] = 81383,
  [SMALL_STATE(1819)] = 81402,
  [SMALL_STATE(1820)] = 81421,
  [SMALL_STATE(1821)] = 81440,
  [SMALL_STATE(1822)] = 81459,
  [SMALL_STATE(1823)] = 81478,
  [SMALL_STATE(1824)] = 81497,
  [SMALL_STATE(1825)] = 81516,
  [SMALL_STATE(1826)] = 81535,
  [SMALL_STATE(1827)] = 81554,
  [SMALL_STATE(1828)] = 81571,
  [SMALL_STATE(1829)] = 81586,
  [SMALL_STATE(1830)] = 81605,
  [SMALL_STATE(1831)] = 81624,
  [SMALL_STATE(1832)] = 81643,
  [SMALL_STATE(1833)] = 81658,
  [SMALL_STATE(1834)] = 81677,
  [SMALL_STATE(1835)] = 81696,
  [SMALL_STATE(1836)] = 81715,
  [SMALL_STATE(1837)] = 81734,
  [SMALL_STATE(1838)] = 81753,
  [SMALL_STATE(1839)] = 81772,
  [SMALL_STATE(1840)] = 81789,
  [SMALL_STATE(1841)] = 81808,
  [SMALL_STATE(1842)] = 81825,
  [SMALL_STATE(1843)] = 81842,
  [SMALL_STATE(1844)] = 81861,
  [SMALL_STATE(1845)] = 81880,
  [SMALL_STATE(1846)] = 81899,
  [SMALL_STATE(1847)] = 81918,
  [SMALL_STATE(1848)] = 81937,
  [SMALL_STATE(1849)] = 81954,
  [SMALL_STATE(1850)] = 81973,
  [SMALL_STATE(1851)] = 81992,
  [SMALL_STATE(1852)] = 82011,
  [SMALL_STATE(1853)] = 82030,
  [SMALL_STATE(1854)] = 82049,
  [SMALL_STATE(1855)] = 82068,
  [SMALL_STATE(1856)] = 82087,
  [SMALL_STATE(1857)] = 82106,
  [SMALL_STATE(1858)] = 82125,
  [SMALL_STATE(1859)] = 82144,
  [SMALL_STATE(1860)] = 82163,
  [SMALL_STATE(1861)] = 82182,
  [SMALL_STATE(1862)] = 82201,
  [SMALL_STATE(1863)] = 82218,
  [SMALL_STATE(1864)] = 82237,
  [SMALL_STATE(1865)] = 82256,
  [SMALL_STATE(1866)] = 82275,
  [SMALL_STATE(1867)] = 82294,
  [SMALL_STATE(1868)] = 82313,
  [SMALL_STATE(1869)] = 82332,
  [SMALL_STATE(1870)] = 82351,
  [SMALL_STATE(1871)] = 82370,
  [SMALL_STATE(1872)] = 82389,
  [SMALL_STATE(1873)] = 82408,
  [SMALL_STATE(1874)] = 82427,
  [SMALL_STATE(1875)] = 82446,
  [SMALL_STATE(1876)] = 82465,
  [SMALL_STATE(1877)] = 82480,
  [SMALL_STATE(1878)] = 82499,
  [SMALL_STATE(1879)] = 82518,
  [SMALL_STATE(1880)] = 82537,
  [SMALL_STATE(1881)] = 82554,
  [SMALL_STATE(1882)] = 82569,
  [SMALL_STATE(1883)] = 82586,
  [SMALL_STATE(1884)] = 82605,
  [SMALL_STATE(1885)] = 82624,
  [SMALL_STATE(1886)] = 82643,
  [SMALL_STATE(1887)] = 82662,
  [SMALL_STATE(1888)] = 82679,
  [SMALL_STATE(1889)] = 82698,
  [SMALL_STATE(1890)] = 82717,
  [SMALL_STATE(1891)] = 82736,
  [SMALL_STATE(1892)] = 82752,
  [SMALL_STATE(1893)] = 82766,
  [SMALL_STATE(1894)] = 82780,
  [SMALL_STATE(1895)] = 82796,
  [SMALL_STATE(1896)] = 82810,
  [SMALL_STATE(1897)] = 82826,
  [SMALL_STATE(1898)] = 82842,
  [SMALL_STATE(1899)] = 82858,
  [SMALL_STATE(1900)] = 82874,
  [SMALL_STATE(1901)] = 82888,
  [SMALL_STATE(1902)] = 82904,
  [SMALL_STATE(1903)] = 82920,
  [SMALL_STATE(1904)] = 82936,
  [SMALL_STATE(1905)] = 82952,
  [SMALL_STATE(1906)] = 82968,
  [SMALL_STATE(1907)] = 82984,
  [SMALL_STATE(1908)] = 83000,
  [SMALL_STATE(1909)] = 83016,
  [SMALL_STATE(1910)] = 83032,
  [SMALL_STATE(1911)] = 83048,
  [SMALL_STATE(1912)] = 83064,
  [SMALL_STATE(1913)] = 83080,
  [SMALL_STATE(1914)] = 83094,
  [SMALL_STATE(1915)] = 83108,
  [SMALL_STATE(1916)] = 83124,
  [SMALL_STATE(1917)] = 83138,
  [SMALL_STATE(1918)] = 83154,
  [SMALL_STATE(1919)] = 83170,
  [SMALL_STATE(1920)] = 83186,
  [SMALL_STATE(1921)] = 83202,
  [SMALL_STATE(1922)] = 83216,
  [SMALL_STATE(1923)] = 83232,
  [SMALL_STATE(1924)] = 83248,
  [SMALL_STATE(1925)] = 83264,
  [SMALL_STATE(1926)] = 83280,
  [SMALL_STATE(1927)] = 83296,
  [SMALL_STATE(1928)] = 83312,
  [SMALL_STATE(1929)] = 83328,
  [SMALL_STATE(1930)] = 83344,
  [SMALL_STATE(1931)] = 83360,
  [SMALL_STATE(1932)] = 83376,
  [SMALL_STATE(1933)] = 83392,
  [SMALL_STATE(1934)] = 83406,
  [SMALL_STATE(1935)] = 83422,
  [SMALL_STATE(1936)] = 83438,
  [SMALL_STATE(1937)] = 83454,
  [SMALL_STATE(1938)] = 83470,
  [SMALL_STATE(1939)] = 83486,
  [SMALL_STATE(1940)] = 83502,
  [SMALL_STATE(1941)] = 83518,
  [SMALL_STATE(1942)] = 83534,
  [SMALL_STATE(1943)] = 83550,
  [SMALL_STATE(1944)] = 83566,
  [SMALL_STATE(1945)] = 83582,
  [SMALL_STATE(1946)] = 83598,
  [SMALL_STATE(1947)] = 83614,
  [SMALL_STATE(1948)] = 83628,
  [SMALL_STATE(1949)] = 83644,
  [SMALL_STATE(1950)] = 83660,
  [SMALL_STATE(1951)] = 83674,
  [SMALL_STATE(1952)] = 83690,
  [SMALL_STATE(1953)] = 83706,
  [SMALL_STATE(1954)] = 83722,
  [SMALL_STATE(1955)] = 83738,
  [SMALL_STATE(1956)] = 83754,
  [SMALL_STATE(1957)] = 83770,
  [SMALL_STATE(1958)] = 83784,
  [SMALL_STATE(1959)] = 83800,
  [SMALL_STATE(1960)] = 83816,
  [SMALL_STATE(1961)] = 83832,
  [SMALL_STATE(1962)] = 83848,
  [SMALL_STATE(1963)] = 83864,
  [SMALL_STATE(1964)] = 83880,
  [SMALL_STATE(1965)] = 83896,
  [SMALL_STATE(1966)] = 83912,
  [SMALL_STATE(1967)] = 83928,
  [SMALL_STATE(1968)] = 83944,
  [SMALL_STATE(1969)] = 83960,
  [SMALL_STATE(1970)] = 83976,
  [SMALL_STATE(1971)] = 83992,
  [SMALL_STATE(1972)] = 84008,
  [SMALL_STATE(1973)] = 84024,
  [SMALL_STATE(1974)] = 84038,
  [SMALL_STATE(1975)] = 84054,
  [SMALL_STATE(1976)] = 84070,
  [SMALL_STATE(1977)] = 84086,
  [SMALL_STATE(1978)] = 84102,
  [SMALL_STATE(1979)] = 84118,
  [SMALL_STATE(1980)] = 84134,
  [SMALL_STATE(1981)] = 84150,
  [SMALL_STATE(1982)] = 84166,
  [SMALL_STATE(1983)] = 84182,
  [SMALL_STATE(1984)] = 84198,
  [SMALL_STATE(1985)] = 84214,
  [SMALL_STATE(1986)] = 84230,
  [SMALL_STATE(1987)] = 84246,
  [SMALL_STATE(1988)] = 84262,
  [SMALL_STATE(1989)] = 84278,
  [SMALL_STATE(1990)] = 84294,
  [SMALL_STATE(1991)] = 84308,
  [SMALL_STATE(1992)] = 84324,
  [SMALL_STATE(1993)] = 84340,
  [SMALL_STATE(1994)] = 84356,
  [SMALL_STATE(1995)] = 84372,
  [SMALL_STATE(1996)] = 84388,
  [SMALL_STATE(1997)] = 84404,
  [SMALL_STATE(1998)] = 84420,
  [SMALL_STATE(1999)] = 84436,
  [SMALL_STATE(2000)] = 84452,
  [SMALL_STATE(2001)] = 84468,
  [SMALL_STATE(2002)] = 84484,
  [SMALL_STATE(2003)] = 84500,
  [SMALL_STATE(2004)] = 84513,
  [SMALL_STATE(2005)] = 84526,
  [SMALL_STATE(2006)] = 84539,
  [SMALL_STATE(2007)] = 84552,
  [SMALL_STATE(2008)] = 84565,
  [SMALL_STATE(2009)] = 84578,
  [SMALL_STATE(2010)] = 84591,
  [SMALL_STATE(2011)] = 84604,
  [SMALL_STATE(2012)] = 84617,
  [SMALL_STATE(2013)] = 84630,
  [SMALL_STATE(2014)] = 84643,
  [SMALL_STATE(2015)] = 84656,
  [SMALL_STATE(2016)] = 84669,
  [SMALL_STATE(2017)] = 84682,
  [SMALL_STATE(2018)] = 84695,
  [SMALL_STATE(2019)] = 84708,
  [SMALL_STATE(2020)] = 84721,
  [SMALL_STATE(2021)] = 84734,
  [SMALL_STATE(2022)] = 84747,
  [SMALL_STATE(2023)] = 84760,
  [SMALL_STATE(2024)] = 84773,
  [SMALL_STATE(2025)] = 84786,
  [SMALL_STATE(2026)] = 84799,
  [SMALL_STATE(2027)] = 84812,
  [SMALL_STATE(2028)] = 84825,
  [SMALL_STATE(2029)] = 84838,
  [SMALL_STATE(2030)] = 84851,
  [SMALL_STATE(2031)] = 84864,
  [SMALL_STATE(2032)] = 84877,
  [SMALL_STATE(2033)] = 84890,
  [SMALL_STATE(2034)] = 84903,
  [SMALL_STATE(2035)] = 84916,
  [SMALL_STATE(2036)] = 84929,
  [SMALL_STATE(2037)] = 84942,
  [SMALL_STATE(2038)] = 84955,
  [SMALL_STATE(2039)] = 84968,
  [SMALL_STATE(2040)] = 84981,
  [SMALL_STATE(2041)] = 84994,
  [SMALL_STATE(2042)] = 85007,
  [SMALL_STATE(2043)] = 85020,
  [SMALL_STATE(2044)] = 85033,
  [SMALL_STATE(2045)] = 85046,
  [SMALL_STATE(2046)] = 85059,
  [SMALL_STATE(2047)] = 85072,
  [SMALL_STATE(2048)] = 85085,
  [SMALL_STATE(2049)] = 85098,
  [SMALL_STATE(2050)] = 85111,
  [SMALL_STATE(2051)] = 85124,
  [SMALL_STATE(2052)] = 85137,
  [SMALL_STATE(2053)] = 85150,
  [SMALL_STATE(2054)] = 85163,
  [SMALL_STATE(2055)] = 85176,
  [SMALL_STATE(2056)] = 85189,
  [SMALL_STATE(2057)] = 85202,
  [SMALL_STATE(2058)] = 85215,
  [SMALL_STATE(2059)] = 85228,
  [SMALL_STATE(2060)] = 85241,
  [SMALL_STATE(2061)] = 85254,
  [SMALL_STATE(2062)] = 85267,
  [SMALL_STATE(2063)] = 85280,
  [SMALL_STATE(2064)] = 85293,
  [SMALL_STATE(2065)] = 85306,
  [SMALL_STATE(2066)] = 85319,
  [SMALL_STATE(2067)] = 85332,
  [SMALL_STATE(2068)] = 85345,
  [SMALL_STATE(2069)] = 85358,
  [SMALL_STATE(2070)] = 85371,
  [SMALL_STATE(2071)] = 85384,
  [SMALL_STATE(2072)] = 85397,
  [SMALL_STATE(2073)] = 85410,
  [SMALL_STATE(2074)] = 85423,
  [SMALL_STATE(2075)] = 85436,
  [SMALL_STATE(2076)] = 85449,
  [SMALL_STATE(2077)] = 85462,
  [SMALL_STATE(2078)] = 85475,
  [SMALL_STATE(2079)] = 85488,
  [SMALL_STATE(2080)] = 85501,
  [SMALL_STATE(2081)] = 85514,
  [SMALL_STATE(2082)] = 85527,
  [SMALL_STATE(2083)] = 85540,
  [SMALL_STATE(2084)] = 85553,
  [SMALL_STATE(2085)] = 85566,
  [SMALL_STATE(2086)] = 85579,
  [SMALL_STATE(2087)] = 85592,
  [SMALL_STATE(2088)] = 85605,
  [SMALL_STATE(2089)] = 85618,
  [SMALL_STATE(2090)] = 85631,
  [SMALL_STATE(2091)] = 85644,
  [SMALL_STATE(2092)] = 85657,
  [SMALL_STATE(2093)] = 85670,
  [SMALL_STATE(2094)] = 85683,
  [SMALL_STATE(2095)] = 85696,
  [SMALL_STATE(2096)] = 85709,
  [SMALL_STATE(2097)] = 85722,
  [SMALL_STATE(2098)] = 85735,
  [SMALL_STATE(2099)] = 85748,
  [SMALL_STATE(2100)] = 85761,
  [SMALL_STATE(2101)] = 85774,
  [SMALL_STATE(2102)] = 85787,
  [SMALL_STATE(2103)] = 85800,
  [SMALL_STATE(2104)] = 85813,
  [SMALL_STATE(2105)] = 85826,
  [SMALL_STATE(2106)] = 85839,
  [SMALL_STATE(2107)] = 85852,
  [SMALL_STATE(2108)] = 85865,
  [SMALL_STATE(2109)] = 85878,
  [SMALL_STATE(2110)] = 85891,
  [SMALL_STATE(2111)] = 85904,
  [SMALL_STATE(2112)] = 85917,
  [SMALL_STATE(2113)] = 85930,
  [SMALL_STATE(2114)] = 85943,
  [SMALL_STATE(2115)] = 85956,
  [SMALL_STATE(2116)] = 85969,
  [SMALL_STATE(2117)] = 85982,
  [SMALL_STATE(2118)] = 85995,
  [SMALL_STATE(2119)] = 86008,
  [SMALL_STATE(2120)] = 86021,
  [SMALL_STATE(2121)] = 86034,
  [SMALL_STATE(2122)] = 86047,
  [SMALL_STATE(2123)] = 86060,
  [SMALL_STATE(2124)] = 86073,
  [SMALL_STATE(2125)] = 86086,
  [SMALL_STATE(2126)] = 86099,
  [SMALL_STATE(2127)] = 86112,
  [SMALL_STATE(2128)] = 86125,
  [SMALL_STATE(2129)] = 86138,
  [SMALL_STATE(2130)] = 86151,
  [SMALL_STATE(2131)] = 86164,
  [SMALL_STATE(2132)] = 86177,
  [SMALL_STATE(2133)] = 86190,
  [SMALL_STATE(2134)] = 86203,
  [SMALL_STATE(2135)] = 86216,
  [SMALL_STATE(2136)] = 86229,
  [SMALL_STATE(2137)] = 86242,
  [SMALL_STATE(2138)] = 86255,
  [SMALL_STATE(2139)] = 86268,
  [SMALL_STATE(2140)] = 86281,
  [SMALL_STATE(2141)] = 86294,
  [SMALL_STATE(2142)] = 86307,
  [SMALL_STATE(2143)] = 86320,
  [SMALL_STATE(2144)] = 86333,
  [SMALL_STATE(2145)] = 86346,
  [SMALL_STATE(2146)] = 86359,
  [SMALL_STATE(2147)] = 86372,
  [SMALL_STATE(2148)] = 86385,
  [SMALL_STATE(2149)] = 86398,
  [SMALL_STATE(2150)] = 86411,
  [SMALL_STATE(2151)] = 86424,
  [SMALL_STATE(2152)] = 86437,
  [SMALL_STATE(2153)] = 86450,
  [SMALL_STATE(2154)] = 86463,
  [SMALL_STATE(2155)] = 86476,
  [SMALL_STATE(2156)] = 86489,
  [SMALL_STATE(2157)] = 86502,
  [SMALL_STATE(2158)] = 86515,
  [SMALL_STATE(2159)] = 86528,
  [SMALL_STATE(2160)] = 86541,
  [SMALL_STATE(2161)] = 86554,
  [SMALL_STATE(2162)] = 86567,
  [SMALL_STATE(2163)] = 86580,
  [SMALL_STATE(2164)] = 86593,
  [SMALL_STATE(2165)] = 86606,
  [SMALL_STATE(2166)] = 86619,
  [SMALL_STATE(2167)] = 86632,
  [SMALL_STATE(2168)] = 86645,
  [SMALL_STATE(2169)] = 86658,
  [SMALL_STATE(2170)] = 86671,
  [SMALL_STATE(2171)] = 86684,
  [SMALL_STATE(2172)] = 86697,
  [SMALL_STATE(2173)] = 86710,
  [SMALL_STATE(2174)] = 86723,
  [SMALL_STATE(2175)] = 86736,
  [SMALL_STATE(2176)] = 86749,
  [SMALL_STATE(2177)] = 86762,
  [SMALL_STATE(2178)] = 86775,
  [SMALL_STATE(2179)] = 86788,
  [SMALL_STATE(2180)] = 86801,
  [SMALL_STATE(2181)] = 86814,
  [SMALL_STATE(2182)] = 86827,
  [SMALL_STATE(2183)] = 86840,
  [SMALL_STATE(2184)] = 86853,
  [SMALL_STATE(2185)] = 86866,
  [SMALL_STATE(2186)] = 86879,
  [SMALL_STATE(2187)] = 86892,
  [SMALL_STATE(2188)] = 86905,
  [SMALL_STATE(2189)] = 86918,
  [SMALL_STATE(2190)] = 86931,
  [SMALL_STATE(2191)] = 86935,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2107),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1761),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1159),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1289),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2006),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2128),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2130),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2042),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2043),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2047),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2049),
  [35] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0),
  [37] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0),
  [39] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1265),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [45] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(2015),
  [48] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 0),
  [51] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(1170),
  [54] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [56] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [58] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(2174),
  [61] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 0),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [67] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym_state_binding_expression, 2, 0, 0),
  [70] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_state_binding_expression, 2, 0, 0),
  [72] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym_state_binding_expression, 2, 0, 0),
  [75] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1238),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(631),
  [79] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_state_binding_expression, 2, 0, 0),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [83] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [85] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(609),
  [89] = {.entry = {.count = 1, .reusable = true}}, SHIFT(609),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [93] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_member_expression, 3, 0, 0),
  [95] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_member_expression, 3, 0, 0),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1261),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(654),
  [101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1392),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1424),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2099),
  [113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2052),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2162),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2176),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2177),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2185),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(4),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1539),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1542),
  [129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(670),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(150),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(145),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1758),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(566),
  [141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(567),
  [145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2110),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1565),
  [151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1546),
  [153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2167),
  [155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(569),
  [159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1390),
  [161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2082),
  [163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1150),
  [165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2041),
  [169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(25),
  [171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1579),
  [173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1571),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(666),
  [177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(397),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(398),
  [183] = {.entry = {.count = 1, .reusable = false}}, SHIFT(648),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(649),
  [189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2029),
  [193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1559),
  [195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1836),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1941),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(676),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2039),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2040),
  [209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1944),
  [211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1945),
  [213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1581),
  [215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2165),
  [217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(651),
  [221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1436),
  [227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1392),
  [230] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0),
  [232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(482),
  [235] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2099),
  [238] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2052),
  [241] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2162),
  [244] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2176),
  [247] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2177),
  [250] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2185),
  [253] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(4),
  [256] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1539),
  [259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1542),
  [262] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(141),
  [268] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(150),
  [271] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(145),
  [274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1758),
  [277] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(566),
  [280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(566),
  [283] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(567),
  [286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(468),
  [289] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2110),
  [292] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1565),
  [295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1546),
  [298] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2167),
  [301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(568),
  [304] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 2, 0, 0), SHIFT_REPEAT(569),
  [307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2081),
  [313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2123),
  [317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(349),
  [327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_assignment, 1, 0, 0),
  [331] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym_property_assignment, 1, 0, 0),
  [334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(3),
  [338] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1392),
  [341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0),
  [343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(482),
  [346] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2099),
  [349] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2052),
  [352] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2162),
  [355] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2176),
  [358] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2177),
  [361] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2185),
  [364] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(3),
  [367] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1539),
  [370] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1542),
  [373] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [376] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(141),
  [379] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(150),
  [382] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(145),
  [385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1758),
  [388] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(566),
  [391] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(566),
  [394] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(567),
  [397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(468),
  [400] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2110),
  [403] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1565),
  [406] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1546),
  [409] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2167),
  [412] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(568),
  [415] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(569),
  [418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2041),
  [430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1417),
  [438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1423),
  [440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1433),
  [444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [446] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1390),
  [449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0),
  [451] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(493),
  [454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2041),
  [457] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(35),
  [460] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1579),
  [463] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1571),
  [466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(666),
  [469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(396),
  [472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(397),
  [475] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(398),
  [478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1758),
  [481] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(648),
  [484] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(648),
  [487] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(649),
  [490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(467),
  [493] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2029),
  [496] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1559),
  [499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1836),
  [502] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(500),
  [505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1941),
  [508] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(676),
  [511] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2039),
  [514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2040),
  [517] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1944),
  [520] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1945),
  [523] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(1581),
  [526] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(2165),
  [529] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(650),
  [532] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(651),
  [535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1403),
  [537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1327),
  [545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(867),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2120),
  [573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1573),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1576),
  [579] = {.entry = {.count = 1, .reusable = false}}, SHIFT(675),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [585] = {.entry = {.count = 1, .reusable = false}}, SHIFT(374),
  [587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(605),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [591] = {.entry = {.count = 1, .reusable = false}}, SHIFT(606),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2188),
  [597] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1570),
  [599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1724),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(524),
  [603] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1998),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(683),
  [607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2186),
  [609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2175),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1999),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2000),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1578),
  [617] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2169),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [621] = {.entry = {.count = 1, .reusable = false}}, SHIFT(608),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [625] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2077),
  [628] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(1179),
  [631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2083),
  [634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2122),
  [637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(1171),
  [640] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2125),
  [643] = {.entry = {.count = 1, .reusable = false}}, SHIFT(574),
  [645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_expression, 5, 0, 0),
  [647] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1230),
  [649] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_expression, 5, 0, 0),
  [651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [655] = {.entry = {.count = 1, .reusable = false}}, SHIFT(577),
  [657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(578),
  [659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(579),
  [661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(580),
  [663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [665] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_conditional_expression, 5, 0, 0), SHIFT(247),
  [668] = {.entry = {.count = 1, .reusable = false}}, SHIFT(581),
  [670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(582),
  [676] = {.entry = {.count = 1, .reusable = false}}, SHIFT(583),
  [678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [682] = {.entry = {.count = 1, .reusable = false}}, SHIFT(705),
  [684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assignment_expression, 3, 0, 0),
  [690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2007),
  [694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment_expression, 3, 0, 0),
  [696] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 3, 0, 0),
  [700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 3, 0, 0),
  [702] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 0),
  [704] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_expression, 3, 0, 0),
  [706] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 0), SHIFT(247),
  [709] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 4, 0, 0),
  [711] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 4, 0, 0),
  [713] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 5, 0, 0),
  [715] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 5, 0, 0),
  [717] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 6, 0, 0),
  [719] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 6, 0, 0),
  [721] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow_function, 7, 0, 0),
  [723] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow_function, 7, 0, 0),
  [725] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 1, 0, 0),
  [731] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_literal, 1, 0, 0),
  [735] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_boolean_literal, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 0),
  [738] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_null_literal, 1, 0, 0),
  [740] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_null_literal, 1, 0, 0),
  [742] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_null_literal, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 0),
  [745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_literal, 2, 0, 0),
  [747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_literal, 2, 0, 0),
  [749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 2, 0, 0),
  [751] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_tuple_type, 2, 0, 0), REDUCE(sym_array_literal, 2, 0, 0),
  [754] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 2, 0, 0),
  [756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0),
  [758] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0),
  [760] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2083),
  [763] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_expression, 2, 0, 0),
  [765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_expression, 2, 0, 0),
  [767] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_qualified_type, 2, 0, 0),
  [769] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_qualified_type, 2, 0, 0),
  [771] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_type, 2, 0, 0),
  [773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0),
  [775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(2083),
  [778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0),
  [780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0),
  [782] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2077),
  [785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_await_expression, 2, 0, 0),
  [787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_await_expression, 2, 0, 0),
  [789] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_update_expression, 2, 0, 0),
  [791] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_update_expression, 2, 0, 0),
  [793] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 2, 0, 0),
  [795] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 2, 0, 0),
  [797] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_annotation, 1, 0, 0),
  [799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_annotation, 1, 0, 0),
  [801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1312),
  [803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1287),
  [805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 3, 0, 0),
  [809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_type, 4, 0, 0),
  [813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_union_type, 2, 0, 0),
  [815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union_type, 2, 0, 0),
  [817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0),
  [819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0),
  [821] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1312),
  [824] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_chain_expression, 4, 0, 0),
  [826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_chain_expression, 4, 0, 0),
  [828] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_chain_expression, 6, 0, 0),
  [830] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_chain_expression, 6, 0, 0),
  [832] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 3, 0, 0),
  [834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 3, 0, 0),
  [836] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_generic_type, 2, 0, 0),
  [838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_generic_type, 2, 0, 0),
  [840] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2125),
  [843] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 2, 0, 0),
  [845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 2, 0, 0),
  [847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 3, 0, 0),
  [849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 3, 0, 0),
  [851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_arguments, 4, 0, 0),
  [853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_arguments, 4, 0, 0),
  [855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_chain_expression, 5, 0, 0),
  [857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_chain_expression, 5, 0, 0),
  [859] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(2125),
  [862] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2122),
  [865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_chain_expression, 2, 0, 0),
  [867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_chain_expression, 2, 0, 0),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [871] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_conditional_type, 7, 0, 0),
  [873] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_type, 7, 0, 0),
  [875] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 7, 0, 0),
  [877] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 7, 0, 0),
  [879] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesized_expression, 3, 0, 0),
  [883] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 2, 0, 0),
  [885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 2, 0, 0),
  [887] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_chain_expression, 3, 0, 0),
  [889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_chain_expression, 3, 0, 0),
  [891] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_as_expression, 3, 0, 0),
  [893] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_as_expression, 3, 0, 0),
  [895] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 2, 0, 0),
  [897] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 2, 0, 0),
  [899] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 3, 0, 0),
  [901] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 3, 0, 0),
  [903] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_literal, 4, 0, 0),
  [905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_literal, 4, 0, 0),
  [907] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_block_statement, 2, 0, 0), REDUCE(sym_object_literal, 2, 0, 0),
  [910] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_block_statement, 2, 0, 0), REDUCE(sym_object_literal, 2, 0, 0),
  [913] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_literal, 4, 0, 0),
  [915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_literal, 4, 0, 0),
  [917] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_resource_expression, 4, 0, 0),
  [919] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_resource_expression, 4, 0, 0),
  [921] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 4, 0, 0),
  [923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 4, 0, 0),
  [925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 3, 0, 0),
  [927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 3, 0, 0),
  [929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subscript_expression, 4, 0, 0),
  [931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subscript_expression, 4, 0, 0),
  [933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_type, 3, 0, 0),
  [935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type, 3, 0, 0),
  [937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_literal, 3, 0, 0),
  [939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_literal, 3, 0, 0),
  [941] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_literal, 3, 0, 0),
  [943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_literal, 3, 0, 0),
  [945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_literal, 5, 0, 0),
  [947] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_literal, 5, 0, 0),
  [949] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 5, 0, 0),
  [951] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 5, 0, 0),
  [953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_argument_list, 4, 0, 0),
  [955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_argument_list, 4, 0, 0),
  [957] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_literal, 2, 0, 0),
  [959] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_literal, 2, 0, 0),
  [961] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_literal, 3, 0, 0),
  [963] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_literal, 3, 0, 0),
  [965] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_array_literal, 3, 0, 0),
  [967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_array_literal, 3, 0, 0),
  [969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_new_expression, 6, 0, 0),
  [971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_new_expression, 6, 0, 0),
  [973] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_statement, 3, 0, 0),
  [975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_statement, 3, 0, 0),
  [977] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_literal, 2, 0, 0),
  [979] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_template_literal, 2, 0, 0),
  [981] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_modifier_chain_expression, 7, 0, 0),
  [983] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_modifier_chain_expression, 7, 0, 0),
  [985] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_call_expression, 2, 0, 0),
  [987] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_call_expression, 2, 0, 0),
  [989] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_object_literal, 5, 0, 0),
  [991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_literal, 5, 0, 0),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1396),
  [995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(484),
  [997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2061),
  [1001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(593),
  [1003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1540),
  [1005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1541),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(653),
  [1009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [1011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1093),
  [1013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1094),
  [1015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(710),
  [1017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [1019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(464),
  [1021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(711),
  [1023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1380),
  [1025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(461),
  [1027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [1031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1584),
  [1033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [1035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1544),
  [1037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2135),
  [1039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [1041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(713),
  [1043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [1045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [1047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1115),
  [1049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(679),
  [1051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [1053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [1055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [1057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [1059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [1061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [1063] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2096),
  [1066] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(1169),
  [1069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2097),
  [1072] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2086),
  [1075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(1178),
  [1078] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2093),
  [1081] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2152),
  [1084] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(1160),
  [1087] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2156),
  [1090] = {.entry = {.count = 1, .reusable = false}}, SHIFT(611),
  [1092] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1233),
  [1094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2151),
  [1098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(612),
  [1100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [1102] = {.entry = {.count = 1, .reusable = false}}, SHIFT(614),
  [1104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [1106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(616),
  [1108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(617),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(617),
  [1112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(225),
  [1114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(618),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [1118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [1120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(619),
  [1122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(620),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [1126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [1128] = {.entry = {.count = 1, .reusable = false}}, SHIFT(707),
  [1130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [1132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [1136] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [1138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(101),
  [1140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(102),
  [1142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(477),
  [1144] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1478),
  [1146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1532),
  [1148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [1150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [1152] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [1154] = {.entry = {.count = 1, .reusable = false}}, SHIFT(206),
  [1156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(207),
  [1158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(478),
  [1160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [1162] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2097),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [1167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2061),
  [1169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(489),
  [1171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(972),
  [1173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(973),
  [1175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [1179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [1181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(628),
  [1183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [1185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1577),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [1189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(630),
  [1191] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 0), SHIFT(225),
  [1194] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2053),
  [1197] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(1181),
  [1200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2055),
  [1203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1393),
  [1205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [1207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [1209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [1211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [1213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(473),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [1217] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(2097),
  [1220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2096),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [1229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2141),
  [1231] = {.entry = {.count = 1, .reusable = false}}, SHIFT(241),
  [1233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1589),
  [1235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1590),
  [1237] = {.entry = {.count = 1, .reusable = false}}, SHIFT(623),
  [1239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [1241] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [1243] = {.entry = {.count = 1, .reusable = false}}, SHIFT(738),
  [1245] = {.entry = {.count = 1, .reusable = false}}, SHIFT(678),
  [1247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(678),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(472),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(557),
  [1253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1554),
  [1257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1538),
  [1259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2117),
  [1261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [1263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [1265] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_conditional_expression, 5, 0, 0), SHIFT(225),
  [1268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1335),
  [1270] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1236),
  [1272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1229),
  [1274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(671),
  [1276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [1278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(487),
  [1282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(998),
  [1284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(999),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [1288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1387),
  [1290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [1292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1294] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2086),
  [1297] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1335),
  [1300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [1302] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(2156),
  [1305] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2152),
  [1308] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(1352),
  [1311] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(2141),
  [1314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(2093),
  [1317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(656),
  [1319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1227),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [1325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2129),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [1331] = {.entry = {.count = 1, .reusable = false}}, SHIFT(659),
  [1333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [1335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(662),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [1341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(226),
  [1343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(663),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [1349] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [1351] = {.entry = {.count = 1, .reusable = false}}, SHIFT(665),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [1357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(702),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [1361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1301),
  [1363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1286),
  [1365] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 0), SHIFT(226),
  [1368] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2156),
  [1371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2093),
  [1374] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_conditional_expression, 5, 0, 0), SHIFT(226),
  [1377] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2055),
  [1380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 1, 0, 0),
  [1382] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1301),
  [1385] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(2055),
  [1388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1390] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2053),
  [1393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 3, 0, 0),
  [1395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2030),
  [1397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2189),
  [1399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(449),
  [1401] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [1403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(790),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [1407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1535),
  [1409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2043),
  [1411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2047),
  [1413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2049),
  [1415] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2060),
  [1418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1420] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [1422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1003),
  [1424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [1426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [1428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1692),
  [1430] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [1432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [1434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [1436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [1438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [1440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [1442] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6),
  [1444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [1446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1491),
  [1448] = {.entry = {.count = 1, .reusable = false}}, SHIFT(801),
  [1450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2085),
  [1452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [1454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [1456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_literal_repeat1, 1, 0, 0),
  [1458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [1460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [1462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [1464] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 0),
  [1467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [1469] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(689),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(541),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1386),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(822),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(823),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1484),
  [1491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [1493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [1495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [1501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [1507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(546),
  [1511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [1513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1481),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [1517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [1519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(537),
  [1523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(370),
  [1525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [1527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [1529] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(1172),
  [1532] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(2060),
  [1535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(450),
  [1537] = {.entry = {.count = 1, .reusable = false}}, SHIFT(723),
  [1539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(36),
  [1541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5),
  [1543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(30),
  [1545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2164),
  [1548] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(1172),
  [1551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2060),
  [1554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [1556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [1558] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(2060),
  [1561] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2164),
  [1564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(556),
  [1566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [1568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(562),
  [1570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [1572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(565),
  [1574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(570),
  [1576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [1578] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 0), SHIFT(246),
  [1581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(573),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(573),
  [1585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [1587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(585),
  [1589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(588),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(556),
  [1593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [1595] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1323),
  [1597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1282),
  [1599] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1256),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2098),
  [1605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [1607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [1609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(591),
  [1611] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_conditional_expression, 5, 0, 0), SHIFT(246),
  [1614] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 3, 0, 0),
  [1616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1367),
  [1618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [1620] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1323),
  [1623] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 1, 0, 0),
  [1625] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expression, 1, 0, 0), REDUCE(sym_parameter, 1, 0, 0),
  [1628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [1630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(604),
  [1632] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_expression, 1, 0, 0), SHIFT(1619),
  [1635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2108),
  [1637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_if_statement, 7, 0, 0),
  [1639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_if_statement, 7, 0, 0),
  [1641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2109),
  [1643] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_component, 5, 0, 0),
  [1645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [1647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_component, 5, 0, 0),
  [1649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [1651] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_component, 4, 0, 0),
  [1653] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_component, 4, 0, 0),
  [1655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_if_statement, 6, 0, 0),
  [1657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_if_statement, 6, 0, 0),
  [1659] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2071),
  [1661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [1663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_element_with_modifiers, 1, 0, 0),
  [1665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_element_with_modifiers, 1, 0, 0),
  [1667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(834),
  [1669] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_component, 3, 0, 0),
  [1671] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_component, 3, 0, 0),
  [1673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [1675] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_container_content_body, 2, 0, 0),
  [1677] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_container_content_body, 2, 0, 0),
  [1679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_custom_component_statement, 4, 0, 0),
  [1681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_custom_component_statement, 4, 0, 0),
  [1683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_custom_component_statement, 6, 0, 0),
  [1685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_custom_component_statement, 6, 0, 0),
  [1687] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_if_statement, 9, 0, 0),
  [1689] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_if_statement, 9, 0, 0),
  [1691] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_element_with_modifiers, 2, 0, 0),
  [1693] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_element_with_modifiers, 2, 0, 0),
  [1695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_if_statement, 10, 0, 0),
  [1697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_if_statement, 10, 0, 0),
  [1699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_build_body_repeat1, 1, 0, 0),
  [1701] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_build_body_repeat1, 1, 0, 0),
  [1703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_custom_component_statement, 5, 0, 0),
  [1705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_custom_component_statement, 5, 0, 0),
  [1707] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_if_statement, 11, 0, 0),
  [1709] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_if_statement, 11, 0, 0),
  [1711] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_container_content_body, 3, 0, 0),
  [1713] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_container_content_body, 3, 0, 0),
  [1715] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ui_control_flow, 1, 0, 0),
  [1717] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ui_control_flow, 1, 0, 0),
  [1719] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [1721] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expression_statement, 2, 0, 0),
  [1723] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_ui_if_statement_repeat1, 1, 0, 0),
  [1725] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_ui_if_statement_repeat1, 1, 0, 0),
  [1727] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arkts_ui_element, 1, 0, 0),
  [1729] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arkts_ui_element, 1, 0, 0),
  [1731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_each_statement, 8, 0, 0),
  [1733] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_each_statement, 8, 0, 0),
  [1735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_each_statement, 6, 0, 0),
  [1737] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_each_statement, 6, 0, 0),
  [1739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 2, 0, 0),
  [1741] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 2, 0, 0),
  [1743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1671),
  [1745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1904),
  [1747] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1669),
  [1749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1981),
  [1751] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2178),
  [1754] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(1162),
  [1757] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_primary_type, 1, 0, 0), SHIFT(2184),
  [1760] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 3, 0, 0),
  [1762] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 0),
  [1764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block_statement, 2, 0, 0),
  [1766] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block_statement, 2, 0, 0),
  [1768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 2, 0, 0),
  [1770] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 2, 0, 0),
  [1772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 5, 0, 0),
  [1774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 5, 0, 0),
  [1776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 7, 0, 0),
  [1778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 7, 0, 0),
  [1780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 3, 0, 0),
  [1782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 3, 0, 0),
  [1784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [1786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 0, 0),
  [1788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1326),
  [1790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [1792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 3, 0, 0),
  [1794] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 3, 0, 0),
  [1796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2178),
  [1799] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_return_statement, 2, 0, 0),
  [1801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_return_statement, 2, 0, 0),
  [1803] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 4, 0, 0),
  [1805] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 4, 0, 0),
  [1807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 2, 0, 0),
  [1809] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 2, 0, 0),
  [1811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [1813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 2, 0, 0),
  [1815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throw_statement, 3, 0, 0),
  [1817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throw_statement, 3, 0, 0),
  [1819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_break_statement, 3, 0, 0),
  [1821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_break_statement, 3, 0, 0),
  [1823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_continue_statement, 3, 0, 0),
  [1825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_continue_statement, 3, 0, 0),
  [1827] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_finally_clause, 2, 0, 0),
  [1829] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_finally_clause, 2, 0, 0),
  [1831] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_try_statement, 4, 0, 0),
  [1833] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, 0, 0),
  [1835] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_while_statement, 5, 0, 0),
  [1837] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 0),
  [1839] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 6, 0, 0),
  [1841] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 6, 0, 0),
  [1843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [1845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 7, 0, 0),
  [1847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 0),
  [1849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 7, 0, 0),
  [1851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 0),
  [1853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 8, 0, 0),
  [1855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 0),
  [1857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_for_statement, 9, 0, 0),
  [1859] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 0),
  [1861] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_statement, 5, 0, 0),
  [1863] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 0),
  [1865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(72),
  [1867] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2184),
  [1870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declaration, 2, 0, 0),
  [1872] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_variable_declaration, 2, 0, 0),
  [1874] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [1876] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_array_type, 2, 0, 0), SHIFT(2184),
  [1879] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0), REDUCE(sym_if_statement, 7, 0, 0),
  [1882] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_statement, 1, 0, 0), REDUCE(sym_if_statement, 7, 0, 0),
  [1885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(634),
  [1887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1224),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [1893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [1895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [1897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(637),
  [1899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [1901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(639),
  [1903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [1907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(240),
  [1909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(641),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(642),
  [1915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(642),
  [1917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(643),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [1921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [1923] = {.entry = {.count = 1, .reusable = false}}, SHIFT(680),
  [1925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(681),
  [1927] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1326),
  [1930] = {.entry = {.count = 1, .reusable = false}}, SHIFT(714),
  [1932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [1934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [1936] = {.entry = {.count = 1, .reusable = false}}, SHIFT(692),
  [1938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [1940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(694),
  [1942] = {.entry = {.count = 1, .reusable = false}}, SHIFT(695),
  [1944] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [1946] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [1948] = {.entry = {.count = 1, .reusable = false}}, SHIFT(715),
  [1950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [1952] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [1954] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [1956] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [1958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [1960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [1962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [1964] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 0), SHIFT(245),
  [1967] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_conditional_expression, 5, 0, 0), SHIFT(245),
  [1970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [1972] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_block_statement_repeat1, 1, 0, 0),
  [1974] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_block_statement_repeat1, 1, 0, 0),
  [1976] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_binary_expression, 3, 0, 0), SHIFT(240),
  [1979] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_conditional_expression, 5, 0, 0), SHIFT(240),
  [1982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [1984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [1986] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_tuple_type, 2, 0, 0), REDUCE(sym_array_literal, 2, 0, 0),
  [1989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [1991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [1993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [1995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [1997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1021),
  [1999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [2001] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_boolean_literal, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 0),
  [2004] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_null_literal, 1, 0, 0), REDUCE(sym_primary_type, 1, 0, 0),
  [2007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [2009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [2011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [2015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [2017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [2025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(821),
  [2027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [2031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [2035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(813),
  [2037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [2043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1474),
  [2045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [2047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [2049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [2051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(390),
  [2053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [2055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(360),
  [2057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1494),
  [2059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [2061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [2063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [2069] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 6, 0, 0),
  [2071] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_parameter, 3, 0, 0),
  [2073] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_assignment, 3, 0, 0),
  [2075] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 3, 0, 0),
  [2077] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 7, 0, 0),
  [2079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 3, 0, 0),
  [2081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_member, 3, 0, 0),
  [2083] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_literal_repeat1, 3, 0, 0),
  [2085] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 5, 0, 0),
  [2087] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 5, 0, 0),
  [2089] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0),
  [2091] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_assignment, 2, 0, 0),
  [2093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_spread_element, 2, 0, 0),
  [2095] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_decorator_repeat1, 2, 0, 0),
  [2097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 4, 0, 0),
  [2099] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_decorator_repeat1, 2, 0, 0), REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0),
  [2102] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_array_literal_repeat1, 2, 0, 0),
  [2104] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [2106] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [2108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1456),
  [2110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [2112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1410),
  [2114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1011),
  [2116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1876),
  [2118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1412),
  [2120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2080),
  [2122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [2124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [2126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [2128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1454),
  [2130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [2132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [2134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [2136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [2138] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [2140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [2142] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [2144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1421),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [2148] = {.entry = {.count = 1, .reusable = true}}, SHIFT(873),
  [2150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(696),
  [2152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1427),
  [2156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1429),
  [2158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [2160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1435),
  [2162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [2164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [2168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1441),
  [2170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [2172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [2174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1449),
  [2176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1453),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [2184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1517),
  [2186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1440),
  [2188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [2192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1448),
  [2194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [2196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [2198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [2200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1442),
  [2202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [2204] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_component_parameters, 2, 0, 0), REDUCE(sym_object_literal, 2, 0, 0),
  [2207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [2209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1761),
  [2212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1159),
  [2215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1289),
  [2218] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2189),
  [2221] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2006),
  [2224] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1727),
  [2227] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1630),
  [2230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2128),
  [2233] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2130),
  [2236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2042),
  [2239] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2043),
  [2242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2047),
  [2245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2049),
  [2248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [2250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1929),
  [2252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1935),
  [2254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [2256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [2258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [2260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [2262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1384),
  [2264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [2266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1167),
  [2268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1295),
  [2270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [2272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [2274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [2276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [2278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [2280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1534),
  [2282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [2284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1522),
  [2286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [2288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [2290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1524),
  [2292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [2294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [2296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1587),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [2300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1458),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [2304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [2306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [2308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1561),
  [2310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [2312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1385),
  [2314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1461),
  [2316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1482),
  [2318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [2320] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [2322] = {.entry = {.count = 1, .reusable = false}}, SHIFT(915),
  [2324] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [2326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [2328] = {.entry = {.count = 1, .reusable = false}}, SHIFT(202),
  [2330] = {.entry = {.count = 1, .reusable = false}}, SHIFT(392),
  [2332] = {.entry = {.count = 1, .reusable = false}}, SHIFT(259),
  [2334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [2336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(75),
  [2338] = {.entry = {.count = 1, .reusable = false}}, SHIFT(120),
  [2340] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [2342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [2344] = {.entry = {.count = 1, .reusable = false}}, SHIFT(201),
  [2346] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [2348] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [2350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [2352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(722),
  [2354] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [2356] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1476),
  [2358] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1467),
  [2360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 4, 0, 0),
  [2362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1691),
  [2364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1379),
  [2366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1844),
  [2368] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 7, 0, 0),
  [2370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [2372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1373),
  [2374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 5, 0, 0),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1663),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1369),
  [2380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2015),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [2386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 6, 0, 0),
  [2388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [2390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1374),
  [2392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1313),
  [2394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [2396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1637),
  [2398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1870),
  [2400] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2160),
  [2402] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2187),
  [2404] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1510),
  [2406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2046),
  [2408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 7, 0, 0),
  [2410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 8, 0, 0),
  [2412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1370),
  [2414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(224),
  [2416] = {.entry = {.count = 1, .reusable = false}}, SHIFT(438),
  [2418] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [2420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [2422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1351),
  [2424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_declaration, 3, 0, 0),
  [2426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_declaration, 4, 0, 0),
  [2428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 3, 0, 0),
  [2430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_component_declaration, 3, 0, 0), REDUCE(sym_component_declaration, 4, 0, 0),
  [2433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 3, 0, 0),
  [2435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1355),
  [2437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1592),
  [2439] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1822),
  [2441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2011),
  [2443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1499),
  [2445] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2137),
  [2447] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1910),
  [2449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 3, 0, 0),
  [2451] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_component_declaration, 4, 0, 0), REDUCE(sym_component_declaration, 5, 0, 0),
  [2454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(81),
  [2456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [2458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(131),
  [2460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [2462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_body, 3, 0, 0),
  [2464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_component_body_repeat1, 2, 0, 0),
  [2466] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_component_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1290),
  [2469] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_component_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1637),
  [2472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_component_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1870),
  [2475] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_component_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2160),
  [2478] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_component_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2187),
  [2481] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_component_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1510),
  [2484] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_component_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2046),
  [2487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 5, 0, 0),
  [2489] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 5, 0, 0),
  [2491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 3, 0, 0),
  [2493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_declaration, 5, 0, 0),
  [2495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 3, 0, 0),
  [2497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 5, 0, 0),
  [2499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body, 3, 0, 0),
  [2501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 0),
  [2503] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1290),
  [2506] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1592),
  [2509] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1822),
  [2512] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2011),
  [2515] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1499),
  [2518] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2137),
  [2521] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1910),
  [2524] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 4, 0, 0),
  [2526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1378),
  [2528] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 7, 0, 0),
  [2530] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_declaration, 5, 0, 0),
  [2532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 6, 0, 0),
  [2534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1372),
  [2536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1388),
  [2538] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1569),
  [2540] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1490),
  [2542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [2544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [2546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(356),
  [2548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(260),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1161),
  [2552] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_declaration, 4, 0, 0),
  [2554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 8, 0, 0),
  [2556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 6, 0, 0),
  [2558] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2015),
  [2561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 2, 0, 0),
  [2563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1371),
  [2565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 8, 0, 0),
  [2567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_declaration, 6, 0, 0),
  [2569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 4, 0, 0),
  [2571] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 6, 0, 0),
  [2573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_object_type, 2, 0, 0),
  [2575] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interface_declaration, 4, 0, 0),
  [2577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 9, 0, 0),
  [2579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1376),
  [2581] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1391),
  [2583] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1501),
  [2585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 2, 0, 0),
  [2587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_body, 2, 0, 0),
  [2589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extend_function_body, 3, 0, 0),
  [2591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 4, 0, 0),
  [2593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_declaration, 6, 0, 0),
  [2595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_body, 2, 0, 0),
  [2597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 7, 0, 0),
  [2599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1377),
  [2601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1324),
  [2603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 4, 0, 0),
  [2605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_declaration, 9, 0, 0),
  [2607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_class_declaration, 9, 0, 0),
  [2609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 5, 0, 0),
  [2611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1366),
  [2613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extend_function_body, 4, 0, 0),
  [2615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 1, 0, 0),
  [2617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_declaration, 10, 0, 0),
  [2619] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_import_declaration, 8, 0, 0),
  [2621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1317),
  [2623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [2625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [2627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2174),
  [2629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2062),
  [2631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [2633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2063),
  [2635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [2637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1715),
  [2639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2066),
  [2641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [2643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [2645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [2647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2009),
  [2649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [2651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2010),
  [2653] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2063),
  [2656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [2658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [2660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [2662] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1317),
  [2665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1031),
  [2667] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 9, 0, 0),
  [2669] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 9, 0, 0),
  [2671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [2673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 3, 0, 0),
  [2675] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 3, 0, 0),
  [2677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [2679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [2681] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 3, 0, 0),
  [2683] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 3, 0, 0),
  [2685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [2687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [2689] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_component_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1290),
  [2692] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_component_declaration_repeat1, 2, 0, 0),
  [2694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 5, 0, 0),
  [2696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 5, 0, 0),
  [2698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 5, 0, 0),
  [2700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 5, 0, 0),
  [2702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 2, 0, 0),
  [2704] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 2, 0, 0),
  [2706] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 10, 0, 0),
  [2708] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 10, 0, 0),
  [2710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [2712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 3, 0, 0),
  [2714] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 3, 0, 0),
  [2716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 10, 0, 0),
  [2718] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 10, 0, 0),
  [2720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1618),
  [2722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1824),
  [2724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2016),
  [2726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1507),
  [2728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2138),
  [2730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [2732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constructor_declaration, 4, 0, 0),
  [2734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constructor_declaration, 4, 0, 0),
  [2736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [2738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 4, 0, 0),
  [2740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 4, 0, 0),
  [2742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 4, 0, 0),
  [2744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 4, 0, 0),
  [2746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_build_body, 2, 0, 0),
  [2748] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_build_body, 2, 0, 0),
  [2750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 6, 0, 0),
  [2752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 6, 0, 0),
  [2754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 6, 0, 0),
  [2756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 6, 0, 0),
  [2758] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1641),
  [2760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1700),
  [2762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2114),
  [2764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1497),
  [2766] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2146),
  [2768] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_body_repeat1, 1, 0, 0),
  [2770] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_class_body_repeat1, 1, 0, 0),
  [2772] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 7, 0, 0),
  [2774] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 7, 0, 0),
  [2776] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_build_body, 3, 0, 0),
  [2778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_build_body, 3, 0, 0),
  [2780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_build_method, 6, 0, 0),
  [2782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_build_method, 6, 0, 0),
  [2784] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 7, 0, 0),
  [2786] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 7, 0, 0),
  [2788] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 9, 0, 0),
  [2790] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 9, 0, 0),
  [2792] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_declaration, 8, 0, 0),
  [2794] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_declaration, 8, 0, 0),
  [2796] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_build_method, 4, 0, 0),
  [2798] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_build_method, 4, 0, 0),
  [2800] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_method_declaration, 8, 0, 0),
  [2802] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_method_declaration, 8, 0, 0),
  [2804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [2806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [2808] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_component_body_repeat1, 1, 0, 0),
  [2810] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_component_body_repeat1, 1, 0, 0),
  [2812] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_component_declaration_repeat1, 2, 0, 0),
  [2814] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_component_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1289),
  [2817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2112),
  [2819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2115),
  [2821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [2823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2144),
  [2825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2094),
  [2827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2181),
  [2829] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2062),
  [2832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator, 2, 0, 0),
  [2834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [2836] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorator, 2, 0, 0),
  [2838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_component_declaration_repeat1, 1, 0, 0),
  [2840] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_component_declaration_repeat1, 1, 0, 0),
  [2842] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_qualified_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2009),
  [2845] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator, 5, 0, 0),
  [2847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorator, 5, 0, 0),
  [2849] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2174),
  [2852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [2854] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator, 6, 0, 0),
  [2856] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorator, 6, 0, 0),
  [2858] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decorator, 4, 0, 0),
  [2860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decorator, 4, 0, 0),
  [2862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1309),
  [2864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1843),
  [2866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [2868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1603),
  [2870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 2, 0, 0),
  [2872] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 4, 0, 0),
  [2874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1349),
  [2876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [2878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1402),
  [2880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [2882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [2884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1411),
  [2886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1240),
  [2888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [2890] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implements_clause, 2, 0, 0),
  [2892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1823),
  [2894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [2896] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2010),
  [2899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [2901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [2903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1446),
  [2905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [2907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [2909] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter_list, 3, 0, 0),
  [2911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1220),
  [2913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1439),
  [2915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1212),
  [2917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [2919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [2921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [2923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1247),
  [2925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [2927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1332),
  [2929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [2931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [2933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [2935] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1901),
  [2937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1575),
  [2939] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_implements_clause_repeat1, 2, 0, 0),
  [2941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [2943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2157),
  [2945] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1332),
  [2948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_union_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1349),
  [2951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1931),
  [2953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2181),
  [2955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1254),
  [2957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2107),
  [2959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2089),
  [2961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2022),
  [2963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [2965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1832),
  [2967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(143),
  [2969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1736),
  [2971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1623),
  [2973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1040),
  [2975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1753),
  [2977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1648),
  [2979] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat2, 2, 0, 0),
  [2981] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat2, 2, 0, 0), SHIFT_REPEAT(1753),
  [2984] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat2, 2, 0, 0), SHIFT_REPEAT(1648),
  [2987] = {.entry = {.count = 1, .reusable = false}}, SHIFT(990),
  [2989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [2991] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_member, 3, 0, 0),
  [2993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [2995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(809),
  [2997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1017),
  [2999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(355),
  [3001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1022),
  [3003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [3005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1931),
  [3007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(162),
  [3009] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_template_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(2022),
  [3012] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_template_literal_repeat1, 2, 0, 0),
  [3014] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_template_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1832),
  [3017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1977),
  [3019] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_member, 2, 0, 0),
  [3021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1237),
  [3023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1926),
  [3025] = {.entry = {.count = 1, .reusable = false}}, SHIFT(755),
  [3027] = {.entry = {.count = 1, .reusable = false}}, SHIFT(416),
  [3029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1988),
  [3031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(351),
  [3033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [3035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [3037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [3039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [3041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1902),
  [3043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1972),
  [3045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(378),
  [3047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(387),
  [3049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(406),
  [3051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(389),
  [3053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1961),
  [3055] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameter, 2, 0, 0),
  [3057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1225),
  [3059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(677),
  [3061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [3063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [3065] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0),
  [3067] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1736),
  [3070] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1623),
  [3073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1912),
  [3075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [3077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [3079] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extend_function_body_repeat1, 2, 0, 0),
  [3081] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_extend_function_body_repeat1, 2, 0, 0), SHIFT_REPEAT(2141),
  [3084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1302),
  [3086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_type_repeat1, 2, 0, 0),
  [3088] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1526),
  [3091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [3093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1430),
  [3095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [3097] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 3, 0, 0),
  [3099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1451),
  [3101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [3103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implements_clause, 1, 0, 0),
  [3105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1502),
  [3107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [3109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1444),
  [3111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [3113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_member, 4, 0, 0),
  [3115] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variable_declarator, 1, 0, 0),
  [3117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1207),
  [3119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [3121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1572),
  [3123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2031),
  [3125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1350),
  [3127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1711),
  [3129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1893),
  [3131] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_type_repeat1, 1, 0, 0),
  [3133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(563),
  [3135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [3137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1405),
  [3139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1234),
  [3141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1829),
  [3143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2024),
  [3145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1511),
  [3147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2139),
  [3149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1319),
  [3151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1526),
  [3153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1214),
  [3155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1799),
  [3157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [3159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(563),
  [3161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 4, 0, 0),
  [3163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [3165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [3167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1399),
  [3169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1243),
  [3171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1345),
  [3173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1608),
  [3175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2026),
  [3177] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 1, 0, 0),
  [3179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [3181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [3183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameters, 2, 0, 0),
  [3185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1422),
  [3187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [3189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1428),
  [3191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [3193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1766),
  [3195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2069),
  [3197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1506),
  [3199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2084),
  [3201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1235),
  [3203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1455),
  [3205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [3207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1409),
  [3209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [3211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1431),
  [3213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1250),
  [3215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1742),
  [3217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1364),
  [3219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1438),
  [3221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [3223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2072),
  [3225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1291),
  [3227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2148),
  [3229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_member, 5, 0, 0),
  [3231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [3233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1445),
  [3235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [3237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1891),
  [3239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [3241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [3243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [3245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [3247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [3249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1536),
  [3251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [3253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [3255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1223),
  [3258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2, 0, 0),
  [3260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [3262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2163),
  [3264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [3266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2145),
  [3268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [3270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [3272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(555),
  [3274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1934),
  [3276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1334),
  [3278] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_object_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(1463),
  [3281] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_object_literal_repeat1, 2, 0, 0),
  [3283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2111),
  [3285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2133),
  [3287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1397),
  [3289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1294),
  [3291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1425),
  [3293] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1755),
  [3296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameter_list_repeat1, 2, 0, 0),
  [3298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(2035),
  [3301] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_import_declaration_repeat1, 2, 0, 0),
  [3303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [3305] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 3, 0, 0),
  [3307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1266),
  [3309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_export_declaration_repeat1, 2, 0, 0),
  [3311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2180),
  [3313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [3315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [3317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [3319] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(1939),
  [3322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_type_parameters_repeat1, 2, 0, 0),
  [3324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1296),
  [3326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [3328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1447),
  [3330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [3332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1505),
  [3334] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_export_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(2072),
  [3337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1450),
  [3339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [3341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1398),
  [3343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [3345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1530),
  [3347] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_member, 1, 0, 0),
  [3349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [3351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1426),
  [3353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [3355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [3357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1321),
  [3359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [3361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [3363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(395),
  [3365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1533),
  [3367] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [3369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2092),
  [3371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [3373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [3375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(401),
  [3377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(431),
  [3379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(898),
  [3381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(865),
  [3383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1420),
  [3385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1755),
  [3387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1508),
  [3389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [3391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1400),
  [3393] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [3395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [3397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1401),
  [3399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [3401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat1, 1, 0, 0),
  [3403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [3405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1527),
  [3407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1465),
  [3409] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_decorator_repeat1, 2, 0, 0), SHIFT_REPEAT(668),
  [3412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_escape_sequence, 2, 0, 0),
  [3414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [3416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [3418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1518),
  [3420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1462),
  [3422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [3424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [3426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [3428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [3430] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_literal_repeat2, 1, 0, 0),
  [3432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1404),
  [3434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [3436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1492),
  [3438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1635),
  [3440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1636),
  [3442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [3444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [3446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1407),
  [3448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1906),
  [3450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [3452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2127),
  [3454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [3456] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2134),
  [3458] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1514),
  [3460] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2021),
  [3462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [3464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [3466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [3468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [3470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [3472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [3474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [3476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [3478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1343),
  [3480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [3482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [3484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1939),
  [3486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1601),
  [3488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [3490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1563),
  [3492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [3494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [3496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [3498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [3500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1555),
  [3502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [3504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1574),
  [3506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [3508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1318),
  [3510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [3512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [3514] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1927),
  [3517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2, 0, 0),
  [3519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [3521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [3523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [3525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [3527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [3529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [3531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [3533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [3535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [3537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(366),
  [3539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [3541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_implements_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(1823),
  [3544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [3546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [3548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [3550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [3552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1415),
  [3554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [3556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1305),
  [3558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1986),
  [3560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1523),
  [3562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_implements_clause, 3, 0, 0),
  [3564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1968),
  [3566] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_component_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(1896),
  [3569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_component_parameters_repeat1, 2, 0, 0),
  [3571] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2036),
  [3573] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1512),
  [3575] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2142),
  [3577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [3579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_template_literal_repeat1, 1, 0, 0),
  [3581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1627),
  [3583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2035),
  [3585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2179),
  [3587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [3589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [3591] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0), SHIFT_REPEAT(1934),
  [3594] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variable_declaration_repeat1, 2, 0, 0),
  [3596] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_array_literal_repeat1, 2, 0, 0), SHIFT_REPEAT(484),
  [3599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [3601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [3603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [3605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [3607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1413),
  [3609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [3611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1962),
  [3613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [3615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(766),
  [3617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [3619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [3621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [3623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1942),
  [3625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1418),
  [3627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [3629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1828),
  [3631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [3633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [3635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_template_substitution, 4, 0, 0),
  [3637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [3639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2045),
  [3641] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_argument_list_repeat1, 2, 0, 0), SHIFT_REPEAT(498),
  [3644] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_type_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1231),
  [3647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1477),
  [3649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [3651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1520),
  [3653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1585),
  [3655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1276),
  [3657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [3659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [3661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [3663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(531),
  [3665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [3667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [3669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [3671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [3673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [3675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [3677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [3679] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2149),
  [3681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1879),
  [3683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(624),
  [3685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [3687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [3689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [3691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [3693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1267),
  [3695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [3697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [3699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1292),
  [3701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [3703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [3705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [3707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1787),
  [3709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2153),
  [3711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [3713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [3715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [3717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(520),
  [3719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [3721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [3723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [3725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2051),
  [3727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1980),
  [3729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1279),
  [3731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_extend_function_body_repeat1, 1, 0, 0),
  [3733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [3735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(554),
  [3737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [3739] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_export_declaration_repeat1, 4, 0, 0),
  [3741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1258),
  [3743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [3745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1259),
  [3747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(543),
  [3749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1611),
  [3751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [3753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [3755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1946),
  [3757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1198),
  [3759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(688),
  [3761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1239),
  [3763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [3765] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_parameter, 5, 0, 0),
  [3767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [3769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [3771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [3773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1241),
  [3775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [3777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [3779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [3781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [3783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [3785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2056),
  [3787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(871),
  [3789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [3791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(526),
  [3793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [3795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [3797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [3799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1496),
  [3801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1525),
  [3803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [3805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [3807] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_parameters, 4, 0, 0),
  [3809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1188),
  [3811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1375),
  [3813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1662),
  [3815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [3817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [3819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1622),
  [3821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [3823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1509),
  [3825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1668),
  [3827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1964),
  [3829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [3831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(559),
  [3833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [3835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(553),
  [3837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [3839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1892),
  [3841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1674),
  [3843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [3845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [3847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [3849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(561),
  [3851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [3853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1963),
  [3855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [3857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1675),
  [3859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1631),
  [3861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1503),
  [3863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1342),
  [3865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1616),
  [3867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [3869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(597),
  [3871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [3873] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [3875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [3877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [3879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1604),
  [3881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1898),
  [3883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [3885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [3887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1471),
  [3889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1406),
  [3891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [3893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [3895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [3897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [3899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [3901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [3903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1690),
  [3905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [3907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [3909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [3911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [3913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [3915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [3917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [3919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [3921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [3923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1588),
  [3925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [3927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1280),
  [3929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2154),
  [3931] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2126),
  [3933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [3935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [3937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_parameters, 3, 0, 0),
  [3939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [3941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1486),
  [3943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1205),
  [3945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [3947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [3949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [3951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [3953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [3955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1632),
  [3957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [3959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [3961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1320),
  [3963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1218),
  [3965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(796),
  [3967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2191),
  [3969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(819),
  [3971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [3973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [3975] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_component_parameters, 2, 0, 0),
  [3977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2113),
  [3979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1625),
  [3981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1749),
  [3983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [3985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [3987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [3989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [3991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [3993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [3995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [3997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [3999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2190),
  [4001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [4003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1654),
  [4005] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [4007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1846),
  [4009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [4011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1925),
  [4013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [4015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [4017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [4019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1593),
  [4021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1656),
  [4023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1624),
  [4025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1246),
  [4027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [4029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [4031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2101),
  [4033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [4035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1948),
  [4037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1609),
  [4039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [4041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1696),
  [4043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [4045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [4047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [4049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2018),
  [4051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1199),
  [4053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [4055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [4057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [4059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [4061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1705),
  [4063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [4065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1970),
  [4067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(774),
  [4069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [4071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1260),
  [4073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [4075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1264),
  [4077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [4079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [4081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [4083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [4085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1278),
  [4087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1485),
  [4089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [4091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1797),
  [4093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [4095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [4097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [4099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [4101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1600),
  [4103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [4105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [4107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [4109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [4111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [4113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [4115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1596),
  [4117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment, 3, 0, 0),
  [4119] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comment, 2, 0, 0),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_arkts(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
    .name = "arkts",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 0,
      .minor_version = 1,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
